# TnmEther.tcl --
#
#	This file contains a simple database of ethernet codes used
#	by various vendors. The main purpose of this module is to
#	map ethernet addresses to vendor names.
#
#	This list is taken from the ethernet code list available 
#	from ftp://ftp.cavebear.com/pub/Ethernet-codes. It was last
#	updated in September 1996.
#
# Copyright (c) 1997-1998 Technical University Braunschweig.
#
# See the file "license.terms" for information on usage and redistribution
# of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#
# @(#) $Id: TnmEther.tcl 14 2008-03-29 13:13:01Z thomas $

package require Tnm 3.0
package provide TnmEther 3.0.0

namespace eval TnmEther {
    namespace export GetVendor GetEthers
}

# TnmEther::GetVendor --
#
#	Get the vendor for a given IEEE 802 ethernet address.
#
# Arguments:
#	The ethernet address must be in the format aa:bb:cc:dd:ee:ff.
# Results:
#	The name of the vendor or an empty string if there is
#	no known vendor for the given ethernet address.

proc TnmEther::GetVendor {ether} {
    set l [string toupper [join [lrange [split $ether :] 0 2] {}]]
    if {[info exists TnmEther::vendor($l)]} {
	return $TnmEther::vendor($l)
    }
    return
}

# TnmEther::GetEthers --
#
#	Get the ethernet address prefixes for all vendors that 
#	match a given pattern.
#
# Arguments:
#	The regular expression pattern used to match the vendor names.
# Results:
#	A list of ethernet address prefixes in the format aa:bb:cc.

proc TnmEther::GetEthers {pattern} {
    set result {}
    foreach ether [array names TnmEther::vendor] {
	if {[regexp -nocase -- $pattern $TnmEther::vendor($ether)]} {
	    lappend result $ether
	}
    }
    return $result
}

namespace eval TnmEther {
    variable vendor

set vendor(000000) {XEROX CORPORATION}
set vendor(000001) {XEROX CORPORATION}
set vendor(000010) {SYTEK INC.}
set vendor(000011) {NORMEREL SYSTEMES}
set vendor(000012) {INFORMATION TECHNOLOGY LIMITED}
set vendor(000013) {CAMEX}
set vendor(000014) {NETRONIX}
set vendor(000015) {DATAPOINT CORPORATION}
set vendor(000016) {DU PONT PIXEL SYSTEMS     .}
set vendor(000017) {TEKELEC}
set vendor(000018) {WEBSTER COMPUTER CORPORATION}
set vendor(000019) {APPLIED DYNAMICS INTERNATIONAL}
set vendor(00001a) {ADVANCED MICRO DEVICES}
set vendor(00001b) {NOVELL INC.}
set vendor(00001c) {BELL TECHNOLOGIES}
set vendor(00001d) {CABLETRON SYSTEMS, INC.}
set vendor(00001e) {TELSIST INDUSTRIA ELECTRONICA}
set vendor(00001f) {Telco Systems, Inc.}
set vendor(000002) {XEROX CORPORATION}
set vendor(000020) {DATAINDUSTRIER DIAB AB}
set vendor(000021) {SUREMAN COMP. & COMMUN. CORP.}
set vendor(000022) {VISUAL TECHNOLOGY INC.}
set vendor(000023) {ABB INDUSTRIAL SYSTEMS AB}
set vendor(000024) {CONNECT AS}
set vendor(000025) {RAMTEK CORP.}
set vendor(000026) {SHA-KEN CO., LTD.}
set vendor(000027) {JAPAN RADIO COMPANY}
set vendor(000028) {PRODIGY SYSTEMS CORPORATION}
set vendor(000029) {IMC NETWORKS CORP.}
set vendor(00002a) {TRW - SEDD/INP}
set vendor(00002b) {CRISP AUTOMATION, INC}
set vendor(00002c) {AUTOTOTE LIMITED}
set vendor(00002d) {CHROMATICS INC}
set vendor(00002e) {SOCIETE EVIRA}
set vendor(00002f) {TIMEPLEX INC.}
set vendor(000003) {XEROX CORPORATION}
set vendor(000030) {VG LABORATORY SYSTEMS LTD}
set vendor(000031) {QPSX COMMUNICATIONS PTY LTD}
set vendor(000032) {Marconi plc}
set vendor(000033) {EGAN MACHINERY COMPANY}
set vendor(000034) {NETWORK RESOURCES CORPORATION}
set vendor(000035) {SPECTRAGRAPHICS CORPORATION}
set vendor(000036) {ATARI CORPORATION}
set vendor(000037) {OXFORD METRICS LIMITED}
set vendor(000038) {CSS LABS}
set vendor(000039) {TOSHIBA CORPORATION}
set vendor(00003a) {CHYRON CORPORATION}
set vendor(00003b) {i Controls, Inc.}
set vendor(00003c) {AUSPEX SYSTEMS INC.}
set vendor(00003d) {UNISYS}
set vendor(00003e) {SIMPACT}
set vendor(00003f) {SYNTREX, INC.}
set vendor(000004) {XEROX CORPORATION}
set vendor(000040) {APPLICON, INC.}
set vendor(000041) {ICE CORPORATION}
set vendor(000042) {METIER MANAGEMENT SYSTEMS LTD.}
set vendor(000043) {MICRO TECHNOLOGY}
set vendor(000044) {CASTELLE CORPORATION}
set vendor(000045) {FORD AEROSPACE & COMM. CORP.}
set vendor(000046) {OLIVETTI NORTH AMERICA}
set vendor(000047) {NICOLET INSTRUMENTS CORP.}
set vendor(000048) {SEIKO EPSON CORPORATION}
set vendor(000049) {APRICOT COMPUTERS, LTD}
set vendor(00004a) {ADC CODENOLL TECHNOLOGY CORP.}
set vendor(00004b) {ICL DATA OY}
set vendor(00004c) {NEC CORPORATION}
set vendor(00004d) {DCI CORPORATION}
set vendor(00004e) {AMPEX CORPORATION}
set vendor(00004f) {LOGICRAFT, INC.}
set vendor(000005) {XEROX CORPORATION}
set vendor(000050) {RADISYS CORPORATION}
set vendor(000051) {HOB ELECTRONIC GMBH & CO. KG}
set vendor(000052) {Intrusion.com, Inc.}
set vendor(000053) {COMPUCORP}
set vendor(000054) {MODICON, INC.}
set vendor(000055) {COMMISSARIAT A L`ENERGIE ATOM.}
set vendor(000056) {DR. B. STRUCK}
set vendor(000057) {SCITEX CORPORATION LTD.}
set vendor(000058) {RACORE COMPUTER PRODUCTS INC.}
set vendor(000059) {HELLIGE GMBH}
set vendor(00005a) {SysKonnect GmbH}
set vendor(00005b) {ELTEC ELEKTRONIK AG}
set vendor(00005c) {TELEMATICS INTERNATIONAL INC.}
set vendor(00005d) {CS TELECOM}
set vendor(00005e) {USC INFORMATION SCIENCES INST}
set vendor(00005f) {SUMITOMO ELECTRIC IND., LTD.}
set vendor(000006) {XEROX CORPORATION}
set vendor(000060) {KONTRON ELEKTRONIK GMBH}
set vendor(000061) {GATEWAY COMMUNICATIONS}
set vendor(000062) {BULL HN INFORMATION SYSTEMS}
set vendor(000063) {DR.ING.SEUFERT GMBH}
set vendor(000064) {YOKOGAWA DIGITAL COMPUTER CORP}
set vendor(000065) {NETWORK ASSOCIATES, INC.}
set vendor(000066) {TALARIS SYSTEMS, INC.}
set vendor(000067) {SOFT * RITE, INC.}
set vendor(000068) {ROSEMOUNT CONTROLS}
set vendor(000069) {CONCORD COMMUNICATIONS INC}
set vendor(00006a) {COMPUTER CONSOLES INC.}
set vendor(00006b) {SILICON GRAPHICS INC./MIPS}
set vendor(00006d) {CRAY COMMUNICATIONS, LTD.}
set vendor(00006e) {ARTISOFT, INC.}
set vendor(00006f) {Madge Ltd.}
set vendor(000007) {XEROX CORPORATION}
set vendor(000070) {HCL LIMITED}
set vendor(000071) {ADRA SYSTEMS INC.}
set vendor(000072) {MINIWARE TECHNOLOGY}
set vendor(000073) {SIECOR CORPORATION}
set vendor(000074) {RICOH COMPANY LTD.}
set vendor(000075) {Nortel Networks}
set vendor(000076) {ABEKAS VIDEO SYSTEM}
set vendor(000077) {INTERPHASE CORPORATION}
set vendor(000078) {LABTAM LIMITED}
set vendor(000079) {NETWORTH INCORPORATED}
set vendor(00007a) {DANA COMPUTER INC.}
set vendor(00007b) {RESEARCH MACHINES}
set vendor(00007c) {AMPERE INCORPORATED}
set vendor(00007d) {SUN MICROSYSTEMS, INC.}
set vendor(00007e) {CLUSTRIX CORPORATION}
set vendor(00007f) {LINOTYPE-HELL AG}
set vendor(000008) {XEROX CORPORATION}
set vendor(000080) {CRAY COMMUNICATIONS A/S}
set vendor(000081) {BAY NETWORKS}
set vendor(000082) {LECTRA SYSTEMES SA}
set vendor(000083) {TADPOLE TECHNOLOGY PLC}
set vendor(000084) {SUPERNET}
set vendor(000085) {CANON INC.}
set vendor(000086) {MEGAHERTZ CORPORATION}
set vendor(000087) {HITACHI, LTD.}
set vendor(000088) {COMPUTER NETWORK TECH. CORP.}
set vendor(000089) {CAYMAN SYSTEMS INC.}
set vendor(00008a) {DATAHOUSE INFORMATION SYSTEMS}
set vendor(00008b) {INFOTRON}
set vendor(00008c) {Alloy Computer Products (Australia) Pty Ltd}
set vendor(00008d) {VERDIX CORPORATION}
set vendor(00008e) {SOLBOURNE COMPUTER, INC.}
set vendor(00008f) {RAYTHEON COMPANY}
set vendor(000009) {XEROX CORPORATION}
set vendor(000090) {MICROCOM}
set vendor(000091) {ANRITSU CORPORATION}
set vendor(000092) {COGENT DATA TECHNOLOGIES}
set vendor(000093) {PROTEON INC.}
set vendor(000094) {ASANTE TECHNOLOGIES}
set vendor(000095) {SONY TEKTRONIX CORP.}
set vendor(000096) {MARCONI ELECTRONICS LTD.}
set vendor(000097) {EPOCH SYSTEMS}
set vendor(000098) {CROSSCOMM CORPORATION}
set vendor(000099) {MTX, INC.}
set vendor(00009a) {RC COMPUTER A/S}
set vendor(00009b) {INFORMATION INTERNATIONAL, INC}
set vendor(00009c) {ROLM MIL-SPEC COMPUTERS}
set vendor(00009d) {LOCUS COMPUTING CORPORATION}
set vendor(00009e) {MARLI S.A.}
set vendor(00009f) {AMERISTAR TECHNOLOGIES INC.}
set vendor(00000a) {OMRON TATEISI ELECTRONICS CO.}
set vendor(0000a0) {TOKYO SANYO ELECTRIC CO. LTD.}
set vendor(0000a1) {MARQUETTE ELECTRIC CO.}
set vendor(0000a2) {BAY NETWORKS}
set vendor(0000a3) {NETWORK APPLICATION TECHNOLOGY}
set vendor(0000a4) {ACORN COMPUTERS LIMITED}
set vendor(0000a5) {COMPATIBLE SYSTEMS CORP.}
set vendor(0000a6) {NETWORK GENERAL CORPORATION}
set vendor(0000a7) {NETWORK COMPUTING DEVICES INC.}
set vendor(0000a8) {STRATUS COMPUTER INC.}
set vendor(0000a9) {NETWORK SYSTEMS CORP.}
set vendor(0000aa) {XEROX CORPORATION}
set vendor(0000ab) {LOGIC MODELING CORPORATION}
set vendor(0000ac) {CONWARE COMPUTER CONSULTING}
set vendor(0000ad) {BRUKER INSTRUMENTS INC.}
set vendor(0000ae) {DASSAULT ELECTRONIQUE}
set vendor(0000af) {NUCLEAR DATA INSTRUMENTATION}
set vendor(00000b) {MATRIX CORPORATION}
set vendor(0000b0) {RND-RAD NETWORK DEVICES}
set vendor(0000b1) {ALPHA MICROSYSTEMS INC.}
set vendor(0000b2) {TELEVIDEO SYSTEMS, INC.}
set vendor(0000b3) {CIMLINC INCORPORATED}
set vendor(0000b4) {EDIMAX COMPUTER COMPANY}
set vendor(0000b5) {DATABILITY SOFTWARE SYS. INC.}
set vendor(0000b6) {MICRO-MATIC RESEARCH}
set vendor(0000b7) {DOVE COMPUTER CORPORATION}
set vendor(0000b8) {SEIKOSHA CO., LTD.}
set vendor(0000b9) {MCDONNELL DOUGLAS COMPUTER SYS}
set vendor(0000ba) {SIIG, INC.}
set vendor(0000bb) {TRI-DATA}
set vendor(0000bc) {ALLEN-BRADLEY CO. INC.}
set vendor(0000bd) {MITSUBISHI CABLE COMPANY}
set vendor(0000be) {THE NTI GROUP}
set vendor(0000bf) {SYMMETRIC COMPUTER SYSTEMS}
set vendor(00000c) {CISCO SYSTEMS, INC.}
set vendor(0000c0) {WESTERN DIGITAL CORPORATION}
set vendor(0000c1) {Madge Ltd.}
set vendor(0000c2) {INFORMATION PRESENTATION TECH.}
set vendor(0000c3) {HARRIS CORP COMPUTER SYS DIV}
set vendor(0000c4) {WATERS DIV. OF MILLIPORE}
set vendor(0000c5) {FARALLON COMPUTING/NETOPIA}
set vendor(0000c6) {EON SYSTEMS}
set vendor(0000c7) {ARIX CORPORATION}
set vendor(0000c8) {ALTOS COMPUTER SYSTEMS}
set vendor(0000c9) {EMULEX CORPORATION}
set vendor(0000ca) {APPLITEK}
set vendor(0000cb) {COMPU-SHACK ELECTRONIC GMBH}
set vendor(0000cc) {DENSAN CO., LTD.}
set vendor(0000cd) {Allied Telesyn Research Ltd.}
set vendor(0000ce) {MEGADATA CORP.}
set vendor(0000cf) {HAYES MICROCOMPUTER PRODUCTS}
set vendor(00000d) {FIBRONICS LTD.}
set vendor(0000d0) {DEVELCON ELECTRONICS LTD.}
set vendor(0000d1) {ADAPTEC INCORPORATED}
set vendor(0000d2) {SBE, INC.}
set vendor(0000d3) {WANG LABORATORIES INC.}
set vendor(0000d4) {PURE DATA LTD.}
set vendor(0000d5) {MICROGNOSIS INTERNATIONAL}
set vendor(0000d6) {PUNCH LINE HOLDING}
set vendor(0000d7) {DARTMOUTH COLLEGE}
set vendor(0000d8) {NOVELL, INC.}
set vendor(0000d9) {NIPPON TELEGRAPH & TELEPHONE}
set vendor(0000da) {ATEX}
set vendor(0000db) {BRITISH TELECOMMUNICATIONS PLC}
set vendor(0000dc) {HAYES MICROCOMPUTER PRODUCTS}
set vendor(0000dd) {TCL INCORPORATED}
set vendor(0000de) {CETIA}
set vendor(0000df) {BELL & HOWELL PUB SYS DIV}
set vendor(00000e) {FUJITSU LIMITED}
set vendor(0000e0) {QUADRAM CORP.}
set vendor(0000e1) {GRID SYSTEMS}
set vendor(0000e2) {ACER TECHNOLOGIES CORP.}
set vendor(0000e3) {INTEGRATED MICRO PRODUCTS LTD}
set vendor(0000e4) {IN2 GROUPE INTERTECHNIQUE}
set vendor(0000e5) {SIGMEX LTD.}
set vendor(0000e6) {APTOR PRODUITS DE COMM INDUST}
set vendor(0000e7) {STAR GATE TECHNOLOGIES}
set vendor(0000e8) {ACCTON TECHNOLOGY CORP.}
set vendor(0000e9) {ISICAD, INC.}
set vendor(0000ea) {UPNOD AB}
set vendor(0000eb) {MATSUSHITA COMM. IND. CO. LTD.}
set vendor(0000ec) {MICROPROCESS}
set vendor(0000ed) {APRIL}
set vendor(0000ee) {NETWORK DESIGNERS, LTD.}
set vendor(0000ef) {KTI}
set vendor(00000f) {NEXT, INC.}
set vendor(0000f0) {SAMSUNG ELECTRONICS CO., LTD.}
set vendor(0000f1) {MAGNA COMPUTER CORPORATION}
set vendor(0000f2) {SPIDER COMMUNICATIONS}
set vendor(0000f3) {GANDALF DATA LIMITED}
set vendor(0000f4) {ALLIED TELESYN INTERNATIONAL}
set vendor(0000f5) {DIAMOND SALES LIMITED}
set vendor(0000f6) {APPLIED MICROSYSTEMS CORP.}
set vendor(0000f7) {YOUTH KEEP ENTERPRISE CO LTD}
set vendor(0000f8) {DIGITAL EQUIPMENT CORPORATION}
set vendor(0000f9) {QUOTRON SYSTEMS INC.}
set vendor(0000fa) {MICROSAGE COMPUTER SYSTEMS INC}
set vendor(0000fb) {RECHNER ZUR KOMMUNIKATION}
set vendor(0000fc) {MEIKO}
set vendor(0000fd) {HIGH LEVEL HARDWARE}
set vendor(0000fe) {ANNAPOLIS MICRO SYSTEMS}
set vendor(0000ff) {CAMTEC ELECTRONICS LTD.}
set vendor(001000) {CABLE TELEVISION LABORATORIES, INC.}
set vendor(001001) {MCK COMMUNICATIONS}
set vendor(001010) {INITIO CORPORATION}
set vendor(001011) {CISCO SYSTEMS, INC.}
set vendor(001012) {PROCESSOR SYSTEMS (I) PVT LTD}
set vendor(001013) {INDUSTRIAL COMPUTER SOURCE}
set vendor(001014) {CISCO SYSTEMS, INC.}
set vendor(001015) {OOmon Inc.}
set vendor(001016) {T.SQWARE}
set vendor(001017) {MICOS GmbH}
set vendor(001018) {BROADCOM CORPORATION}
set vendor(001019) {SIRONA DENTAL SYSTEMS GmbH & Co. KG}
set vendor(00101a) {PictureTel Corp.}
set vendor(00101b) {CORNET TECHNOLOGY, INC.}
set vendor(00101c) {OHM TECHNOLOGIES INTL, LLC}
set vendor(00101d) {WINBOND ELECTRONICS CORP.}
set vendor(00101e) {MATSUSHITA ELECTRONIC INSTRUMENTS CORP.}
set vendor(00101f) {CISCO SYSTEMS, INC.}
set vendor(001002) {ACTIA}
set vendor(001020) {WELCH ALLYN, DATA COLLECTION}
set vendor(001021) {ENCANTO NETWORKS, INC.}
set vendor(001022) {SatCom Media Corporation}
set vendor(001023) {FLOWWISE NETWORKS, INC.}
set vendor(001024) {NAGOYA ELECTRIC WORKS CO., LTD}
set vendor(001025) {GRAYHILL INC.}
set vendor(001026) {ACCELERATED NETWORKS, INC.}
set vendor(001027) {L-3 COMMUNICATIONS EAST}
set vendor(001028) {COMPUTER TECHNICA, INC.}
set vendor(001029) {CISCO SYSTEMS, INC.}
set vendor(00102a) {ZF MICROSYSTEMS, INC.}
set vendor(00102b) {UMAX DATA SYSTEMS, INC.}
set vendor(00102c) {Lasat Networks A/S}
set vendor(00102d) {HITACHI SOFTWARE ENGINEERING}
set vendor(00102e) {NETWORK SYSTEMS & TECHNOLOGIES PVT. LTD.}
set vendor(00102f) {CISCO SYSTEMS, INC.}
set vendor(001003) {IMATRON, INC.}
set vendor(001030) {Wi-LAN, Inc.}
set vendor(001031) {OBJECTIVE COMMUNICATIONS, INC.}
set vendor(001032) {ALTA TECHNOLOGY}
set vendor(001033) {ACCESSLAN COMMUNICATIONS, INC.}
set vendor(001034) {GNP Computers}
set vendor(001035) {ELITEGROUP COMPUTER SYSTEMS CO., LTD}
set vendor(001036) {INTER-TEL INTEGRATED SYSTEMS}
set vendor(001037) {CYQ've Technology Co., Ltd.}
set vendor(001038) {MICRO RESEARCH INSTITUTE, INC.}
set vendor(001039) {Vectron Systems AG}
set vendor(00103a) {DIAMOND NETWORK TECH}
set vendor(00103b) {HIPPI NETWORKING FORUM}
set vendor(00103c) {IC ENSEMBLE, INC.}
set vendor(00103d) {PHASECOM, LTD.}
set vendor(00103e) {NETSCHOOLS CORPORATION}
set vendor(00103f) {TOLLGRADE COMMUNICATIONS, INC.}
set vendor(001004) {THE BRANTLEY COILE COMPANY,INC}
set vendor(001040) {INTERMEC CORPORATION}
set vendor(001041) {BRISTOL BABCOCK, INC.}
set vendor(001042) {AlacriTech}
set vendor(001043) {A2 CORPORATION}
set vendor(001044) {InnoLabs Corporation}
set vendor(001045) {Nortel Networks}
set vendor(001046) {ALCORN MCBRIDE INC.}
set vendor(001047) {ECHO ELETRIC CO. LTD.}
set vendor(001048) {HTRC AUTOMATION, INC.}
set vendor(001049) {SHORELINE TELEWORKS, INC.}
set vendor(00104a) {THE PARVUC CORPORATION}
set vendor(00104b) {3COM CORPORATION}
set vendor(00104c) {COMPUTER ACCESS TECHNOLOGY}
set vendor(00104d) {SURTEC INDUSTRIES, INC.}
set vendor(00104e) {CEOLOGIC}
set vendor(00104f) {STORAGE TECHNOLOGY CORPORATION}
set vendor(001005) {UEC COMMERCIAL}
set vendor(001050) {RION CO., LTD.}
set vendor(001051) {CMICRO CORPORATION}
set vendor(001052) {METTLER-TOLEDO (ALBSTADT) GMBH}
set vendor(001053) {COMPUTER TECHNOLOGY CORP.}
set vendor(001054) {CISCO SYSTEMS, INC.}
set vendor(001055) {FUJITSU MICROELECTRONICS, INC.}
set vendor(001056) {SODICK CO., LTD.}
set vendor(001057) {Rebel.com, Inc.}
set vendor(001058) {ArrowPoint Communications}
set vendor(001059) {DIABLO RESEARCH CO. LLC}
set vendor(00105a) {3COM CORPORATION}
set vendor(00105b) {NET INSIGHT AB}
set vendor(00105c) {QUANTUM DESIGNS (H.K.) LTD.}
set vendor(00105d) {Draeger Medical}
set vendor(00105e) {HEKIMIAN LABORATORIES, INC.}
set vendor(00105f) {IN-SNEC}
set vendor(001006) {Thales Contact Solutions Ltd.}
set vendor(001060) {BILLIONTON SYSTEMS, INC.}
set vendor(001061) {HOSTLINK CORP.}
set vendor(001062) {NX SERVER, ILNC.}
set vendor(001063) {STARGUIDE DIGITAL NETWORKS}
set vendor(001064) {DNPG, LLC}
set vendor(001065) {RADYNE CORPORATION}
set vendor(001066) {ADVANCED CONTROL SYSTEMS, INC.}
set vendor(001067) {REDBACK NETWORKS, INC.}
set vendor(001068) {COMOS TELECOM}
set vendor(001069) {HELIOSS COMMUNICATIONS, INC.}
set vendor(00106a) {DIGITAL MICROWAVE CORPORATION}
set vendor(00106b) {SONUS NETWORKS, INC.}
set vendor(00106c) {INFRATEC PLUS GmbH}
set vendor(00106d) {INTEGRITY COMMUNICATIONS, INC.}
set vendor(00106e) {TADIRAN COM. LTD.}
set vendor(00106f) {TRENTON TECHNOLOGY INC.}
set vendor(001007) {CISCO SYSTEMS, INC.}
set vendor(001070) {CARADON TREND LTD.}
set vendor(001071) {ADVANET INC.}
set vendor(001072) {GVN TECHNOLOGIES, INC.}
set vendor(001073) {TECHNOBOX, INC.}
set vendor(001074) {ATEN INTERNATIONAL CO., LTD.}
set vendor(001075) {Maxtor Corporation}
set vendor(001076) {EUREM GmbH}
set vendor(001077) {SAF DRIVE SYSTEMS, LTD.}
set vendor(001078) {NUERA COMMUNICATIONS, INC.}
set vendor(001079) {CISCO SYSTEMS, INC.}
set vendor(00107a) {AmbiCom, Inc.}
set vendor(00107b) {CISCO SYSTEMS, INC.}
set vendor(00107c) {P-COM, INC.}
set vendor(00107d) {AURORA COMMUNICATIONS, LTD.}
set vendor(00107e) {BACHMANN ELECTRONIC GmbH}
set vendor(00107f) {CRESTRON ELECTRONICS, INC.}
set vendor(001008) {VIENNA SYSTEMS CORPORATION}
set vendor(001080) {METAWAVE COMMUNICATIONS}
set vendor(001081) {DPS, INC.}
set vendor(001082) {JNA TELECOMMUNICATIONS LIMITED}
set vendor(001083) {HEWLETT-PACKARD COMPANY}
set vendor(001084) {K-BOT COMMUNICATIONS}
set vendor(001085) {POLARIS COMMUNICATIONS, INC.}
set vendor(001086) {ATTO TECHNOLOGY, INC.}
set vendor(001087) {Xstreamis PLC}
set vendor(001088) {AMERICAN NETWORKS INC.}
set vendor(001089) {WebSonic}
set vendor(00108a) {TeraLogic, Inc.}
set vendor(00108b) {LASERANIMATION SOLLINGER GmbH}
set vendor(00108c) {FUJITSU TELECOMMUNICATIONS EUROPE, LTD.}
set vendor(00108d) {JOHNSON CONTROLS, INC.}
set vendor(00108e) {HUGH SYMONS CONCEPT Technologies Ltd.}
set vendor(00108f) {RAPTOR SYSTEMS}
set vendor(001009) {HORO QUARTZ}
set vendor(001090) {CIMETRICS, INC.}
set vendor(001091) {NO WIRES NEEDED BV}
set vendor(001092) {NETCORE INC.}
set vendor(001093) {CMS COMPUTERS, LTD.}
set vendor(001094) {Performance Analysis Broadband, Spirent plc}
set vendor(001095) {Thomson Multimedia, Inc.}
set vendor(001096) {TRACEWELL SYSTEMS, INC.}
set vendor(001097) {WinNet Metropolitan Communications Systems, Inc.}
set vendor(001098) {STARNET TECHNOLOGIES, INC.}
set vendor(001099) {InnoMedia, Inc.}
set vendor(00109a) {NETLINE}
set vendor(00109b) {VIXEL CORPORATION}
set vendor(00109c) {M-SYSTEM CO., LTD.}
set vendor(00109d) {CLARINET SYSTEMS, INC.}
set vendor(00109e) {AWARE, INC.}
set vendor(00109f) {PAVO, INC.}
set vendor(00100a) {WILLIAMS COMMUNICATIONS GROUP}
set vendor(0010a0) {INNOVEX TECHNOLOGIES, INC.}
set vendor(0010a1) {KENDIN SEMICONDUCTOR, INC.}
set vendor(0010a2) {TNS}
set vendor(0010a3) {OMNITRONIX, INC.}
set vendor(0010a4) {XIRCOM}
set vendor(0010a5) {OXFORD INSTRUMENTS}
set vendor(0010a6) {CISCO SYSTEMS, INC.}
set vendor(0010a7) {UNEX TECHNOLOGY CORPORATION}
set vendor(0010a8) {RELIANCE COMPUTER CORP.}
set vendor(0010a9) {ADHOC TECHNOLOGIES}
set vendor(0010aa) {MEDIA4, INC.}
set vendor(0010ab) {KOITO INDUSTRIES, LTD.}
set vendor(0010ac) {IMCI TECHNOLOGIES}
set vendor(0010ad) {SOFTRONICS USB, INC.}
set vendor(0010ae) {SHINKO ELECTRIC INDUSTRIES CO.}
set vendor(0010af) {TAC SYSTEMS, INC.}
set vendor(00100b) {CISCO SYSTEMS, INC.}
set vendor(0010b0) {MERIDIAN TECHNOLOGY CORP.}
set vendor(0010b1) {FOR-A CO., LTD.}
set vendor(0010b2) {COACTIVE AESTHETICS}
set vendor(0010b3) {NOKIA MULTIMEDIA TERMINALS}
set vendor(0010b4) {ATMOSPHERE NETWORKS}
set vendor(0010b5) {ACCTON TECHNOLOGY CORPORATION}
set vendor(0010b6) {ENTRATA COMMUNICATIONS CORP.}
set vendor(0010b7) {COYOTE TECHNOLOGIES, LLC}
set vendor(0010b8) {ISHIGAKI COMPUTER SYSTEM CO.}
set vendor(0010b9) {MAXTOR CORP.}
set vendor(0010ba) {MARTINHO-DAVIS SYSTEMS, INC.}
set vendor(0010bb) {DATA & INFORMATION TECHNOLOGY}
set vendor(0010bc) {Aastra Telecom}
set vendor(0010bd) {THE TELECOMMUNICATION TECHNOLOGY COMMITTEE}
set vendor(0010be) {TELEXIS CORP.}
set vendor(0010bf) {InterAir Wireless}
set vendor(00100c) {ITO CO., LTD.}
set vendor(0010c0) {ARMA, INC.}
set vendor(0010c1) {OI ELECTRIC CO., LTD.}
set vendor(0010c2) {WILLNET, INC.}
set vendor(0010c3) {CSI-CONTROL SYSTEMS}
set vendor(0010c4) {MEDIA LINKS CO., LTD.}
set vendor(0010c5) {PROTOCOL TECHNOLOGIES, INC.}
set vendor(0010c6) {USI}
set vendor(0010c7) {DATA TRANSMISSION NETWORK}
set vendor(0010c8) {COMMUNICATIONS ELECTRONICS SECURITY GROUP}
set vendor(0010c9) {MITSUBISHI ELECTRONICS LOGISTIC SUPPORT CO.}
set vendor(0010ca) {INTEGRAL ACCESS}
set vendor(0010cb) {FACIT K.K.}
set vendor(0010cc) {CLP COMPUTER LOGISTIK PLANUNG GmbH}
set vendor(0010cd) {INTERFACE CONCEPT}
set vendor(0010ce) {VOLAMP, LTD.}
set vendor(0010cf) {FIBERLANE COMMUNICATIONS}
set vendor(00100d) {CISCO SYSTEMS, INC.}
set vendor(0010d0) {WITCOM, LTD.}
set vendor(0010d1) {Top Layer Networks, Inc.}
set vendor(0010d2) {NITTO TSUSHINKI CO., LTD}
set vendor(0010d3) {GRIPS ELECTRONIC GMBH}
set vendor(0010d4) {STORAGE COMPUTER CORPORATION}
set vendor(0010d5) {IMASDE CANARIAS, S.A.}
set vendor(0010d6) {ITT - A/CD}
set vendor(0010d7) {ARGOSY RESEARCH INC.}
set vendor(0010d8) {CALISTA}
set vendor(0010d9) {IBM JAPAN, FUJISAWA MT+D}
set vendor(0010da) {MOTION ENGINEERING, INC.}
set vendor(0010db) {NetScreen Technologies, Inc.}
set vendor(0010dc) {MICRO-STAR INTERNATIONAL CO., LTD.}
set vendor(0010dd) {ENABLE SEMICONDUCTOR, INC.}
set vendor(0010de) {INTERNATIONAL DATACASTING CORPORATION}
set vendor(0010df) {RISE COMPUTER INC.}
set vendor(00100e) {MICRO LINEAR COPORATION}
set vendor(0010e0) {COBALT MICROSERVER, INC.}
set vendor(0010e1) {S.I. TECH, INC.}
set vendor(0010e2) {ArrayComm, Inc.}
set vendor(0010e3) {COMPAQ COMPUTER CORPORATION}
set vendor(0010e4) {NSI CORPORATION}
set vendor(0010e5) {SOLECTRON TEXAS}
set vendor(0010e6) {APPLIED INTELLIGENT SYSTEMS, INC.}
set vendor(0010e7) {BreezeCom}
set vendor(0010e8) {TELOCITY, INCORPORATED}
set vendor(0010e9) {RAIDTEC LTD.}
set vendor(0010ea) {ADEPT TECHNOLOGY}
set vendor(0010eb) {SELSIUS SYSTEMS, INC.}
set vendor(0010ec) {RPCG, LLC}
set vendor(0010ed) {SUNDANCE TECHNOLOGY, INC.}
set vendor(0010ee) {CTI PRODUCTS, INC.}
set vendor(0010ef) {DBTEL INCORPORATED}
set vendor(00100f) {INDUSTRIAL CPU SYSTEMS}
set vendor(0010f1) {I-O CORPORATION}
set vendor(0010f2) {ANTEC}
set vendor(0010f3) {Nexcom International Co., Ltd.}
set vendor(0010f4) {VERTICAL NETWORKS, INC.}
set vendor(0010f5) {AMHERST SYSTEMS, INC.}
set vendor(0010f6) {CISCO SYSTEMS, INC.}
set vendor(0010f7) {IRIICHI TECHNOLOGIES Inc.}
set vendor(0010f8) {KENWOOD TMI CORPORATION}
set vendor(0010f9) {UNIQUE SYSTEMS, INC.}
set vendor(0010fa) {ZAYANTE, INC.}
set vendor(0010fb) {ZIDA TECHNOLOGIES LIMITED}
set vendor(0010fc) {BROADBAND NETWORKS, INC.}
set vendor(0010fd) {COCOM A/S}
set vendor(0010fe) {DIGITAL EQUIPMENT CORPORATION}
set vendor(0010ff) {CISCO SYSTEMS, INC.}
set vendor(001700) {Kabel}
set vendor(000100) {EQUIP'TRANS}
set vendor(000110) {Gotham Networks}
set vendor(000111) {iDigm Inc.}
set vendor(000112) {Shark Multimedia Inc.}
set vendor(000113) {OLYMPUS CORPORATION}
set vendor(000114) {KANDA TSUSHIN KOGYO CO., LTD.}
set vendor(000115) {EXTRATECH CORPORATION}
set vendor(000116) {Netspect Technologies, Inc.}
set vendor(000117) {CANAL +}
set vendor(000118) {EZ Digital Co., Ltd.}
set vendor(000119) {Action Controls Pty. Ltd.}
set vendor(00011a) {EEH DataLink GmbH}
set vendor(00011b) {Unizone Technologies, Inc.}
set vendor(00011c) {Universal Talkware Corporation}
set vendor(00011d) {Centillium Communications}
set vendor(00011e) {Precidia Technologies, Inc.}
set vendor(00011f) {RC Networks, Inc.}
set vendor(000102) {3COM CORPORATION}
set vendor(000120) {OSCILLOQUARTZ S.A.}
set vendor(000121) {RapidStream Inc.}
set vendor(000122) {Trend Communications, Ltd.}
set vendor(000123) {DIGITAL ELECTRONICS CORP.}
set vendor(000124) {Acer Incorporated}
set vendor(000125) {YAESU MUSEN CO., LTD.}
set vendor(000126) {PAC Labs}
set vendor(000127) {The OPEN Group Limited}
set vendor(000128) {EnjoyWeb, Inc.}
set vendor(000129) {DFI Inc.}
set vendor(00012a) {Telematica Sistems Inteligente}
set vendor(00012b) {TELENET Co., Ltd.}
set vendor(00012c) {Aravox Technologies, Inc.}
set vendor(00012d) {Komodo Technology}
set vendor(00012e) {PC Partner Ltd.}
set vendor(00012f) {Twinhead International Corp}
set vendor(000103) {3COM CORPORATION}
set vendor(000130) {Extreme Networks}
set vendor(000131) {Detection Systems, Inc.}
set vendor(000132) {Dranetz - BMI}
set vendor(000133) {KYOWA Electronic Instruments C}
set vendor(000134) {SIG Positec Systems AG}
set vendor(000135) {KDC Corp.}
set vendor(000136) {CyberTAN Technology, Inc.}
set vendor(000137) {IT Farm Corporation}
set vendor(000138) {XAVi Technologies Corp.}
set vendor(000139) {Point Multimedia Systems}
set vendor(00013a) {SHELCAD COMMUNICATIONS, LTD.}
set vendor(00013b) {BNA SYSTEMS}
set vendor(00013c) {TIW SYSTEMS}
set vendor(00013d) {RiscStation Ltd.}
set vendor(00013e) {Ascom Tateco AB}
set vendor(00013f) {Neighbor World Co., Ltd.}
set vendor(000104) {DVICO Co., Ltd.}
set vendor(000140) {Sendtek Corporation}
set vendor(000141) {CABLE PRINT}
set vendor(000142) {Cisco Systems, Inc.}
set vendor(000143) {Cisco Systems, Inc.}
set vendor(000144) {Cereva Networks, Inc.}
set vendor(000145) {WINSYSTEMS, INC.}
set vendor(000146) {Tesco Controls, Inc.}
set vendor(000147) {Zhone Technologies}
set vendor(000148) {X-traWeb Inc.}
set vendor(000149) {T.D.T. Transfer Data Test GmbH}
set vendor(00014a) {SONY COMPUTER SCIENCE LABS., I}
set vendor(00014b) {Ennovate Networks, Inc.}
set vendor(00014c) {Berkeley Process Control}
set vendor(00014d) {Shin Kin Enterprises Co., Ltd}
set vendor(00014e) {WIN Enterprises, Inc.}
set vendor(00014f) {LUMINOUS Networks, Inc.}
set vendor(000105) {BECKHOFF GmbH}
set vendor(000150) {GILAT COMMUNICATIONS, LTD.}
set vendor(000151) {Ensemble Communications}
set vendor(000152) {CHROMATEK INC.}
set vendor(000153) {ARCHTEK TELECOM CORPORATION}
set vendor(000154) {G3M Corporation}
set vendor(000155) {Promise Technology, Inc.}
set vendor(000156) {FIREWIREDIRECT.COM, INC.}
set vendor(000157) {SYSWAVE CO., LTD}
set vendor(000158) {Electro Industries/Gauge Tech}
set vendor(000159) {S1 Corporation}
set vendor(00015a) {Digital Video Broadcasting}
set vendor(00015b) {ITALTEL S.p.A/RF-UP-I}
set vendor(00015c) {CADANT INC.}
set vendor(00015d) {Sun Microsystems, Inc}
set vendor(00015e) {BEST TECHNOLOGY CO., LTD.}
set vendor(00015f) {DIGITAL DESIGN GmbH}
set vendor(000106) {Tews Datentechnik GmbH}
set vendor(000160) {ELMEX Co., LTD.}
set vendor(000161) {Meta Machine Technology}
set vendor(000162) {Cygnet Technologies, Inc.}
set vendor(000163) {Cisco Systems, Inc.}
set vendor(000164) {Cisco Systems, Inc.}
set vendor(000165) {AirSwitch Corporation}
set vendor(000166) {TC GROUP A/S}
set vendor(000167) {HIOKI E.E. CORPORATION}
set vendor(000168) {VITANA CORPORATION}
set vendor(000169) {Celestix Networks Pte Ltd.}
set vendor(00016a) {ALITEC}
set vendor(00016b) {LightChip, Inc.}
set vendor(00016c) {FOXCONN}
set vendor(00016d) {CarrierComm Inc.}
set vendor(00016e) {Conklin Corporation}
set vendor(00016f) {HAITAI ELECTRONICS CO., LTD.}
set vendor(000107) {Leiser GmbH}
set vendor(000170) {ESE Embedded System Engineer'g}
set vendor(000171) {Allied Data Technologies}
set vendor(000172) {TechnoLand Co., LTD.}
set vendor(000173) {JNI Corporation}
set vendor(000174) {CyberOptics Corporation}
set vendor(000175) {Radiant Communications Corp.}
set vendor(000176) {Orient Silver Enterprises}
set vendor(000177) {EDSL}
set vendor(000178) {MARGI Systems, Inc.}
set vendor(000179) {WIRELESS TECHNOLOGY, INC.}
set vendor(00017a) {Chengdu Maipu Electric Industrial Co., Ltd.}
set vendor(00017b) {Heidelberger Druckmaschinen AG}
set vendor(00017c) {AG-E GmbH}
set vendor(00017d) {ThermoQuest}
set vendor(00017e) {ADTEK System Science Co., Ltd.}
set vendor(00017f) {Experience Music Project}
set vendor(000108) {AVLAB Technology, Inc.}
set vendor(000180) {AOpen, Inc.}
set vendor(000181) {Nortel Networks}
set vendor(000182) {DICA TECHNOLOGIES AG}
set vendor(000183) {ANITE TELECOMS}
set vendor(000184) {SIEB & MEYER AG}
set vendor(000185) {Aloka Co., Ltd.}
set vendor(000186) {DISCH GmbH}
set vendor(000187) {i2SE GmbH}
set vendor(000188) {LXCO Technologies ag}
set vendor(000189) {Refraction Technology, Inc.}
set vendor(00018a) {ROI COMPUTER AG}
set vendor(00018b) {NetLinks Co., Ltd.}
set vendor(00018c) {Mega Vision}
set vendor(00018d) {AudeSi Technologies}
set vendor(00018e) {Logitec Corporation}
set vendor(00018f) {Kenetec, Inc.}
set vendor(000109) {Nagano Japan Radio Co., Ltd.}
set vendor(000190) {SMK-M}
set vendor(000191) {SYRED Data Systems}
set vendor(000192) {Texas Digital Systems}
set vendor(000193) {Hanbyul Telecom Co., Ltd.}
set vendor(000194) {Capital Equipment Corporation}
set vendor(000195) {Sena Technologies, Inc.}
set vendor(000196) {Cisco Systems, Inc.}
set vendor(000197) {Cisco Systems, Inc.}
set vendor(000198) {Darim Vision}
set vendor(000199) {HeiSei Electronics}
set vendor(00019a) {LEUNIG GmbH}
set vendor(00019b) {Kyoto Microcomputer Co., Ltd.}
set vendor(00019c) {JDS Uniphase Inc.}
set vendor(00019d) {E-Control Systems, Inc.}
set vendor(00019e) {ESS Technology, Inc.}
set vendor(00019f) {Phonex Broadband}
set vendor(00010a) {CIS TECHNOLOGY INC.}
set vendor(0001a0) {Infinilink Corporation}
set vendor(0001a1) {Mag-Tek, Inc.}
set vendor(0001a2) {Logical Co., Ltd.}
set vendor(0001a3) {GENESYS LOGIC, INC.}
set vendor(0001a4) {Microlink Corporation}
set vendor(0001a5) {Nextcomm, Inc.}
set vendor(0001a6) {Scientific-Atlanta Arcodan A/S}
set vendor(0001a7) {UNEX TECHNOLOGY CORPORATION}
set vendor(0001a8) {Welltech Computer Co., Ltd.}
set vendor(0001a9) {BMW AG}
set vendor(0001aa) {Airspan Communications, Ltd.}
set vendor(0001ab) {Main Street Networks}
set vendor(0001ac) {Sitara Networks, Inc.}
set vendor(0001ad) {Coach Master International  d.b.a. CMI Worldwide, Inc.}
set vendor(0001ae) {Trex Enterprises}
set vendor(0001af) {Motorola Computer Group}
set vendor(00010b) {Space CyberLink, Inc.}
set vendor(0001b0) {Fulltek Technology Co., Ltd.}
set vendor(0001b1) {General Bandwidth}
set vendor(0001b2) {Digital Processing Systems, Inc.}
set vendor(0001b3) {Precision Electronic Manufacturing}
set vendor(0001b4) {Wayport, Inc.}
set vendor(0001b5) {Turin Networks, Inc.}
set vendor(0001b6) {SAEJIN T&M Co., Ltd.}
set vendor(0001b7) {Centos, Inc.}
set vendor(0001b8) {Netsensity, Inc.}
set vendor(0001b9) {SKF Condition Monitoring}
set vendor(0001ba) {IC-Net, Inc.}
set vendor(0001bb) {Frequentis}
set vendor(0001bc) {Brains Corporation}
set vendor(0001bd) {Peterson Electro-Musical Products, Inc.}
set vendor(0001be) {Gigalink Co., Ltd.}
set vendor(0001bf) {Teleforce Co., Ltd.}
set vendor(00010c) {System Talks Inc.}
set vendor(0001c0) {CompuLab, Ltd.}
set vendor(0001c1) {Vitesse Semiconductor Corporation}
set vendor(0001c2) {ARK Research Corp.}
set vendor(0001c3) {Acromag, Inc.}
set vendor(0001c4) {NeoWave, Inc.}
set vendor(0001c5) {Simpler Networks}
set vendor(0001c6) {Quarry Technologies}
set vendor(0001c7) {Cisco Systems, Inc.}
set vendor(0001c8) {CONRAD CORP. *also* THOMAS CONRAD CORP.}
set vendor(0001c9) {Cisco Systems, Inc.}
set vendor(0001ca) {Geocast Network Systems, Inc.}
set vendor(0001cb) {NetGame, Ltd.}
set vendor(0001cc) {Japan Total Design Communication Co., Ltd.}
set vendor(0001cd) {ARtem}
set vendor(0001ce) {Custom Micro Products, Ltd.}
set vendor(0001cf) {Alpha Data Parallel Systems, Ltd.}
set vendor(00010d) {CORECO, INC.}
set vendor(0001d0) {VitalPoint, Inc.}
set vendor(0001d1) {CoNet Communications, Inc.}
set vendor(0001d2) {MacPower Peripherals, Ltd.}
set vendor(0001d3) {PAXCOMM, Inc.}
set vendor(0001d4) {Leisure Time, Inc.}
set vendor(0001d5) {HAEDONG INFO & COMM CO., LTD}
set vendor(0001d6) {MAN Roland Druckmaschinen AG}
set vendor(0001d7) {F5 Networks, Inc.}
set vendor(0001d8) {Teltronics, Inc.}
set vendor(0001d9) {Sigma, Inc.}
set vendor(0001da) {WINCOMM Corporation}
set vendor(0001db) {Freecom Technologies GmbH}
set vendor(0001dc) {Activetelco}
set vendor(0001dd) {Avail Networks}
set vendor(0001de) {Trango Systems, Inc.}
set vendor(0001df) {ISDN Communications, Ltd.}
set vendor(00010e) {Bri-Link Technologies Co., Ltd}
set vendor(0001e0) {Fast Systems, Inc.}
set vendor(0001e1) {Kinpo Electronics, Inc.}
set vendor(0001e2) {Ando Electric Corporation}
set vendor(0001e3) {Siemens AG}
set vendor(0001e4) {Sitera, Inc.}
set vendor(0001e5) {Supernet, Inc.}
set vendor(0001e6) {Hewlett-Packard Company}
set vendor(0001e7) {Hewlett-Packard Company}
set vendor(0001e8) {Force10 Networks, Inc.}
set vendor(0001e9) {Litton Marine Systems B.V.}
set vendor(0001ea) {Cirilium Corp.}
set vendor(0001eb) {C-COM Corporation}
set vendor(0001ec) {Ericsson Group}
set vendor(0001ed) {SETA Corp.}
set vendor(0001ee) {Comtrol Europe, Ltd.}
set vendor(0001ef) {Camtel Technology Corp.}
set vendor(00010f) {Nishan Systems, Inc.}
set vendor(0001f0) {Tridium, Inc.}
set vendor(0001f1) {Innovative Concepts, Inc.}
set vendor(0001f2) {Mark of the Unicorn, Inc.}
set vendor(0001f3) {QPS, Inc.}
set vendor(0001f4) {Enterasys Networks}
set vendor(0001f5) {ERIM S.A.}
set vendor(0001f6) {Association of Musical Electronics Industry}
set vendor(0001f7) {Image Display Systems, Inc.}
set vendor(0001f8) {Adherent Systems, Ltd.}
set vendor(0001f9) {TeraGlobal Communications Corp.}
set vendor(0001fa) {HOROSCAS}
set vendor(0001fb) {DoTop Technology, Inc.}
set vendor(0001fc) {Keyence Corporation}
set vendor(0001fd) {Digital Voice Systems, Inc.}
set vendor(0001fe) {DIGITAL EQUIPMENT CORPORATION}
set vendor(0001ff) {Data Direct Networks, Inc.}
set vendor(001c7c) {PERQ SYSTEMS CORPORATION}
set vendor(002000) {LEXMARK INTERNATIONAL, INC.}
set vendor(002001) {DSP SOLUTIONS, INC.}
set vendor(002010) {JEOL SYSTEM TECHNOLOGY CO. LTD}
set vendor(002011) {CANOPUS CO., LTD.}
set vendor(002012) {CAMTRONICS MEDICAL SYSTEMS}
set vendor(002013) {DIVERSIFIED TECHNOLOGY, INC.}
set vendor(002014) {GLOBAL VIEW CO., LTD.}
set vendor(002015) {ACTIS COMPUTER SA}
set vendor(002016) {SHOWA ELECTRIC WIRE & CABLE CO}
set vendor(002017) {ORBOTECH}
set vendor(002018) {CIS TECHNOLOGY INC.}
set vendor(002019) {OHLER GmbH}
set vendor(00201a) {N-BASE SWITCH COMMUNICATIONS}
set vendor(00201b) {NORTHERN TELECOM/NETWORK}
set vendor(00201c) {EXCEL, INC.}
set vendor(00201d) {KATANA PRODUCTS}
set vendor(00201e) {NETQUEST CORPORATION}
set vendor(00201f) {BEST POWER TECHNOLOGY, INC.}
set vendor(002002) {SERITECH ENTERPRISE CO., LTD.}
set vendor(002020) {MEGATRON COMPUTER INDUSTRIES PTY, LTD.}
set vendor(002021) {ALGORITHMS SOFTWARE PVT. LTD.}
set vendor(002022) {TEKNIQUE, INC.}
set vendor(002023) {T.C. TECHNOLOGIES PTY. LTD}
set vendor(002024) {PACIFIC COMMUNICATION SCIENCES}
set vendor(002025) {CONTROL TECHNOLOGY, INC.}
set vendor(002026) {AMKLY SYSTEMS, INC.}
set vendor(002027) {MING FORTUNE INDUSTRY CO., LTD}
set vendor(002028) {WEST EGG SYSTEMS, INC.}
set vendor(002029) {TELEPROCESSING PRODUCTS, INC.}
set vendor(00202a) {N.V. DZINE}
set vendor(00202b) {ADVANCED TELECOMMUNICATIONS MODULES, LTD.}
set vendor(00202c) {WELLTRONIX CO., LTD.}
set vendor(00202d) {TAIYO CORPORATION}
set vendor(00202e) {DAYSTAR DIGITAL}
set vendor(00202f) {ZETA COMMUNICATIONS, LTD.}
set vendor(002003) {PIXEL POWER LTD.}
set vendor(002030) {ANALOG & DIGITAL SYSTEMS}
set vendor(002031) {ERTEC GmbH}
set vendor(002032) {ALCATEL TAISEL}
set vendor(002033) {SYNAPSE TECHNOLOGIES, INC.}
set vendor(002034) {ROTEC INDUSTRIEAUTOMATION GMBH}
set vendor(002035) {IBM CORPORATION}
set vendor(002036) {BMC SOFTWARE}
set vendor(002037) {SEAGATE TECHNOLOGY}
set vendor(002038) {VME MICROSYSTEMS INTERNATIONAL CORPORATION}
set vendor(002039) {SCINETS}
set vendor(00203a) {DIGITAL BI0METRICS INC.}
set vendor(00203b) {WISDM LTD.}
set vendor(00203c) {EUROTIME AB}
set vendor(00203d) {NOVAR ELECTRONICS CORPORATION}
set vendor(00203e) {LogiCan Technologies, Inc.}
set vendor(00203f) {JUKI CORPORATION}
set vendor(002004) {YAMATAKE-HONEYWELL CO., LTD.}
set vendor(002040) {Motorola Broadband Communications Sector}
set vendor(002041) {DATA NET}
set vendor(002042) {DATAMETRICS CORP.}
set vendor(002043) {NEURON COMPANY LIMITED}
set vendor(002044) {GENITECH PTY LTD}
set vendor(002045) {ION Networks, Inc.}
set vendor(002046) {CIPRICO, INC.}
set vendor(002047) {STEINBRECHER CORP.}
set vendor(002048) {Marconi Communications}
set vendor(002049) {COMTRON, INC.}
set vendor(00204a) {PRONET GMBH}
set vendor(00204b) {AUTOCOMPUTER CO., LTD.}
set vendor(00204c) {MITRON COMPUTER PTE LTD.}
set vendor(00204d) {INOVIS GMBH}
set vendor(00204e) {NETWORK SECURITY SYSTEMS, INC.}
set vendor(00204f) {DEUTSCHE AEROSPACE AG}
set vendor(002005) {SIMPLE TECHNOLOGY}
set vendor(002050) {KOREA COMPUTER INC.}
set vendor(002051) {Verilink Corporation}
set vendor(002052) {RAGULA SYSTEMS}
set vendor(002053) {HUNTSVILLE MICROSYSTEMS, INC.}
set vendor(002054) {EASTERN RESEARCH, INC.}
set vendor(002055) {ALTECH CO., LTD.}
set vendor(002056) {NEOPRODUCTS}
set vendor(002057) {TITZE DATENTECHNIK GmbH}
set vendor(002058) {ALLIED SIGNAL INC.}
set vendor(002059) {MIRO COMPUTER PRODUCTS AG}
set vendor(00205a) {COMPUTER IDENTICS}
set vendor(00205b) {SKYLINE TECHNOLOGY}
set vendor(00205c) {InterNet Systems of Florida, Inc.}
set vendor(00205d) {NANOMATIC OY}
set vendor(00205e) {CASTLE ROCK, INC.}
set vendor(00205f) {GAMMADATA COMPUTER GMBH}
set vendor(002006) {GARRETT COMMUNICATIONS, INC.}
set vendor(002060) {ALCATEL ITALIA S.p.A.}
set vendor(002061) {DYNATECH COMMUNICATIONS, INC.}
set vendor(002062) {SCORPION LOGIC, LTD.}
set vendor(002063) {WIPRO INFOTECH LTD.}
set vendor(002064) {PROTEC MICROSYSTEMS, INC.}
set vendor(002065) {SUPERNET NETWORKING INC.}
set vendor(002066) {GENERAL MAGIC, INC.}
set vendor(002068) {ISDYNE}
set vendor(002069) {ISDN SYSTEMS CORPORATION}
set vendor(00206a) {OSAKA COMPUTER CORP.}
set vendor(00206b) {KONICA MINOLTA HOLDINGS, INC.}
set vendor(00206c) {EVERGREEN TECHNOLOGY CORP.}
set vendor(00206d) {DATA RACE, INC.}
set vendor(00206e) {XACT, INC.}
set vendor(00206f) {FLOWPOINT CORPORATION}
set vendor(002007) {SFA, INC.}
set vendor(002070) {HYNET, LTD.}
set vendor(002071) {IBR GMBH}
set vendor(002072) {WORKLINK INNOVATIONS}
set vendor(002073) {FUSION SYSTEMS CORPORATION}
set vendor(002074) {SUNGWOON SYSTEMS}
set vendor(002075) {MOTOROLA COMMUNICATION ISRAEL}
set vendor(002076) {REUDO CORPORATION}
set vendor(002077) {KARDIOS SYSTEMS CORP.}
set vendor(002078) {RUNTOP, INC.}
set vendor(002079) {MIKRON GMBH}
set vendor(00207a) {WiSE Communications, Inc.}
set vendor(00207b) {Intel Corporation}
set vendor(00207c) {AUTEC GmbH}
set vendor(00207d) {ADVANCED COMPUTER APPLICATIONS}
set vendor(00207e) {FINECOM Co., Ltd.}
set vendor(00207f) {KYOEI SANGYO CO., LTD.}
set vendor(002008) {CABLE & COMPUTER TECHNOLOGY}
set vendor(002080) {SYNERGY (UK) LTD.}
set vendor(002081) {TITAN ELECTRONICS}
set vendor(002082) {ONEAC CORPORATION}
set vendor(002083) {PRESTICOM INCORPORATED}
set vendor(002084) {OCE PRINTING SYSTEMS, GMBH}
set vendor(002085) {EXIDE ELECTRONICS}
set vendor(002086) {MICROTECH ELECTRONICS LIMITED}
set vendor(002087) {MEMOTEC COMMUNICATIONS CORP.}
set vendor(002088) {GLOBAL VILLAGE COMMUNICATION}
set vendor(002089) {T3PLUS NETWORKING, INC.}
set vendor(00208a) {SONIX COMMUNICATIONS, LTD.}
set vendor(00208b) {LAPIS TECHNOLOGIES, INC.}
set vendor(00208c) {GALAXY NETWORKS, INC.}
set vendor(00208d) {CMD TECHNOLOGY}
set vendor(00208e) {CHEVIN SOFTWARE ENG. LTD.}
set vendor(00208f) {ECI TELECOM LTD.}
set vendor(002009) {PACKARD BELL ELEC., INC.}
set vendor(002090) {ADVANCED COMPRESSION TECHNOLOGY, INC.}
set vendor(002091) {J125, NATIONAL SECURITY AGENCY}
set vendor(002092) {CHESS ENGINEERING B.V.}
set vendor(002093) {LANDINGS TECHNOLOGY CORP.}
set vendor(002094) {CUBIX CORPORATION}
set vendor(002095) {RIVA ELECTRONICS}
set vendor(002096) {Invensys}
set vendor(002097) {APPLIED SIGNAL TECHNOLOGY}
set vendor(002098) {HECTRONIC AB}
set vendor(002099) {BON ELECTRIC CO., LTD.}
set vendor(00209a) {THE 3DO COMPANY}
set vendor(00209b) {ERSAT ELECTRONIC GMBH}
set vendor(00209c) {PRIMARY ACCESS CORP.}
set vendor(00209d) {LIPPERT AUTOMATIONSTECHNIK}
set vendor(00209e) {BROWN'S OPERATING SYSTEM SERVICES, LTD.}
set vendor(00209f) {MERCURY COMPUTER SYSTEMS, INC.}
set vendor(00200a) {SOURCE-COMM CORP.}
set vendor(0020a0) {OA LABORATORY CO., LTD.}
set vendor(0020a1) {DOVATRON}
set vendor(0020a2) {GALCOM NETWORKING LTD.}
set vendor(0020a3) {DIVICOM INC.}
set vendor(0020a4) {MULTIPOINT NETWORKS}
set vendor(0020a5) {API ENGINEERING}
set vendor(0020a6) {PROXIM, INC.}
set vendor(0020a7) {PAIRGAIN TECHNOLOGIES, INC.}
set vendor(0020a8) {SAST TECHNOLOGY CORP.}
set vendor(0020a9) {WHITE HORSE INDUSTRIAL}
set vendor(0020aa) {DIGIMEDIA VISION LTD.}
set vendor(0020ab) {MICRO INDUSTRIES CORP.}
set vendor(0020ac) {INTERFLEX DATENSYSTEME GMBH}
set vendor(0020ad) {LINQ SYSTEMS}
set vendor(0020ae) {ORNET DATA COMMUNICATION TECH.}
set vendor(0020af) {3COM CORPORATION}
set vendor(00200b) {OCTAGON SYSTEMS CORP.}
set vendor(0020b0) {GATEWAY DEVICES, INC.}
set vendor(0020b1) {COMTECH RESEARCH INC.}
set vendor(0020b2) {GKD Gesellschaft Fur Kommunikation Und Datentechnik}
set vendor(0020b3) {SCLTEC COMMUNICATIONS SYSTEMS}
set vendor(0020b4) {TERMA ELEKTRONIK AS}
set vendor(0020b5) {YASKAWA ELECTRIC CORPORATION}
set vendor(0020b6) {AGILE NETWORKS, INC.}
set vendor(0020b7) {NAMAQUA COMPUTERWARE}
set vendor(0020b8) {PRIME OPTION, INC.}
set vendor(0020b9) {METRICOM, INC.}
set vendor(0020ba) {CENTER FOR HIGH PERFORMANCE}
set vendor(0020bb) {ZAX CORPORATION}
set vendor(0020bc) {JTEC PTY LTD.}
set vendor(0020bd) {NIOBRARA R & D CORPORATION}
set vendor(0020be) {LAN ACCESS CORP.}
set vendor(0020bf) {AEHR TEST SYSTEMS}
set vendor(00200c) {ADASTRA SYSTEMS CORP.}
set vendor(0020c0) {PULSE ELECTRONICS, INC.}
set vendor(0020c1) {TAIKO ELECTRIC WORKS, LTD.}
set vendor(0020c2) {TEXAS MEMORY SYSTEMS, INC.}
set vendor(0020c3) {COUNTER SOLUTIONS LTD.}
set vendor(0020c4) {INET,INC.}
set vendor(0020c5) {EAGLE TECHNOLOGY}
set vendor(0020c6) {NECTEC}
set vendor(0020c7) {AKAI Professional M.I. Corp.}
set vendor(0020c8) {LARSCOM INCORPORATED}
set vendor(0020c9) {VICTRON BV}
set vendor(0020ca) {DIGITAL OCEAN}
set vendor(0020cb) {PRETEC ELECTRONICS CORP.}
set vendor(0020cc) {DIGITAL SERVICES, LTD.}
set vendor(0020cd) {HYBRID NETWORKS, INC.}
set vendor(0020ce) {LOGICAL DESIGN GROUP, INC.}
set vendor(0020cf) {TEST & MEASUREMENT SYSTEMS INC}
set vendor(00200d) {CARL ZEISS}
set vendor(0020d0) {VERSALYNX CORPORATION}
set vendor(0020d1) {MICROCOMPUTER SYSTEMS (M) SDN.}
set vendor(0020d2) {RAD DATA COMMUNICATIONS, LTD.}
set vendor(0020d3) {OST (OUEST STANDARD TELEMATIQU}
set vendor(0020d4) {CABLETRON - ZEITTNET INC.}
set vendor(0020d5) {VIPA GMBH}
set vendor(0020d6) {BREEZECOM}
set vendor(0020d7) {JAPAN MINICOMPUTER SYSTEMS CO., Ltd.}
set vendor(0020d8) {Nortel Networks}
set vendor(0020d9) {PANASONIC TECHNOLOGIES, INC./MIECO-US}
set vendor(0020da) {XYLAN CORPORATION}
set vendor(0020db) {XNET TECHNOLOGY, INC.}
set vendor(0020dc) {DENSITRON TAIWAN LTD.}
set vendor(0020dd) {Cybertec Pty Ltd}
set vendor(0020de) {JAPAN DIGITAL LABORAT'Y CO.LTD}
set vendor(0020df) {KYOSAN ELECTRIC MFG. CO., LTD.}
set vendor(00200e) {SATELLITE TECHNOLOGY MGMT, INC}
set vendor(0020e0) {PREMAX ELECTRONICS, INC.}
set vendor(0020e1) {ALAMAR ELECTRONICS}
set vendor(0020e2) {INFORMATION RESOURCE ENGINEERING}
set vendor(0020e3) {MCD KENCOM CORPORATION}
set vendor(0020e4) {HSING TECH ENTERPRISE CO., LTD}
set vendor(0020e5) {APEX DATA, INC.}
set vendor(0020e6) {LIDKOPING MACHINE TOOLS AB}
set vendor(0020e7) {B&W NUCLEAR SERVICE COMPANY}
set vendor(0020e8) {DATATREK CORPORATION}
set vendor(0020e9) {DANTEL}
set vendor(0020ea) {EFFICIENT NETWORKS, INC.}
set vendor(0020eb) {CINCINNATI MICROWAVE, INC.}
set vendor(0020ec) {TECHWARE SYSTEMS CORP.}
set vendor(0020ed) {GIGA-BYTE TECHNOLOGY CO., LTD.}
set vendor(0020ee) {GTECH CORPORATION}
set vendor(0020ef) {USC CORPORATION}
set vendor(00200f) {TANBAC CO., LTD.}
set vendor(0020f0) {UNIVERSAL MICROELECTRONICS CO.}
set vendor(0020f1) {ALTOS INDIA LIMITED}
set vendor(0020f2) {SUN MICROSYSTEMS, INC.}
set vendor(0020f3) {RAYNET CORPORATION}
set vendor(0020f4) {SPECTRIX CORPORATION}
set vendor(0020f5) {PANDATEL AG}
set vendor(0020f6) {NET TEK  AND KARLNET, INC.}
set vendor(0020f7) {CYBERDATA}
set vendor(0020f8) {CARRERA COMPUTERS, INC.}
set vendor(0020f9) {PARALINK NETWORKS, INC.}
set vendor(0020fa) {GDE SYSTEMS, INC.}
set vendor(0020fb) {OCTEL COMMUNICATIONS CORP.}
set vendor(0020fc) {MATROX}
set vendor(0020fd) {ITV TECHNOLOGIES, INC.}
set vendor(0020fe) {TOPWARE INC. / GRAND COMPUTER}
set vendor(0020ff) {SYMMETRICAL TECHNOLOGIES}
set vendor(000200) {Net & Sys Co., Ltd.}
set vendor(000201) {IFM Electronic gmbh}
set vendor(000210) {Fenecom}
set vendor(000211) {Nature Worldwide Technology Corp.}
set vendor(000212) {SierraCom}
set vendor(000213) {S.D.E.L.}
set vendor(000214) {DTVRO}
set vendor(000215) {Cotas Computer Technology A/B}
set vendor(000216) {Cisco Systems, Inc.}
set vendor(000217) {Cisco Systems, Inc.}
set vendor(000218) {Advanced Scientific Corp}
set vendor(000219) {Paralon Technologies}
set vendor(00021a) {Zuma Networks}
set vendor(00021b) {Kollmorgen-Servotronix}
set vendor(00021c) {Network Elements, Inc.}
set vendor(00021d) {Data General Communication Ltd.}
set vendor(00021e) {SIMTEL S.R.L.}
set vendor(00021f) {Aculab PLC}
set vendor(000202) {Amino Communications, Ltd.}
set vendor(000220) {Canon Aptex, Inc.}
set vendor(000221) {DSP Application, Ltd.}
set vendor(000222) {Chromisys, Inc.}
set vendor(000223) {ClickTV}
set vendor(000224) {Lantern Communications, Inc.}
set vendor(000225) {Certus Technology, Inc.}
set vendor(000226) {XESystems, Inc.}
set vendor(000227) {ESD GmbH}
set vendor(000228) {Necsom, Ltd.}
set vendor(000229) {Adtec Corporation}
set vendor(00022a) {Asound Electronic}
set vendor(00022b) {Tamura Electric Works, Ltd.}
set vendor(00022c) {ABB Bomem, Inc.}
set vendor(00022d) {Agere Systems}
set vendor(00022e) {TEAC Corp. R& D}
set vendor(00022f) {P-Cube, Ltd.}
set vendor(000203) {Woonsang Telecom, Inc.}
set vendor(000230) {Intersoft Electronics}
set vendor(000231) {Ingersoll-Rand}
set vendor(000232) {Avision, Inc.}
set vendor(000233) {Mantra Communications, Inc.}
set vendor(000234) {Imperial Technology, Inc.}
set vendor(000235) {Paragon Networks International}
set vendor(000236) {INIT GmbH}
set vendor(000237) {Cosmo Research Corp.}
set vendor(000238) {Serome Technology, Inc.}
set vendor(000239) {Visicom}
set vendor(00023a) {ZSK Stickmaschinen GmbH}
set vendor(00023b) {Redback Networks}
set vendor(00023c) {Creative Technology, Ltd.}
set vendor(00023d) {NuSpeed, Inc.}
set vendor(00023e) {Selta Telematica S.p.a}
set vendor(00023f) {Compal Electronics, Inc.}
set vendor(000204) {Bodmann Industries Elektronik GmbH}
set vendor(000240) {Seedek Co., Ltd.}
set vendor(000241) {Amer.com}
set vendor(000242) {Videoframe Systems}
set vendor(000243) {Raysis Co., Ltd.}
set vendor(000244) {SURECOM Technology Co.}
set vendor(000245) {Lampus Co, Ltd.}
set vendor(000246) {All-Win Tech Co., Ltd.}
set vendor(000247) {Great Dragon Information Technology (Group) Co., Ltd.}
set vendor(000248) {Pilz GmbH & Co.}
set vendor(000249) {Aviv Infocom Co, Ltd.}
set vendor(00024a) {Cisco Systems, Inc.}
set vendor(00024b) {Cisco Systems, Inc.}
set vendor(00024c) {SiByte, Inc.}
set vendor(00024d) {Mannesman Dematic Colby Pty. Ltd.}
set vendor(00024e) {Datacard Group}
set vendor(00024f) {IPM Datacom S.R.L.}
set vendor(000205) {Hitachi Denshi, Ltd.}
set vendor(000250) {Geyser Networks, Inc.}
set vendor(000251) {Soma Networks}
set vendor(000252) {Carrier Corporation}
set vendor(000253) {Televideo, Inc.}
set vendor(000254) {WorldGate}
set vendor(000255) {IBM Corporation}
set vendor(000256) {Alpha Processor, Inc.}
set vendor(000257) {Microcom Corp.}
set vendor(000258) {Flying Packets Communications}
set vendor(000259) {Tsann Kuen China (Shanghai)Enterprise Co., Ltd. IT Group}
set vendor(00025a) {Catena Networks}
set vendor(00025b) {Cambridge Silicon Radio}
set vendor(00025c) {SCI Systems (Kunshan) Co., Ltd.}
set vendor(00025d) {Calix Networks}
set vendor(00025e) {High Technology Ltd}
set vendor(00025f) {Nortel Networks}
set vendor(000206) {Telital R&D Denmark A/S}
set vendor(000260) {Accordion Networks, Inc.}
set vendor(000261) {i3 Micro Technology AB}
set vendor(000262) {Soyo Group Soyo Com Tech Co., Ltd}
set vendor(000263) {UPS Manufacturing SRL}
set vendor(000264) {AudioRamp.com}
set vendor(000265) {Virditech Co. Ltd.}
set vendor(000266) {Thermalogic Corporation}
set vendor(000267) {NODE RUNNER, INC.}
set vendor(000268) {Harris Government Communications}
set vendor(000269) {Nadatel Co., Ltd}
set vendor(00026a) {Cocess Telecom Co., Ltd.}
set vendor(00026b) {BCM Computers Co., Ltd.}
set vendor(00026c) {Philips CFT}
set vendor(00026d) {Adept Telecom}
set vendor(00026e) {NeGeN Access, Inc.}
set vendor(00026f) {Senao International Co., Ltd.}
set vendor(000207) {VisionGlobal Network Corp.}
set vendor(000270) {Crewave Co., Ltd.}
set vendor(000271) {Vpacket Communications}
set vendor(000272) {CC&C Technologies, Inc.}
set vendor(000273) {Coriolis Networks}
set vendor(000274) {Tommy Technologies Corp.}
set vendor(000275) {SMART Technologies, Inc.}
set vendor(000276) {Primax Electronics Ltd.}
set vendor(000277) {Cash Systemes Industrie}
set vendor(000278) {Samsung Electro-Mechanics Co., Ltd.}
set vendor(000279) {Control Applications, Ltd.}
set vendor(00027a) {IOI Technology Corporation}
set vendor(00027b) {Amplify Net, Inc.}
set vendor(00027c) {Trilithic, Inc.}
set vendor(00027d) {Cisco Systems, Inc.}
set vendor(00027e) {Cisco Systems, Inc.}
set vendor(00027f) {ask-technologies.com}
set vendor(000208) {Unify Networks, Inc.}
set vendor(000280) {Mu Net, Inc.}
set vendor(000281) {Madge Ltd.}
set vendor(000282) {ViaClix, Inc.}
set vendor(000283) {Spectrum Controls, Inc.}
set vendor(000284) {Alstom T&D P&C}
set vendor(000285) {Riverstone Networks}
set vendor(000286) {Occam Networks}
set vendor(000287) {Adapcom}
set vendor(000288) {GLOBAL VILLAGE COMMUNICATION}
set vendor(000289) {DNE Technologies}
set vendor(00028a) {Ambit Microsystems Corporation}
set vendor(00028b) {VDSL Systems OY}
set vendor(00028c) {Micrel-Synergy Semiconductor}
set vendor(00028d) {Movita Technologies, Inc.}
set vendor(00028e) {Rapid 5 Networks, Inc.}
set vendor(00028f) {Globetek, Inc.}
set vendor(000209) {Shenzhen SED Information Technology Co., Ltd.}
set vendor(000290) {Woorigisool, Inc.}
set vendor(000291) {Open Network Co., Ltd.}
set vendor(000292) {Logic Innovations, Inc.}
set vendor(000293) {Solid Data Systems}
set vendor(000294) {Tokyo Sokushin Co., Ltd.}
set vendor(000295) {IP.Access Limited}
set vendor(000296) {Lectron Co,. Ltd.}
set vendor(000297) {C-COR.net}
set vendor(000298) {Broadframe Corporation}
set vendor(000299) {Apex, Inc.}
set vendor(00029a) {Storage Apps}
set vendor(00029b) {Kreatel Communications AB}
set vendor(00029c) {3COM}
set vendor(00029d) {Merix Corp.}
set vendor(00029e) {Information Equipment Co., Ltd.}
set vendor(00029f) {L-3 Communication Aviation Recorders}
set vendor(00020a) {Gefran Spa}
set vendor(0002a0) {Flatstack Ltd.}
set vendor(0002a1) {World Wide Packets}
set vendor(0002a2) {Hilscher GmbH}
set vendor(0002a3) {ABB Power Automation}
set vendor(0002a4) {AddPac Technology Co., Ltd.}
set vendor(0002a5) {Compaq Computer Corporation}
set vendor(0002a6) {Effinet Systems Co., Ltd.}
set vendor(0002a7) {Vivace Networks}
set vendor(0002a8) {Air Link Technology}
set vendor(0002a9) {RACOM, s.r.o.}
set vendor(0002aa) {PLcom Co., Ltd.}
set vendor(0002ab) {CTC Union Technologies Co., Ltd.}
set vendor(0002ac) {3PAR data}
set vendor(0002ad) {Pentax Corpotation}
set vendor(0002ae) {Scannex Electronics Ltd.}
set vendor(0002af) {TeleCruz Technology, Inc.}
set vendor(00020b) {Native Networks, Inc.}
set vendor(0002b0) {Hokubu Communication & Industrial Co., Ltd.}
set vendor(0002b1) {Anritsu, Ltd.}
set vendor(0002b2) {Cablevision}
set vendor(0002b3) {Intel Corporation}
set vendor(0002b4) {DAPHNE}
set vendor(0002b5) {Avnet, Inc.}
set vendor(0002b6) {Acrosser Technology Co., Ltd.}
set vendor(0002b7) {Watanabe Electric Industry Co., Ltd.}
set vendor(0002b8) {WHI KONSULT AB}
set vendor(0002b9) {Cisco Systems, Inc.}
set vendor(0002ba) {Cisco Systems, Inc.}
set vendor(0002bb) {Continuous Computing}
set vendor(0002bc) {LVL 7 Systems, Inc.}
set vendor(0002bd) {Bionet Co., Ltd.}
set vendor(0002be) {Totsu Engineering, Inc.}
set vendor(0002bf) {dotRocket, Inc.}
set vendor(00020c) {Metro-Optix}
set vendor(0002c0) {Bencent Tzeng Industry Co., Ltd.}
set vendor(0002c1) {Innovative Electronic Designs, Inc.}
set vendor(0002c2) {Net Vision Telecom}
set vendor(0002c3) {Arelnet Ltd.}
set vendor(0002c4) {Vector International BUBA}
set vendor(0002c5) {Evertz Microsystems Ltd.}
set vendor(0002c6) {Data Track Technology PLC}
set vendor(0002c7) {ALPS ELECTRIC Co., Ltd.}
set vendor(0002c8) {Technocom Communications Technology (pte) Ltd}
set vendor(0002c9) {Mellanox Technologies}
set vendor(0002ca) {EndPoints, Inc.}
set vendor(0002cb) {TriState Ltd.}
set vendor(0002cc) {M.C.C.I}
set vendor(0002cd) {TeleDream, Inc.}
set vendor(0002ce) {FoxJet, Inc.}
set vendor(0002cf) {ZyGate Communications, Inc.}
set vendor(00020d) {Micronpc.com}
set vendor(0002d0) {Comdial Corporation}
set vendor(0002d1) {Vivotek, Inc.}
set vendor(0002d2) {Workstation AG}
set vendor(0002d3) {NetBotz, Inc.}
set vendor(0002d4) {PDA Peripherals, Inc.}
set vendor(0002d5) {ACR}
set vendor(0002d6) {NICE Systems}
set vendor(0002d7) {EMPEG Ltd}
set vendor(0002d8) {BRECIS Communications Corporation}
set vendor(0002d9) {Reliable Controls}
set vendor(0002da) {ExiO Communications, Inc.}
set vendor(0002db) {NETSEC}
set vendor(0002dc) {Fujitsu General Limited}
set vendor(0002dd) {Bromax Communications, Ltd.}
set vendor(0002de) {Astrodesign, Inc.}
set vendor(0002df) {Net Com Systems, Inc.}
set vendor(00020e) {Laurel Networks, Inc.}
set vendor(0002e0) {ETAS GmbH}
set vendor(0002e1) {Integrated Network Corporation}
set vendor(0002e2) {NDC Infared Engineering}
set vendor(0002e3) {LITE-ON Communications, Inc.}
set vendor(0002e4) {JC HYUN Systems, Inc.}
set vendor(0002e5) {Timeware Ltd.}
set vendor(0002e6) {Gould Instrument Systems, Inc.}
set vendor(0002e7) {CAB GmbH & Co KG}
set vendor(0002e8) {E.D.&A.}
set vendor(0002e9) {CS Systemes De Securite - C3S}
set vendor(0002ea) {Videonics, Inc.}
set vendor(0002eb) {Pico Communications}
set vendor(0002ec) {Maschoff Design Engineering}
set vendor(0002ed) {DXO Telecom Co., Ltd.}
set vendor(0002ee) {Nokia Danmark A/S}
set vendor(0002ef) {CCC Network Systems Group Ltd.}
set vendor(00020f) {AATR}
set vendor(0002f0) {AME Optimedia Technology Co., Ltd.}
set vendor(0002f1) {Pinetron Co., Ltd.}
set vendor(0002f2) {eDevice, Inc.}
set vendor(0002f3) {Media Serve Co., Ltd.}
set vendor(0002f4) {PCTEL, Inc.}
set vendor(0002f5) {VIVE Synergies, Inc.}
set vendor(0002f6) {Equipe Communications}
set vendor(0002f7) {ARM}
set vendor(0002f8) {SEAKR Engineering, Inc.}
set vendor(0002f9) {Mimos Semiconductor SDN BHD}
set vendor(0002fa) {DX Antenna Co., Ltd.}
set vendor(0002fb) {Baumuller Aulugen-Systemtechnik GmbH}
set vendor(0002fc) {Cisco Systems, Inc.}
set vendor(0002fd) {Cisco Systems, Inc.}
set vendor(0002fe) {Viditec, Inc.}
set vendor(0002ff) {Handan BroadInfoCom}
set vendor(003000) {ALLWELL TECHNOLOGY CORP.}
set vendor(003001) {SMP}
set vendor(003010) {VISIONETICS INTERNATIONAL}
set vendor(003011) {HMS FIELDBUS SYSTEMS AB}
set vendor(003012) {DIGITAL ENGINEERING LTD.}
set vendor(003013) {NEC Corporation}
set vendor(003014) {DIVIO, INC.}
set vendor(003015) {CP CLARE CORP.}
set vendor(003016) {ISHIDA CO., LTD.}
set vendor(003017) {TERASTACK LTD.}
set vendor(003018) {Jetway Information Co., Ltd.}
set vendor(003019) {CISCO SYSTEMS, INC.}
set vendor(00301a) {SMARTBRIDGES PTE. LTD.}
set vendor(00301b) {SHUTTLE, INC.}
set vendor(00301c) {ALTVATER AIRDATA SYSTEMS}
set vendor(00301d) {SKYSTREAM, INC.}
set vendor(00301e) {3COM Europe Ltd.}
set vendor(00301f) {OPTICAL NETWORKS, INC.}
set vendor(003002) {Expand Networks}
set vendor(003020) {TSI, Inc..}
set vendor(003021) {HSING TECH. ENTERPRISE CO.,LTD}
set vendor(003022) {Fong Kai Industrial Co., Ltd.}
set vendor(003023) {COGENT COMPUTER SYSTEMS, INC.}
set vendor(003024) {CISCO SYSTEMS, INC.}
set vendor(003025) {CHECKOUT COMPUTER SYSTEMS, LTD}
set vendor(003026) {HEITEL}
set vendor(003027) {KERBANGO, INC.}
set vendor(003028) {FASE Saldatura srl}
set vendor(003029) {OPICOM}
set vendor(00302a) {SOUTHERN INFORMATION}
set vendor(00302b) {INALP NETWORKS, INC.}
set vendor(00302c) {SYLANTRO SYSTEMS CORPORATION}
set vendor(00302d) {QUANTUM BRIDGE COMMUNICATIONS}
set vendor(00302e) {Hoft & Wessel AG}
set vendor(00302f) {Smiths Industries}
set vendor(003003) {Phasys Ltd.}
set vendor(003030) {HARMONIX CORPORATION}
set vendor(003031) {LIGHTWAVE COMMUNICATIONS, INC.}
set vendor(003032) {MagicRam, Inc.}
set vendor(003033) {ORIENT TELECOM CO., LTD.}
set vendor(003036) {RMP ELEKTRONIKSYSTEME GMBH}
set vendor(003037) {Packard Bell Nec Services}
set vendor(003038) {XCP, INC.}
set vendor(003039) {SOFTBOOK PRESS}
set vendor(00303a) {MAATEL}
set vendor(00303b) {PowerCom Technology}
set vendor(00303c) {ONNTO CORP.}
set vendor(00303d) {IVA CORPORATION}
set vendor(00303e) {Radcom Ltd.}
set vendor(00303f) {TurboComm Tech Inc.}
set vendor(003004) {LEADTEK RESEARCH INC.}
set vendor(003040) {CISCO SYSTEMS, INC.}
set vendor(003041) {SAEJIN T & M CO., LTD.}
set vendor(003042) {DeTeWe-Deutsche Telephonwerke}
set vendor(003043) {IDREAM TECHNOLOGIES, PTE. LTD.}
set vendor(003044) {Portsmith LLC}
set vendor(003045) {Village Networks, Inc. (VNI)}
set vendor(003046) {Controlled Electronic Manageme}
set vendor(003047) {NISSEI ELECTRIC CO., LTD.}
set vendor(003048) {Supermicro Computer, Inc.}
set vendor(003049) {BRYANT TECHNOLOGY, LTD.}
set vendor(00304a) {FRAUNHOFER INSTITUTE IMS}
set vendor(00304b) {ORBACOM SYSTEMS, INC.}
set vendor(00304c) {APPIAN COMMUNICATIONS, INC.}
set vendor(00304d) {ESI}
set vendor(00304e) {BUSTEC PRODUCTION LTD.}
set vendor(00304f) {PLANET Technology Corporation}
set vendor(003005) {Fujitsu Siemens Computers}
set vendor(003050) {Versa Technology}
set vendor(003051) {ORBIT AVIONIC & COMMUNICATION}
set vendor(003052) {ELASTIC NETWORKS}
set vendor(003053) {Basler AG}
set vendor(003054) {CASTLENET TECHNOLOGY, INC.}
set vendor(003055) {Hitachi Semiconductor America,}
set vendor(003056) {Beck IPC GmbH}
set vendor(003057) {E-Tel Corporation}
set vendor(003058) {API MOTION}
set vendor(003059) {DIGITAL-LOGIC AG}
set vendor(00305a) {TELGEN CORPORATION}
set vendor(00305b) {MODULE DEPARTMENT}
set vendor(00305c) {SMAR Laboratories Corp.}
set vendor(00305d) {DIGITRA SYSTEMS, INC.}
set vendor(00305e) {Abelko Innovation}
set vendor(00305f) {IMACON APS}
set vendor(003006) {SUPERPOWER COMPUTER}
set vendor(003060) {STARMATIX, INC.}
set vendor(003061) {MobyTEL}
set vendor(003062) {PATH 1 NETWORK TECHNOL'S INC.}
set vendor(003063) {SANTERA SYSTEMS, INC.}
set vendor(003064) {ADLINK TECHNOLOGY, INC.}
set vendor(003065) {APPLE COMPUTER, INC.}
set vendor(003066) {DIGITAL WIRELESS CORPORATION}
set vendor(003067) {BIOSTAR MICROTECH INT'L CORP.}
set vendor(003068) {CYBERNETICS TECH. CO., LTD.}
set vendor(003069) {IMPACCT TECHNOLOGY CORP.}
set vendor(00306a) {PENTA MEDIA CO., LTD.}
set vendor(00306b) {CMOS SYSTEMS, INC.}
set vendor(00306c) {Hitex Holding GmbH}
set vendor(00306d) {LUCENT TECHNOLOGIES}
set vendor(00306e) {HEWLETT PACKARD}
set vendor(00306f) {SEYEON TECH. CO., LTD.}
set vendor(003007) {OPTI, INC.}
set vendor(003070) {1Net Corporation}
set vendor(003071) {Cisco Systems, Inc.}
set vendor(003072) {INTELLIBYTE INC.}
set vendor(003073) {International Microsystems, In}
set vendor(003074) {EQUIINET LTD.}
set vendor(003075) {ADTECH}
set vendor(003076) {Akamba Corporation}
set vendor(003077) {ONPREM NETWORKS}
set vendor(003078) {Cisco Systems, Inc.}
set vendor(003079) {CQOS, INC.}
set vendor(00307a) {Advanced Technology & Systems}
set vendor(00307b) {Cisco Systems, Inc.}
set vendor(00307c) {ADID SA}
set vendor(00307d) {GRE AMERICA, INC.}
set vendor(00307e) {Redflex Communication Systems}
set vendor(00307f) {IRLAN LTD.}
set vendor(003008) {AVIO DIGITAL, INC.}
set vendor(003080) {CISCO SYSTEMS, INC.}
set vendor(003081) {ALTOS C&C}
set vendor(003082) {TAIHAN ELECTRIC WIRE CO., LTD.}
set vendor(003083) {Ivron Systems}
set vendor(003084) {ALLIED TELESYN INTERNAIONAL}
set vendor(003085) {CISCO SYSTEMS, INC.}
set vendor(003086) {Transistor Devices, Inc.}
set vendor(003087) {VEGA GRIESHABER KG}
set vendor(003088) {Siara Systems, Inc.}
set vendor(003089) {Spectrapoint Wireless, LLC}
set vendor(00308a) {NICOTRA SISTEMI S.P.A}
set vendor(00308b) {Brix Networks}
set vendor(00308c) {ADVANCED DIGITAL INFORMATION}
set vendor(00308d) {PINNACLE SYSTEMS, INC.}
set vendor(00308e) {CROSS MATCH TECHNOLOGIES, INC.}
set vendor(00308f) {MICRILOR, Inc.}
set vendor(003009) {Tachion Networks, Inc.}
set vendor(003090) {CYRA TECHNOLOGIES, INC.}
set vendor(003091) {TAIWAN FIRST LINE ELEC. CORP.}
set vendor(003092) {ModuNORM GmbH}
set vendor(003093) {SONNET TECHNOLOGIES, INC.}
set vendor(003094) {Cisco Systems, Inc.}
set vendor(003095) {Procomp Informatics, Ltd.}
set vendor(003096) {CISCO SYSTEMS, INC.}
set vendor(003097) {EXOMATIC AB}
set vendor(003098) {Global Converging Technologies}
set vendor(003099) {BOENIG UND KALLENBACH OHG}
set vendor(00309a) {ASTRO TERRA CORP.}
set vendor(00309b) {Smartware}
set vendor(00309c) {Timing Applications, Inc.}
set vendor(00309d) {Nimble Microsystems, Inc.}
set vendor(00309e) {WORKBIT CORPORATION.}
set vendor(00309f) {AMBER NETWORKS}
set vendor(00300a) {AZTECH SYSTEMS LTD.}
set vendor(0030a0) {TYCO SUBMARINE SYSTEMS, LTD.}
set vendor(0030a1) {WEBGATE Inc.}
set vendor(0030a2) {Lightner Engineering}
set vendor(0030a3) {CISCO SYSTEMS, INC.}
set vendor(0030a4) {Woodwind Communications System}
set vendor(0030a5) {ACTIVE POWER}
set vendor(0030a6) {VIANET TECHNOLOGIES, LTD.}
set vendor(0030a7) {SCHWEITZER ENGINEERING}
set vendor(0030a8) {OL'E COMMUNICATIONS, INC.}
set vendor(0030a9) {Netiverse, Inc.}
set vendor(0030aa) {AXUS MICROSYSTEMS, INC.}
set vendor(0030ab) {DELTA NETWORKS, INC.}
set vendor(0030ac) {Systeme Lauer GmbH & Co., Ltd.}
set vendor(0030ad) {SHANGHAI COMMUNICATION}
set vendor(0030ae) {Times N System, Inc.}
set vendor(0030af) {Honeywell GmbH}
set vendor(00300b) {mPHASE Technologies, Inc.}
set vendor(0030b0) {Convergenet Technologies}
set vendor(0030b1) {GOC GESELLSCHAFT FUR OPTISCHE}
set vendor(0030b2) {WESCAM - HEALDSBURG}
set vendor(0030b3) {San Valley Systems, Inc.}
set vendor(0030b4) {INTERSIL CORP.}
set vendor(0030b5) {Tadiran Microwave Networks}
set vendor(0030b6) {CISCO SYSTEMS, INC.}
set vendor(0030b7) {Teletrol Systems, Inc.}
set vendor(0030b8) {RiverDelta Networks}
set vendor(0030b9) {ECTEL}
set vendor(0030ba) {AC&T SYSTEM CO., LTD.}
set vendor(0030bb) {CacheFlow, Inc.}
set vendor(0030bc) {Optronic AG}
set vendor(0030bd) {BELKIN COMPONENTS}
set vendor(0030be) {City-Net Technology, Inc.}
set vendor(0030bf) {MULTIDATA GMBH}
set vendor(00300c) {CONGRUENCY, LTD.}
set vendor(0030c0) {Lara Technology, Inc.}
set vendor(0030c1) {HEWLETT-PACKARD}
set vendor(0030c2) {COMONE}
set vendor(0030c3) {FLUECKIGER ELEKTRONIK AG}
set vendor(0030c4) {Niigata Canotec Co., Inc.}
set vendor(0030c5) {CADENCE DESIGN SYSTEMS}
set vendor(0030c6) {CONTROL SOLUTIONS, INC.}
set vendor(0030c7) {MACROMATE CORP.}
set vendor(0030c8) {GAD LINE, LTD.}
set vendor(0030c9) {LuxN, N}
set vendor(0030ca) {Discovery Com}
set vendor(0030cb) {OMNI FLOW COMPUTERS, INC.}
set vendor(0030cc) {Tenor Networks, Inc.}
set vendor(0030cd) {CONEXANT SYSTEMS, INC.}
set vendor(0030ce) {Zaffire}
set vendor(0030cf) {TWO TECHNOLOGIES, INC.}
set vendor(00300d) {MMC Technology, Inc.}
set vendor(0030d1) {INOVA CORPORATION}
set vendor(0030d2) {WIN TECHNOLOGIES, CO., LTD.}
set vendor(0030d3) {Agilent Technologies}
set vendor(0030d4) {COMTIER}
set vendor(0030d5) {DResearch GmbH}
set vendor(0030d6) {MSC VERTRIEBS GMBH}
set vendor(0030d7) {Innovative Systems, L.L.C.}
set vendor(0030d8) {SITEK}
set vendor(0030d9) {DATACORE SOFTWARE CORP.}
set vendor(0030da) {COMTREND CO.}
set vendor(0030db) {Mindready Solutions, Inc.}
set vendor(0030dc) {RIGHTECH CORPORATION}
set vendor(0030dd) {INDIGITA CORPORATION}
set vendor(0030de) {WAGO Kontakttechnik GmbH}
set vendor(0030df) {KB/TEL TELECOMUNICACIONES}
set vendor(00300e) {Klotz Digital AG}
set vendor(0030e0) {OXFORD SEMICONDUCTOR LTD.}
set vendor(0030e1) {ACROTRON SYSTEMS, INC.}
set vendor(0030e2) {GARNET SYSTEMS CO., LTD.}
set vendor(0030e3) {SEDONA NETWORKS CORP.}
set vendor(0030e4) {CHIYODA SYSTEM RIKEN}
set vendor(0030e5) {Amper Datos S.A.}
set vendor(0030e6) {SIEMENS MEDICAL SYSTEMS}
set vendor(0030e7) {CNF MOBILE SOLUTIONS, INC.}
set vendor(0030e8) {ENSIM CORP.}
set vendor(0030e9) {GMA COMMUNICATION MANUFACT'G}
set vendor(0030ea) {TeraForce Technology Corporation}
set vendor(0030eb) {TURBONET COMMUNICATIONS, INC.}
set vendor(0030ec) {BORGARDT}
set vendor(0030ed) {Expert Magnetics Corp.}
set vendor(0030ee) {DSG Technology, Inc.}
set vendor(0030ef) {NEON TECHNOLOGY, INC.}
set vendor(00300f) {IMT - Information Management T}
set vendor(0030f0) {Uniform Industrial Corp.}
set vendor(0030f1) {Accton Technology Corp.}
set vendor(0030f2) {CISCO SYSTEMS, INC.}
set vendor(0030f3) {At Work Computers}
set vendor(0030f4) {STARDOT TECHNOLOGIES}
set vendor(0030f5) {Wild Lab. Ltd.}
set vendor(0030f6) {SECURELOGIX CORPORATION}
set vendor(0030f7) {RAMIX INC.}
set vendor(0030f8) {Dynapro Systems, Inc.}
set vendor(0030f9) {Sollae Systems Co., Ltd.}
set vendor(0030fa) {TELICA, INC.}
set vendor(0030fb) {AZS Technology AG}
set vendor(0030fc) {Terawave Communications, Inc.}
set vendor(0030fd) {INTEGRATED SYSTEMS DESIGN}
set vendor(0030fe) {DSA GmbH}
set vendor(0030ff) {DATAFAB SYSTEMS, INC.}
set vendor(000300) {NetContinuum, Inc.}
set vendor(000301) {Avantas Networks Corporation}
set vendor(000310) {Link Evolution Corp.}
set vendor(000311) {Micro Technology Co., Ltd.}
set vendor(000312) {TR-Systemtechnik GmbH}
set vendor(000313) {Access Media SPA}
set vendor(000314) {Teleware Network Systems}
set vendor(000315) {Cidco Incorporated}
set vendor(000316) {Nobell Communications, Inc.}
set vendor(000317) {Merlin Systems, Inc.}
set vendor(000318) {Cyras Systems, Inc.}
set vendor(000319) {Infineon AG}
set vendor(00031a) {Beijing Broad Telecom Ltd., China}
set vendor(00031b) {Cellvision Systems, Inc.}
set vendor(00031c) {Svenska Hardvarufabriken AB}
set vendor(00031d) {Taiwan Commate Computer, Inc.}
set vendor(00031e) {Optranet, Inc.}
set vendor(00031f) {Condev Ltd.}
set vendor(000302) {Oasys Telecom, Inc.}
set vendor(000320) {Xpeed, Inc.}
set vendor(000321) {Reco Research Co., Ltd.}
set vendor(000322) {IDIS Co., Ltd.}
set vendor(000323) {Cornet Technology, Inc.}
set vendor(000324) {SANYO Multimedia Tottori Co., Ltd.}
set vendor(000325) {Arima Computer Corp.}
set vendor(000326) {Iwasaki Information Systems Co., Ltd.}
set vendor(000327) {ACT'L}
set vendor(000328) {Mace Group, Inc.}
set vendor(000329) {F3, Inc.}
set vendor(00032a) {UniData Communication Systems, Inc.}
set vendor(00032b) {GAI Datenfunksysteme GmbH}
set vendor(00032c) {ABB Industrie AG}
set vendor(00032d) {IBASE Technology, Inc.}
set vendor(00032e) {Scope Information Management, Ltd.}
set vendor(00032f) {Global Sun Technology, Inc.}
set vendor(000303) {JAMA Electronics Co., Ltd.}
set vendor(000330) {Imagenics, Co., Ltd.}
set vendor(000331) {Cisco Systems, Inc.}
set vendor(000332) {Cisco Systems, Inc.}
set vendor(000333) {Digitel Co., Ltd.}
set vendor(000334) {Newport Electronics}
set vendor(000335) {Mirae Technology}
set vendor(000336) {Zetes Technologies}
set vendor(000337) {Vaone, Inc.}
set vendor(000338) {Oak Technology}
set vendor(000339) {Eurologic Systems, Ltd.}
set vendor(00033a) {Silicon Wave, Inc.}
set vendor(00033b) {TAMI Tech Co., Ltd.}
set vendor(00033c) {Daiden Co., Ltd.}
set vendor(00033d) {ILSHin Lab}
set vendor(00033e) {Tateyama System Laboratory Co., Ltd.}
set vendor(00033f) {BigBand Networks, Ltd.}
set vendor(000304) {Pacific Broadband Communications}
set vendor(000340) {Floware Wireless Systems, Ltd.}
set vendor(000341) {Axon Digital Design}
set vendor(000342) {Nortel Networks}
set vendor(000343) {Martin Professional A/S}
set vendor(000344) {Tietech.Co., Ltd.}
set vendor(000345) {Routrek Networks Corporation}
set vendor(000346) {Hitachi Kokusai Electric, Inc.}
set vendor(000347) {Intel Corporation}
set vendor(000348) {Norscan Instruments, Ltd.}
set vendor(000349) {Vidicode Datacommunicatie B.V.}
set vendor(00034a) {RIAS Corporation}
set vendor(00034b) {Nortel Networks}
set vendor(00034c) {Shanghai DigiVision Technology Co., Ltd.}
set vendor(00034d) {Chiaro Networks, Ltd.}
set vendor(00034e) {Pos Data Company, Ltd.}
set vendor(00034f) {Sur-Gard Security}
set vendor(000305) {Smart Network Devices GmbH}
set vendor(000350) {BTICINO SPA}
set vendor(000351) {Diebold, Inc.}
set vendor(000352) {Colubris Networks}
set vendor(000353) {Mitac, Inc.}
set vendor(000354) {Fiber Logic Communications}
set vendor(000355) {TeraBeam Internet Systems}
set vendor(000356) {Wincor Nixdorf GmbH & Co KG}
set vendor(000357) {Intervoice-Brite, Inc.}
set vendor(000358) {iCable System Co., Ltd.}
set vendor(000359) {DigitalSis}
set vendor(00035a) {Photron Limited}
set vendor(00035b) {BridgeWave Communications}
set vendor(00035c) {Saint Song Corp.}
set vendor(00035d) {Bosung Hi-Net Co., Ltd.}
set vendor(00035e) {Metropolitan Area Networks, Inc.}
set vendor(00035f) {Prueftechnik Condition Monitoring GmbH & Co. KG}
set vendor(000306) {Fusion In Tech Co., Ltd.}
set vendor(000360) {PAC Interactive Technology, Inc.}
set vendor(000361) {Widcomm, Inc.}
set vendor(000362) {Vodtel Communications, Inc.}
set vendor(000363) {Miraesys Co., Ltd.}
set vendor(000364) {Scenix Semiconductor, Inc.}
set vendor(000365) {Kira Information & Communications, Ltd.}
set vendor(000366) {ASM Pacific Technology}
set vendor(000367) {Jasmine Networks, Inc.}
set vendor(000368) {Embedone Co., Ltd.}
set vendor(000369) {Nippon Antenna Co., Ltd.}
set vendor(00036a) {Mainnet, Ltd.}
set vendor(00036b) {Cisco Systems, Inc.}
set vendor(00036c) {Cisco Systems, Inc.}
set vendor(00036d) {Runtop, Inc.}
set vendor(00036e) {Nicon Systems (Pty) Limited}
set vendor(00036f) {Telsey SPA}
set vendor(000307) {Secure Works, Inc.}
set vendor(000370) {NXTV, Inc.}
set vendor(000371) {Acomz Networks Corp.}
set vendor(000372) {ULAN}
set vendor(000373) {Aselsan A.S}
set vendor(000374) {Hunter Watertech}
set vendor(000375) {NetMedia, Inc.}
set vendor(000376) {Graphtec Technology, Inc.}
set vendor(000377) {Gigabit Wireless}
set vendor(000378) {HUMAX Co., Ltd.}
set vendor(000379) {Proscend Communications, Inc.}
set vendor(00037a) {Taiyo Yuden Co., Ltd.}
set vendor(00037b) {IDEC IZUMI Corporation}
set vendor(00037c) {Coax Media}
set vendor(00037d) {Stellcom}
set vendor(00037e) {PORTech Communications, Inc.}
set vendor(00037f) {Atheros Communications, Inc.}
set vendor(000308) {AM Communications, Inc.}
set vendor(000380) {SSH Communications Security Corp.}
set vendor(000381) {Ingenico International}
set vendor(000382) {A-One Co., Ltd.}
set vendor(000383) {Metera Networks, Inc.}
set vendor(000384) {AETA}
set vendor(000385) {Actelis Networks, Inc.}
set vendor(000386) {Ho Net, Inc.}
set vendor(000387) {Blaze Network Products}
set vendor(000388) {Fastfame Technology Co., Ltd.}
set vendor(000389) {Plantronics}
set vendor(00038a) {America Online, Inc.}
set vendor(00038b) {PLUS-ONE I&T, Inc.}
set vendor(00038c) {Total Impact}
set vendor(00038d) {PCS Revenue Control Systems, Inc.}
set vendor(00038e) {Atoga Systems, Inc.}
set vendor(00038f) {Weinschel Corporation}
set vendor(000309) {Texcel Technology PLC}
set vendor(000390) {Digital Video Communications, Inc.}
set vendor(000392) {Hyundai Teletek Co., Ltd.}
set vendor(000393) {Apple Computer, Inc.}
set vendor(000394) {Connect One}
set vendor(000395) {California Amplifier}
set vendor(000396) {EZ Cast Co., Ltd.}
set vendor(000397) {Watchfront Electronics}
set vendor(000398) {WISI}
set vendor(000399) {Dongju Informations & Communications Co., Ltd.}
set vendor(00039a) {nSine, Ltd.}
set vendor(00039b) {NetChip Technology, Inc.}
set vendor(00039c) {OptiMight Communications, Inc.}
set vendor(00039d) {BENQ CORPORATION}
set vendor(00039e) {Tera System Co., Ltd.}
set vendor(00039f) {Cisco Systems, Inc.}
set vendor(00030a) {Argus Technologies}
set vendor(0003a0) {Cisco Systems, Inc.}
set vendor(0003a1) {HIPER Information & Communication, Inc.}
set vendor(0003a2) {Catapult Communications}
set vendor(0003a3) {MAVIX, Ltd.}
set vendor(0003a4) {Data Storage and Information Management}
set vendor(0003a5) {Medea Corporation}
set vendor(0003a7) {Unixtar Technology, Inc.}
set vendor(0003a8) {IDOT Computers, Inc.}
set vendor(0003a9) {AXCENT Media AG}
set vendor(0003aa) {Watlow}
set vendor(0003ab) {Bridge Information Systems}
set vendor(0003ac) {Fronius Schweissmaschinen}
set vendor(0003ad) {Emerson Energy Systems AB}
set vendor(0003ae) {Allied Advanced Manufacturing Pte, Ltd.}
set vendor(0003af) {Paragea Communications}
set vendor(00030b) {Hunter Technology, Inc.}
set vendor(0003b0) {Xsense Technology Corp.}
set vendor(0003b1) {Abbott Laboratories HPD}
set vendor(0003b2) {Radware}
set vendor(0003b3) {IA Link Systems Co., Ltd.}
set vendor(0003b4) {Macrotek International Corp.}
set vendor(0003b5) {Entra Technology Co.}
set vendor(0003b6) {QSI Corporation}
set vendor(0003b7) {ZACCESS Systems}
set vendor(0003b8) {NetKit Solutions, LLC}
set vendor(0003b9) {Hualong Telecom Co., Ltd.}
set vendor(0003ba) {Sun Microsystems}
set vendor(0003bb) {Signal Communications Limited}
set vendor(0003bc) {COT GmbH}
set vendor(0003bd) {OmniCluster Technologies, Inc.}
set vendor(0003be) {Netility}
set vendor(0003bf) {Centerpoint Broadband Technologies, Inc.}
set vendor(00030c) {Telesoft Technologies Ltd.}
set vendor(0003c0) {RFTNC Co., Ltd.}
set vendor(0003c1) {Packet Dynamics Ltd}
set vendor(0003c2) {Solphone K.K.}
set vendor(0003c3) {Micronik Multimedia}
set vendor(0003c4) {Tomra Systems ASA}
set vendor(0003c5) {Mobotix AG}
set vendor(0003c6) {ICUE Systems, Inc.}
set vendor(0003c7) {hopf Elektronik GmbH}
set vendor(0003c8) {CML Emergency Services}
set vendor(0003c9) {TECOM Co., Ltd.}
set vendor(0003ca) {MTS Systems Corp.}
set vendor(0003cb) {Nippon Systems Development Co., Ltd.}
set vendor(0003cc) {Momentum Computer, Inc.}
set vendor(0003cd) {Clovertech, Inc.}
set vendor(0003ce) {ETEN Technologies, Inc.}
set vendor(0003cf) {Muxcom, Inc.}
set vendor(00030d) {Uniwill Computer Corp.}
set vendor(0003d0) {KOANKEISO Co., Ltd.}
set vendor(0003d1) {Takaya Corporation}
set vendor(0003d2) {Crossbeam Systems, Inc.}
set vendor(0003d3) {Internet Energy Systems, Inc.}
set vendor(0003d4) {Alloptic, Inc.}
set vendor(0003d5) {Advanced Communications Co., Ltd.}
set vendor(0003d6) {RADVision, Ltd.}
set vendor(0003d7) {NextNet Wireless, Inc.}
set vendor(0003d8) {iMPath Networks, Inc.}
set vendor(0003d9) {Secheron SA}
set vendor(0003da) {Takamisawa Cybernetics Co., Ltd.}
set vendor(0003db) {Apogee Electronics Corp.}
set vendor(0003dc) {Lexar Media, Inc.}
set vendor(0003dd) {Comark Corp.}
set vendor(0003de) {OTC Wireless}
set vendor(0003df) {Desana Systems}
set vendor(00030e) {Core Communications Co., Ltd.}
set vendor(0003e0) {RadioFrame Networks, Inc.}
set vendor(0003e1) {Winmate Communication, Inc.}
set vendor(0003e2) {Comspace Corporation}
set vendor(0003e3) {Cisco Systems, Inc.}
set vendor(0003e4) {Cisco Systems, Inc.}
set vendor(0003e5) {Hermstedt SG}
set vendor(0003e6) {Entone Technologies, Inc.}
set vendor(0003e7) {Logostek Co. Ltd.}
set vendor(0003e8) {Wavelength Digital Limited}
set vendor(0003e9) {Akara Canada, Inc.}
set vendor(0003ea) {Mega System Technologies, Inc.}
set vendor(0003eb) {Atrica}
set vendor(0003ec) {ICG Research, Inc.}
set vendor(0003ed) {Shinkawa Electric Co., Ltd.}
set vendor(0003ee) {MKNet Corporation}
set vendor(0003ef) {Oneline AG}
set vendor(00030f) {Digital China (Shanghai) Networks Ltd.}
set vendor(0003f0) {Redfern Broadband Networks}
set vendor(0003f1) {Cicada Semiconductor, Inc.}
set vendor(0003f2) {Seneca Networks}
set vendor(0003f3) {Dazzle Multimedia, Inc.}
set vendor(0003f4) {NetBurner}
set vendor(0003f5) {Chip2Chip}
set vendor(0003f6) {Allegro Networks, Inc.}
set vendor(0003f7) {Plast-Control GmbH}
set vendor(0003f8) {SanCastle Technologies, Inc.}
set vendor(0003f9) {Pleiades Communications, Inc.}
set vendor(0003fa) {TiMetra Networks}
set vendor(0003fb) {Toko Seiki Company, Ltd.}
set vendor(0003fc) {Intertex Data AB}
set vendor(0003fd) {Cisco Systems, Inc.}
set vendor(0003fe) {Cisco Systems, Inc.}
set vendor(0003ff) {Connectix}
set vendor(004000) {PCI COMPONENTES DA AMZONIA LTD}
set vendor(004001) {ZYXEL COMMUNICATIONS, INC.}
set vendor(004010) {SONIC SYSTEMS, INC.}
set vendor(004011) {ANDOVER CONTROLS CORPORATION}
set vendor(004012) {WINDATA, INC.}
set vendor(004013) {NTT DATA COMM. SYSTEMS CORP.}
set vendor(004014) {COMSOFT GMBH}
set vendor(004015) {ASCOM INFRASYS AG}
set vendor(004016) {HADAX ELECTRONICS, INC.}
set vendor(004017) {XCD INC.}
set vendor(004018) {ADOBE SYSTEMS, INC.}
set vendor(004019) {AEON SYSTEMS, INC.}
set vendor(00401a) {FUJI ELECTRIC CO., LTD.}
set vendor(00401b) {PRINTER SYSTEMS CORP.}
set vendor(00401c) {AST RESEARCH, INC.}
set vendor(00401d) {INVISIBLE SOFTWARE, INC.}
set vendor(00401e) {ICC}
set vendor(00401f) {COLORGRAPH LTD}
set vendor(004002) {PERLE SYSTEMS LIMITED}
set vendor(004020) {PINACL COMMUNICATION}
set vendor(004021) {RASTER GRAPHICS}
set vendor(004022) {KLEVER COMPUTERS, INC.}
set vendor(004023) {LOGIC CORPORATION}
set vendor(004024) {COMPAC INC.}
set vendor(004025) {MOLECULAR DYNAMICS}
set vendor(004026) {MELCO, INC.}
set vendor(004027) {SMC MASSACHUSETTS, INC.}
set vendor(004028) {NETCOMM LIMITED}
set vendor(004029) {COMPEX}
set vendor(00402a) {CANOGA-PERKINS}
set vendor(00402b) {TRIGEM COMPUTER, INC.}
set vendor(00402c) {ISIS DISTRIBUTED SYSTEMS, INC.}
set vendor(00402d) {HARRIS ADACOM CORPORATION}
set vendor(00402e) {PRECISION SOFTWARE, INC.}
set vendor(00402f) {XLNT DESIGNS INC.}
set vendor(004003) {WESTINGHOUSE PROCESS CONTROL}
set vendor(004030) {GK COMPUTER}
set vendor(004031) {KOKUSAI ELECTRIC CO., LTD}
set vendor(004032) {DIGITAL COMMUNICATIONS}
set vendor(004033) {ADDTRON TECHNOLOGY CO., LTD.}
set vendor(004034) {BUSTEK CORPORATION}
set vendor(004035) {OPCOM}
set vendor(004036) {TRIBE COMPUTER WORKS, INC.}
set vendor(004037) {SEA-ILAN, INC.}
set vendor(004038) {TALENT ELECTRIC INCORPORATED}
set vendor(004039) {OPTEC DAIICHI DENKO CO., LTD.}
set vendor(00403a) {IMPACT TECHNOLOGIES}
set vendor(00403b) {SYNERJET INTERNATIONAL CORP.}
set vendor(00403c) {FORKS, INC.}
set vendor(00403d) {TERADATA}
set vendor(00403e) {RASTER OPS CORPORATION}
set vendor(00403f) {SSANGYONG COMPUTER SYSTEMS}
set vendor(004004) {ICM CO. LTD.}
set vendor(004040) {RING ACCESS, INC.}
set vendor(004041) {FUJIKURA LTD.}
set vendor(004042) {N.A.T. GMBH}
set vendor(004043) {NOKIA TELECOMMUNICATIONS}
set vendor(004044) {QNIX COMPUTER CO., LTD.}
set vendor(004045) {TWINHEAD CORPORATION}
set vendor(004046) {UDC RESEARCH LIMITED}
set vendor(004047) {WIND RIVER SYSTEMS}
set vendor(004048) {SMD INFORMATICA S.A.}
set vendor(004049) {TEGIMENTA AG}
set vendor(00404a) {WEST AUSTRALIAN DEPARTMENT}
set vendor(00404b) {MAPLE COMPUTER SYSTEMS}
set vendor(00404c) {HYPERTEC PTY LTD.}
set vendor(00404d) {TELECOMMUNICATIONS TECHNIQUES}
set vendor(00404e) {FLUENT, INC.}
set vendor(00404f) {SPACE & NAVAL WARFARE SYSTEMS}
set vendor(004005) {ANI COMMUNICATIONS INC.}
set vendor(004050) {IRONICS, INCORPORATED}
set vendor(004051) {GRACILIS, INC.}
set vendor(004052) {STAR TECHNOLOGIES, INC.}
set vendor(004053) {AMPRO COMPUTERS}
set vendor(004054) {CONNECTION MACHINES SERVICES}
set vendor(004055) {METRONIX GMBH}
set vendor(004056) {MCM JAPAN LTD.}
set vendor(004057) {LOCKHEED - SANDERS}
set vendor(004058) {KRONOS, INC.}
set vendor(004059) {YOSHIDA KOGYO K. K.}
set vendor(00405a) {GOLDSTAR INFORMATION & COMM.}
set vendor(00405b) {FUNASSET LIMITED}
set vendor(00405c) {FUTURE SYSTEMS, INC.}
set vendor(00405d) {STAR-TEK, INC.}
set vendor(00405e) {NORTH HILLS ISRAEL}
set vendor(00405f) {AFE COMPUTERS LTD.}
set vendor(004006) {SAMPO TECHNOLOGY CORPORATION}
set vendor(004060) {COMENDEC LTD}
set vendor(004061) {DATATECH ENTERPRISES CO., LTD.}
set vendor(004062) {E-SYSTEMS, INC./GARLAND DIV.}
set vendor(004063) {VIA TECHNOLOGIES, INC.}
set vendor(004064) {KLA INSTRUMENTS CORPORATION}
set vendor(004065) {GTE SPACENET}
set vendor(004066) {HITACHI CABLE, LTD.}
set vendor(004067) {OMNIBYTE CORPORATION}
set vendor(004068) {EXTENDED SYSTEMS}
set vendor(004069) {LEMCOM SYSTEMS, INC.}
set vendor(00406a) {KENTEK INFORMATION SYSTEMS,INC}
set vendor(00406b) {SYSGEN}
set vendor(00406c) {COPERNIQUE}
set vendor(00406d) {LANCO, INC.}
set vendor(00406e) {COROLLARY, INC.}
set vendor(00406f) {SYNC RESEARCH INC.}
set vendor(004007) {TELMAT INFORMATIQUE}
set vendor(004070) {INTERWARE CO., LTD.}
set vendor(004071) {ATM COMPUTER GMBH}
set vendor(004072) {Applied Innovation Inc.}
set vendor(004073) {BASS ASSOCIATES}
set vendor(004074) {CABLE AND WIRELESS}
set vendor(004075) {M-TRADE (UK) LTD}
set vendor(004076) {Sun Conversion Technologies}
set vendor(004077) {MAXTON TECHNOLOGY CORPORATION}
set vendor(004078) {WEARNES AUTOMATION PTE LTD}
set vendor(004079) {JUKO MANUFACTURE COMPANY, LTD.}
set vendor(00407a) {SOCIETE D'EXPLOITATION DU CNIT}
set vendor(00407b) {SCIENTIFIC ATLANTA}
set vendor(00407c) {QUME CORPORATION}
set vendor(00407d) {EXTENSION TECHNOLOGY CORP.}
set vendor(00407e) {EVERGREEN SYSTEMS, INC.}
set vendor(00407f) {FLIR Systems}
set vendor(004008) {A PLUS INFO CORPORATION}
set vendor(004080) {ATHENIX CORPORATION}
set vendor(004081) {MANNESMANN SCANGRAPHIC GMBH}
set vendor(004082) {LABORATORY EQUIPMENT CORP.}
set vendor(004083) {TDA INDUSTRIA DE PRODUTOS}
set vendor(004084) {HONEYWELL INC.}
set vendor(004085) {SAAB INSTRUMENTS AB}
set vendor(004086) {MICHELS & KLEBERHOFF COMPUTER}
set vendor(004087) {UBITREX CORPORATION}
set vendor(004088) {MOBIUS TECHNOLOGIES, INC.}
set vendor(004089) {MEIDENSHA CORPORATION}
set vendor(00408a) {TPS TELEPROCESSING SYS. GMBH}
set vendor(00408b) {RAYLAN CORPORATION}
set vendor(00408c) {AXIS COMMUNICATIONS AB}
set vendor(00408d) {THE GOODYEAR TIRE & RUBBER CO.}
set vendor(00408e) {DIGILOG, INC.}
set vendor(00408f) {WM-DATA MINFO AB}
set vendor(004009) {TACHIBANA TECTRON CO., LTD.}
set vendor(004090) {ANSEL COMMUNICATIONS}
set vendor(004091) {PROCOMP INDUSTRIA ELETRONICA}
set vendor(004092) {ASP COMPUTER PRODUCTS, INC.}
set vendor(004093) {PAXDATA NETWORKS LTD.}
set vendor(004094) {SHOGRAPHICS, INC.}
set vendor(004095) {R.P.T. INTERGROUPS INT'L LTD.}
set vendor(004096) {Aironet Wireless Communication}
set vendor(004097) {DATEX DIVISION OF}
set vendor(004098) {DRESSLER GMBH & CO.}
set vendor(004099) {NEWGEN SYSTEMS CORP.}
set vendor(00409a) {NETWORK EXPRESS, INC.}
set vendor(00409b) {HAL COMPUTER SYSTEMS INC.}
set vendor(00409c) {TRANSWARE}
set vendor(00409d) {DIGIBOARD, INC.}
set vendor(00409e) {CONCURRENT TECHNOLOGIES  LTD.}
set vendor(00409f) {LANCAST/CASAT TECHNOLOGY, INC.}
set vendor(00400a) {PIVOTAL TECHNOLOGIES, INC.}
set vendor(0040a0) {GOLDSTAR CO., LTD.}
set vendor(0040a1) {ERGO COMPUTING}
set vendor(0040a2) {KINGSTAR TECHNOLOGY INC.}
set vendor(0040a3) {MICROUNITY SYSTEMS ENGINEERING}
set vendor(0040a4) {ROSE ELECTRONICS}
set vendor(0040a5) {CLINICOMP INTL.}
set vendor(0040a6) {Cray, Inc.}
set vendor(0040a7) {ITAUTEC PHILCO S.A.}
set vendor(0040a8) {IMF INTERNATIONAL LTD.}
set vendor(0040a9) {DATACOM INC.}
set vendor(0040aa) {VALMET AUTOMATION INC.}
set vendor(0040ab) {ROLAND DG CORPORATION}
set vendor(0040ac) {SUPER WORKSTATION, INC.}
set vendor(0040ad) {SMA REGELSYSTEME GMBH}
set vendor(0040ae) {DELTA CONTROLS, INC.}
set vendor(0040af) {DIGITAL PRODUCTS, INC.}
set vendor(00400b) {CISCO SYSTEMS, INC.}
set vendor(0040b0) {BYTEX CORPORATION, ENGINEERING}
set vendor(0040b1) {CODONICS INC.}
set vendor(0040b2) {SYSTEMFORSCHUNG}
set vendor(0040b3) {PAR MICROSYSTEMS CORPORATION}
set vendor(0040b4) {NEXTCOM K.K.}
set vendor(0040b5) {VIDEO TECHNOLOGY COMPUTERS LTD}
set vendor(0040b6) {COMPUTERM  CORPORATION}
set vendor(0040b7) {STEALTH COMPUTER SYSTEMS}
set vendor(0040b8) {IDEA ASSOCIATES}
set vendor(0040b9) {MACQ ELECTRONIQUE SA}
set vendor(0040ba) {ALLIANT COMPUTER SYSTEMS CORP.}
set vendor(0040bb) {GOLDSTAR CABLE CO., LTD.}
set vendor(0040bc) {ALGORITHMICS LTD.}
set vendor(0040bd) {STARLIGHT NETWORKS, INC.}
set vendor(0040be) {BOEING DEFENSE & SPACE}
set vendor(0040bf) {CHANNEL SYSTEMS INTERN'L INC.}
set vendor(00400c) {GENERAL MICRO SYSTEMS, INC.}
set vendor(0040c0) {VISTA CONTROLS CORPORATION}
set vendor(0040c1) {BIZERBA-WERKE WILHEIM KRAUT}
set vendor(0040c2) {APPLIED COMPUTING DEVICES}
set vendor(0040c3) {FISCHER AND PORTER CO.}
set vendor(0040c4) {KINKEI SYSTEM CORPORATION}
set vendor(0040c5) {MICOM COMMUNICATIONS INC.}
set vendor(0040c6) {FIBERNET RESEARCH, INC.}
set vendor(0040c7) {RUBY TECH CORPORATION}
set vendor(0040c8) {MILAN TECHNOLOGY CORPORATION}
set vendor(0040c9) {NCUBE}
set vendor(0040ca) {FIRST INTERNAT'L COMPUTER, INC}
set vendor(0040cb) {LANWAN TECHNOLOGIES}
set vendor(0040cc) {SILCOM MANUF'G TECHNOLOGY INC.}
set vendor(0040cd) {TERA MICROSYSTEMS, INC.}
set vendor(0040ce) {NET-SOURCE, INC.}
set vendor(0040cf) {STRAWBERRY TREE, INC.}
set vendor(00400d) {LANNET DATA COMMUNICATIONS,LTD}
set vendor(0040d0) {MITAC INTERNATIONAL CORP.}
set vendor(0040d1) {FUKUDA DENSHI CO., LTD.}
set vendor(0040d2) {PAGINE CORPORATION}
set vendor(0040d3) {KIMPSION INTERNATIONAL CORP.}
set vendor(0040d4) {GAGE TALKER CORP.}
set vendor(0040d5) {SARTORIUS AG}
set vendor(0040d6) {LOCAMATION B.V.}
set vendor(0040d7) {STUDIO GEN INC.}
set vendor(0040d8) {OCEAN OFFICE AUTOMATION LTD.}
set vendor(0040d9) {AMERICAN MEGATRENDS INC.}
set vendor(0040da) {TELSPEC LTD}
set vendor(0040db) {ADVANCED TECHNICAL SOLUTIONS}
set vendor(0040dc) {TRITEC ELECTRONIC GMBH}
set vendor(0040dd) {HONG TECHNOLOGIES}
set vendor(0040de) {ELETTRONICA SAN GIORGIO}
set vendor(0040df) {DIGALOG SYSTEMS, INC.}
set vendor(00400e) {MEMOTEC COMMUNICATIONS, INC.}
set vendor(0040e0) {ATOMWIDE LTD.}
set vendor(0040e1) {MARNER INTERNATIONAL, INC.}
set vendor(0040e2) {MESA RIDGE TECHNOLOGIES, INC.}
set vendor(0040e3) {QUIN SYSTEMS LTD}
set vendor(0040e4) {E-M TECHNOLOGY, INC.}
set vendor(0040e5) {SYBUS CORPORATION}
set vendor(0040e6) {C.A.E.N.}
set vendor(0040e7) {ARNOS INSTRUMENTS & COMPUTER}
set vendor(0040e8) {CHARLES RIVER DATA SYSTEMS,INC}
set vendor(0040e9) {ACCORD SYSTEMS, INC.}
set vendor(0040ea) {PLAIN TREE SYSTEMS INC}
set vendor(0040eb) {MARTIN MARIETTA CORPORATION}
set vendor(0040ec) {MIKASA SYSTEM ENGINEERING}
set vendor(0040ed) {NETWORK CONTROLS INT'NATL INC.}
set vendor(0040ee) {OPTIMEM}
set vendor(0040ef) {HYPERCOM, INC.}
set vendor(00400f) {DATACOM TECHNOLOGIES}
set vendor(0040f0) {MICRO SYSTEMS, INC.}
set vendor(0040f1) {CHUO ELECTRONICS CO., LTD.}
set vendor(0040f2) {JANICH & KLASS COMPUTERTECHNIK}
set vendor(0040f3) {NETCOR}
set vendor(0040f4) {CAMEO COMMUNICATIONS, INC.}
set vendor(0040f5) {OEM ENGINES}
set vendor(0040f6) {KATRON COMPUTERS INC.}
set vendor(0040f7) {POLAROID MEDICAL IMAGING SYS.}
set vendor(0040f8) {SYSTEMHAUS DISCOM}
set vendor(0040f9) {COMBINET}
set vendor(0040fa) {MICROBOARDS, INC.}
set vendor(0040fb) {CASCADE COMMUNICATIONS CORP.}
set vendor(0040fc) {IBR COMPUTER TECHNIK GMBH}
set vendor(0040fd) {LXE}
set vendor(0040fe) {SYMPLEX COMMUNICATIONS}
set vendor(0040ff) {TELEBIT CORPORATION}
set vendor(004252) {RLX Technologies}
set vendor(004854) {Digital SemiConductor		21143/2 based 10/100}
set vendor(000400) {LEXMARK INTERNATIONAL, INC.}
set vendor(000401) {Osaki Electric Co., Ltd.}
set vendor(000410) {Spinnaker Networks, Inc.}
set vendor(000411) {Inkra Networks, Inc.}
set vendor(000412) {WaveSmith Networks, Inc.}
set vendor(000413) {SNOM Technology AG}
set vendor(000414) {Umezawa Musen Denki Co., Ltd.}
set vendor(000415) {Rasteme Systems Co., Ltd.}
set vendor(000416) {Parks S/A Comunicacoes Digitais}
set vendor(000417) {ELAU AG}
set vendor(000418) {Teltronic S.A.U.}
set vendor(000419) {Fibercycle Networks, Inc.}
set vendor(00041a) {ines GmbH}
set vendor(00041b) {Digital Interfaces Ltd.}
set vendor(00041c) {ipDialog, Inc.}
set vendor(00041d) {Corega of America}
set vendor(00041e) {Shikoku Instrumentation Co., Ltd.}
set vendor(00041f) {Sony Computer Entertainment, Inc.}
set vendor(000402) {Nexsan Technologies, Ltd.}
set vendor(000420) {Slim Devices, Inc.}
set vendor(000421) {Ocular Networks}
set vendor(000422) {Gordon Kapes, Inc.}
set vendor(000423) {Intel Corporation}
set vendor(000424) {TMC s.r.l.}
set vendor(000425) {Atmel Corporation}
set vendor(000426) {Autosys}
set vendor(000427) {Cisco Systems, Inc.}
set vendor(000428) {Cisco Systems, Inc.}
set vendor(000429) {Pixord Corporation}
set vendor(00042a) {Wireless Networks, Inc.}
set vendor(00042b) {IT Access Co., Ltd.}
set vendor(00042c) {Minet, Inc.}
set vendor(00042d) {Sarian Systems, Ltd.}
set vendor(00042e) {Netous Technologies, Ltd.}
set vendor(00042f) {International Communications Products, Inc.}
set vendor(000403) {Nexsi Corporation}
set vendor(000430) {Netgem}
set vendor(000431) {GlobalStreams, Inc.}
set vendor(000432) {Voyetra Turtle Beach, Inc.}
set vendor(000433) {Cyberboard A/S}
set vendor(000434) {Accelent Systems, Inc.}
set vendor(000435) {Comptek International, Inc.}
set vendor(000436) {ELANsat Technologies, Inc.}
set vendor(000437) {Powin Information Technology, Inc.}
set vendor(000438) {Nortel Networks}
set vendor(000439) {Rosco Entertainment Technology, Inc.}
set vendor(00043a) {Intelligent Telecommunications, Inc.}
set vendor(00043b) {Lava Computer Mfg., Inc.}
set vendor(00043c) {SONOS Co., Ltd.}
set vendor(00043d) {INDEL AG}
set vendor(00043e) {Telencomm}
set vendor(00043f) {Electronic Systems Technology, Inc.}
set vendor(000404) {Makino Milling Machine Co., Ltd.}
set vendor(000440) {cyberPIXIE, Inc.}
set vendor(000441) {Half Dome Systems, Inc.}
set vendor(000442) {NACT}
set vendor(000443) {Agilent Technologies, Inc.}
set vendor(000444) {Western Multiplex Corporation}
set vendor(000445) {LMS Skalar Instruments GmbH}
set vendor(000446) {CYZENTECH Co., Ltd.}
set vendor(000447) {Acrowave Systems Co., Ltd.}
set vendor(000448) {Polaroid Professional Imaging}
set vendor(000449) {Mapletree Networks}
set vendor(00044a) {iPolicy Networks, Inc.}
set vendor(00044b) {NVIDIA}
set vendor(00044c) {JENOPTIK}
set vendor(00044d) {Cisco Systems, Inc.}
set vendor(00044e) {Cisco Systems, Inc.}
set vendor(00044f) {Leukhardt Systemelektronik GmbH}
set vendor(000405) {ACN Technologies}
set vendor(000450) {DMD Computers SRL}
set vendor(000451) {Medrad, Inc.}
set vendor(000452) {RocketLogix, Inc.}
set vendor(000453) {YottaYotta, Inc.}
set vendor(000454) {Quadriga UK}
set vendor(000455) {ANTARA.net}
set vendor(000456) {PipingHot Networks}
set vendor(000457) {Universal Access Technology, Inc.}
set vendor(000458) {Fusion X Co., Ltd.}
set vendor(000459) {Veristar Corporation}
set vendor(00045a) {The Linksys Group, Inc.}
set vendor(00045b) {Techsan Electronics Co., Ltd.}
set vendor(00045c) {Mobiwave Pte Ltd}
set vendor(00045d) {BEKA Elektronik}
set vendor(00045e) {PolyTrax Information Technology AG}
set vendor(00045f) {Evalue Technology, Inc.}
set vendor(000406) {Fa. Metabox AG}
set vendor(000460) {Knilink Technology, Inc.}
set vendor(000461) {EPOX Computer Co., Ltd.}
set vendor(000462) {DAKOS Data & Communication Co., Ltd.}
set vendor(000463) {Bosch Security Systems}
set vendor(000464) {Fantasma Networks, Inc.}
set vendor(000465) {i.s.t isdn-support technik GmbH}
set vendor(000466) {ARMITEL Co.}
set vendor(000467) {Wuhan Research Institute of MII}
set vendor(000468) {Vivity, Inc.}
set vendor(000469) {Innocom, Inc.}
set vendor(00046a) {Navini Networks}
set vendor(00046b) {Palm Wireless, Inc.}
set vendor(00046c) {Cyber Technology Co., Ltd.}
set vendor(00046d) {Cisco Systems, Inc.}
set vendor(00046e) {Cisco Systems, Inc.}
set vendor(00046f) {Digitel S/A Industria Eletronica}
set vendor(000407) {Topcon Positioning Systems, Inc.}
set vendor(000470) {ipUnplugged AB}
set vendor(000471) {IPrad}
set vendor(000472) {Telelynx, Inc.}
set vendor(000473) {Photonex Corporation}
set vendor(000474) {LEGRAND}
set vendor(000475) {3 Com Corporation}
set vendor(000476) {3 Com Corporation}
set vendor(000477) {Scalant Systems, Inc.}
set vendor(000478) {G. Star Technology Corporation}
set vendor(000479) {Radius Co., Ltd.}
set vendor(00047a) {AXXESSIT ASA}
set vendor(00047b) {Schlumberger}
set vendor(00047c) {Skidata AG}
set vendor(00047d) {Pelco}
set vendor(00047e) {NKF Electronics}
set vendor(00047f) {Chr. Mayr GmbH & Co. KG}
set vendor(000408) {Sanko Electronics Co., Ltd.}
set vendor(000480) {Foundry Networks, Inc.}
set vendor(000481) {Econolite Control Products, Inc.}
set vendor(000482) {Medialogic Corp.}
set vendor(000483) {Deltron Technology, Inc.}
set vendor(000484) {Amann GmbH}
set vendor(000485) {PicoLight}
set vendor(000486) {ITTC, University of Kansas}
set vendor(000487) {Cogency Semiconductor, Inc.}
set vendor(000488) {Eurotherm Action Incorporated.}
set vendor(000489) {YAFO Networks, Inc.}
set vendor(00048a) {Temia Vertriebs GmbH}
set vendor(00048b) {Poscon Corporation}
set vendor(00048c) {Nayna Networks, Inc.}
set vendor(00048d) {Tone Commander Systems, Inc.}
set vendor(00048e) {Ohm Tech Labs, Inc.}
set vendor(00048f) {TD Systems Corp.}
set vendor(000409) {Cratos Networks}
set vendor(000490) {Optical Access}
set vendor(000491) {Technovision, Inc.}
set vendor(000492) {Hive Internet, Ltd.}
set vendor(000493) {Tsinghua Unisplendour Co., Ltd.}
set vendor(000494) {Breezecom, Ltd.}
set vendor(000495) {Tejas Networks}
set vendor(000496) {Extreme Networks}
set vendor(000497) {MacroSystem Digital Video AG}
set vendor(000499) {Chino Corporation}
set vendor(00049a) {Cisco Systems, Inc.}
set vendor(00049b) {Cisco Systems, Inc.}
set vendor(00049c) {Surgient Networks, Inc.}
set vendor(00049d) {Ipanema Technologies}
set vendor(00049e) {Wirelink Co., Ltd.}
set vendor(00049f) {Metrowerks}
set vendor(00040a) {Sage Systems}
set vendor(0004a0) {Verity Instruments, Inc.}
set vendor(0004a1) {Pathway Connectivity}
set vendor(0004a2) {L.S.I. Japan Co., Ltd.}
set vendor(0004a3) {Microchip Technology, Inc.}
set vendor(0004a4) {NetEnabled, Inc.}
set vendor(0004a5) {Barco Projection Systems NV}
set vendor(0004a6) {SAF Tehnika Ltd.}
set vendor(0004a7) {FabiaTech Corporation}
set vendor(0004a8) {Broadmax Technologies, Inc.}
set vendor(0004a9) {SandStream Technologies, Inc.}
set vendor(0004aa) {Jetstream Communications}
set vendor(0004ab) {Comverse Network Systems, Inc.}
set vendor(0004ac) {IBM CORP.}
set vendor(0004ad) {Malibu Networks}
set vendor(0004ae) {Liquid Metronics}
set vendor(0004af) {Digital Fountain, Inc.}
set vendor(00040b) {3com Europe Ltd.}
set vendor(0004b0) {ELESIGN Co., Ltd.}
set vendor(0004b1) {Signal Technology, Inc.}
set vendor(0004b2) {ESSEGI SRL}
set vendor(0004b3) {Videotek, Inc.}
set vendor(0004b4) {CIAC}
set vendor(0004b5) {Equitrac Corporation}
set vendor(0004b6) {Stratex Networks, Inc.}
set vendor(0004b7) {AMB i.t. Holding}
set vendor(0004b8) {Kumahira Co., Ltd.}
set vendor(0004b9) {S.I. Soubou, Inc.}
set vendor(0004ba) {KDD Media Will Corporation}
set vendor(0004bb) {Bardac Corporation}
set vendor(0004bc) {Giantec, Inc.}
set vendor(0004bd) {Motorola BCS}
set vendor(0004be) {OptXCon, Inc.}
set vendor(0004bf) {VersaLogic Corp.}
set vendor(00040c) {KANNO Work's Ltd.}
set vendor(0004c0) {Cisco Systems, Inc.}
set vendor(0004c1) {Cisco Systems, Inc.}
set vendor(0004c2) {Magnipix, Inc.}
set vendor(0004c3) {CASTOR Informatique}
set vendor(0004c4) {Allen & Heath Limited}
set vendor(0004c5) {ASE Technologies, USA}
set vendor(0004c6) {Yamaha Motor Co., Ltd.}
set vendor(0004c7) {NetMount}
set vendor(0004c8) {LIBA Maschinenfabrik GmbH}
set vendor(0004c9) {Micro Electron Co., Ltd.}
set vendor(0004ca) {FreeMs Corp.}
set vendor(0004cb) {Tdsoft Communication, Ltd.}
set vendor(0004cc) {Peek Traffic B.V.}
set vendor(0004cd) {Informedia Research Group}
set vendor(0004ce) {Patria Ailon}
set vendor(0004cf) {Seagate Technology}
set vendor(00040d) {Avaya, Inc.}
set vendor(0004d0) {Softlink s.r.o.}
set vendor(0004d1) {Drew Technologies, Inc.}
set vendor(0004d2) {Adcon Telemetry AG}
set vendor(0004d3) {Toyokeiki Co., Ltd.}
set vendor(0004d4) {Proview Electronics Co., Ltd.}
set vendor(0004d5) {Hitachi Communication Systems, Inc.}
set vendor(0004d6) {Takagi Industrial Co., Ltd.}
set vendor(0004d7) {Omitec Instrumentation Ltd.}
set vendor(0004d8) {IPWireless, Inc.}
set vendor(0004d9) {Titan Electronics, Inc.}
set vendor(0004da) {Relax Technology, Inc.}
set vendor(0004db) {Tellus Group Corp.}
set vendor(0004dc) {Nortel Networks}
set vendor(0004dd) {Cisco Systems, Inc.}
set vendor(0004de) {Cisco Systems, Inc.}
set vendor(0004df) {Teracom Telematica Ltda.}
set vendor(00040e) {AVM GmbH}
set vendor(0004e0) {Procket Networks}
set vendor(0004e1) {Infinior Microsystems}
set vendor(0004e2) {SMC Networks, Inc.}
set vendor(0004e3) {Accton Technology Corp.}
set vendor(0004e4) {Daeryung Ind., Inc.}
set vendor(0004e5) {Glonet Systems, Inc.}
set vendor(0004e6) {Banyan Network Private Limited}
set vendor(0004e7) {Lightpointe Communications, Inc}
set vendor(0004e8) {IER, Inc.}
set vendor(0004e9) {Infiniswitch Corporation}
set vendor(0004ea) {Hewlett-Packard Company}
set vendor(0004eb) {Paxonet Communications, Inc.}
set vendor(0004ec) {Memobox SA}
set vendor(0004ed) {Billion Electric Co., Ltd.}
set vendor(0004ee) {Lincoln Electric Company}
set vendor(0004ef) {Polestar Corp.}
set vendor(00040f) {Asus Network Technologies, Inc.}
set vendor(0004f0) {International Computers, Ltd}
set vendor(0004f1) {WhereNet}
set vendor(0004f2) {Circa Communications, Ltd.}
set vendor(0004f3) {FS FORTH-SYSTEME GmbH}
set vendor(0004f4) {Infinite Electronics Inc.}
set vendor(0004f5) {SnowShore Networks, Inc.}
set vendor(0004f6) {Amphus}
set vendor(0004f7) {Omega Band, Inc.}
set vendor(0004f8) {QUALICABLE TV Industria E Com., Ltda}
set vendor(0004f9) {Xtera Communications, Inc.}
set vendor(0004fa) {MIST Inc.}
set vendor(0004fb) {Commtech, Inc.}
set vendor(0004fc) {Stratus Computer (DE), Inc.}
set vendor(0004fd) {Japan Control Engineering Co., Ltd.}
set vendor(0004fe) {Pelago Networks}
set vendor(0004ff) {Acronet Co., Ltd.}
set vendor(004f49) {Realtek}
set vendor(004f4b) {Pine Technology Ltd.}
set vendor(005000) {NEXO COMMUNICATIONS, INC.}
set vendor(005001) {YAMASHITA SYSTEMS CORP.}
set vendor(005010) {NovaNET Learning, Inc.}
set vendor(005012) {CBL - GMBH}
set vendor(005013) {Chaparral Network Storage}
set vendor(005014) {CISCO SYSTEMS, INC.}
set vendor(005015) {BRIGHT STAR ENGINEERING}
set vendor(005016) {SST/WOODHEAD INDUSTRIES}
set vendor(005017) {RSR S.R.L.}
set vendor(005018) {ADVANCED MULTIMEDIA INTERNET TECHNOLOGY INC.}
set vendor(005019) {SPRING TIDE NETWORKS, INC.}
set vendor(00501a) {UISIQN}
set vendor(00501b) {ABL CANADA, INC.}
set vendor(00501c) {JATOM SYSTEMS, INC.}
set vendor(00501e) {Miranda Technologies, Inc.}
set vendor(00501f) {MRG SYSTEMS, LTD.}
set vendor(005002) {OMNISEC AG}
set vendor(005020) {MEDIASTAR CO., LTD.}
set vendor(005021) {EIS INTERNATIONAL, INC.}
set vendor(005022) {ZONET TECHNOLOGY, INC.}
set vendor(005023) {PG DESIGN ELECTRONICS, INC.}
set vendor(005024) {NAVIC SYSTEMS, INC.}
set vendor(005026) {COSYSTEMS, INC.}
set vendor(005027) {GENICOM CORPORATION}
set vendor(005028) {AVAL COMMUNICATIONS}
set vendor(005029) {1394 PRINTER WORKING GROUP}
set vendor(00502a) {CISCO SYSTEMS, INC.}
set vendor(00502b) {GENRAD LTD.}
set vendor(00502c) {SOYO COMPUTER, INC.}
set vendor(00502d) {ACCEL, INC.}
set vendor(00502e) {CAMBEX CORPORATION}
set vendor(00502f) {TollBridge Technologies, Inc.}
set vendor(005003) {GRETAG MACBETH AG}
set vendor(005030) {FUTURE PLUS SYSTEMS}
set vendor(005031) {AEROFLEX LABORATORIES, INC.}
set vendor(005032) {PICAZO COMMUNICATIONS, INC.}
set vendor(005033) {MAYAN NETWORKS}
set vendor(005036) {NETCAM, LTD.}
set vendor(005037) {KOGA ELECTRONICS CO.}
set vendor(005038) {DAIN TELECOM CO., LTD.}
set vendor(005039) {MARINER NETWORKS}
set vendor(00503a) {DATONG ELECTRONICS LTD.}
set vendor(00503b) {MEDIAFIRE CORPORATION}
set vendor(00503c) {TSINGHUA NOVEL ELECTRONICS}
set vendor(00503e) {CISCO SYSTEMS, INC.}
set vendor(00503f) {ANCHOR GAMES}
set vendor(005004) {3COM CORPORATION}
set vendor(005040) {EMWARE, INC.}
set vendor(005041) {CTX OPTO ELECTRONIC CORP.}
set vendor(005042) {SCI MANUFACTURING SINGAPORE PTE, LTD.}
set vendor(005043) {MARVELL SEMICONDUCTOR, INC.}
set vendor(005044) {ASACA CORPORATION}
set vendor(005045) {RIOWORKS SOLUTIONS, INC.}
set vendor(005046) {MENICX INTERNATIONAL CO., LTD.}
set vendor(005048) {INFOLIBRIA}
set vendor(005049) {ELLACOYA NETWORKS, INC.}
set vendor(00504a) {ELTECO A.S.}
set vendor(00504b) {BARCONET N.V.}
set vendor(00504c) {GALIL MOTION CONTROL, INC.}
set vendor(00504d) {TOKYO ELECTRON DEVICE LTD.}
set vendor(00504e) {SIERRA MONITOR CORP.}
set vendor(00504f) {OLENCOM ELECTRONICS}
set vendor(005050) {CISCO SYSTEMS, INC.}
set vendor(005051) {IWATSU ELECTRIC CO., LTD.}
set vendor(005052) {TIARA NETWORKS, INC.}
set vendor(005053) {CISCO SYSTEMS, INC.}
set vendor(005054) {CISCO SYSTEMS, INC.}
set vendor(005055) {DOMS A/S}
set vendor(005056) {VMWare, Inc.}
set vendor(005057) {BROADBAND ACCESS SYSTEMS}
set vendor(005058) {VEGASTREAM LIMITED}
set vendor(005059) {SUITE TECHNOLOGY SYSTEMS NETWORK}
set vendor(00505a) {NETWORK ALCHEMY, INC.}
set vendor(00505b) {KAWASAKI LSI U.S.A., INC.}
set vendor(00505c) {TUNDO CORPORATION}
set vendor(00505e) {DIGITEK MICROLOGIC S.A.}
set vendor(00505f) {BRAND INNOVATORS}
set vendor(005006) {TAC AB}
set vendor(005060) {TANDBERG TELECOM AS}
set vendor(005062) {KOUWELL ELECTRONICS CORP.  **}
set vendor(005063) {OY COMSEL SYSTEM AB}
set vendor(005064) {CAE ELECTRONICS}
set vendor(005065) {DENSEI-LAMBAD Co., Ltd.}
set vendor(005066) {AtecoM GmbH advanced telecomunication modules}
set vendor(005067) {AEROCOMM, INC.}
set vendor(005068) {ELECTRONIC INDUSTRIES ASSOCIATION}
set vendor(005069) {PixStream Incorporated}
set vendor(00506a) {EDEVA, INC.}
set vendor(00506b) {SPX-ATEG}
set vendor(00506c) {G & L BEIJER ELECTRONICS AB}
set vendor(00506d) {VIDEOJET SYSTEMS}
set vendor(00506e) {CORDER ENGINEERING CORPORATION}
set vendor(00506f) {G-CONNECT}
set vendor(005007) {SIEMENS TELECOMMUNICATION SYSTEMS LIMITED}
set vendor(005070) {CHAINTECH COMPUTER CO., LTD.}
set vendor(005071) {AIWA CO., LTD.}
set vendor(005072) {CORVIS CORPORATION}
set vendor(005073) {CISCO SYSTEMS, INC.}
set vendor(005074) {ADVANCED HI-TECH CORP.}
set vendor(005075) {KESTREL SOLUTIONS}
set vendor(005076) {IBM}
set vendor(005077) {PROLIFIC TECHNOLOGY, INC.}
set vendor(005078) {MEGATON HOUSE, LTD.}
set vendor(00507a) {XPEED, INC.}
set vendor(00507b) {MERLOT COMMUNICATIONS}
set vendor(00507c) {VIDEOCON AG}
set vendor(00507d) {IFP}
set vendor(00507e) {NEWER TECHNOLOGY}
set vendor(00507f) {DrayTek Corp.}
set vendor(005008) {TIVA MICROCOMPUTER CORP. (TMC)}
set vendor(005080) {CISCO SYSTEMS, INC.}
set vendor(005081) {MURATA MACHINERY, LTD.}
set vendor(005082) {FORESSON CORPORATION}
set vendor(005083) {GILBARCO, INC.}
set vendor(005084) {ATL PRODUCTS}
set vendor(005086) {TELKOM SA, LTD.}
set vendor(005087) {TERASAKI ELECTRIC CO., LTD.}
set vendor(005088) {AMANO CORPORATION}
set vendor(005089) {SAFETY MANAGEMENT SYSTEMS}
set vendor(00508b) {COMPAQ COMPUTER CORPORATION}
set vendor(00508c) {RSI SYSTEMS}
set vendor(00508d) {ABIT COMPUTER CORPORATION}
set vendor(00508e) {OPTIMATION, INC.}
set vendor(00508f) {ASITA TECHNOLOGIES INT'L LTD.}
set vendor(005009) {PHILIPS BROADBAND NETWORKS}
set vendor(005090) {DCTRI}
set vendor(005091) {NETACCESS, INC.}
set vendor(005092) {RIGAKU INDUSTRIAL CORPORATION}
set vendor(005093) {BOEING}
set vendor(005094) {PACE MICRO TECHNOLOGY PLC}
set vendor(005095) {PERACOM NETWORKS}
set vendor(005096) {SALIX TECHNOLOGIES, INC.}
set vendor(005097) {MMC-EMBEDDED COMPUTERTECHNIK GmbH}
set vendor(005098) {GLOBALOOP, LTD.}
set vendor(005099) {3COM EUROPE, LTD.}
set vendor(00509a) {TAG ELECTRONIC SYSTEMS}
set vendor(00509b) {SWITCHCORE AB}
set vendor(00509c) {BETA RESEARCH}
set vendor(00509d) {THE INDUSTREE B.V.}
set vendor(00509e) {Les Technologies SoftAcoustik Inc.}
set vendor(00509f) {HORIZON COMPUTER}
set vendor(00500a) {IRIS TECHNOLOGIES, INC.}
set vendor(0050a0) {DELTA COMPUTER SYSTEMS, INC.}
set vendor(0050a1) {CARLO GAVAZZI, INC.}
set vendor(0050a2) {CISCO SYSTEMS, INC.}
set vendor(0050a3) {TransMedia Communications, Inc.}
set vendor(0050a4) {IO TECH, INC.}
set vendor(0050a5) {CAPITOL BUSINESS SYSTEMS, LTD.}
set vendor(0050a6) {OPTRONICS}
set vendor(0050a7) {CISCO SYSTEMS, INC.}
set vendor(0050a8) {OpenCon Systems, Inc.}
set vendor(0050a9) {MOLDAT WIRELESS TECHNOLGIES}
set vendor(0050aa) {KONICA MINOLTA HOLDINGS, INC.}
set vendor(0050ab) {NALTEC, INC.}
set vendor(0050ac) {MAPLE COMPUTER CORPORATION}
set vendor(0050ad) {CommUnique Wireless Corp.}
set vendor(0050ae) {IWAKI ELECTRONICS CO., LTD.}
set vendor(0050af) {INTERGON, INC.}
set vendor(00500b) {CISCO SYSTEMS, INC.}
set vendor(0050b0) {TECHNOLOGY ATLANTA CORPORATION}
set vendor(0050b1) {GIDDINGS & LEWIS}
set vendor(0050b2) {BRODEL AUTOMATION}
set vendor(0050b3) {VOICEBOARD CORPORATION}
set vendor(0050b4) {SATCHWELL CONTROL SYSTEMS, LTD}
set vendor(0050b5) {FICHET-BAUCHE}
set vendor(0050b6) {GOOD WAY IND. CO., LTD.}
set vendor(0050b7) {BOSER TECHNOLOGY CO., LTD.}
set vendor(0050b8) {INOVA COMPUTERS GMBH & CO. KG}
set vendor(0050b9) {XITRON TECHNOLOGIES, INC.}
set vendor(0050ba) {D-LINK}
set vendor(0050bb) {CMS TECHNOLOGIES}
set vendor(0050bc) {HAMMER STORAGE SOLUTIONS}
set vendor(0050bd) {CISCO SYSTEMS, INC.}
set vendor(0050be) {FAST MULTIMEDIA AG}
set vendor(0050bf) {MOTOTECH INC.}
set vendor(00500c) {e-Tek Labs, Inc.}
set vendor(0050c0) {GATAN, INC.}
set vendor(0050c1) {GEMFLEX NETWORKS, LTD.}
set vendor(0050c2) {IEEE REGISTRATION AUTHORITY}
set vendor(0050c4) {IMD}
set vendor(0050c5) {ADS TECHNOLOGIES, INC.}
set vendor(0050c6) {LOOP TELECOMMUNICATION INTERNATIONAL, INC.}
set vendor(0050c8) {ADDONICS COMMUNICATIONS, INC.}
set vendor(0050c9) {MASPRO DENKOH CORP.}
set vendor(0050ca) {NET TO NET TECHNOLOGIES}
set vendor(0050cb) {JETTER}
set vendor(0050cc) {XYRATEX}
set vendor(0050cd) {DIGIANSWER A/S}
set vendor(0050ce) {LG INTERNATIONAL CORP.}
set vendor(0050cf) {VANLINK COMMUNICATION TECHNOLOGY RESEARCH INSTITUTE}
set vendor(00500d) {SATORI ELECTORIC CO., LTD.}
set vendor(0050d0) {MINERVA SYSTEMS}
set vendor(0050d1) {CISCO SYSTEMS, INC.}
set vendor(0050d2) {BAE Systems Canada, Inc.}
set vendor(0050d3) {DIGITAL AUDIO PROCESSING PTY. LTD.}
set vendor(0050d4) {JOOHONG INFORMATION &}
set vendor(0050d5) {AD SYSTEMS CORP.}
set vendor(0050d6) {ATLAS COPCO TOOLS AB}
set vendor(0050d7) {TELSTRAT}
set vendor(0050d8) {UNICORN COMPUTER CORP.}
set vendor(0050d9) {ENGETRON-ENGENHARIA ELETRONICA IND. e COM. LTDA}
set vendor(0050da) {3COM CORPORATION}
set vendor(0050db) {CONTEMPORARY CONTROL}
set vendor(0050dc) {TAS TELEFONBAU A. SCHWABE GMBH & CO. KG}
set vendor(0050dd) {SERRA SOLDADURA, S.A.}
set vendor(0050de) {SIGNUM SYSTEMS CORP.}
set vendor(0050df) {AirFiber, Inc.}
set vendor(00500e) {CHROMATIS NETWORKS, INC.}
set vendor(0050e1) {NS TECH ELECTRONICS SDN BHD}
set vendor(0050e2) {CISCO SYSTEMS, INC.}
set vendor(0050e3) {Terayon Communications Systems}
set vendor(0050e4) {APPLE COMPUTER, INC.}
set vendor(0050e6) {HAKUSAN CORPORATION}
set vendor(0050e7) {PARADISE INNOVATIONS (ASIA)}
set vendor(0050e8) {NOMADIX INC.}
set vendor(0050ea) {XEL COMMUNICATIONS, INC.}
set vendor(0050eb) {ALPHA-TOP CORPORATION}
set vendor(0050ec) {OLICOM A/S}
set vendor(0050ed) {ANDA NETWORKS}
set vendor(0050ee) {TEK DIGITEL CORPORATION}
set vendor(0050ef) {SPE Systemhaus GmbH}
set vendor(00500f) {CISCO SYSTEMS, INC.}
set vendor(0050f0) {CISCO SYSTEMS, INC.}
set vendor(0050f1) {LIBIT SIGNAL PROCESSING, LTD.}
set vendor(0050f2) {MICROSOFT CORP.}
set vendor(0050f3) {GLOBAL NET INFORMATION CO., Ltd.}
set vendor(0050f4) {SIGMATEK GMBH & CO. KG}
set vendor(0050f6) {PAN-INTERNATIONAL INDUSTRIAL CORP.}
set vendor(0050f7) {VENTURE MANUFACTURING (SINGAPORE) LTD.}
set vendor(0050f8) {ENTREGA TECHNOLOGIES, INC.}
set vendor(0050fa) {OXTEL, LTD.}
set vendor(0050fb) {VSK ELECTRONICS}
set vendor(0050fc) {EDIMAX TECHNOLOGY CO., LTD.}
set vendor(0050fd) {VISIONCOMM CO., LTD.}
set vendor(0050fe) {PCTVnet ASA}
set vendor(0050ff) {HAKKO ELECTRONICS CO., LTD.}
set vendor(005500) {Xerox}
set vendor(000500) {Cisco Systems, Inc.}
set vendor(000501) {Cisco Systems, Inc.}
set vendor(000510) {Infinite Shanghai Communication Terminals Ltd.}
set vendor(000511) {Complementary Technologies Ltd}
set vendor(000512) {MeshNetworks, Inc.}
set vendor(000513) {VTLinx Multimedia Systems, Inc.}
set vendor(000514) {KDT Systems Co., Ltd.}
set vendor(000515) {Nuark Co., Ltd.}
set vendor(000516) {SMART Modular Technologies}
set vendor(000517) {Shellcomm, Inc.}
set vendor(000518) {Jupiters Technology}
set vendor(000519) {Siemens Building Technologies AG,}
set vendor(00051a) {3Com Europe Ltd.}
set vendor(00051b) {Magic Control Technology Corporation}
set vendor(00051c) {Xnet Technology Corp.}
set vendor(00051d) {Airocon, Inc.}
set vendor(00051e) {Brocade Communications Systems, Inc.}
set vendor(00051f) {Taijin Media Co., Ltd.}
set vendor(000502) {APPLE COMPUTER}
set vendor(000520) {Smartronix, Inc.}
set vendor(000521) {Control Microsystems}
set vendor(000522) {LEA*D Corporation, Inc.}
set vendor(000523) {AVL List GmbH}
set vendor(000524) {BTL System (HK) Limited}
set vendor(000525) {Puretek Industrial Co., Ltd.}
set vendor(000526) {IPAS GmbH}
set vendor(000527) {SJ Tek Co. Ltd}
set vendor(000528) {New Focus, Inc.}
set vendor(000529) {Shanghai Broadan Communication Technology Co., Ltd}
set vendor(00052a) {Ikegami Tsushinki Co., Ltd.}
set vendor(00052b) {HORIBA, Ltd.}
set vendor(00052c) {Supreme Magic Corporation}
set vendor(00052d) {Zoltrix International Limited}
set vendor(00052e) {Cinta Networks}
set vendor(00052f) {Leviton Voice and Data}
set vendor(000503) {ICONAG}
set vendor(000530) {Andiamo Systems, Inc.}
set vendor(000531) {Cisco Systems, Inc.}
set vendor(000532) {Cisco Systems, Inc.}
set vendor(000533) {Sanera Systems, Inc.}
set vendor(000534) {Northstar Engineering Ltd.}
set vendor(000535) {Chip PC Ltd.}
set vendor(000536) {Danam Communications, Inc.}
set vendor(000537) {Nets Technology Co., Ltd.}
set vendor(000538) {Merilus, Inc.}
set vendor(000539) {A Brand New World in Sweden AB}
set vendor(00053a) {Willowglen Services Pte Ltd}
set vendor(00053b) {Harbour Networks Ltd., Co. Beijing}
set vendor(00053c) {Xircom}
set vendor(00053d) {Agere Systems}
set vendor(00053e) {KID Systeme GmbH}
set vendor(00053f) {VisionTek, Inc.}
set vendor(000504) {Naray Information & Communication Enterprise}
set vendor(000540) {FAST Corporation}
set vendor(000541) {Advanced Systems Co., Ltd.}
set vendor(000542) {Otari, Inc.}
set vendor(000543) {IQ Wireless GmbH}
set vendor(000544) {Valley Technologies, Inc.}
set vendor(000545) {Internet Photonics}
set vendor(000546) {K-Solutions Inc.}
set vendor(000547) {Starent Networks}
set vendor(000548) {Disco Corporation}
set vendor(000549) {Salira Optical Network Systems}
set vendor(00054a) {Ario Data Networks, Inc.}
set vendor(00054b) {Micro Innovation AG}
set vendor(00054c) {RF Innovations Pty Ltd}
set vendor(00054d) {Brans Technologies, Inc.}
set vendor(00054e) {Philips Components}
set vendor(000505) {Systems Integration Solutions, Inc.}
set vendor(000550) {Digi-Tech Communications Limited}
set vendor(000551) {F & S Elektronik Systeme GmbH}
set vendor(000552) {Xycotec Computer GmbH}
set vendor(000553) {DVC Company, Inc.}
set vendor(000554) {Rangestar Wireless}
set vendor(000555) {Japan Cash Machine Co., Ltd.}
set vendor(000556) {360 Systems}
set vendor(000557) {Agile TV Corporation}
set vendor(000558) {Synchronous, Inc.}
set vendor(000559) {Intracom S.A.}
set vendor(00055a) {Power Dsine Ltd.}
set vendor(00055b) {Charles Industries, Ltd.}
set vendor(00055c) {Kowa Company, Ltd.}
set vendor(00055d) {D-Link Systems, Inc.}
set vendor(00055e) {Cisco Systems, Inc.}
set vendor(00055f) {Cisco Systems, Inc.}
set vendor(000506) {Reddo Networks AB}
set vendor(000560) {LEADER COMM.CO., LTD}
set vendor(000561) {nac Image Technology, Inc.}
set vendor(000562) {Digital View Limited}
set vendor(000563) {J-Works, Inc.}
set vendor(000564) {Tsinghua Bitway Co., Ltd.}
set vendor(000565) {Tailyn Communication Company Ltd.}
set vendor(000566) {Secui.com Corporation}
set vendor(000567) {Etymonic Design, Inc.}
set vendor(000568) {Piltofish Networks AB}
set vendor(000569) {VMWARE, Inc.}
set vendor(00056a) {Heuft Systemtechnik GmbH}
set vendor(00056b) {C.P. Technology Co., Ltd.}
set vendor(00056c) {Hung Chang Co., Ltd.}
set vendor(00056d) {Pacific Corporation}
set vendor(00056e) {National Enhance Technology, Inc.}
set vendor(00056f) {Innomedia Technologies Pvt. Ltd.}
set vendor(000507) {Fine Appliance Corp.}
set vendor(000570) {Baydel Ltd.}
set vendor(000571) {Seiwa Electronics Co.}
set vendor(000572) {Deonet Co., Ltd.}
set vendor(000573) {Cisco Systems, Inc.}
set vendor(000574) {Cisco Systems, Inc.}
set vendor(000575) {CDS-Electronics BV}
set vendor(000576) {NSM Technology Ltd.}
set vendor(000577) {SM Information & Communication}
set vendor(000579) {Universal Control Solution Corp.}
set vendor(00057a) {Hatteras Networks}
set vendor(00057b) {Chung Nam Electronic Co., Ltd.}
set vendor(00057c) {RCO Security AB}
set vendor(00057d) {Sun Communications, Inc.}
set vendor(00057e) {Eckelmann Steuerungstechnik GmbH}
set vendor(00057f) {Acqis Technology}
set vendor(000508) {Inetcam, Inc.}
set vendor(000580) {Fibrolan Ltd.}
set vendor(000581) {Snell & Wilcox Ltd.}
set vendor(000582) {ClearCube Technology}
set vendor(000583) {ImageCom Limited}
set vendor(000584) {AbsoluteValue Systems, Inc.}
set vendor(000585) {Juniper Networks, Inc.}
set vendor(000586) {Lucent Technologies}
set vendor(000587) {Locus, Incorporated}
set vendor(000588) {Sensoria Corp.}
set vendor(000589) {National Datacomputer}
set vendor(00058a) {Netcom Co., Ltd.}
set vendor(00058b) {IPmental, Inc.}
set vendor(00058c) {Opentech Inc.}
set vendor(00058d) {Lynx Photonic Networks, Inc.}
set vendor(00058e) {Flextronics International GmbH & Co. Nfg. KG}
set vendor(00058f) {CLCsoft co.}
set vendor(000509) {AVOC Nishimura Ltd.}
set vendor(000590) {Swissvoice Ltd.}
set vendor(000591) {Active Silicon Ltd.}
set vendor(000592) {Pultek Corp.}
set vendor(000593) {Grammar Engine Inc.}
set vendor(000594) {IXXAT Automation GmbH}
set vendor(000595) {Alesis Corporation}
set vendor(000596) {Genotech Co., Ltd.}
set vendor(000597) {Eagle Traffic Control Systems}
set vendor(000598) {CRONOS S.r.l.}
set vendor(000599) {DRS Test and Energy Management or DRS-TEM}
set vendor(00059a) {Cisco Systems, Inc.}
set vendor(00059b) {Cisco Systems, Inc.}
set vendor(00059c) {Kleinknecht GmbH, Ing. Buero}
set vendor(00059d) {Daniel Computing Systems, Inc.}
set vendor(00059e) {Zinwell Corporation}
set vendor(00059f) {Yotta Networks, Inc.}
set vendor(00050a) {ICS Spa}
set vendor(0005a0) {MOBILINE Kft.}
set vendor(0005a1) {Zenocom}
set vendor(0005a2) {CELOX Networks}
set vendor(0005a3) {QEI, Inc.}
set vendor(0005a4) {Lucid Voice Ltd.}
set vendor(0005a5) {KOTT}
set vendor(0005a6) {Extron Electronics}
set vendor(0005a7) {Hyperchip, Inc.}
set vendor(0005a8) {WYLE ELECTRONICS}
set vendor(0005a9) {Princeton Networks, Inc.}
set vendor(0005aa) {Moore Industries International Inc.}
set vendor(0005ab) {Cyber Fone, Inc.}
set vendor(0005ac) {Northern Digital, Inc.}
set vendor(0005ad) {Topspin Communications, Inc.}
set vendor(0005ae) {Mediaport USA}
set vendor(0005af) {InnoScan Computing A/S}
set vendor(00050b) {SICOM Systems, Inc.}
set vendor(0005b0) {Korea Computer Technology Co., Ltd.}
set vendor(0005b1) {ASB Technology BV}
set vendor(0005b2) {Medison Co., Ltd.}
set vendor(0005b3) {Asahi-Engineering Co., Ltd.}
set vendor(0005b4) {Aceex Corporation}
set vendor(0005b5) {Broadcom Technologies}
set vendor(0005b6) {INSYS Microelectronics GmbH}
set vendor(0005b7) {Arbor Technology Corp.}
set vendor(0005b8) {Electronic Design Associates, Inc.}
set vendor(0005b9) {Airvana, Inc.}
set vendor(0005ba) {Area Netwoeks, Inc.}
set vendor(0005bb) {Myspace AB}
set vendor(0005bc) {Resorsys Ltd.}
set vendor(0005bd) {ROAX BV}
set vendor(0005be) {Kongsberg Seatex AS}
set vendor(0005bf) {JustEzy Technology, Inc.}
set vendor(00050c) {Network Photonics, Inc.}
set vendor(0005c0) {Digital Network Alacarte Co., Ltd.}
set vendor(0005c1) {A-Kyung Motion, Inc.}
set vendor(0005c2) {Soronti, Inc.}
set vendor(0005c3) {Pacific Instruments, Inc.}
set vendor(0005c4) {Telect, Inc.}
set vendor(0005c5) {Flaga HF}
set vendor(0005c6) {Triz Communications}
set vendor(0005c7) {I/F-COM A/S}
set vendor(0005c8) {VERYTECH}
set vendor(0005c9) {LG Innotek}
set vendor(0005ca) {Hitron Technology, Inc.}
set vendor(0005cb) {ROIS Technologies, Inc.}
set vendor(0005cc) {Sumtel Communications, Inc.}
set vendor(0005cd) {Denon, Ltd.}
set vendor(0005ce) {Prolink Microsystems Corporation}
set vendor(0005cf) {Thunder River Technologies, Inc.}
set vendor(00050d) {Midstream Technologies, Inc.}
set vendor(0005d0) {Solinet Systems}
set vendor(0005d1) {Metavector Technologies}
set vendor(0005d2) {DAP Technologies}
set vendor(0005d3) {eProduction Solutions, Inc.}
set vendor(0005d4) {FutureSmart Networks, Inc.}
set vendor(0005d5) {Speedcom Wireless}
set vendor(0005d6) {Titan Wireless}
set vendor(0005d7) {Vista Imaging, Inc.}
set vendor(0005d8) {Arescom, Inc.}
set vendor(0005d9) {Techno Valley, Inc.}
set vendor(0005da) {Apex Automationstechnik}
set vendor(0005db) {Nentec GmbH}
set vendor(0005dc) {Cisco Systems, Inc.}
set vendor(0005dd) {Cisco Systems, Inc.}
set vendor(0005de) {Gi Fone Korea, Inc.}
set vendor(0005df) {Electronic Innovation, Inc.}
set vendor(00050e) {3ware, Inc.}
set vendor(0005e0) {Empirix Corp.}
set vendor(0005e1) {Trellis Photonics, Ltd.}
set vendor(0005e2) {Creativ Network Technologies}
set vendor(0005e3) {LightSand Communications, Inc.}
set vendor(0005e4) {Red Lion Controls L.P.}
set vendor(0005e5) {Renishaw PLC}
set vendor(0005e6) {Egenera, Inc.}
set vendor(0005e7) {Netrake Corp.}
set vendor(0005e8) {TurboWave, Inc.}
set vendor(0005e9) {Unicess Network, Inc.}
set vendor(0005ea) {Rednix}
set vendor(0005eb) {Blue Ridge Networks, Inc.}
set vendor(0005ec) {Mosaic Systems Inc.}
set vendor(0005ed) {Technikum Joanneum GmbH}
set vendor(0005ee) {BEWATOR Group}
set vendor(0005ef) {ADOIR Digital Technology}
set vendor(00050f) {Tanaka S/S Ltd.}
set vendor(0005f0) {SATEC}
set vendor(0005f1) {Vrcom, Inc.}
set vendor(0005f2) {Power R, Inc.}
set vendor(0005f3) {Weboyn}
set vendor(0005f4) {System Base Co., Ltd.}
set vendor(0005f5) {OYO Geospace Corp.}
set vendor(0005f6) {Young Chang Co. Ltd.}
set vendor(0005f7) {Analog Devices, Inc.}
set vendor(0005f8) {Real Time Access, Inc.}
set vendor(0005f9) {TOA Corporation}
set vendor(0005fa) {IPOptical, Inc.}
set vendor(0005fb) {ShareGate, Inc.}
set vendor(0005fc) {Schenck Pegasus Corp.}
set vendor(0005fd) {PacketLight Networks Ltd.}
set vendor(0005fe) {Traficon N.V.}
set vendor(0005ff) {SNS Solutions, Inc.}
set vendor(006000) {XYCOM INC.}
set vendor(006001) {InnoSys, Inc.}
set vendor(006010) {NETWORK MACHINES, INC.}
set vendor(006011) {CRYSTAL SEMICONDUCTOR CORP.}
set vendor(006012) {POWER COMPUTING CORPORATION}
set vendor(006013) {NETSTAL MASCHINEN AG}
set vendor(006014) {EDEC CO., LTD.}
set vendor(006015) {NET2NET CORPORATION}
set vendor(006016) {CLARIION}
set vendor(006017) {TOKIMEC INC.}
set vendor(006018) {STELLAR ONE CORPORATION}
set vendor(006019) {Roche Diagnostics}
set vendor(00601a) {KEITHLEY INSTRUMENTS}
set vendor(00601b) {MESA ELECTRONICS}
set vendor(00601c) {TELXON CORPORATION}
set vendor(00601d) {LUCENT TECHNOLOGIES}
set vendor(00601e) {SOFTLAB, INC.}
set vendor(00601f) {STALLION TECHNOLOGIES}
set vendor(006002) {SCREEN SUBTITLING SYSTEMS, LTD}
set vendor(006020) {PIVOTAL NETWORKING, INC.}
set vendor(006021) {DSC CORPORATION}
set vendor(006022) {VICOM SYSTEMS, INC.}
set vendor(006023) {PERICOM SEMICONDUCTOR CORP.}
set vendor(006024) {GRADIENT TECHNOLOGIES, INC.}
set vendor(006025) {ACTIVE IMAGING PLC}
set vendor(006026) {VIKING COMPONENTS, INC.}
set vendor(006027) {Superior Modular Products}
set vendor(006028) {MACROVISION CORPORATION}
set vendor(006029) {CARY PERIPHERALS INC.}
set vendor(00602a) {SYMICRON COMPUTER COMMUNICATIONS, LTD.}
set vendor(00602b) {PEAK AUDIO}
set vendor(00602c) {LINX Data Terminals, Inc.}
set vendor(00602d) {ALERTON TECHNOLOGIES, INC.}
set vendor(00602e) {CYCLADES CORPORATION}
set vendor(00602f) {CISCO SYSTEMS, INC.}
set vendor(006003) {TERAOKA WEIGH SYSTEM PTE, LTD.}
set vendor(006030) {VILLAGE TRONIC ENTWICKLUNG}
set vendor(006031) {HRK SYSTEMS}
set vendor(006032) {I-CUBE, INC.}
set vendor(006033) {ACUITY IMAGING, INC.}
set vendor(006034) {ROBERT BOSCH GmbH}
set vendor(006035) {DALLAS SEMICONDUCTOR, INC.}
set vendor(006036) {AUSTRIAN RESEARCH CENTER SEIBERSDORF}
set vendor(006037) {PHILIPS SEMICONDUCTORS}
set vendor(006038) {Nortel Networks}
set vendor(006039) {SanCom Technology, Inc.}
set vendor(00603a) {QUICK CONTROLS LTD.}
set vendor(00603b) {AMTEC spa}
set vendor(00603c) {HAGIWARA SYS-COM CO., LTD.}
set vendor(00603d) {3CX}
set vendor(00603e) {CISCO SYSTEMS, INC.}
set vendor(00603f) {PATAPSCO DESIGNS}
set vendor(006004) {COMPUTADORES MODULARES SA}
set vendor(006040) {NETRO CORP.}
set vendor(006041) {Yokogawa Electric Corporation}
set vendor(006042) {TKS (USA), INC.}
set vendor(006043) {ComSoft Systems, Inc.}
set vendor(006044) {LITTON/POLY-SCIENTIFIC}
set vendor(006045) {PATHLIGHT TECHNOLOGIES}
set vendor(006046) {VMETRO, INC.}
set vendor(006047) {CISCO SYSTEMS, INC.}
set vendor(006048) {EMC CORPORATION}
set vendor(006049) {VINA TECHNOLOGIES}
set vendor(00604a) {SAIC IDEAS GROUP}
set vendor(00604b) {BIODATA GmbH}
set vendor(00604c) {SAT}
set vendor(00604d) {MMC NETWORKS, INC.}
set vendor(00604e) {CYCLE COMPUTER CORPORATION, INC.}
set vendor(00604f) {SUZUKI MFG. CO., LTD.}
set vendor(006005) {FEEDBACK DATA LTD.}
set vendor(006050) {INTERNIX INC.}
set vendor(006051) {QUALITY SEMICONDUCTOR}
set vendor(006052) {PERIPHERALS ENTERPRISE CO., Ltd.}
set vendor(006053) {TOYODA MACHINE WORKS, LTD.}
set vendor(006054) {CONTROLWARE GMBH}
set vendor(006055) {CORNELL UNIVERSITY}
set vendor(006056) {NETWORK TOOLS, INC.}
set vendor(006057) {MURATA MANUFACTURING CO., LTD.}
set vendor(006058) {COPPER MOUNTAIN COMMUNICATIONS, INC.}
set vendor(006059) {TECHNICAL COMMUNICATIONS CORP.}
set vendor(00605a) {CELCORE, INC.}
set vendor(00605b) {IntraServer Technology, Inc.}
set vendor(00605c) {CISCO SYSTEMS, INC.}
set vendor(00605d) {SCANIVALVE CORP.}
set vendor(00605e) {LIBERTY TECHNOLOGY NETWORKING}
set vendor(00605f) {NIPPON UNISOFT CORPORATION}
set vendor(006006) {SOTEC CO., LTD}
set vendor(006060) {DAWNING TECHNOLOGIES, INC.}
set vendor(006061) {WHISTLE COMMUNICATIONS CORP.}
set vendor(006062) {TELESYNC, INC.}
set vendor(006063) {PSION DACOM PLC.}
set vendor(006064) {NETCOMM LIMITED}
set vendor(006065) {BERNECKER & RAINER INDUSTRIE-ELEKTRONIC GmbH}
set vendor(006066) {LACROIX TECHNOLGIE}
set vendor(006067) {ACER NETXUS INC.}
set vendor(006068) {EICON TECHNOLOGY CORPORATION}
set vendor(006069) {BROCADE COMMUNICATIONS SYSTEMS, Inc.}
set vendor(00606a) {MITSUBISHI WIRELESS COMMUNICATIONS. INC.}
set vendor(00606b) {Synclayer Inc.}
set vendor(00606c) {ARESCOM}
set vendor(00606d) {DIGITAL EQUIPMENT CORP.}
set vendor(00606e) {DAVICOM SEMICONDUCTOR, INC.}
set vendor(00606f) {CLARION CORPORATION OF AMERICA}
set vendor(006007) {ACRES GAMING, INC.}
set vendor(006070) {CISCO SYSTEMS, INC.}
set vendor(006071) {MIDAS LAB, INC.}
set vendor(006072) {VXL INSTRUMENTS, LIMITED}
set vendor(006073) {REDCREEK COMMUNICATIONS, INC.}
set vendor(006074) {QSC AUDIO PRODUCTS}
set vendor(006075) {PENTEK, INC.}
set vendor(006076) {SCHLUMBERGER TECHNOLOGIES RETAIL PETROLEUM SYSTEMS}
set vendor(006077) {PRISA NETWORKS}
set vendor(006078) {POWER MEASUREMENT LTD.}
set vendor(006079) {Mainstream Data, Inc.}
set vendor(00607a) {DVS GmbH}
set vendor(00607b) {FORE SYSTEMS, INC.}
set vendor(00607c) {WaveAccess, Ltd.}
set vendor(00607d) {SENTIENT NETWORKS INC.}
set vendor(00607e) {GIGALABS, INC.}
set vendor(00607f) {AURORA TECHNOLOGIES, INC.}
set vendor(006008) {3COM CORPORATION}
set vendor(006080) {MICROTRONIX DATACOM LTD.}
set vendor(006081) {TV/COM INTERNATIONAL}
set vendor(006082) {NOVALINK TECHNOLOGIES, INC.}
set vendor(006083) {CISCO SYSTEMS, INC.}
set vendor(006084) {DIGITAL VIDEO}
set vendor(006085) {Storage Concepts}
set vendor(006086) {LOGIC REPLACEMENT TECH. LTD.}
set vendor(006087) {KANSAI ELECTRIC CO., LTD.}
set vendor(006088) {WHITE MOUNTAIN DSP, INC.}
set vendor(006089) {XATA}
set vendor(00608a) {CITADEL COMPUTER}
set vendor(00608b) {ConferTech International}
set vendor(00608c) {3COM CORPORATION}
set vendor(00608d) {UNIPULSE CORP.}
set vendor(00608e) {HE ELECTRONICS, TECHNOLOGIE & SYSTEMTECHNIK GmbH}
set vendor(00608f) {TEKRAM TECHNOLOGY CO., LTD.}
set vendor(006009) {CISCO SYSTEMS, INC.}
set vendor(006090) {ABLE COMMUNICATIONS, INC.}
set vendor(006091) {FIRST PACIFIC NETWORKS, INC.}
set vendor(006092) {MICRO/SYS, INC.}
set vendor(006093) {VARIAN}
set vendor(006094) {IBM CORP.}
set vendor(006095) {ACCU-TIME SYSTEMS, INC.}
set vendor(006096) {T.S. MICROTECH INC.}
set vendor(006097) {3COM CORPORATION}
set vendor(006098) {HT COMMUNICATIONS}
set vendor(006099) {LAN MEDIA CORPORATION}
set vendor(00609a) {NJK TECHNO CO.}
set vendor(00609b) {ASTRO-MED, INC.}
set vendor(00609c) {Perkin-Elmer Incorporated}
set vendor(00609d) {PMI FOOD EQUIPMENT GROUP}
set vendor(00609e) {ASC X3 - INFORMATION TECHNOLOGY STANDARDS SECRETARIATS}
set vendor(00609f) {PHAST CORPORATION}
set vendor(00600a) {SORD COMPUTER CORPORATION}
set vendor(0060a0) {SWITCHED NETWORK TECHNOLOGIES, INC.}
set vendor(0060a1) {VPNet, Inc.}
set vendor(0060a2) {NIHON UNISYS LIMITED CO.}
set vendor(0060a3) {CONTINUUM TECHNOLOGY CORP.}
set vendor(0060a4) {GRINAKER SYSTEM TECHNOLOGIES}
set vendor(0060a5) {PERFORMANCE TELECOM CORP.}
set vendor(0060a6) {PARTICLE MEASURING SYSTEMS}
set vendor(0060a7) {MICROSENS GmbH & CO. KG}
set vendor(0060a8) {TIDOMAT AB}
set vendor(0060a9) {GESYTEC MbH}
set vendor(0060aa) {INTELLIGENT DEVICES INC. (IDI)}
set vendor(0060ab) {LARSCOM INCORPORATED}
set vendor(0060ac) {RESILIENCE CORPORATION}
set vendor(0060ad) {MegaChips Corporation}
set vendor(0060ae) {TRIO INFORMATION SYSTEMS AB}
set vendor(0060af) {PACIFIC MICRO DATA, INC.}
set vendor(00600b) {LOGWARE GmbH}
set vendor(0060b0) {HEWLETT-PACKARD CO.}
set vendor(0060b1) {INPUT/OUTPUT, INC.}
set vendor(0060b2) {PROCESS CONTROL CORP.}
set vendor(0060b3) {Z-COM, INC.}
set vendor(0060b4) {GLENAYRE R&D INC.}
set vendor(0060b5) {KEBA GmbH}
set vendor(0060b6) {LAND COMPUTER CO., LTD.}
set vendor(0060b7) {CHANNELMATIC, INC.}
set vendor(0060b8) {CORELIS INC.}
set vendor(0060b9) {NITSUKO CORPORATION}
set vendor(0060ba) {SAHARA NETWORKS, INC.}
set vendor(0060bb) {CABLETRON - NETLINK, INC.}
set vendor(0060bc) {KeunYoung Electronics & Communication Co., Ltd.}
set vendor(0060bd) {HUBBELL-PULSECOM}
set vendor(0060be) {WEBTRONICS}
set vendor(0060bf) {MACRAIGOR SYSTEMS, INC.}
set vendor(00600c) {APPLIED DATA SYSTEMS, INC.}
set vendor(0060c0) {NERA AS}
set vendor(0060c1) {WaveSpan Corporation}
set vendor(0060c2) {MPL AG}
set vendor(0060c3) {NETVISION CORPORATION}
set vendor(0060c4) {SOLITON SYSTEMS K.K.}
set vendor(0060c5) {ANCOT CORP.}
set vendor(0060c6) {DCS AG}
set vendor(0060c7) {AMATI COMMUNICATIONS CORP.}
set vendor(0060c8) {KUKA WELDING SYSTEMS & ROBOTS}
set vendor(0060c9) {ControlNet, Inc.}
set vendor(0060ca) {HARMONIC SYSTEMS INCORPORATED}
set vendor(0060cb) {HITACHI ZOSEN CORPORATION}
set vendor(0060cc) {EMTRAK, INCORPORATED}
set vendor(0060cd) {VideoServer, Inc.}
set vendor(0060ce) {ACCLAIM COMMUNICATIONS}
set vendor(0060cf) {ALTEON NETWORKS, INC.}
set vendor(00600d) {Digital Logic GmbH}
set vendor(0060d0) {SNMP RESEARCH INCORPORATED}
set vendor(0060d1) {CASCADE COMMUNICATIONS}
set vendor(0060d2) {LUCENT TECHNOLOGIES TAIWAN TELECOMMUNICATIONS CO., LTD.}
set vendor(0060d3) {AT&T}
set vendor(0060d4) {ELDAT COMMUNICATION LTD.}
set vendor(0060d5) {MIYACHI TECHNOS CORP.}
set vendor(0060d6) {NovAtel Wireless Technologies Ltd.}
set vendor(0060d7) {ECOLE POLYTECHNIQUE FEDERALE DE LAUSANNE (EPFL)}
set vendor(0060d8) {ELMIC SYSTEMS, INC.}
set vendor(0060d9) {TRANSYS NETWORKS INC.}
set vendor(0060da) {JBM ELECTRONICS CO.}
set vendor(0060db) {NTP ELEKTRONIK A/S}
set vendor(0060dc) {TOYO COMMUNICATION EQUIPMENT Co., Ltd.}
set vendor(0060dd) {MYRICOM, INC.}
set vendor(0060de) {KAYSER-THREDE GmbH}
set vendor(0060df) {CNT Corporation}
set vendor(00600e) {WAVENET INTERNATIONAL, INC.}
set vendor(0060e0) {AXIOM TECHNOLOGY CO., LTD.}
set vendor(0060e1) {ORCKIT COMMUNICATIONS LTD.}
set vendor(0060e2) {QUEST ENGINEERING & DEVELOPMENT}
set vendor(0060e3) {ARBIN INSTRUMENTS}
set vendor(0060e4) {COMPUSERVE, INC.}
set vendor(0060e5) {FUJI AUTOMATION CO., LTD.}
set vendor(0060e6) {SHOMITI SYSTEMS INCORPORATED}
set vendor(0060e7) {RANDATA}
set vendor(0060e8) {HITACHI COMPUTER PRODUCTS (AMERICA), INC.}
set vendor(0060e9) {ATOP TECHNOLOGIES, INC.}
set vendor(0060ea) {StreamLogic}
set vendor(0060eb) {FOURTHTRACK SYSTEMS}
set vendor(0060ec) {HERMARY OPTO ELECTRONICS INC.}
set vendor(0060ed) {RICARDO TEST AUTOMATION LTD.}
set vendor(0060ee) {APOLLO}
set vendor(0060ef) {FLYTECH TECHNOLOGY CO., LTD.}
set vendor(00600f) {WESTELL, INC.}
set vendor(0060f0) {JOHNSON & JOHNSON MEDICAL, INC}
set vendor(0060f1) {EXP COMPUTER, INC.}
set vendor(0060f2) {LASERGRAPHICS, INC.}
set vendor(0060f3) {Performance Analysis Broadband, Spirent plc}
set vendor(0060f4) {ADVANCED COMPUTER SOLUTIONS, Inc.}
set vendor(0060f5) {ICON WEST, INC.}
set vendor(0060f6) {NEXTEST COMMUNICATIONS PRODUCTS, INC.}
set vendor(0060f7) {DATAFUSION SYSTEMS}
set vendor(0060f8) {Loran International Technologies Inc.}
set vendor(0060f9) {DIAMOND LANE COMMUNICATIONS}
set vendor(0060fa) {EDUCATIONAL TECHNOLOGY RESOURCES, INC.}
set vendor(0060fb) {PACKETEER, INC.}
set vendor(0060fc) {CONSERVATION THROUGH INNOVATION LTD.}
set vendor(0060fd) {NetICs, Inc.}
set vendor(0060fe) {LYNX SYSTEM DEVELOPERS, INC.}
set vendor(0060ff) {QuVis, Inc.}
set vendor(000600) {Tokyo Electronic Industry Co., Ltd.}
set vendor(000601) {Otanikeiki Co., Ltd.}
set vendor(000610) {Abeona Networks Inc}
set vendor(000611) {Zeus Wireless, Inc.}
set vendor(000612) {Accusys, Inc.}
set vendor(000613) {Kawasaki Microelectronics Incorporated}
set vendor(000614) {Prism Holdings}
set vendor(000615) {Kimoto Electric Co., Ltd.}
set vendor(000616) {Tel Net Co., Ltd.}
set vendor(000617) {Redswitch Inc.}
set vendor(000618) {DigiPower Manufacturing Inc.}
set vendor(000619) {Connection Technology Systems}
set vendor(00061a) {Zetari Inc.}
set vendor(00061b) {Portable Systems, IBM Japan Co, Ltd}
set vendor(00061c) {Hoshino Metal Industries, Ltd.}
set vendor(00061d) {MIP Telecom, Inc.}
set vendor(00061e) {Maxan Systems}
set vendor(00061f) {Vision Components GmbH}
set vendor(000602) {Cirkitech Electronics Co.}
set vendor(000620) {Serial System Ltd.}
set vendor(000621) {Hinox, Co., Ltd.}
set vendor(000622) {Chung Fu Chen Yeh Enterprise Corp.}
set vendor(000623) {MGE UPS Systems France}
set vendor(000624) {Gentner Communications Corp.}
set vendor(000625) {The Linksys Group, Inc.}
set vendor(000626) {MWE GmbH}
set vendor(000627) {Uniwide Technologies, Inc.}
set vendor(000628) {Cisco Systems, Inc.}
set vendor(000629) {IBM CORPORATION}
set vendor(00062a) {Cisco Systems, Inc.}
set vendor(00062b) {INTRASERVER TECHNOLOGY}
set vendor(00062c) {Network Robots, Inc.}
set vendor(00062d) {TouchStar Technologies, L.L.C.}
set vendor(00062e) {Aristos Logic Corp.}
set vendor(00062f) {Pivotech Systems Inc.}
set vendor(000603) {Baker Hughes Inc.}
set vendor(000630) {Adtranz Sweden}
set vendor(000631) {Optical Solutions, Inc.}
set vendor(000632) {Mesco Engineering GmbH}
set vendor(000633) {Heimann Biometric Systems GmbH}
set vendor(000634) {GTE Airfone Inc.}
set vendor(000635) {PacketAir Networks, Inc.}
set vendor(000636) {Jedai Broadband Networks}
set vendor(000637) {Toptrend-Meta Information (ShenZhen) Inc.}
set vendor(000638) {Sungjin C&C Co., Ltd.}
set vendor(000639) {Newtec}
set vendor(00063a) {Dura Micro, Inc.}
set vendor(00063b) {Arcturus Networks, Inc.}
set vendor(00063c) {NMI Electronics Ltd}
set vendor(00063d) {Microwave Data Systems Inc.}
set vendor(00063e) {Opthos Inc.}
set vendor(00063f) {Everex Communications Inc.}
set vendor(000604) {@Track Communications, Inc.}
set vendor(000640) {White Rock Networks}
set vendor(000641) {ITCN}
set vendor(000642) {Genetel Systems Inc.}
set vendor(000643) {SONO Computer Co., Ltd.}
set vendor(000644) {NEIX Inc.}
set vendor(000645) {Meisei Electric Co. Ltd.}
set vendor(000646) {ShenZhen XunBao Network Technology Co Ltd}
set vendor(000647) {Etrali S.A.}
set vendor(000648) {Seedsware, Inc.}
set vendor(000649) {Quante}
set vendor(00064a) {Honeywell Co., Ltd. (KOREA)}
set vendor(00064b) {Alexon Co., Ltd.}
set vendor(00064c) {Invicta Networks, Inc.}
set vendor(00064d) {Sencore}
set vendor(00064e) {Broad Net Technology Inc.}
set vendor(00064f) {PRO-NETS Technology Corporation}
set vendor(000605) {Inncom International, Inc.}
set vendor(000650) {Tiburon Networks, Inc.}
set vendor(000651) {Aspen Networks Inc.}
set vendor(000652) {Cisco Systems, Inc.}
set vendor(000653) {Cisco Systems, Inc.}
set vendor(000654) {Maxxio Technologies}
set vendor(000655) {Yipee, Inc.}
set vendor(000656) {Tactel AB}
set vendor(000657) {Market Central, Inc.}
set vendor(000658) {Helmut Fischer GmbH & Co. KG}
set vendor(000659) {EAL (Apeldoorn) B.V.}
set vendor(00065a) {Strix Systems}
set vendor(00065b) {Dell Computer Corp.}
set vendor(00065c) {Malachite Technologies, Inc.}
set vendor(00065d) {Heidelberg Web Systems}
set vendor(00065e) {Photuris, Inc.}
set vendor(00065f) {ECI Telecom - NGTS Ltd.}
set vendor(000606) {RapidWAN, Inc.}
set vendor(000660) {NADEX Co., Ltd.}
set vendor(000661) {NIA Home Technologies Corp.}
set vendor(000662) {MBM Technology Ltd.}
set vendor(000663) {Human Technology Co., Ltd.}
set vendor(000664) {Fostex Corporation}
set vendor(000665) {Sunny Giken, Inc.}
set vendor(000666) {Roving Networks}
set vendor(000667) {Tripp Lite}
set vendor(000668) {Vicon Industries Inc.}
set vendor(000669) {Datasound Laboratories Ltd}
set vendor(00066a) {InfiniCon Systems, Inc.}
set vendor(00066b) {Sysmex Corporation}
set vendor(00066c) {Robinson Corporation}
set vendor(00066d) {Compuprint S.P.A.}
set vendor(00066e) {Delta Electronics, Inc.}
set vendor(00066f) {Korea Data Systems}
set vendor(000607) {Omni Directional Control Technology Inc.}
set vendor(000670) {Upponetti Oy}
set vendor(000671) {Softing AG}
set vendor(000672) {Netezza}
set vendor(000673) {Optelecom, Inc.}
set vendor(000674) {Spectrum Control, Inc.}
set vendor(000675) {Banderacom, Inc.}
set vendor(000676) {Novra Technologies Inc.}
set vendor(000677) {SICK AG}
set vendor(000678) {Marantz Japan, Inc.}
set vendor(000679) {Konami Corporation}
set vendor(00067a) {JMP Systems}
set vendor(00067b) {Toplink C&C Corporation}
set vendor(00067c) {CISCO SYSTEMS, INC.}
set vendor(00067d) {Takasago Ltd.}
set vendor(00067e) {WinCom Systems, Inc.}
set vendor(00067f) {Rearden Steel Technologies}
set vendor(000608) {At-Sky SAS}
set vendor(000680) {Card Access, Inc.}
set vendor(000681) {Goepel Electronic GmbH}
set vendor(000682) {Convedia}
set vendor(000683) {Bravara Communications, Inc.}
set vendor(000684) {Biacore AB}
set vendor(000685) {NetNearU Corporation}
set vendor(000686) {ZARDCOM Co., Ltd.}
set vendor(000687) {Omnitron Systems Technology, Inc.}
set vendor(000688) {Telways Communication Co., Ltd.}
set vendor(000689) {yLez Technologies Pte Ltd}
set vendor(00068a) {NeuronNet Co. Ltd. R&D Center}
set vendor(00068b) {AirRunner Technologies, Inc.}
set vendor(00068c) {3Com Corporation}
set vendor(00068d) {SANgate Systems}
set vendor(00068e) {HID Corporation}
set vendor(00068f) {Telemonitor, Inc.}
set vendor(000609) {Crossport Systems}
set vendor(000690) {Euracom Communication GmbH}
set vendor(000691) {PT Inovacao}
set vendor(000692) {Intruvert Networks, Inc.}
set vendor(000693) {Flexus Computer Technology, Inc.}
set vendor(000694) {Mobillian Corporation}
set vendor(000695) {Ensure Technologies, Inc.}
set vendor(000696) {Advent Networks}
set vendor(000697) {R & D Center}
set vendor(000698) {egnite Software GmbH}
set vendor(000699) {Vida Design Co.}
set vendor(00069a) {e & Tel}
set vendor(00069b) {AVT Audio Video Technologies GmbH}
set vendor(00069c) {Transmode Systems AB}
set vendor(00069d) {Petards Mobile Intelligence}
set vendor(00069e) {UNIQA, Inc.}
set vendor(00069f) {Kuokoa Networks}
set vendor(00060a) {Blue2space}
set vendor(0006a0) {Mx Imaging}
set vendor(0006a1) {Celsian Technologies, Inc.}
set vendor(0006a2) {Microtune, Inc.}
set vendor(0006a3) {Bitran Corporation}
set vendor(0006a4) {INNOWELL Corp.}
set vendor(0006a5) {PINON Corp.}
set vendor(0006a6) {Artistic Licence (UK) Ltd}
set vendor(0006a7) {Primarion}
set vendor(0006a8) {KC Technology, Inc.}
set vendor(0006a9) {Universal Instruments Corp.}
set vendor(0006aa) {Miltope Corporation}
set vendor(0006ab) {W-Link Systems, Inc.}
set vendor(0006ac) {Intersoft Co.}
set vendor(0006ad) {KB Electronics Ltd.}
set vendor(0006ae) {Himachal Futuristic Communications Ltd}
set vendor(00060b) {Paceline Systems Corporation}
set vendor(0006b0) {Comtech EF Data Corp.}
set vendor(0006b1) {Sonicwall}
set vendor(0006b2) {Linxtek Co.}
set vendor(0006b3) {Diagraph Corporation}
set vendor(0006b4) {Vorne Industries, Inc.}
set vendor(0006b5) {Luminent, Inc.}
set vendor(0006b6) {Nir-Or Israel Ltd.}
set vendor(0006b7) {TELEM GmbH}
set vendor(0006b8) {Bandspeed Pty Ltd}
set vendor(0006b9) {A5TEK Corp.}
set vendor(0006ba) {Westwave Communications}
set vendor(0006bb) {ATI Technologies Inc.}
set vendor(0006bc) {Macrolink, Inc.}
set vendor(0006bd) {BNTECHNOLOGY Co., Ltd.}
set vendor(0006be) {Baumer Optronic GmbH}
set vendor(0006bf) {Accella Technologies Co., Ltd.}
set vendor(00060c) {Melco Industries, Inc.}
set vendor(0006c0) {United Internetworks, Inc.}
set vendor(0006c1) {CISCO SYSTEMS, INC.}
set vendor(0006c2) {Smartmatic Corporation}
set vendor(0006c3) {Schindler Elevators Ltd.}
set vendor(0006c4) {Piolink Inc.}
set vendor(0006c5) {INNOVI Technologies Limited}
set vendor(0006c6) {lesswire AG}
set vendor(0006c7) {RFNET Technologies Pte Ltd (S)}
set vendor(0006c8) {Sumitomo Metal Micro Devices, Inc.}
set vendor(0006c9) {Technical Marketing Research, Inc.}
set vendor(0006ca) {American Computer & Digital Components, Inc. (ACDC)}
set vendor(0006cb) {Jotron Electronics A/S}
set vendor(0006cc) {JMI Electronics Co., Ltd.}
set vendor(0006cd) {CreoScitex Corporation Ltd.}
set vendor(0006ce) {DATENO}
set vendor(0006cf) {Thales Avionics In-Flight Systems, LLC}
set vendor(00060d) {Wave7 Optics}
set vendor(0006d0) {Elgar Electronics Corp.}
set vendor(0006d1) {Tahoe Networks, Inc.}
set vendor(0006d2) {Tundra Semiconductor Corp.}
set vendor(0006d3) {Alpha Telecom, Inc. U.S.A.}
set vendor(0006d4) {Interactive Objects, Inc.}
set vendor(0006d5) {Diamond Systems Corp.}
set vendor(0006d6) {Cisco Systems, Inc.}
set vendor(0006d7) {Cisco Systems, Inc.}
set vendor(0006d8) {Maple Optical Systems}
set vendor(0006d9) {IPM-Net S.p.A.}
set vendor(0006da) {ITRAN Communications Ltd.}
set vendor(0006db) {ICHIPS Co., Ltd.}
set vendor(0006dc) {Syabas Technology (Amquest)}
set vendor(0006dd) {AT & T Laboratories - Cambridge Ltd}
set vendor(0006de) {Flash Technology}
set vendor(0006df) {AIDONIC Corporation}
set vendor(00060e) {IGYS Systems, Inc.}
set vendor(0006e0) {MAT Co., Ltd.}
set vendor(0006e1) {Techno Trade s.a}
set vendor(0006e2) {Ceemax Technology Co., Ltd.}
set vendor(0006e3) {Quantitative Imaging Corporation}
set vendor(0006e4) {Citel Technologies Ltd.}
set vendor(0006e5) {Fujian Newland Computer Ltd. Co.}
set vendor(0006e6) {DongYang Telecom Co., Ltd.}
set vendor(0006e7) {Bit Blitz Communications Inc.}
set vendor(0006e8) {Optical Network Testing, Inc.}
set vendor(0006e9) {Intime Corp.}
set vendor(0006ea) {ELZET80 Mikrocomputer GmbH&Co. KG}
set vendor(0006eb) {Global Data}
set vendor(0006ec) {M/A COM Private Radio System Inc.}
set vendor(0006ed) {Inara Networks}
set vendor(0006ee) {Shenyang Neu-era Information & Technology Stock Co., Ltd}
set vendor(0006ef) {Maxxan Systems, Inc.}
set vendor(00060f) {Narad Networks Inc}
set vendor(0006f0) {Digeo, Inc.}
set vendor(0006f1) {Optillion}
set vendor(0006f2) {Platys Communications}
set vendor(0006f3) {AcceLight Networks}
set vendor(0006f4) {Prime Electronics & Satellitics Inc.}
set vendor(0006f9) {Mitsui Zosen Systems Research Inc.}
set vendor(0006fa) {IP SQUARE Co, Ltd.}
set vendor(0006fb) {Hitachi Printing Solutions, Ltd.}
set vendor(0006fc) {Fnet Co., Ltd.}
set vendor(0006fd) {Comjet Information Systems Corp.}
set vendor(0006fe) {Celion Networks, Inc.}
set vendor(0006ff) {Sheba Systems Co., Ltd.}
set vendor(0070b0) {M/A-COM INC. COMPANIES}
set vendor(0070b3) {DATA RECALL LTD.}
set vendor(000700) {Zettamedia Korea}
set vendor(000701) {RACAL-DATACOM}
set vendor(000710) {Adax, Inc.}
set vendor(000711) {Acterna}
set vendor(000712) {JAL Information Technology}
set vendor(000713) {IP One, Inc.}
set vendor(000714) {Brightcom}
set vendor(000715) {General Research of Electronics, Inc.}
set vendor(000716) {J & S Marine Ltd.}
set vendor(000717) {Wieland Electric GmbH}
set vendor(000718) {iCanTek Co., Ltd.}
set vendor(000719) {Mobiis Co., Ltd.}
set vendor(00071a) {Finedigital Inc.}
set vendor(00071b) {Position Technology Inc.}
set vendor(00071c) {AT&T Fixed Wireless Services}
set vendor(00071d) {Satelsa Sistemas Y Aplicaciones De Telecomunicaciones, S.A.}
set vendor(00071e) {Tri-M Engineering / Nupak Dev. Corp.}
set vendor(00071f) {European Systems Integration}
set vendor(000702) {Varian Medical Systems}
set vendor(000720) {Trutzschler GmbH & Co. KG}
set vendor(000721) {Formac Elektronik GmbH}
set vendor(000722) {Nielsen Media Research}
set vendor(000723) {ELCON Systemtechnik GmbH}
set vendor(000724) {Telemax Co., Ltd.}
set vendor(000725) {Bematech International Corp.}
set vendor(000727) {Zi Corporation (HK) Ltd.}
set vendor(000728) {Neo Telecom}
set vendor(000729) {Kistler Instrumente AG}
set vendor(00072a) {Innovance Networks}
set vendor(00072b) {Jung Myung Telecom Co., Ltd.}
set vendor(00072c) {Fabricom}
set vendor(00072d) {CNSystems}
set vendor(00072e) {North Node AB}
set vendor(00072f) {Instransa, Inc.}
set vendor(000703) {CSEE Transport}
set vendor(000730) {Hutchison OPTEL Telecom Technology Co., Ltd.}
set vendor(000731) {Spiricon, Inc.}
set vendor(000732) {AAEON Technology Inc.}
set vendor(000733) {DANCONTROL Engineering}
set vendor(000734) {ONStor, Inc.}
set vendor(000735) {Flarion Technologies, Inc.}
set vendor(000736) {Data Video Technologies Co., Ltd.}
set vendor(000737) {Soriya Co. Ltd.}
set vendor(000738) {Young Technology Co., Ltd.}
set vendor(000739) {Motion Media Technology Ltd.}
set vendor(00073a) {Inventel Systemes}
set vendor(00073b) {Tenovis GmbH & Co KG}
set vendor(00073c) {Telecom Design}
set vendor(00073d) {Nanjing Postel Telecommunications Co., Ltd.}
set vendor(00073e) {China Great-Wall Computer Shenzhen Co., Ltd.}
set vendor(00073f) {Woojyun Systec Co., Ltd.}
set vendor(000740) {Melco Inc.}
set vendor(000741) {Sierra Automated Systems}
set vendor(000742) {Current Technologies}
set vendor(000743) {Chelsio Communications}
set vendor(000744) {Unico, Inc.}
set vendor(000745) {Radlan Computer Communications Ltd.}
set vendor(000746) {Interlink BT, LLC}
set vendor(000747) {Mecalc}
set vendor(000748) {The Imaging Source Europe}
set vendor(000749) {CENiX Inc.}
set vendor(00074a) {Carl Valentin GmbH}
set vendor(00074b) {Daihen Corporation}
set vendor(00074c) {Beicom Inc.}
set vendor(00074d) {Zebra Technologies Corp.}
set vendor(00074e) {Naughty boy co., Ltd.}
set vendor(00074f) {Cisco Systems, Inc.}
set vendor(000705) {Endress & Hauser GmbH & Co}
set vendor(000750) {Cisco Systems, Inc.}
set vendor(000751) {m.u.t. - GmbH}
set vendor(000752) {Rhythm Watch Co., Ltd.}
set vendor(000753) {Beijing Qxcomm Technology Co., Ltd.}
set vendor(000754) {Xyterra Computing, Inc.}
set vendor(000755) {Lafon SA}
set vendor(000756) {Juyoung Telecom}
set vendor(000757) {Topcall International AG}
set vendor(000758) {Dragonwave}
set vendor(000759) {Boris Manufacturing Corp.}
set vendor(00075a) {Air Products and Chemicals, Inc.}
set vendor(00075b) {Gibson Guitars}
set vendor(00075c) {ENCAD, Inc.}
set vendor(00075d) {Celleritas Inc.}
set vendor(00075e) {Pulsar Technologies, Inc.}
set vendor(00075f) {VCS Video Communication Systems AG}
set vendor(000706) {Sanritz Corporation}
set vendor(000760) {TOMIS Information & Telecom Corp.}
set vendor(000761) {Logitech SA}
set vendor(000762) {Group Sense Limited}
set vendor(000763) {Sunniwell Cyber Tech. Co., Ltd.}
set vendor(000764) {YoungWoo Telecom Co. Ltd.}
set vendor(000765) {Jade Quantum Technologies, Inc.}
set vendor(000766) {Chou Chin Industrial Co., Ltd.}
set vendor(000767) {Yuxing Electronics Company Limited}
set vendor(000768) {Danfoss A/S}
set vendor(000769) {Italiana Macchi SpA}
set vendor(00076a) {NEXTEYE Co., Ltd.}
set vendor(00076b) {Stralfors AB}
set vendor(00076c) {Daehanet, Inc.}
set vendor(00076d) {Flexlight Networks}
set vendor(00076e) {Sinetica Corporation Ltd.}
set vendor(00076f) {Synoptics Limited}
set vendor(000707) {Interalia Inc.}
set vendor(000770) {Locusnetworks Corporation}
set vendor(000771) {Embedded System Corporation}
set vendor(000772) {Alcatel Shanghai Bell Co., Ltd.}
set vendor(000773) {Ascom Powerline Communications Ltd.}
set vendor(000774) {GuangZhou Thinker Technology Co. Ltd.}
set vendor(000775) {Valence Semiconductor, Inc.}
set vendor(000776) {Federal APD}
set vendor(000777) {Motah Ltd.}
set vendor(000778) {GERSTEL GmbH & Co. KG}
set vendor(000779) {Sungil Telecom Co., Ltd.}
set vendor(00077a) {Infoware System Co., Ltd.}
set vendor(00077b) {Millimetrix Broadband Networks}
set vendor(00077c) {OnTime Networks}
set vendor(00077e) {Elrest GmbH}
set vendor(00077f) {J Communications Co., Ltd.}
set vendor(000708) {Bitrage Inc.}
set vendor(000780) {Bluegiga Technologies OY}
set vendor(000781) {Itron Inc.}
set vendor(000782) {Nauticus Networks, Inc.}
set vendor(000783) {SynCom Network, Inc.}
set vendor(000784) {Cisco Systems Inc.}
set vendor(000785) {Cisco Systems Inc.}
set vendor(000786) {Wireless Networks Inc.}
set vendor(000787) {Idea System Co., Ltd.}
set vendor(000788) {Clipcomm, Inc.}
set vendor(000789) {Eastel Systems Corporation}
set vendor(00078a) {Mentor Data System Inc.}
set vendor(00078b) {Wegener Communications, Inc.}
set vendor(00078c) {Elektronikspecialisten i Borlange AB}
set vendor(00078d) {NetEngines Ltd.}
set vendor(00078e) {Garz & Friche GmbH}
set vendor(00078f) {Emkay Innovative Products}
set vendor(000709) {Westerstrand Urfabrik AB}
set vendor(000790) {Tri-M Technologies (s) Limited}
set vendor(000791) {International Data Communications, Inc.}
set vendor(000792) {Suetron Electronic GmbH}
set vendor(000794) {Simple Devices, Inc.}
set vendor(000795) {Elitegroup Computer System Co. (ECS)}
set vendor(000796) {LSI Systems, Inc.}
set vendor(000797) {Netpower Co., Ltd.}
set vendor(000798) {Selea SRL}
set vendor(000799) {Tipping Point Technologies, Inc.}
set vendor(00079a) {SmartSight Networks Inc.}
set vendor(00079b) {Aurora Networks}
set vendor(00079c) {Golden Electronics Technology Co., Ltd.}
set vendor(00079d) {Musashi Co., Ltd.}
set vendor(00079e) {Ilinx Co., Ltd.}
set vendor(00079f) {Action Digital Inc.}
set vendor(00070a) {Unicom Automation Co., Ltd.}
set vendor(0007a0) {e-Watch Inc.}
set vendor(0007a1) {VIASYS Healthcare GmbH}
set vendor(0007a2) {Opteon Corporation}
set vendor(0007a3) {Ositis Software, Inc.}
set vendor(0007a4) {GN Netcom Ltd.}
set vendor(0007a5) {Y.D.K Co. Ltd.}
set vendor(0007a6) {Home Automation, Inc.}
set vendor(0007a7) {A-Z Inc.}
set vendor(0007a8) {Haier Group Technologies Ltd.}
set vendor(0007a9) {Novasonics}
set vendor(0007aa) {Quantum Data Inc.}
set vendor(0007ac) {Eolring}
set vendor(0007ad) {Pentacon GmbH Foto-und Feinwerktechnik}
set vendor(0007ae) {Layer N Networks}
set vendor(0007af) {N-Tron Corp.}
set vendor(00070b) {Octal, SA}
set vendor(0007b0) {Office Details, Inc.}
set vendor(0007b1) {Equator Technologies}
set vendor(0007b2) {Transaccess S.A.}
set vendor(0007b3) {Cisco Systems Inc.}
set vendor(0007b4) {Cisco Systems Inc.}
set vendor(0007b5) {Any One Wireless Ltd.}
set vendor(0007b6) {Telecom Technology Ltd.}
set vendor(0007b7) {Samurai Ind. Prods Eletronicos Ltda}
set vendor(0007b8) {American Predator Corp.}
set vendor(0007b9) {Ginganet Corporation}
set vendor(0007ba) {Xebeo Communications, Inc.}
set vendor(0007bb) {Candera Inc.}
set vendor(0007bc) {Identix Inc.}
set vendor(0007bd) {Radionet Ltd.}
set vendor(0007be) {DataLogic SpA}
set vendor(0007bf) {Armillaire Technologies, Inc.}
set vendor(00070c) {SVA-Intrusion.com Co. Ltd.}
set vendor(0007c0) {NetZerver Inc.}
set vendor(0007c1) {Overture Networks, Inc.}
set vendor(0007c2) {Netsys Telecom}
set vendor(0007c3) {Cirpack}
set vendor(0007c4) {JEAN Co. Ltd.}
set vendor(0007c5) {Gcom, Inc.}
set vendor(0007c6) {VDS Vosskuhler GmbH}
set vendor(0007c7) {Synectics Systems Limited}
set vendor(0007c8) {Brain21, Inc.}
set vendor(0007c9) {Technol Seven Co., Ltd.}
set vendor(0007ca) {Creatix Polymedia Ges Fur Kommunikaitonssysteme}
set vendor(0007cb) {Freebox SA}
set vendor(0007cc) {Kaba Benzing GmbH}
set vendor(0007cd) {NMTEL Co., Ltd.}
set vendor(0007ce) {Cabletime Limited}
set vendor(0007cf) {Anoto AB}
set vendor(00070d) {Cisco Systems Inc.}
set vendor(0007d0) {Automat Engenharia de Automaoa Ltda.}
set vendor(0007d1) {Spectrum Signal Processing Inc.}
set vendor(0007d2) {Logopak Systeme}
set vendor(0007d3) {Stork Digital Imaging B.V.}
set vendor(0007d4) {Zhejiang Yutong Network Communication Co Ltd.}
set vendor(0007d5) {3e Technologies Int;., Inc.}
set vendor(0007d6) {Commil Ltd.}
set vendor(0007d7) {Caporis Networks AG}
set vendor(0007d8) {Hitron Systems Inc.}
set vendor(0007d9) {Splicecom}
set vendor(0007da) {Neuro Telecom Co., Ltd.}
set vendor(0007db) {Kirana Networks, Inc.}
set vendor(0007dc) {Atek Co, Ltd.}
set vendor(0007dd) {Cradle Technologies}
set vendor(0007de) {eCopilt AB}
set vendor(0007df) {Vbrick Systems Inc.}
set vendor(00070e) {Cisco Systems Inc.}
set vendor(0007e0) {Palm Inc.}
set vendor(0007e1) {WIS Communications Co. Ltd.}
set vendor(0007e2) {Bitworks, Inc.}
set vendor(0007e3) {Navcom Technology, Inc.}
set vendor(0007e4) {SoftRadio Co., Ltd.}
set vendor(0007e5) {Coup Corporation}
set vendor(0007e6) {edgeflow Canada Inc.}
set vendor(0007e7) {FreeWave Technologies}
set vendor(0007e8) {St. Bernard Software}
set vendor(0007e9) {Intel Corporation}
set vendor(0007ea) {Massana, Inc.}
set vendor(0007eb) {Cisco Systems Inc.}
set vendor(0007ec) {Cisco Systems Inc.}
set vendor(0007ed) {Altera Corporation}
set vendor(0007ee) {telco Informationssysteme GmbH}
set vendor(0007ef) {Lockheed Martin Tactical Systems}
set vendor(00070f) {Fujant, Inc.}
set vendor(0007f0) {LogiSync Corporation}
set vendor(0007f1) {TeraBurst Networks Inc.}
set vendor(0007f2) {IOA Corporation}
set vendor(0007f3) {Think Engine Networks}
set vendor(0007f4) {Eletex Co., Ltd.}
set vendor(0007f5) {Bridgeco Co AG}
set vendor(0007f6) {Qqest Software Systems}
set vendor(0007f7) {Galtronics}
set vendor(0007f8) {ITDevices, Inc.}
set vendor(0007f9) {Phonetics, Inc.}
set vendor(0007fa) {ITT Co., Ltd.}
set vendor(0007fb) {Giga Stream UMTS Technologies GmbH}
set vendor(0007fc) {Adept Systems Inc.}
set vendor(0007fd) {LANergy Ltd.}
set vendor(0007fe) {Rigaku Corporation}
set vendor(0007ff) {Gluon Networks}
set vendor(008000) {MULTITECH SYSTEMS, INC.}
set vendor(008001) {PERIPHONICS CORPORATION}
set vendor(008010) {COMMODORE INTERNATIONAL}
set vendor(008011) {DIGITAL SYSTEMS INT'L. INC.}
set vendor(008012) {INTEGRATED MEASUREMENT SYSTEMS}
set vendor(008013) {THOMAS-CONRAD CORPORATION}
set vendor(008014) {ESPRIT SYSTEMS}
set vendor(008015) {SEIKO SYSTEMS, INC.}
set vendor(008016) {WANDEL AND GOLTERMANN}
set vendor(008017) {PFU LIMITED}
set vendor(008018) {KOBE STEEL, LTD.}
set vendor(008019) {DAYNA COMMUNICATIONS, INC.}
set vendor(00801a) {BELL ATLANTIC}
set vendor(00801b) {KODIAK TECHNOLOGY}
set vendor(00801c) {NEWPORT SYSTEMS SOLUTIONS}
set vendor(00801d) {INTEGRATED INFERENCE MACHINES}
set vendor(00801e) {XINETRON, INC.}
set vendor(00801f) {KRUPP ATLAS ELECTRONIK GMBH}
set vendor(008002) {SATELCOM (UK) LTD}
set vendor(008020) {NETWORK PRODUCTS}
set vendor(008021) {Alcatel Canada Inc.}
set vendor(008022) {SCAN-OPTICS}
set vendor(008023) {INTEGRATED BUSINESS NETWORKS}
set vendor(008024) {KALPANA, INC.}
set vendor(008025) {STOLLMANN GMBH}
set vendor(008026) {NETWORK PRODUCTS CORPORATION}
set vendor(008027) {ADAPTIVE SYSTEMS, INC.}
set vendor(008028) {TRADPOST (HK) LTD}
set vendor(008029) {EAGLE TECHNOLOGY, INC.}
set vendor(00802a) {TEST SYSTEMS & SIMULATIONS INC}
set vendor(00802b) {INTEGRATED MARKETING CO}
set vendor(00802c) {THE SAGE GROUP PLC}
set vendor(00802d) {XYLOGICS INC}
set vendor(00802e) {CASTLE ROCK COMPUTING}
set vendor(00802f) {NATIONAL INSTRUMENTS CORP.}
set vendor(008003) {HYTEC ELECTRONICS LTD.}
set vendor(008030) {NEXUS ELECTRONICS}
set vendor(008031) {BASYS, CORP.}
set vendor(008032) {ACCESS CO., LTD.}
set vendor(008033) {FORMATION, INC.}
set vendor(008034) {SMT GOUPIL}
set vendor(008035) {TECHNOLOGY WORKS, INC.}
set vendor(008036) {REFLEX MANUFACTURING SYSTEMS}
set vendor(008037) {Ericsson Group}
set vendor(008038) {DATA RESEARCH & APPLICATIONS}
set vendor(008039) {ALCATEL STC AUSTRALIA}
set vendor(00803a) {VARITYPER, INC.}
set vendor(00803b) {APT COMMUNICATIONS, INC.}
set vendor(00803c) {TVS ELECTRONICS LTD}
set vendor(00803d) {SURIGIKEN CO.,  LTD.}
set vendor(00803e) {SYNERNETICS}
set vendor(00803f) {TATUNG COMPANY}
set vendor(008004) {ANTLOW COMMUNICATIONS, LTD.}
set vendor(008040) {JOHN FLUKE MANUFACTURING CO.}
set vendor(008041) {VEB KOMBINAT ROBOTRON}
set vendor(008042) {FORCE COMPUTERS}
set vendor(008043) {NETWORLD, INC.}
set vendor(008044) {SYSTECH COMPUTER CORP.}
set vendor(008045) {MATSUSHITA ELECTRIC IND. CO}
set vendor(008046) {UNIVERSITY OF TORONTO}
set vendor(008047) {IN-NET CORP.}
set vendor(008048) {COMPEX INCORPORATED}
set vendor(008049) {NISSIN ELECTRIC CO., LTD.}
set vendor(00804a) {PRO-LOG}
set vendor(00804b) {EAGLE TECHNOLOGIES PTY.LTD.}
set vendor(00804c) {CONTEC CO., LTD.}
set vendor(00804d) {CYCLONE MICROSYSTEMS, INC.}
set vendor(00804e) {APEX COMPUTER COMPANY}
set vendor(00804f) {DAIKIN INDUSTRIES, LTD.}
set vendor(008005) {CACTUS COMPUTER INC.}
set vendor(008050) {ZIATECH CORPORATION}
set vendor(008051) {FIBERMUX}
set vendor(008052) {TECHNICALLY ELITE CONCEPTS}
set vendor(008053) {INTELLICOM, INC.}
set vendor(008054) {FRONTIER TECHNOLOGIES CORP.}
set vendor(008055) {FERMILAB}
set vendor(008056) {SPHINX ELEKTRONIK GMBH}
set vendor(008057) {ADSOFT, LTD.}
set vendor(008058) {PRINTER SYSTEMS CORPORATION}
set vendor(008059) {STANLEY ELECTRIC CO., LTD}
set vendor(00805a) {TULIP COMPUTERS INTERNAT'L B.V}
set vendor(00805b) {CONDOR SYSTEMS, INC.}
set vendor(00805c) {AGILIS CORPORATION}
set vendor(00805d) {CANSTAR}
set vendor(00805e) {LSI LOGIC CORPORATION}
set vendor(00805f) {COMPAQ COMPUTER CORPORATION}
set vendor(008006) {COMPUADD CORPORATION}
set vendor(008060) {NETWORK INTERFACE CORPORATION}
set vendor(008061) {LITTON SYSTEMS, INC.}
set vendor(008062) {INTERFACE  CO.}
set vendor(008063) {RICHARD HIRSCHMANN GMBH & CO.}
set vendor(008064) {WYSE TECHNOLOGY}
set vendor(008065) {CYBERGRAPHIC SYSTEMS PTY LTD.}
set vendor(008066) {ARCOM CONTROL SYSTEMS, LTD.}
set vendor(008067) {SQUARE D COMPANY}
set vendor(008068) {YAMATECH SCIENTIFIC LTD.}
set vendor(008069) {COMPUTONE SYSTEMS}
set vendor(00806a) {ERI (EMPAC RESEARCH INC.)}
set vendor(00806b) {SCHMID TELECOMMUNICATION}
set vendor(00806c) {CEGELEC PROJECTS LTD}
set vendor(00806d) {CENTURY SYSTEMS CORP.}
set vendor(00806e) {NIPPON STEEL CORPORATION}
set vendor(00806f) {ONELAN LTD.}
set vendor(008007) {DLOG NC-SYSTEME}
set vendor(008070) {COMPUTADORAS MICRON}
set vendor(008071) {SAI TECHNOLOGY}
set vendor(008072) {MICROPLEX SYSTEMS LTD.}
set vendor(008073) {DWB ASSOCIATES}
set vendor(008074) {FISHER CONTROLS}
set vendor(008075) {PARSYTEC GMBH}
set vendor(008076) {MCNC}
set vendor(008077) {BROTHER INDUSTRIES, LTD.}
set vendor(008078) {PRACTICAL PERIPHERALS, INC.}
set vendor(008079) {MICROBUS DESIGNS LTD.}
set vendor(00807a) {AITECH SYSTEMS LTD.}
set vendor(00807b) {ARTEL COMMUNICATIONS CORP.}
set vendor(00807c) {FIBERCOM, INC.}
set vendor(00807d) {EQUINOX SYSTEMS INC.}
set vendor(00807e) {SOUTHERN PACIFIC LTD.}
set vendor(00807f) {DY-4 INCORPORATED}
set vendor(008008) {DYNATECH COMPUTER SYSTEMS}
set vendor(008080) {DATAMEDIA CORPORATION}
set vendor(008081) {KENDALL SQUARE RESEARCH CORP.}
set vendor(008082) {PEP MODULAR COMPUTERS GMBH}
set vendor(008083) {AMDAHL}
set vendor(008084) {THE CLOUD INC.}
set vendor(008085) {H-THREE SYSTEMS CORPORATION}
set vendor(008086) {COMPUTER GENERATION INC.}
set vendor(008087) {OKI ELECTRIC INDUSTRY CO., LTD}
set vendor(008088) {VICTOR COMPANY OF JAPAN, LTD.}
set vendor(008089) {TECNETICS (PTY) LTD.}
set vendor(00808a) {SUMMIT MICROSYSTEMS CORP.}
set vendor(00808b) {DACOLL LIMITED}
set vendor(00808c) {NetScout Systems, Inc.}
set vendor(00808d) {WESTCOAST TECHNOLOGY B.V.}
set vendor(00808e) {RADSTONE TECHNOLOGY}
set vendor(00808f) {C. ITOH ELECTRONICS, INC.}
set vendor(008009) {JUPITER SYSTEMS, INC.}
set vendor(008090) {MICROTEK INTERNATIONAL, INC.}
set vendor(008091) {TOKYO ELECTRIC CO.,LTD}
set vendor(008092) {JAPAN COMPUTER INDUSTRY, INC.}
set vendor(008093) {XYRON CORPORATION}
set vendor(008094) {ALFA LAVAL AUTOMATION AB}
set vendor(008095) {BASIC MERTON HANDELSGES.M.B.H.}
set vendor(008096) {HUMAN DESIGNED SYSTEMS, INC.}
set vendor(008097) {CENTRALP AUTOMATISMES}
set vendor(008098) {TDK CORPORATION}
set vendor(008099) {KLOCKNER MOELLER IPC}
set vendor(00809a) {NOVUS NETWORKS LTD}
set vendor(00809b) {JUSTSYSTEM CORPORATION}
set vendor(00809c) {LUXCOM, INC.}
set vendor(00809d) {Commscraft Ltd.}
set vendor(00809e) {DATUS GMBH}
set vendor(00809f) {ALCATEL BUSINESS SYSTEMS}
set vendor(00800a) {JAPAN COMPUTER CORP.}
set vendor(0080a0) {EDISA HEWLETT PACKARD S/A}
set vendor(0080a1) {MICROTEST, INC.}
set vendor(0080a2) {CREATIVE ELECTRONIC SYSTEMS}
set vendor(0080a3) {LANTRONIX}
set vendor(0080a4) {LIBERTY ELECTRONICS}
set vendor(0080a5) {SPEED INTERNATIONAL}
set vendor(0080a6) {REPUBLIC TECHNOLOGY, INC.}
set vendor(0080a7) {MEASUREX CORP.}
set vendor(0080a8) {VITACOM CORPORATION}
set vendor(0080a9) {CLEARPOINT RESEARCH}
set vendor(0080aa) {MAXPEED}
set vendor(0080ab) {DUKANE NETWORK INTEGRATION}
set vendor(0080ac) {IMLOGIX, DIVISION OF GENESYS}
set vendor(0080ad) {CNET TECHNOLOGY, INC.}
set vendor(0080ae) {HUGHES NETWORK SYSTEMS}
set vendor(0080af) {ALLUMER CO., LTD.}
set vendor(00800b) {CSK CORPORATION}
set vendor(0080b0) {ADVANCED INFORMATION}
set vendor(0080b1) {SOFTCOM A/S}
set vendor(0080b2) {NETWORK EQUIPMENT TECHNOLOGIES}
set vendor(0080b3) {AVAL DATA CORPORATION}
set vendor(0080b4) {SOPHIA SYSTEMS}
set vendor(0080b5) {UNITED NETWORKS INC.}
set vendor(0080b6) {THEMIS COMPUTER}
set vendor(0080b7) {STELLAR COMPUTER}
set vendor(0080b8) {BUG, INCORPORATED}
set vendor(0080b9) {ARCHE TECHNOLIGIES INC.}
set vendor(0080ba) {SPECIALIX (ASIA) PTE, LTD}
set vendor(0080bb) {HUGHES LAN SYSTEMS}
set vendor(0080bc) {HITACHI ENGINEERING CO., LTD}
set vendor(0080bd) {THE FURUKAWA ELECTRIC CO., LTD}
set vendor(0080be) {ARIES RESEARCH}
set vendor(0080bf) {TAKAOKA ELECTRIC MFG. CO. LTD.}
set vendor(00800c) {VIDECOM LIMITED}
set vendor(0080c0) {PENRIL DATACOMM}
set vendor(0080c1) {LANEX CORPORATION}
set vendor(0080c2) {IEEE 802.1 COMMITTEE}
set vendor(0080c3) {BICC INFORMATION SYSTEMS & SVC}
set vendor(0080c4) {DOCUMENT TECHNOLOGIES, INC.}
set vendor(0080c5) {NOVELLCO DE MEXICO}
set vendor(0080c6) {NATIONAL DATACOMM CORPORATION}
set vendor(0080c7) {XIRCOM}
set vendor(0080c8) {D-LINK SYSTEMS, INC.}
set vendor(0080c9) {ALBERTA MICROELECTRONIC CENTRE}
set vendor(0080ca) {NETCOM RESEARCH INCORPORATED}
set vendor(0080cb) {FALCO DATA PRODUCTS}
set vendor(0080cc) {MICROWAVE BYPASS SYSTEMS}
set vendor(0080cd) {MICRONICS COMPUTER, INC.}
set vendor(0080ce) {BROADCAST TELEVISION SYSTEMS}
set vendor(0080cf) {EMBEDDED PERFORMANCE INC.}
set vendor(00800d) {VOSSWINKEL F.U.}
set vendor(0080d0) {COMPUTER PERIPHERALS, INC.}
set vendor(0080d1) {KIMTRON CORPORATION}
set vendor(0080d2) {SHINNIHONDENKO CO., LTD.}
set vendor(0080d3) {SHIVA CORP.}
set vendor(0080d4) {CHASE RESEARCH LTD.}
set vendor(0080d5) {CADRE TECHNOLOGIES}
set vendor(0080d6) {NUVOTECH, INC.}
set vendor(0080d7) {Fantum Engineering}
set vendor(0080d8) {NETWORK PERIPHERALS INC.}
set vendor(0080d9) {EMK ELEKTRONIK}
set vendor(0080da) {BRUEL & KJAER}
set vendor(0080db) {GRAPHON CORPORATION}
set vendor(0080dc) {PICKER INTERNATIONAL}
set vendor(0080dd) {GMX INC/GIMIX}
set vendor(0080de) {GIPSI S.A.}
set vendor(0080df) {ADC CODENOLL TECHNOLOGY CORP.}
set vendor(00800e) {ATLANTIX CORPORATION}
set vendor(0080e0) {XTP SYSTEMS, INC.}
set vendor(0080e1) {STMICROELECTRONICS}
set vendor(0080e2) {T.D.I. CO., LTD.}
set vendor(0080e3) {CORAL NETWORK CORPORATION}
set vendor(0080e4) {NORTHWEST DIGITAL SYSTEMS, INC}
set vendor(0080e5) {MYLEX CORPORATION}
set vendor(0080e6) {PEER NETWORKS, INC.}
set vendor(0080e7) {LYNWOOD SCIENTIFIC DEV. LTD.}
set vendor(0080e8) {CUMULUS CORPORATIION}
set vendor(0080e9) {Madge Ltd.}
set vendor(0080ea) {ADVA Optical Networking Ltd.}
set vendor(0080eb) {COMPCONTROL B.V.}
set vendor(0080ec) {SUPERCOMPUTING SOLUTIONS, INC.}
set vendor(0080ed) {IQ TECHNOLOGIES, INC.}
set vendor(0080ee) {THOMSON CSF}
set vendor(0080ef) {RATIONAL}
set vendor(00800f) {STANDARD MICROSYSTEMS}
set vendor(0080f0) {Panasonic Communications Co., Ltd.}
set vendor(0080f1) {OPUS SYSTEMS}
set vendor(0080f2) {RAYCOM SYSTEMS INC}
set vendor(0080f3) {SUN ELECTRONICS CORP.}
set vendor(0080f4) {TELEMECANIQUE ELECTRIQUE}
set vendor(0080f5) {QUANTEL LTD}
set vendor(0080f6) {SYNERGY MICROSYSTEMS}
set vendor(0080f7) {ZENITH ELECTRONICS}
set vendor(0080f8) {MIZAR, INC.}
set vendor(0080f9) {HEURIKON CORPORATION}
set vendor(0080fa) {RWT GMBH}
set vendor(0080fb) {BVM LIMITED}
set vendor(0080fc) {AVATAR CORPORATION}
set vendor(0080fd) {EXSCEED CORPRATION}
set vendor(0080fe) {AZURE TECHNOLOGIES, INC.}
set vendor(0080ff) {SOC. DE TELEINFORMATIQUE RTC}
set vendor(000800) {MULTITECH SYSTEMS, INC.}
set vendor(000801) {HighSpeed Surfing Inc.}
set vendor(000810) {Key Technology, Inc.}
set vendor(000811) {VOIX Corporation}
set vendor(000812) {GM-2 Corporation}
set vendor(000813) {Diskbank, Inc.}
set vendor(000814) {TIL Technologies}
set vendor(000815) {CATS Co., Ltd.}
set vendor(000816) {Bluetags A/S}
set vendor(000817) {EmergeCore Networks LLC}
set vendor(000818) {Pixelworks, Inc.}
set vendor(000819) {Banksys}
set vendor(00081a) {Sanrad Intelligence Storage Communications (2000) Ltd.}
set vendor(00081b) {Windigo Systems}
set vendor(00081c) {@pos.com}
set vendor(00081d) {Ipsil, Incorporated}
set vendor(00081e) {Repeatit AB}
set vendor(00081f) {Pou Yuen Tech Corp. Ltd.}
set vendor(000802) {Compaq Computer Corporation}
set vendor(000820) {Cisco Systems Inc.}
set vendor(000821) {Cisco Systems Inc.}
set vendor(000822) {InPro Comm}
set vendor(000823) {Texa Corp.}
set vendor(000824) {Promatek Industries Ltd.}
set vendor(000825) {Acme Packet}
set vendor(000826) {Colorado Med Tech}
set vendor(000827) {Pirelli Cables & Systems}
set vendor(000828) {Koei Engineering Ltd.}
set vendor(000829) {Aval Nagasaki Corporation}
set vendor(00082a) {Powerwallz Network Security}
set vendor(00082b) {Wooksung Electronics, Inc.}
set vendor(00082c) {Homag AG}
set vendor(00082d) {Indus Teqsite Private Limited}
set vendor(00082e) {Multitone Electronics PLC}
set vendor(000803) {Cos Tron}
set vendor(000804) {ICA Inc.}
set vendor(00084e) {DivergeNet, Inc.}
set vendor(00084f) {Qualstar Corporation}
set vendor(000805) {Techno-Holon Corporation}
set vendor(000850) {Arizona Instrument Corp.}
set vendor(000851) {Canadian Bank Note Company, Ltd.}
set vendor(000852) {Davolink Co. Inc.}
set vendor(000853) {Schleicher GmbH & Co. Relaiswerke KG}
set vendor(000854) {Netronix, Inc.}
set vendor(000855) {NASA-Goddard Space Flight Center}
set vendor(000856) {Gamatronic Electronic Industries Ltd.}
set vendor(000857) {Polaris Networks, Inc.}
set vendor(000858) {Novatechnology Inc.}
set vendor(000859) {ShenZhen Unitone Electronics Co., Ltd.}
set vendor(00085a) {IntiGate Inc.}
set vendor(00085b) {Hanbit Electronics Co., Ltd.}
set vendor(00085c) {Shanghai Dare Technologies Co. Ltd.}
set vendor(00085d) {Aastra}
set vendor(00085e) {PCO AG}
set vendor(00085f) {Picanol N.V.}
set vendor(000806) {Raonet Systems, Inc.}
set vendor(000860) {LodgeNet Entertainment Corp.}
set vendor(000861) {SoftEnergy Co., Ltd.}
set vendor(000862) {NEC Eluminant Technologies, Inc.}
set vendor(000863) {Entrisphere Inc.}
set vendor(000864) {Fasy S.p.A.}
set vendor(000865) {JASCOM CO., LTD}
set vendor(000866) {DSX Access Systems, Inc.}
set vendor(000867) {Uptime Devices}
set vendor(000868) {PurOptix}
set vendor(000869) {Command-e Technology Co.,Ltd.}
set vendor(00086a) {Industrie Technik IPS GmbH}
set vendor(00086b) {MIPSYS}
set vendor(00086c) {Plasmon LMS}
set vendor(00086d) {Missouri FreeNet}
set vendor(00086e) {Hyglo AB}
set vendor(00086f) {Resources Computer Network Ltd.}
set vendor(000807) {Access Devices Limited}
set vendor(000870) {Rasvia Systems, Inc.}
set vendor(000871) {NORTHDATA Co., Ltd.}
set vendor(000872) {Sorenson Technologies, Inc.}
set vendor(000873) {DAP Design B.V.}
set vendor(000874) {Dell Computer Corp.}
set vendor(000875) {Acorp Electronics Corp.}
set vendor(000876) {SDSystem}
set vendor(000877) {Liebert HIROSS S.p.A.}
set vendor(000878) {Benchmark Storage Innovations}
set vendor(000879) {CEM Corporation}
set vendor(00087a) {Wipotec GmbH}
set vendor(00087b) {RTX Telecom A/S}
set vendor(00087c) {Cisco Systems, Inc.}
set vendor(00087d) {Cisco Systems Inc.}
set vendor(00087e) {Bon Electro-Telecom Inc.}
set vendor(00087f) {SPAUN electronic GmbH & Co. KG}
set vendor(000808) {PPT Vision, Inc.}
set vendor(000880) {BroadTel Canada Communications inc.}
set vendor(000881) {DIGITAL HANDS CO.,LTD.}
set vendor(000882) {SIGMA CORPORATION}
set vendor(000883) {Hewlett-Packard Company}
set vendor(000884) {Index Braille AB}
set vendor(000885) {EMS Dr. Thomas Wuensche}
set vendor(000886) {Hansung Teliann, Inc.}
set vendor(000887) {Maschinenfabrik Reinhausen GmbH}
set vendor(000888) {OULLIM Information Technology Inc,.}
set vendor(000889) {Echostar Technologies Corp}
set vendor(00088a) {Minds@Work}
set vendor(00088b) {Tropic Networks Inc.}
set vendor(00088c) {Quanta Network Systems Inc.}
set vendor(00088d) {Sigma-Links Inc.}
set vendor(00088e) {Nihon Computer Co., Ltd.}
set vendor(00088f) {ADVANCED DIGITAL TECHNOLOGY}
set vendor(000809) {Systemonic AG}
set vendor(000890) {AVILINKS SA}
set vendor(000891) {Lyan Inc.}
set vendor(000892) {EM Solutions}
set vendor(000894) {InnoVISION Multimedia Ltd.}
set vendor(000895) {DIRC Technologie GmbH & Co.KG}
set vendor(000896) {Printronix, Inc.}
set vendor(000897) {Quake Technologies}
set vendor(000898) {Gigabit Optics Corporation}
set vendor(000899) {Netbind, Inc.}
set vendor(00089a) {Alcatel Microelectronics}
set vendor(00089b) {ICP Electronics Inc.}
set vendor(00089c) {Elecs Industry Co., Ltd.}
set vendor(00089d) {UHD-Elektronik}
set vendor(00089e) {Beijing Enter-Net co.LTD}
set vendor(00089f) {EFM Networks}
set vendor(00080a) {Espera-Werke GmbH}
set vendor(0008a0) {Stotz Feinmesstechnik GmbH}
set vendor(0008a1) {CNet Technology Inc.}
set vendor(0008a2) {ADI Engineering, Inc.}
set vendor(0008a3) {Cisco Systems}
set vendor(0008a4) {Cisco Systems}
set vendor(0008a5) {Peninsula Systems Inc.}
set vendor(0008a6) {Multiware & Image Co., Ltd.}
set vendor(0008a7) {iLogic Inc.}
set vendor(0008a8) {Systec Co., Ltd.}
set vendor(0008a9) {SangSang Technology, Inc.}
set vendor(0008aa) {KARAM}
set vendor(0008ab) {EnerLinx.com, Inc.}
set vendor(0008ad) {Toyo-Linx Co., Ltd.}
set vendor(0008ae) {Packetfront}
set vendor(0008af) {Novatec Corporation}
set vendor(00080b) {Birka BPA Informationssystem AB}
set vendor(0008b0) {BKtel communications GmbH}
set vendor(0008b1) {ProQuent Systems}
set vendor(0008b2) {SHENZHEN COMPASS TECHNOLOGY DEVELOPMENT CO.,LTD}
set vendor(0008b3) {Fastwel}
set vendor(0008b4) {SYSPOL}
set vendor(0008b5) {TAI GUEN ENTERPRISE CO., LTD}
set vendor(0008b6) {RouteFree, Inc.}
set vendor(0008b7) {HIT Incorporated}
set vendor(0008b8) {E.F. Johnson}
set vendor(0008b9) {KAON MEDIA Co., Ltd.}
set vendor(0008ba) {Erskine Systems Ltd}
set vendor(0008bb) {NetExcell}
set vendor(0008bc) {Ilevo AB}
set vendor(0008bd) {TEPG-US}
set vendor(0008be) {XENPAK MSA Group}
set vendor(0008bf) {Aptus Elektronik AB}
set vendor(00080c) {VDA elettronica SrL}
set vendor(0008c0) {ASA SYSTEMS}
set vendor(0008c1) {Avistar Communications Corporation}
set vendor(0008c2) {Cisco Systems}
set vendor(0008c3) {Contex A/S}
set vendor(0008c4) {Hikari Co.,Ltd.}
set vendor(0008c5) {Liontech Co., Ltd.}
set vendor(0008c6) {Philips Consumer Communications}
set vendor(0008c7) {COMPAQ COMPUTER CORPORATION}
set vendor(0008c8) {Soneticom, Inc.}
set vendor(0008c9) {TechniSat Digital GmbH}
set vendor(0008ca) {TwinHan Technology Co.,Ltd}
set vendor(0008cb) {Zeta Broadband Inc.}
set vendor(0008cc) {Remotec, Inc.}
set vendor(0008cd) {With-Net Inc}
set vendor(0008cf) {Nippon Koei Power Systems Co., Ltd.}
set vendor(00080d) {Toshiba}
set vendor(0008d0) {Musashi Engineering Co., LTD.}
set vendor(0008d1) {KAREL INC.}
set vendor(0008d2) {ZOOM Networks Inc.}
set vendor(0008d3) {Hercules Technologies S.A.}
set vendor(0008d4) {IneoQuest Technologies, Inc}
set vendor(0008d5) {Vanguard Managed Solutions}
set vendor(0008d6) {HASSNET Inc.}
set vendor(0008d7) {HOW CORPORATION}
set vendor(0008d8) {Dowkey Microwave}
set vendor(0008d9) {Mitadenshi Co.,LTD}
set vendor(0008da) {SofaWare Technologies Ltd.}
set vendor(0008db) {Corrigent Systems}
set vendor(0008dc) {Wiznet}
set vendor(0008dd) {Telena Communications, Inc.}
set vendor(0008de) {3UP Systems}
set vendor(0008df) {Alistel Inc.}
set vendor(00080e) {Motorola, BCS}
set vendor(0008e0) {ATO Technology Ltd.}
set vendor(0008e1) {Barix AG}
set vendor(0008e2) {Cisco Systems}
set vendor(0008e3) {Cisco Systems}
set vendor(0008e4) {Envenergy Inc}
set vendor(0008e5) {IDK Corporation}
set vendor(0008e6) {Littlefeet}
set vendor(0008e7) {SHI ControlSystems,Ltd.}
set vendor(0008e8) {Excel Master Ltd.}
set vendor(0008e9) {NextGig}
set vendor(0008ea) {Motion Control Engineering, Inc}
set vendor(0008eb) {ROMWin Co.,Ltd.}
set vendor(0008ec) {Zonu, Inc.}
set vendor(0008ed) {ST&T Instrument Corp.}
set vendor(0008ee) {Logic Product Development}
set vendor(0008ef) {DIBAL,S.A.}
set vendor(00080f) {Proximion Fiber Optics AB}
set vendor(0008f0) {Next Generation Systems, Inc.}
set vendor(0008f1) {Voltaire}
set vendor(0008f2) {C&S Technology}
set vendor(0008f3) {WANY}
set vendor(0008f4) {Bluetake Technology Co., Ltd.}
set vendor(0008f5) {YESTECHNOLOGY Co.,Ltd.}
set vendor(0008f6) {SUMITOMO ELECTRIC HIGHTECHS.co.,ltd.}
set vendor(0008f7) {Hitachi Ltd, Semiconductor &amp; Integrated Circuits Gr}
set vendor(0008f8) {Guardall Ltd}
set vendor(0008f9) {Padcom, Inc.}
set vendor(0008fa) {Karl E.Brinkmann GmbH}
set vendor(0008fb) {SonoSite, Inc.}
set vendor(0008fc) {Gigaphoton Inc.}
set vendor(0008fd) {BlueKorea Co., Ltd.}
set vendor(0008fe) {UNIK C&C Co.,Ltd.}
set vendor(0008ff) {Trilogy Broadcast (Holdings) Ltd}
set vendor(009000) {DIAMOND MULTIMEDIA}
set vendor(009001) {NISHIMU ELECTRONICS INDUSTRIES CO., LTD.}
set vendor(009010) {SIMULATION LABORATORIES, INC.}
set vendor(009011) {WAVTrace, Inc.}
set vendor(009012) {GLOBESPAN SEMICONDUCTOR, INC.}
set vendor(009013) {SAMSAN CORP.}
set vendor(009014) {ROTORK INSTRUMENTS, LTD.}
set vendor(009015) {CENTIGRAM COMMUNICATIONS CORP.}
set vendor(009016) {ZAC}
set vendor(009017) {ZYPCOM, INC.}
set vendor(009018) {ITO ELECTRIC INDUSTRY CO, LTD.}
set vendor(009019) {HERMES ELECTRONICS CO., LTD.}
set vendor(00901a) {UNISPHERE SOLUTIONS}
set vendor(00901b) {DIGITAL CONTROLS}
set vendor(00901c) {mps Software Gmbh}
set vendor(00901d) {PEC (NZ) LTD.}
set vendor(00901e) {SELESTA INGEGNE RIA S.P.A.}
set vendor(00901f) {ADTEC PRODUCTIONS, INC.}
set vendor(009002) {ALLGON AB}
set vendor(009020) {PHILIPS ANALYTICAL X-RAY B.V.}
set vendor(009021) {CISCO SYSTEMS, INC.}
set vendor(009022) {IVEX}
set vendor(009023) {ZILOG INC.}
set vendor(009024) {PIPELINKS, INC.}
set vendor(009025) {VISION SYSTEMS LTD. PTY}
set vendor(009026) {ADVANCED SWITCHING COMMUNICATIONS, INC.}
set vendor(009027) {INTEL CORPORATION}
set vendor(009028) {NIPPON SIGNAL CO., LTD.}
set vendor(009029) {CRYPTO AG}
set vendor(00902a) {COMMUNICATION DEVICES, INC.}
set vendor(00902b) {CISCO SYSTEMS, INC.}
set vendor(00902c) {DATA & CONTROL EQUIPMENT LTD.}
set vendor(00902d) {DATA ELECTRONICS (AUST.) PTY, LTD.}
set vendor(00902e) {NAMCO LIMITED}
set vendor(00902f) {NETCORE SYSTEMS, INC.}
set vendor(009003) {APLIO}
set vendor(009030) {HONEYWELL-DATING}
set vendor(009031) {MYSTICOM, LTD.}
set vendor(009032) {PELCOMBE GROUP LTD.}
set vendor(009033) {INNOVAPHONE GmbH}
set vendor(009034) {IMAGIC, INC.}
set vendor(009035) {ALPHA TELECOM, INC.}
set vendor(009036) {ens, inc.}
set vendor(009037) {ACUCOMM, INC.}
set vendor(009038) {FOUNTAIN TECHNOLOGIES, INC.}
set vendor(009039) {SHASTA NETWORKS}
set vendor(00903a) {NIHON MEDIA TOOL INC.}
set vendor(00903b) {TriEMS Research Lab, Inc.}
set vendor(00903c) {ATLANTIC NETWORK SYSTEMS}
set vendor(00903d) {BIOPAC SYSTEMS, INC.}
set vendor(00903e) {N.V. PHILIPS INDUSTRIAL ACTIVITIES}
set vendor(00903f) {AZTEC RADIOMEDIA}
set vendor(009004) {3COM EUROPE LTD.}
set vendor(009040) {Siemens Network Convergence LLC}
set vendor(009041) {APPLIED DIGITAL ACCESS}
set vendor(009042) {ECCS, Inc.}
set vendor(009043) {NICHIBEI DENSHI CO., LTD.}
set vendor(009044) {ASSURED DIGITAL, INC.}
set vendor(009045) {Marconi Communications}
set vendor(009046) {DEXDYNE, LTD.}
set vendor(009047) {GIGA FAST E. LTD.}
set vendor(009048) {ZEAL CORPORATION}
set vendor(009049) {ENTRIDIA CORPORATION}
set vendor(00904a) {CONCUR SYSTEM TECHNOLOGIES}
set vendor(00904b) {GemTek Technology Co., Ltd.}
set vendor(00904c) {EPIGRAM, INC.}
set vendor(00904d) {SPEC S.A.}
set vendor(00904e) {DELEM BV}
set vendor(00904f) {ABB POWER T&D COMPANY, INC.}
set vendor(009005) {PROTECH SYSTEMS CO., LTD.}
set vendor(009050) {TELESTE OY}
set vendor(009051) {ULTIMATE TECHNOLOGY CORP.}
set vendor(009052) {SELCOM ELETTRONICA S.R.L.}
set vendor(009053) {DAEWOO ELECTRONICS CO., LTD.}
set vendor(009054) {INNOVATIVE SEMICONDUCTORS, INC}
set vendor(009055) {PARKER HANNIFIN CORPORATION COMPUMOTOR DIVISION}
set vendor(009056) {TELESTREAM, INC.}
set vendor(009057) {AANetcom, Inc.}
set vendor(009058) {Ultra Electronics Ltd., Command and Control Systems}
set vendor(009059) {TELECOM DEVICE K.K.}
set vendor(00905a) {DEARBORN GROUP, INC.}
set vendor(00905b) {RAYMOND AND LAE ENGINEERING}
set vendor(00905c) {EDMI}
set vendor(00905d) {NETCOM SICHERHEITSTECHNIK GmbH}
set vendor(00905e) {RAULAND-BORG CORPORATION}
set vendor(00905f) {CISCO SYSTEMS, INC.}
set vendor(009006) {HAMAMATSU PHOTONICS K.K.}
set vendor(009060) {SYSTEM CREATE CORP.}
set vendor(009061) {PACIFIC RESEARCH & ENGINEERING CORPORATION}
set vendor(009062) {ICP VORTEX COMPUTERSYSTEME GmbH}
set vendor(009063) {COHERENT COMMUNICATIONS SYSTEMS CORPORATION}
set vendor(009064) {THOMSON BROADCAST SYSTEMS}
set vendor(009065) {FINISAR CORPORATION}
set vendor(009066) {Troika Networks, Inc.}
set vendor(009067) {WalkAbout Computers, Inc.}
set vendor(009068) {DVT CORP.}
set vendor(009069) {JUNIPER NETWORKS, INC.}
set vendor(00906a) {TURNSTONE SYSTEMS, INC.}
set vendor(00906b) {APPLIED RESOURCES, INC.}
set vendor(00906c) {GWT GLOBAL WEIGHING TECHNOLOGIES GmbH}
set vendor(00906d) {CISCO SYSTEMS, INC.}
set vendor(00906e) {PRAXON, INC.}
set vendor(00906f) {CISCO SYSTEMS, INC.}
set vendor(009007) {DOMEX TECHNOLOGY CORP.}
set vendor(009070) {NEO NETWORKS, INC.}
set vendor(009071) {Applied Innovation Inc.}
set vendor(009072) {SIMRAD AS}
set vendor(009073) {GAIO TECHNOLOGY}
set vendor(009074) {ARGON NETWORKS, INC.}
set vendor(009075) {NEC DO BRASIL S.A.}
set vendor(009076) {FMT AIRCRAFT GATE SUPPORT SYSTEMS AB}
set vendor(009077) {ADVANCED FIBRE COMMUNICATIONS}
set vendor(009078) {MER TELEMANAGEMENT SOLUTIONS, LTD.}
set vendor(009079) {ClearOne, Inc.}
set vendor(00907a) {SPECTRALINK CORP.}
set vendor(00907b) {E-TECH, INC.}
set vendor(00907c) {DIGITALCAST, INC.}
set vendor(00907d) {Lake Communications}
set vendor(00907e) {VETRONIX CORP.}
set vendor(00907f) {WatchGuard Technologies, Inc.}
set vendor(009008) {HanA Systems Inc.}
set vendor(009080) {NOT LIMITED, INC.}
set vendor(009081) {ALOHA NETWORKS, INC.}
set vendor(009082) {FORCE INSTITUTE}
set vendor(009083) {TURBO COMMUNICATION, INC.}
set vendor(009084) {ATECH SYSTEM}
set vendor(009085) {GOLDEN ENTERPRISES, INC.}
set vendor(009086) {CISCO SYSTEMS, INC.}
set vendor(009087) {ITIS}
set vendor(009088) {BAXALL SECURITY LTD.}
set vendor(009089) {SOFTCOM MICROSYSTEMS, INC.}
set vendor(00908a) {BAYLY COMMUNICATIONS, INC.}
set vendor(00908b) {CELL COMPUTING, INC.}
set vendor(00908c) {ETREND ELECTRONICS, INC.}
set vendor(00908d) {VICKERS ELECTRONICS SYSTEMS}
set vendor(00908e) {Nortel Networks Broadband Access}
set vendor(00908f) {AUDIO CODES LTD.}
set vendor(009009) {i Controls, Inc.}
set vendor(009090) {I-BUS}
set vendor(009091) {DigitalScape, Inc.}
set vendor(009092) {CISCO SYSTEMS, INC.}
set vendor(009093) {NANAO CORPORATION}
set vendor(009094) {OSPREY TECHNOLOGIES, INC.}
set vendor(009095) {UNIVERSAL AVIONICS}
set vendor(009096) {ASKEY COMPUTER CORP.}
set vendor(009097) {SYCAMORE NETWORKS}
set vendor(009098) {SBC DESIGNS, INC.}
set vendor(009099) {ALLIED TELESIS, K.K.}
set vendor(00909a) {ONE WORLD SYSTEMS, INC.}
set vendor(00909b) {MARKPOINT AB}
set vendor(00909c) {Terayon Communications Systems}
set vendor(00909d) {GSE SYSTEMS, INC.}
set vendor(00909e) {Critical IO, LLC}
set vendor(00909f) {DIGI-DATA CORPORATION}
set vendor(00900a) {PROTON ELECTRONIC INDUSTRIAL CO., LTD.}
set vendor(0090a0) {8X8 INC.}
set vendor(0090a1) {FLYING PIG SYSTEMS, LTD.}
set vendor(0090a2) {CYBERTAN TECHNOLOGY, INC.}
set vendor(0090a3) {Corecess Inc.}
set vendor(0090a4) {ALTIGA NETWORKS}
set vendor(0090a5) {SPECTRA LOGIC}
set vendor(0090a6) {CISCO SYSTEMS, INC.}
set vendor(0090a7) {CLIENTEC CORPORATION}
set vendor(0090a8) {NineTiles Networks, Ltd.}
set vendor(0090a9) {WESTERN DIGITAL}
set vendor(0090aa) {INDIGO ACTIVE VISION SYSTEMS LIMITED}
set vendor(0090ab) {CISCO SYSTEMS, INC.}
set vendor(0090ac) {OPTIVISION, INC.}
set vendor(0090ad) {ASPECT ELECTRONICS, INC.}
set vendor(0090ae) {ITALTEL S.p.A.}
set vendor(0090af) {J. MORITA MFG. CORP.}
set vendor(00900b) {LANNER ELECTRONICS, INC.}
set vendor(0090b0) {VADEM}
set vendor(0090b1) {CISCO SYSTEMS, INC.}
set vendor(0090b2) {AVICI SYSTEMS INC.}
set vendor(0090b3) {AGRANAT SYSTEMS}
set vendor(0090b4) {WILLOWBROOK TECHNOLOGIES}
set vendor(0090b5) {NIKON CORPORATION}
set vendor(0090b6) {FIBEX SYSTEMS}
set vendor(0090b7) {DIGITAL LIGHTWAVE, INC.}
set vendor(0090b8) {ROHDE & SCHWARZ GMBH & CO. KG}
set vendor(0090b9) {BERAN INSTRUMENTS LTD.}
set vendor(0090ba) {VALID NETWORKS, INC.}
set vendor(0090bb) {TAINET COMMUNICATION SYSTEM Corp.}
set vendor(0090bc) {TELEMANN CO., LTD.}
set vendor(0090bd) {OMNIA COMMUNICATIONS, INC.}
set vendor(0090be) {IBC/INTEGRATED BUSINESS COMPUTERS}
set vendor(0090bf) {CISCO SYSTEMS, INC.}
set vendor(00900c) {CISCO SYSTEMS, INC.}
set vendor(0090c0) {K.J. LAW ENGINEERS, INC.}
set vendor(0090c1) {Peco II, Inc.}
set vendor(0090c2) {JK microsystems, Inc.}
set vendor(0090c3) {TOPIC SEMICONDUCTOR CORP.}
set vendor(0090c4) {JAVELIN SYSTEMS, INC.}
set vendor(0090c5) {INTERNET MAGIC, INC.}
set vendor(0090c6) {OPTIM SYSTEMS, INC.}
set vendor(0090c7) {ICOM INC.}
set vendor(0090c8) {WAVERIDER COMMUNICATIONS (CANADA) INC.}
set vendor(0090c9) {DPAC Technologies}
set vendor(0090ca) {ACCORD VIDEO TELECOMMUNICATIONS, LTD.}
set vendor(0090cb) {Wireless OnLine, Inc.}
set vendor(0090cc) {PLANET COMMUNICATIONS, INC.}
set vendor(0090cd) {ENT-EMPRESA NACIONAL DE TELECOMMUNICACOES, S.A.}
set vendor(0090ce) {TETRA GmbH}
set vendor(0090cf) {NORTEL}
set vendor(00900d) {OVERLAND DATA INC.}
set vendor(0090d0) {Thomson Belgium}
set vendor(0090d1) {LEICHU ENTERPRISE CO., LTD.}
set vendor(0090d2) {ARTEL VIDEO SYSTEMS}
set vendor(0090d3) {GIESECKE & DEVRIENT GmbH}
set vendor(0090d4) {BindView Development Corp.}
set vendor(0090d5) {EUPHONIX, INC.}
set vendor(0090d6) {CRYSTAL GROUP}
set vendor(0090d7) {NetBoost Corp.}
set vendor(0090d8) {WHITECROSS SYSTEMS}
set vendor(0090d9) {CISCO SYSTEMS, INC.}
set vendor(0090da) {DYNARC, INC.}
set vendor(0090db) {NEXT LEVEL COMMUNICATIONS}
set vendor(0090dc) {TECO INFORMATION SYSTEMS}
set vendor(0090dd) {THE MIHARU COMMUNICATIONS CO., LTD.}
set vendor(0090de) {CARDKEY SYSTEMS, INC.}
set vendor(0090df) {MITSUBISHI CHEMICAL AMERICA, INC.}
set vendor(00900e) {HANDLINK TECHNOLOGIES, INC.}
set vendor(0090e0) {SYSTRAN CORP.}
set vendor(0090e1) {TELENA S.P.A.}
set vendor(0090e2) {DISTRIBUTED PROCESSING TECHNOLOGY}
set vendor(0090e3) {AVEX ELECTRONICS INC.}
set vendor(0090e4) {NEC AMERICA, INC.}
set vendor(0090e5) {TEKNEMA, INC.}
set vendor(0090e6) {ACER LABORATORIES, INC.}
set vendor(0090e7) {HORSCH ELEKTRONIK AG}
set vendor(0090e8) {MOXA TECHNOLOGIES CORP., LTD.}
set vendor(0090e9) {JANZ COMPUTER AG}
set vendor(0090ea) {ALPHA TECHNOLOGIES, INC.}
set vendor(0090eb) {SENTRY TELECOM SYSTEMS}
set vendor(0090ec) {PYRESCOM}
set vendor(0090ed) {CENTRAL SYSTEM RESEARCH CO., LTD.}
set vendor(0090ee) {PERSONAL COMMUNICATIONS TECHNOLOGIES}
set vendor(0090ef) {INTEGRIX, INC.}
set vendor(00900f) {KAWASAKI HEAVY INDUSTRIES, LTD}
set vendor(0090f0) {HARMONIC LIGHTWAVES, LTD.}
set vendor(0090f1) {DOT HILL SYSTEMS CORPORATION}
set vendor(0090f2) {CISCO SYSTEMS, INC.}
set vendor(0090f3) {ASPECT COMMUNICATIONS}
set vendor(0090f4) {LIGHTNING INSTRUMENTATION}
set vendor(0090f5) {CLEVO CO.}
set vendor(0090f6) {ESCALATE NETWORKS, INC.}
set vendor(0090f7) {NBASE COMMUNICATIONS LTD.}
set vendor(0090f8) {MEDIATRIX TELECOM}
set vendor(0090f9) {LEITCH}
set vendor(0090fa) {GigaNet, Inc.}
set vendor(0090fb) {PORTWELL, INC.}
set vendor(0090fc) {NETWORK COMPUTING DEVICES}
set vendor(0090fd) {CopperCom, Inc.}
set vendor(0090fe) {ELECOM CO., LTD.  (LANEED DIV.)}
set vendor(0090ff) {TELLUS TECHNOLOGY INC.}
set vendor(0091d6) {Crystal Group, Inc.}
set vendor(000900) {TMT}
set vendor(000901) {Shenzhen Shixuntong Information & Technoligy Co}
set vendor(000910) {Simple Access Inc.}
set vendor(000911) {Cisco Systems}
set vendor(000912) {Cisco Systems}
set vendor(000914) {COMPUTROLS INC.}
set vendor(000915) {CAS Corp.}
set vendor(000916) {Listman Home Technologies, Inc.}
set vendor(000917) {WEM Technology Inc}
set vendor(000918) {SAMSUNG TECHWIN CO.,LTD}
set vendor(000919) {MDS Gateways}
set vendor(00091a) {Macat Optics & Electronics Co., Ltd.}
set vendor(00091b) {Digital Generation Inc.}
set vendor(00091c) {CacheVision, Inc}
set vendor(00091d) {Proteam Computer Corporation}
set vendor(00091e) {Firstech Technology Corp.}
set vendor(00091f) {A&amp;D Co., Ltd.}
set vendor(000902) {Redline Communications Inc.}
set vendor(000920) {EpoX COMPUTER CO.,LTD.}
set vendor(000921) {Planmeca Oy}
set vendor(000922) {Touchless Sensor Technology AG}
set vendor(000923) {Heaman System Co., Ltd}
set vendor(000924) {Telebau GmbH}
set vendor(000925) {VSN Systemen BV}
set vendor(000926) {YODA COMMUNICATIONS, INC.}
set vendor(000927) {TOYOKEIKI CO.,LTD.}
set vendor(000928) {Telecore Inc}
set vendor(000929) {Sanyo Industries (UK) Limited}
set vendor(00092a) {MYTECS Co.,Ltd.}
set vendor(00092b) {iQstor Networks, Inc.}
set vendor(00092c) {Hitpoint Inc.}
set vendor(00092d) {High Tech Computer, Corp.}
set vendor(00092e) {B&Tech System Inc.}
set vendor(00092f) {Akom Technology Corporation}
set vendor(000903) {Panasas, Inc}
set vendor(000930) {AeroConcierge Inc.}
set vendor(000931) {Future Internet, Inc.}
set vendor(000932) {Omnilux}
set vendor(000933) {OPTOVALLEY Co. Ltd.}
set vendor(000934) {Dream-Multimedia-Tv GmbH}
set vendor(000935) {Sandvine Incorporated}
set vendor(000936) {Ipetronik GmbH & Co.KG}
set vendor(000937) {Inventec Appliance Corp}
set vendor(000938) {Allot Communications}
set vendor(000939) {ShibaSoku Co.,Ltd.}
set vendor(00093a) {Molex Fiber Optics}
set vendor(00093b) {HYUNDAI NETWORKS INC.}
set vendor(00093c) {Jacques Technologies P/L}
set vendor(00093d) {Newisys,Inc.}
set vendor(00093e) {C&I Technologies}
set vendor(00093f) {Double-Win Enterpirse CO., LTD}
set vendor(000904) {MONDIAL electronic}
set vendor(000940) {AGFEO GmbH & Co. KG}
set vendor(000941) {Allied Telesis K.K.}
set vendor(000942) {CRESCO, LTD.}
set vendor(000943) {Cisco Systems}
set vendor(000944) {Cisco Systems}
set vendor(000945) {Palmmicro Communications Inc}
set vendor(000946) {Cluster Labs GmbH}
set vendor(000947) {Aztek, Inc.}
set vendor(000948) {Vista Control Systems, Corp.}
set vendor(000949) {Glyph Technologies Inc.}
set vendor(00094a) {Homenet Communications}
set vendor(00094b) {FillFactory NV}
set vendor(00094c) {Communication Weaver Co.,Ltd.}
set vendor(00094d) {Braintree Communications Pty Ltd}
set vendor(00094e) {BARTECH SYSTEMS INTERNATIONAL, INC}
set vendor(00094f) {elmegt GmbH & Co. KG}
set vendor(000905) {iTEC Technologies Ltd.}
set vendor(000950) {Independent Storage Corporation}
set vendor(000951) {Apogee Instruments, Inc}
set vendor(000952) {Auerswald GmbH & Co. KG}
set vendor(000953) {Linkage System Integration Co.Ltd.}
set vendor(000954) {AMiT spol. s. r. o.}
set vendor(000955) {Young Generation International Corp.}
set vendor(000956) {Network Systems Group, Ltd. (NSG)}
set vendor(000957) {Supercaller, Inc.}
set vendor(000958) {INTELNET S.A.}
set vendor(000959) {Sitecsoft}
set vendor(00095a) {RACEWOOD TECHNOLOGY}
set vendor(00095b) {Netgear, Inc.}
set vendor(00095c) {Philips Medical Systems - Cardiac and Monitoring Systems (CM}
set vendor(00095d) {Dialogue Technology Corp.}
set vendor(00095e) {Masstech Group Inc.}
set vendor(00095f) {Telebyte, Inc.}
set vendor(000906) {Esteem Networks}
set vendor(000960) {YOZAN Inc.}
set vendor(000961) {Switchgear and Instrumentation Ltd}
set vendor(000962) {Filetrac AS}
set vendor(000963) {Dominion Lasercom Inc.}
set vendor(000964) {Hi-Techniques}
set vendor(000966) {Thales Navigation}
set vendor(000967) {Tachyon, Inc}
set vendor(000968) {TECHNOVENTURE, INC.}
set vendor(000969) {Meret Optical Communications}
set vendor(00096a) {Cloverleaf Communications Inc.}
set vendor(00096b) {IBM Corporation}
set vendor(00096c) {Imedia Semiconductor Corp.}
set vendor(00096d) {Powernet Technologies Corp.}
set vendor(00096e) {GIANT ELECTRONICS LTD.}
set vendor(00096f) {Beijing Zhongqing Elegant Tech. Corp.,Limited}
set vendor(000907) {Chrysalis Development}
set vendor(000970) {Vibration Research Corporation}
set vendor(000971) {Time Management, Inc.}
set vendor(000972) {Securebase,Inc}
set vendor(000973) {Lenten Technology Co., Ltd.}
set vendor(000974) {Innopia Technologies, Inc.}
set vendor(000975) {fSONA Communications Corporation}
set vendor(000976) {Datasoft ISDN Systems GmbH}
set vendor(000977) {Brunner Elektronik AG}
set vendor(000978) {AIJI System Co., Ltd.}
set vendor(000979) {Advanced Television Systems Committee, Inc.}
set vendor(00097a) {Louis Design Labs.}
set vendor(00097b) {Cisco Systems}
set vendor(00097c) {Cisco Systems}
set vendor(00097d) {SecWell Networks Oy}
set vendor(00097e) {IMI TECHNOLOGY CO., LTD}
set vendor(00097f) {Vsecure 2000 LTD.}
set vendor(000908) {VTech Technology Corp.}
set vendor(000980) {Power Zenith Inc.}
set vendor(000981) {Newport Networks}
set vendor(000982) {Loewe Opta GmbH}
set vendor(000983) {Gvision Incorporated}
set vendor(000984) {MyCasa Network Inc.}
set vendor(000985) {Auto Telecom Company}
set vendor(000986) {Metalink LTD.}
set vendor(000987) {NISHI NIPPON ELECTRIC WIRE & CABLE CO.,LTD.}
set vendor(000988) {Nudian Electron Co., Ltd.}
set vendor(000989) {VividLogic Inc.}
set vendor(00098a) {EqualLogic Inc}
set vendor(00098b) {Entropic Communications, Inc.}
set vendor(00098c) {Possio AB}
set vendor(00098d) {DCT Ltd (Digital Communication Technologies Ltd)}
set vendor(00098e) {ipcas GmbH}
set vendor(00098f) {Cetacean Networks}
set vendor(000909) {Telenor Connect A/S}
set vendor(000990) {ACKSYS Communications & systems}
set vendor(000991) {GE Fanuc Automation Manufacturing, Inc.}
set vendor(000992) {InterEpoch Technology,INC.}
set vendor(000993) {Visteon Corporation}
set vendor(000994) {Cronyx Engineering}
set vendor(000995) {Castle Technology Ltd}
set vendor(000996) {RDI}
set vendor(000997) {Nortel Networks}
set vendor(000998) {Capinfo Company Limited}
set vendor(000999) {CP GEORGES RENAULT}
set vendor(00099a) {ELMO COMPANY, LIMITED}
set vendor(00099b) {Western Telematic Inc.}
set vendor(00099c) {Naval Research Laboratory}
set vendor(00099d) {Haliplex Communications}
set vendor(00099e) {Testech, Inc.}
set vendor(00099f) {VIDEX INC.}
set vendor(00090a) {SnedFar Technology Co., Ltd.}
set vendor(0009a0) {Microtechno Corporation}
set vendor(0009a1) {Telewise Communications, Inc.}
set vendor(0009a2) {Interface Co., Ltd.}
set vendor(0009a3) {Leadfly Techologies Corp. Ltd.}
set vendor(0009a4) {HARTEC Corporation}
set vendor(0009a5) {HANSUNG ELETRONIC INDUSTRIES DEVELOPMENT CO., LTD}
set vendor(0009a6) {Ignis Optics, Inc.}
set vendor(0009a7) {Bang & Olufsen A/S}
set vendor(0009a8) {Eastmode Pte Ltd}
set vendor(0009a9) {Ikanos Communications}
set vendor(0009aa) {Data Comm for Business, Inc.}
set vendor(0009ab) {Netcontrol Oy}
set vendor(0009ac) {LANVOICE}
set vendor(0009ad) {HYUNDAI SYSCOMM, INC.}
set vendor(0009ae) {OKANO ELECTRIC CO.,LTD}
set vendor(0009af) {e-generis}
set vendor(00090b) {MTL  Instruments PLC}
set vendor(0009b0) {Onkyo Corporation}
set vendor(0009b1) {Kanematsu Electronics, Ltd.}
set vendor(0009b2) {L&F Inc.}
set vendor(0009b3) {MCM Systems Ltd}
set vendor(0009b4) {KISAN TELECOM CO., LTD.}
set vendor(0009b5) {3J Tech. Co., Ltd.}
set vendor(0009b6) {Cisco Systems}
set vendor(0009b7) {Cisco Systems}
set vendor(0009b8) {Entise Systems}
set vendor(0009b9) {Action Imaging Solutions}
set vendor(0009ba) {MAKU Informationstechik GmbH}
set vendor(0009bb) {MathStar, Inc.}
set vendor(0009bc) {Digital Safety Technologies Inc.}
set vendor(0009bd) {Epygi Technologies, Ltd.}
set vendor(0009be) {Mamiya-OP Co.,Ltd.}
set vendor(0009bf) {Nintendo Co.,Ltd.}
set vendor(00090c) {Mayekawa Mfg. Co. Ltd.}
set vendor(0009c0) {6WIND}
set vendor(0009c1) {PROCES-DATA A/S}
set vendor(0009c3) {NETAS}
set vendor(0009c4) {Medicore Co., Ltd}
set vendor(0009c5) {KINGENE Technology Corporation}
set vendor(0009c6) {Visionics Corporation}
set vendor(0009c7) {Movistec}
set vendor(0009c8) {SINAGAWA TSUSHIN KEISOU SERVICE}
set vendor(0009c9) {BlueWINC Co., Ltd.}
set vendor(0009ca) {iMaxNetworks(Shenzhen)Limited.}
set vendor(0009cb) {HBrain}
set vendor(0009cc) {Moog GmbH}
set vendor(0009cd) {HUDSON SOFT CO.,LTD.}
set vendor(0009ce) {SpaceBridge Semiconductor Corp.}
set vendor(0009cf) {iAd GmbH}
set vendor(00090d) {LEADER ELECTRONICS CORP.}
set vendor(0009d0) {Versatel Networks}
set vendor(0009d1) {SERANOA NETWORKS INC}
set vendor(0009d2) {Mai Logic Inc.}
set vendor(0009d3) {Western DataCom Co., Inc.}
set vendor(0009d4) {Transtech Networks}
set vendor(0009d5) {Signal Communication, Inc.}
set vendor(0009d6) {KNC One GmbH}
set vendor(0009d7) {DC Security Products}
set vendor(0009d9) {Neoscale Systems, Inc}
set vendor(0009da) {Control Module Inc.}
set vendor(0009db) {eSpace}
set vendor(0009dc) {Galaxis Technology AG}
set vendor(0009dd) {Mavin Technology Inc.}
set vendor(0009de) {Samjin Information & Communications Co., Ltd.}
set vendor(0009df) {Vestel Komunikasyon Sanayi ve Ticaret A.S.}
set vendor(00090e) {Helix Technology Inc.}
set vendor(0009e0) {XEMICS S.A.}
set vendor(0009e1) {Gemtek Technology Co., Ltd.}
set vendor(0009e2) {Sinbon Electronics Co., Ltd.}
set vendor(0009e3) {Angel Iglesias S.A.}
set vendor(0009e4) {K Tech Infosystem Inc.}
set vendor(0009e5) {Hottinger Baldwin Messtechnik GmbH}
set vendor(0009e6) {Cyber Switching Inc.}
set vendor(0009e7) {ADC Techonology}
set vendor(0009e8) {Cisco Systems}
set vendor(0009e9) {Cisco Systems}
set vendor(0009ea) {YEM Inc.}
set vendor(0009eb) {HuMANDATA LTD.}
set vendor(0009ec) {Daktronics, Inc.}
set vendor(0009ed) {CipherOptics}
set vendor(0009ee) {MEIKYO ELECTRIC CO.,LTD}
set vendor(0009ef) {Vocera Communications}
set vendor(00090f) {Fortinet Inc.}
set vendor(0009f0) {Shimizu Technology Inc.}
set vendor(0009f1) {Yamaki Electric Corporation}
set vendor(0009f2) {Cohu, Inc., Electronics Division}
set vendor(0009f3) {WELL Communication Corp.}
set vendor(0009f4) {Alcon Laboratories, Inc.}
set vendor(0009f5) {Emerson Network Power Co.,Ltd}
set vendor(0009f6) {Shenzhen Eastern Digital Tech Ltd.}
set vendor(0009f7) {SED, a division of Calian}
set vendor(0009f8) {UNIMO TECHNOLOGY CO., LTD.}
set vendor(0009f9) {ART JAPAN CO., LTD.}
set vendor(0009fb) {Philips Medizinsysteme Boeblingen GmbH}
set vendor(0009fc) {IPFLEX Inc.}
set vendor(0009fd) {Ubinetics Limited}
set vendor(0009fe) {Daisy Technologies, Inc.}
set vendor(0009ff) {X.net 2000 GmbH}
set vendor(009d8e) {CARDIAC RECORDERS, INC.}
set vendor(00a000) {CENTILLION NETWORKS, INC.}
set vendor(00a001) {WATKINS-JOHNSON COMPANY}
set vendor(00a010) {SYSLOGIC DATENTECHNIK AG}
set vendor(00a011) {MUTOH INDUSTRIES LTD.}
set vendor(00a012) {B.A.T.M. ADVANCED TECHNOLOGIES}
set vendor(00a013) {TELTREND LTD.}
set vendor(00a014) {CSIR}
set vendor(00a015) {WYLE}
set vendor(00a016) {MICROPOLIS CORP.}
set vendor(00a017) {J B M CORPORATION}
set vendor(00a018) {CREATIVE CONTROLLERS, INC.}
set vendor(00a019) {NEBULA CONSULTANTS, INC.}
set vendor(00a01a) {BINAR ELEKTRONIK AB}
set vendor(00a01b) {PREMISYS COMMUNICATIONS, INC.}
set vendor(00a01c) {NASCENT NETWORKS CORPORATION}
set vendor(00a01d) {SIXNET}
set vendor(00a01e) {EST CORPORATION}
set vendor(00a01f) {TRICORD SYSTEMS, INC.}
set vendor(00a002) {LEEDS & NORTHRUP AUSTRALIA PTY LTD}
set vendor(00a020) {CITICORP/TTI}
set vendor(00a021) {GENERAL DYNAMICS-}
set vendor(00a022) {CENTRE FOR DEVELOPMENT OF ADVANCED COMPUTING}
set vendor(00a023) {APPLIED CREATIVE TECHNOLOGY, INC.}
set vendor(00a024) {3COM CORPORATION}
set vendor(00a025) {REDCOM LABS INC.}
set vendor(00a026) {TELDAT, S.A.}
set vendor(00a027) {FIREPOWER SYSTEMS, INC.}
set vendor(00a028) {CONNER PERIPHERALS}
set vendor(00a029) {COULTER CORPORATION}
set vendor(00a02a) {TRANCELL SYSTEMS}
set vendor(00a02b) {TRANSITIONS RESEARCH CORP.}
set vendor(00a02c) {interWAVE Communications}
set vendor(00a02d) {1394 Trade Association}
set vendor(00a02e) {BRAND COMMUNICATIONS, LTD.}
set vendor(00a02f) {PIRELLI CAVI}
set vendor(00a003) {STAEFA CONTROL SYSTEM}
set vendor(00a030) {CAPTOR NV/SA}
set vendor(00a031) {HAZELTINE CORPORATION, MS 1-17}
set vendor(00a032) {GES SINGAPORE PTE. LTD.}
set vendor(00a033) {imc MeBsysteme GmbH}
set vendor(00a034) {AXEL}
set vendor(00a035) {CYLINK CORPORATION}
set vendor(00a036) {APPLIED NETWORK TECHNOLOGY}
set vendor(00a037) {DATASCOPE CORPORATION}
set vendor(00a038) {EMAIL ELECTRONICS}
set vendor(00a039) {ROSS TECHNOLOGY, INC.}
set vendor(00a03a) {KUBOTEK CORPORATION}
set vendor(00a03b) {TOSHIN ELECTRIC CO., LTD.}
set vendor(00a03c) {EG&G NUCLEAR INSTRUMENTS}
set vendor(00a03d) {OPTO-22}
set vendor(00a03e) {ATM FORUM}
set vendor(00a03f) {COMPUTER SOCIETY MICROPROCESSOR & MICROPROCESSOR STANDARDS C}
set vendor(00a004) {NETPOWER, INC.}
set vendor(00a040) {APPLE COMPUTER}
set vendor(00a041) {LEYBOLD-INFICON}
set vendor(00a042) {SPUR PRODUCTS CORP.}
set vendor(00a043) {AMERICAN TECHNOLOGY LABS, INC.}
set vendor(00a044) {NTT IT CO., LTD.}
set vendor(00a045) {PHOENIX CONTACT GMBH & CO.}
set vendor(00a046) {SCITEX CORP. LTD.}
set vendor(00a047) {INTEGRATED FITNESS CORP.}
set vendor(00a048) {QUESTECH, LTD.}
set vendor(00a049) {DIGITECH INDUSTRIES, INC.}
set vendor(00a04a) {NISSHIN ELECTRIC CO., LTD.}
set vendor(00a04b) {TFL LAN INC.}
set vendor(00a04c) {INNOVATIVE SYSTEMS & TECHNOLOGIES, INC.}
set vendor(00a04d) {EDA INSTRUMENTS, INC.}
set vendor(00a04e) {VOELKER TECHNOLOGIES, INC.}
set vendor(00a04f) {AMERITEC CORP.}
set vendor(00a005) {DANIEL INSTRUMENTS, LTD.}
set vendor(00a050) {CYPRESS SEMICONDUCTOR}
set vendor(00a051) {ANGIA COMMUNICATIONS. INC.}
set vendor(00a052) {STANILITE ELECTRONICS PTY. LTD}
set vendor(00a053) {COMPACT DEVICES, INC.}
set vendor(00a055) {Data Device Corporation}
set vendor(00a056) {MICROPROSS}
set vendor(00a057) {LANCOM Systems GmbH}
set vendor(00a058) {GLORY, LTD.}
set vendor(00a059) {HAMILTON HALLMARK}
set vendor(00a05a) {KOFAX IMAGE PRODUCTS}
set vendor(00a05b) {MARQUIP, INC.}
set vendor(00a05c) {INVENTORY CONVERSION, INC./}
set vendor(00a05d) {CS COMPUTER SYSTEME GmbH}
set vendor(00a05e) {MYRIAD LOGIC INC.}
set vendor(00a05f) {BTG ENGINEERING BV}
set vendor(00a006) {IMAGE DATA PROCESSING SYSTEM GROUP}
set vendor(00a060) {ACER PERIPHERALS, INC.}
set vendor(00a061) {PURITAN BENNETT}
set vendor(00a062) {AES PRODATA}
set vendor(00a063) {JRL SYSTEMS, INC.}
set vendor(00a064) {KVB/ANALECT}
set vendor(00a065) {NEXLAND, INC.}
set vendor(00a066) {ISA CO., LTD.}
set vendor(00a067) {NETWORK SERVICES GROUP}
set vendor(00a068) {BHP LIMITED}
set vendor(00a069) {Symmetricom, Inc.}
set vendor(00a06a) {Verilink Corporation}
set vendor(00a06b) {DMS DORSCH MIKROSYSTEM GMBH}
set vendor(00a06c) {SHINDENGEN ELECTRIC MFG. CO., LTD.}
set vendor(00a06d) {MANNESMANN TALLY CORPORATION}
set vendor(00a06e) {AUSTRON, INC.}
set vendor(00a06f) {THE APPCON GROUP, INC.}
set vendor(00a007) {APEXX TECHNOLOGY, INC.}
set vendor(00a070) {COASTCOM}
set vendor(00a071) {VIDEO LOTTERY TECHNOLOGIES,INC}
set vendor(00a072) {OVATION SYSTEMS LTD.}
set vendor(00a073) {COM21, INC.}
set vendor(00a074) {PERCEPTION TECHNOLOGY}
set vendor(00a075) {MICRON TECHNOLOGY, INC.}
set vendor(00a076) {CARDWARE LAB, INC.}
set vendor(00a077) {FUJITSU NEXION, INC.}
set vendor(00a078) {Marconi Communications}
set vendor(00a079) {ALPS ELECTRIC (USA), INC.}
set vendor(00a07a) {ADVANCED PERIPHERALS TECHNOLOGIES, INC.}
set vendor(00a07b) {DAWN COMPUTER INCORPORATION}
set vendor(00a07c) {TONYANG NYLON CO., LTD.}
set vendor(00a07d) {SEEQ TECHNOLOGY, INC.}
set vendor(00a07e) {AVID TECHNOLOGY, INC.}
set vendor(00a07f) {GSM-SYNTEL, LTD.}
set vendor(00a008) {NETCORP}
set vendor(00a080) {ANTARES MICROSYSTEMS}
set vendor(00a081) {ALCATEL DATA NETWORKS}
set vendor(00a082) {NKT ELEKTRONIK A/S}
set vendor(00a083) {ASIMMPHONY TURKEY}
set vendor(00a084) {DATAPLEX PTY. LTD.}
set vendor(00a086) {AMBER WAVE SYSTEMS, INC.}
set vendor(00a087) {Zarlink Semiconductor Ltd.}
set vendor(00a088) {ESSENTIAL COMMUNICATIONS}
set vendor(00a089) {XPOINT TECHNOLOGIES, INC.}
set vendor(00a08a) {BROOKTROUT TECHNOLOGY, INC.}
set vendor(00a08b) {ASTON ELECTRONIC DESIGNS LTD.}
set vendor(00a08c) {MultiMedia LANs, Inc.}
set vendor(00a08d) {JACOMO CORPORATION}
set vendor(00a08e) {Nokia Internet Communications}
set vendor(00a08f) {DESKNET SYSTEMS, INC.}
set vendor(00a009) {WHITETREE NETWORK}
set vendor(00a090) {TimeStep Corporation}
set vendor(00a091) {APPLICOM INTERNATIONAL}
set vendor(00a092) {H. BOLLMANN MANUFACTURERS, LTD}
set vendor(00a093) {B/E AEROSPACE, Inc.}
set vendor(00a094) {COMSAT CORPORATION}
set vendor(00a095) {ACACIA NETWORKS, INC.}
set vendor(00a096) {MITUMI ELECTRIC CO., LTD.}
set vendor(00a097) {JC INFORMATION SYSTEMS}
set vendor(00a098) {NETWORK APPLIANCE CORP.}
set vendor(00a099) {K-NET LTD.}
set vendor(00a09a) {NIHON KOHDEN AMERICA}
set vendor(00a09b) {QPSX COMMUNICATIONS, LTD.}
set vendor(00a09c) {Xyplex, Inc.}
set vendor(00a09d) {JOHNATHON FREEMAN TECHNOLOGIES}
set vendor(00a09e) {ICTV}
set vendor(00a09f) {COMMVISION CORP.}
set vendor(00a00a) {R.D.C. COMMUNICATION}
set vendor(00a0a0) {COMPACT DATA, LTD.}
set vendor(00a0a1) {EPIC DATA INC.}
set vendor(00a0a2) {DIGICOM S.P.A.}
set vendor(00a0a3) {RELIABLE POWER METERS}
set vendor(00a0a4) {MICROS SYSTEMS, INC.}
set vendor(00a0a5) {TEKNOR MICROSYSTEME, INC.}
set vendor(00a0a6) {M.I. SYSTEMS, K.K.}
set vendor(00a0a7) {VORAX CORPORATION}
set vendor(00a0a8) {RENEX CORPORATION}
set vendor(00a0a9) {GN NETTEST (CANADA) NAVTEL DIVISION}
set vendor(00a0aa) {SPACELABS MEDICAL}
set vendor(00a0ab) {NETCS INFORMATIONSTECHNIK GMBH}
set vendor(00a0ac) {GILAT SATELLITE NETWORKS, LTD.}
set vendor(00a0ad) {MARCONI SPA}
set vendor(00a0ae) {NUCOM SYSTEMS, INC.}
set vendor(00a0af) {WMS INDUSTRIES}
set vendor(00a00b) {COMPUTEX CO., LTD.}
set vendor(00a0b0) {I-O DATA DEVICE, INC.}
set vendor(00a0b1) {FIRST VIRTUAL CORPORATION}
set vendor(00a0b2) {SHIMA SEIKI}
set vendor(00a0b3) {ZYKRONIX}
set vendor(00a0b4) {TEXAS MICROSYSTEMS, INC.}
set vendor(00a0b5) {3H TECHNOLOGY}
set vendor(00a0b6) {SANRITZ AUTOMATION CO., LTD.}
set vendor(00a0b7) {CORDANT, INC.}
set vendor(00a0b8) {SYMBIOS LOGIC INC.}
set vendor(00a0b9) {EAGLE TECHNOLOGY, INC.}
set vendor(00a0ba) {PATTON ELECTRONICS CO.}
set vendor(00a0bb) {HILAN GMBH}
set vendor(00a0bc) {VIASAT, INCORPORATED}
set vendor(00a0bd) {I-TECH CORP.}
set vendor(00a0be) {INTEGRATED CIRCUIT SYSTEMS, INC. COMMUNICATIONS GROUP}
set vendor(00a0bf) {WIRELESS DATA GROUP MOTOROLA}
set vendor(00a00c) {KINGMAX TECHNOLOGY, INC.}
set vendor(00a0c0) {DIGITAL LINK CORP.}
set vendor(00a0c1) {ORTIVUS MEDICAL AB}
set vendor(00a0c2) {R.A. SYSTEMS CO., LTD.}
set vendor(00a0c3) {UNICOMPUTER GMBH}
set vendor(00a0c4) {CRISTIE ELECTRONICS LTD.}
set vendor(00a0c5) {ZYXEL COMMUNICATION}
set vendor(00a0c6) {QUALCOMM INCORPORATED}
set vendor(00a0c7) {TADIRAN TELECOMMUNICATIONS}
set vendor(00a0c8) {ADTRAN INC.}
set vendor(00a0c9) {INTEL CORPORATION - HF1-06}
set vendor(00a0ca) {FUJITSU DENSO LTD.}
set vendor(00a0cb) {ARK TELECOMMUNICATIONS, INC.}
set vendor(00a0cc) {LITE-ON COMMUNICATIONS, INC.}
set vendor(00a0cd) {DR. JOHANNES HEIDENHAIN GmbH}
set vendor(00a0ce) {ASTROCOM CORPORATION}
set vendor(00a0cf) {SOTAS, INC.}
set vendor(00a00d) {THE PANDA PROJECT}
set vendor(00a0d0) {TEN X TECHNOLOGY, INC.}
set vendor(00a0d1) {INVENTEC CORPORATION}
set vendor(00a0d2) {ALLIED TELESIS INTERNATIONAL CORPORATION}
set vendor(00a0d3) {INSTEM COMPUTER SYSTEMS, LTD.}
set vendor(00a0d4) {RADIOLAN,  INC.}
set vendor(00a0d5) {SIERRA WIRELESS INC.}
set vendor(00a0d6) {SBE, INC.}
set vendor(00a0d7) {KASTEN CHASE APPLIED RESEARCH}
set vendor(00a0d8) {SPECTRA - TEK}
set vendor(00a0d9) {CONVEX COMPUTER CORPORATION}
set vendor(00a0da) {INTEGRATED SYSTEMS Technology, Inc.}
set vendor(00a0db) {FISHER & PAYKEL PRODUCTION}
set vendor(00a0dc) {O.N. ELECTRONIC CO., LTD.}
set vendor(00a0dd) {AZONIX CORPORATION}
set vendor(00a0de) {YAMAHA CORPORATION}
set vendor(00a0df) {STS TECHNOLOGIES, INC.}
set vendor(00a00e) {VISUAL NETWORKS, INC.}
set vendor(00a0e0) {TENNYSON TECHNOLOGIES PTY LTD}
set vendor(00a0e1) {WESTPORT RESEARCH ASSOCIATES, INC.}
set vendor(00a0e2) {KEISOKU GIKEN CORP.}
set vendor(00a0e3) {XKL SYSTEMS CORP.}
set vendor(00a0e4) {OPTIQUEST}
set vendor(00a0e5) {NHC COMMUNICATIONS}
set vendor(00a0e6) {DIALOGIC CORPORATION}
set vendor(00a0e7) {CENTRAL DATA CORPORATION}
set vendor(00a0e8) {REUTERS HOLDINGS PLC}
set vendor(00a0e9) {ELECTRONIC RETAILING SYSTEMS INTERNATIONAL}
set vendor(00a0ea) {ETHERCOM CORP.}
set vendor(00a0eb) {Encore Networks}
set vendor(00a0ec) {TRANSMITTON LTD.}
set vendor(00a0ed) {PRI AUTOMATION}
set vendor(00a0ee) {NASHOBA NETWORKS}
set vendor(00a0ef) {LUCIDATA LTD.}
set vendor(00a00f) {Broadband Technologies}
set vendor(00a0f0) {TORONTO MICROELECTRONICS INC.}
set vendor(00a0f1) {MTI}
set vendor(00a0f2) {INFOTEK COMMUNICATIONS, INC.}
set vendor(00a0f3) {STAUBLI}
set vendor(00a0f4) {GE}
set vendor(00a0f5) {RADGUARD LTD.}
set vendor(00a0f6) {AutoGas Systems Inc.}
set vendor(00a0f7) {V.I COMPUTER CORP.}
set vendor(00a0f8) {SYMBOL TECHNOLOGIES, INC.}
set vendor(00a0f9) {BINTEC COMMUNICATIONS GMBH}
set vendor(00a0fa) {Marconi Communication GmbH}
set vendor(00a0fb) {TORAY ENGINEERING CO., LTD.}
set vendor(00a0fc) {IMAGE SCIENCES, INC.}
set vendor(00a0fd) {SCITEX DIGITAL PRINTING, INC.}
set vendor(00a0fe) {BOSTON TECHNOLOGY, INC.}
set vendor(00a0ff) {TELLABS OPERATIONS, INC.}
set vendor(000a00) {Mediatek Corp.}
set vendor(000a01) {SOHOware, Inc.}
set vendor(000a10) {FAST media integrations AG}
set vendor(000a11) {ExPet Technologies, Inc}
set vendor(000a12) {Azylex Technology, Inc}
set vendor(000a13) {Silent Witness}
set vendor(000a14) {TECO a.s.}
set vendor(000a15) {Silicon Data, Inc}
set vendor(000a16) {Lassen Research}
set vendor(000a17) {NESTAR COMMUNICATIONS, INC}
set vendor(000a18) {Vichel Inc.}
set vendor(000a19) {Valere Power, Inc.}
set vendor(000a1a) {Imerge Ltd}
set vendor(000a1b) {Stream Labs}
set vendor(000a1c) {Bridge Information Co., Ltd.}
set vendor(000a1d) {Optical Communications Products Inc.}
set vendor(000a1e) {Red-M (Communications) Limited}
set vendor(000a1f) {ART WARE Telecommunication Co., Ltd.}
set vendor(000a02) {ANNSO CO., LTD.}
set vendor(000a20) {SVA Networks, Inc.}
set vendor(000a21) {Integra Telecom Co. Ltd}
set vendor(000a22) {Amperion Inc}
set vendor(000a23) {Parama Networks Inc}
set vendor(000a24) {Octave Communications}
set vendor(000a25) {CERAGON NETWORKS}
set vendor(000a26) {CEIA S.p.A.}
set vendor(000a27) {Apple Computer, Inc.}
set vendor(000a28) {Motorola}
set vendor(000a29) {Pan Dacom Networking AG}
set vendor(000a2a) {QSI Systems Inc.}
set vendor(000a2b) {Etherstuff}
set vendor(000a2c) {Active Tchnology Corporation}
set vendor(000a2e) {MAPLE NETWORKS CO., LTD}
set vendor(000a2f) {Artnix Inc.}
set vendor(000a03) {ENDESA SERVICIOS, S.L.}
set vendor(000a30) {Johnson Controls-ASG}
set vendor(000a31) {HCV Wireless}
set vendor(000a32) {Xsido Corporation}
set vendor(000a33) {Sierra Logic, Inc.}
set vendor(000a34) {Identicard Systems Incorporated}
set vendor(000a35) {Xilinx}
set vendor(000a36) {Synelec Telecom Multimedia}
set vendor(000a37) {Procera Networks, Inc.}
set vendor(000a38) {Netlock Technologies, Inc.}
set vendor(000a39) {LoPA Information Technology}
set vendor(000a3a) {J-THREE INTERNATIONAL Holding Co., Ltd.}
set vendor(000a3b) {GCT Semiconductor, Inc}
set vendor(000a3c) {Enerpoint Ltd.}
set vendor(000a3d) {Elo Sistemas Eletronicos S.A.}
set vendor(000a3e) {EADS Telecom}
set vendor(000a3f) {Data East Corporation}
set vendor(000a04) {3Com Europe Ltd}
set vendor(000a40) {Crown Audio}
set vendor(000a41) {Cisco Systems}
set vendor(000a42) {Cisco Systems}
set vendor(000a43) {Chunghwa Telecom Co., Ltd.}
set vendor(000a44) {Avery Dennison Deutschland GmbH}
set vendor(000a45) {Audio-Technica Corp.}
set vendor(000a46) {ARO Controls SAS}
set vendor(000a47) {Allied Vision Technologies}
set vendor(000a48) {Albatron Technology}
set vendor(000a49) {Acopia Networks}
set vendor(000a4a) {Targa Systems Ltd.}
set vendor(000a4b) {DataPower Technology, Inc.}
set vendor(000a4c) {Molecular Devices Corporation}
set vendor(000a4d) {Noritz Corporation}
set vendor(000a4e) {UNITEK Electronics INC.}
set vendor(000a4f) {Brain Boxes Limited}
set vendor(000a05) {Widax Corp.}
set vendor(000a50) {REMOTEK CORPORATION}
set vendor(000a51) {GyroSignal Technology Co., Ltd.}
set vendor(000a52) {Venitek Co. Ltd.}
set vendor(000a53) {Intronics, Incorporated}
set vendor(000a54) {Laguna Hills, Inc.}
set vendor(000a55) {MARKEM Corporation}
set vendor(000a56) {HITACHI Maxell Ltd.}
set vendor(000a57) {Hewlett-Packard Company - Standards}
set vendor(000a58) {Ingenieur-Buero Freyer & Siegel}
set vendor(000a59) {HW server}
set vendor(000a5a) {GreenNET Technologies Co.,Ltd.}
set vendor(000a5b) {Power-One as}
set vendor(000a5c) {Carel s.p.a.}
set vendor(000a5d) {PUC Founder (MSC) Berhad}
set vendor(000a5e) {3COM Corporation}
set vendor(000a5f) {almedio inc.}
set vendor(000a06) {Teledex LLC}
set vendor(000a60) {Autostar Technology Pte Ltd}
set vendor(000a61) {Cellinx Systems Inc.}
set vendor(000a62) {Crinis Networks, Inc.}
set vendor(000a63) {DHD GmbH}
set vendor(000a64) {Eracom Technologies}
set vendor(000a65) {GentechMedia.co.,ltd.}
set vendor(000a66) {MITSUBISHI ELECTRIC SYSTEM & SERVICE CO.,LTD.}
set vendor(000a67) {OngCorp}
set vendor(000a68) {SolarFlare Communications, Inc.}
set vendor(000a69) {SUNNY bell Technology Co., Ltd.}
set vendor(000a6a) {SVM Microwaves s.r.o.}
set vendor(000a6b) {Tadiran Telecom Business Systems LTD}
set vendor(000a6c) {Walchem Corporation}
set vendor(000a6d) {EKS Elektronikservice GmbH}
set vendor(000a6e) {Broadcast Technology Limited}
set vendor(000a6f) {ZyTera Technologies Inc.}
set vendor(000a07) {WebWayOne Ltd}
set vendor(000a70) {MPLS Forum}
set vendor(000a71) {Avrio Technologies, Inc}
set vendor(000a72) {SimpleTech, Inc.}
set vendor(000a73) {Scientific Atlanta}
set vendor(000a74) {Manticom Networks Inc.}
set vendor(000a75) {Cat Electronics}
set vendor(000a76) {Beida Jade Bird Huaguang Technology Co.,Ltd}
set vendor(000a77) {Bluewire Technologies LLC}
set vendor(000a78) {OLITEC}
set vendor(000a79) {corega K.K.}
set vendor(000a7a) {Kyoritsu Electric Co., Ltd.}
set vendor(000a7b) {Cornelius Consult}
set vendor(000a7c) {Tecton Ltd}
set vendor(000a7d) {Valo, Inc.}
set vendor(000a7e) {The Advantage Group}
set vendor(000a7f) {Teradon Industries, Inc}
set vendor(000a08) {ALPINE ELECTRONICS, INC.}
set vendor(000a80) {Telkonet Inc.}
set vendor(000a81) {TEIMA Audiotex S.L.}
set vendor(000a82) {TATSUTA SYSTEM ELECTRONICS CO.,LTD.}
set vendor(000a83) {SALTO SYSTEMS S.L.}
set vendor(000a84) {Rainsun Enterprise Co., Ltd.}
set vendor(000a85) {PLAT'C2,Inc}
set vendor(000a86) {Lenze}
set vendor(000a87) {Integrated Micromachines Inc.}
set vendor(000a88) {InCypher S.A.}
set vendor(000a89) {Creval Systems, Inc.}
set vendor(000a8a) {Cisco Systems}
set vendor(000a8b) {Cisco Systems}
set vendor(000a8c) {Guardware Systems Ltd.}
set vendor(000a8d) {EUROTHERM LIMITED}
set vendor(000a8e) {Invacom Ltd}
set vendor(000a8f) {Aska International Inc.}
set vendor(000a09) {TaraCom Integrated Products, Inc.}
set vendor(000a90) {Bayside Interactive, Inc.}
set vendor(000a91) {HemoCue AB}
set vendor(000a92) {Presonus Corporation}
set vendor(000a93) {W2 Networks, Inc.}
set vendor(000a94) {ShangHai cellink CO., LTD}
set vendor(000a95) {Apple Computer, Inc.}
set vendor(000a96) {MEWTEL TECHNOLOGY INC.}
set vendor(000a97) {SONICblue, Inc.}
set vendor(000a98) {M+F Gwinner GmbH & Co}
set vendor(000a99) {Dataradio Inc.}
set vendor(000a9a) {Aiptek International Inc}
set vendor(000a9b) {Towa Meccs Corporation}
set vendor(000a9c) {Server Technology, Inc.}
set vendor(000a9d) {King Young Technology Co. Ltd.}
set vendor(000a9e) {BroadWeb Corportation}
set vendor(000a9f) {Pannaway Technologies, Inc.}
set vendor(000a0a) {SUNIX Co., Ltd.}
set vendor(000aa0) {Cedar Point Communications}
set vendor(000aa1) {V V S Limited}
set vendor(000aa2) {SYSTEK INC.}
set vendor(000aa3) {SHIMAFUJI ELECTRIC CO.,LTD.}
set vendor(000aa4) {SHANGHAI SURVEILLANCE TECHNOLOGY CO,LTD}
set vendor(000aa5) {MAXLINK INDUSTRIES LIMITED}
set vendor(000aa6) {Hochiki Corporation}
set vendor(000aa7) {FEI Company}
set vendor(000aa8) {ePipe Pty. Ltd.}
set vendor(000aa9) {Brooks Automation GmbH}
set vendor(000aaa) {AltiGen Communications Inc.}
set vendor(000aab) {TOYOTA MACS, INC.}
set vendor(000aac) {TerraTec Electronic GmbH}
set vendor(000aad) {Stargames Corporation}
set vendor(000aae) {Rosemount Process Analytical}
set vendor(000aaf) {Pipal Systems}
set vendor(000a0b) {Sealevel Systems, Inc.}
set vendor(000ab0) {LOYTEC electronics GmbH}
set vendor(000ab1) {GENETEC Corporation}
set vendor(000ab2) {Fresnel Wireless Systems}
set vendor(000ab3) {Fa. GIRA}
set vendor(000ab4) {ETIC Telecommunications}
set vendor(000ab5) {Digital Electronic Network}
set vendor(000ab6) {COMPUNETIX, INC}
set vendor(000ab7) {Cisco Systems}
set vendor(000ab8) {Cisco Systems}
set vendor(000ab9) {Astera Technologies Corp.}
set vendor(000aba) {Arcon Technology Limited}
set vendor(000abb) {Taiwan Secom Co,. Ltd}
set vendor(000abc) {Seabridge Ltd.}
set vendor(000abd) {Rupprecht & Patashnick Co.}
set vendor(000abe) {OPNET Technologies CO., LTD.}
set vendor(000abf) {HIROTA SS}
set vendor(000a0c) {Scientific Research Corporation}
set vendor(000ac0) {Fuyoh Video Industry CO., LTD.}
set vendor(000ac1) {Futuretel}
set vendor(000ac2) {FiberHome Telecommunication Technologies CO.,LTD}
set vendor(000ac3) {eM Technics Co., Ltd.}
set vendor(000ac4) {Daewoo Teletech Co., Ltd}
set vendor(000ac5) {Color Kinetics}
set vendor(000ac7) {Unication Group}
set vendor(000ac8) {ZPSYS CO.,LTD. (Planning&Management)}
set vendor(000ac9) {Zambeel Inc}
set vendor(000aca) {YOKOYAMA SHOKAI CO.,Ltd.}
set vendor(000acb) {XPAK MSA Group}
set vendor(000acc) {Winnow Networks, Inc.}
set vendor(000acd) {Sunrich Technology Limited}
set vendor(000ace) {RADIANTECH, INC.}
set vendor(000acf) {PROVIDEO Multimedia Co. Ltd.}
set vendor(000a0d) {MergeOptics GmbH}
set vendor(000ad0) {Niigata Develoment Center,  F.I.T. Co., Ltd.}
set vendor(000ad1) {MWS}
set vendor(000ad2) {JEPICO Corporation}
set vendor(000ad3) {INITECH Co., Ltd}
set vendor(000ad4) {CoreBell Systems Inc.}
set vendor(000ad5) {Brainchild Electronic Co., Ltd.}
set vendor(000ad6) {BeamReach Networks}
set vendor(000ad8) {IPCserv Technology Corp.}
set vendor(000ad9) {Sony Ericsson Mobile Communications AB}
set vendor(000adb) {SkyPilot Network, Inc}
set vendor(000adc) {RuggedCom Inc.}
set vendor(000add) {InSciTek Microsystems, Inc.}
set vendor(000ade) {Happy Communication Co., Ltd.}
set vendor(000adf) {Gennum Corporation}
set vendor(000a0e) {Invivo Research Inc.}
set vendor(000ae0) {Fujitsu Softek}
set vendor(000ae1) {EG Technology}
set vendor(000ae2) {Binatone Electronics International, Ltd}
set vendor(000ae3) {YANG MEI TECHNOLOGY CO., LTD}
set vendor(000ae4) {Wistron Corp.}
set vendor(000ae5) {ScottCare Corporation}
set vendor(000ae6) {Elitegroup Computer System Co. (ECS)}
set vendor(000ae7) {ELIOP S.A.}
set vendor(000ae8) {Cathay Roxus Information Technology Co. LTD}
set vendor(000ae9) {AirVast Technology Inc.}
set vendor(000aea) {ADAM ELEKTRONIK LTD.STI.}
set vendor(000aeb) {Shenzhen Tp-link Technology Co; Ltd.}
set vendor(000aec) {Koatsu Gas Kogyo Co., Ltd.}
set vendor(000aed) {HARTING Vending G.m.b.H. & CO KG}
set vendor(000aee) {GCD Hard- & Software GmbH}
set vendor(000aef) {OTRUM ASA}
set vendor(000a0f) {Ilryung Telesys, Inc}
set vendor(000af0) {SHIN-OH ELECTRONICS CO., LTD. R&D}
set vendor(000af1) {Clarity Design, Inc.}
set vendor(000af2) {NeoAxiom Corp.}
set vendor(000af3) {Cisco Systems}
set vendor(000af4) {Cisco Systems}
set vendor(000af5) {Airgo Networks, Inc.}
set vendor(000af6) {Computer Process Controls}
set vendor(000af7) {Broadcom Corp.}
set vendor(000af8) {American Telecare Inc.}
set vendor(000afa) {Traverse Technologies Australia}
set vendor(000afb) {Ambri Limited}
set vendor(000afc) {Core Tec Communications, LLC}
set vendor(000afd) {Viking Electronic Services}
set vendor(000afe) {NovaPal Ltd}
set vendor(000aff) {Kilchherr Elektronik AG}
set vendor(00aa00) {INTEL CORPORATION}
set vendor(00aa01) {INTEL CORPORATION}
set vendor(00aa02) {INTEL CORPORATION}
set vendor(00aa3c) {OLIVETTI TELECOM SPA (OLTECO)}
set vendor(00b017) {InfoGear Technology Corp.}
set vendor(00b019) {Casi-Rusco}
set vendor(00b01c) {Westport Technologies}
set vendor(00b01e) {Rantic Labs, Inc.}
set vendor(00b02a) {ORSYS GmbH}
set vendor(00b02d) {ViaGate Technologies, Inc.}
set vendor(00b03b) {HiQ Networks}
set vendor(00b048) {Marconi Communications Inc.}
set vendor(00b04a) {Cisco Systems, Inc.}
set vendor(00b052) {Intellon Corporation}
set vendor(00b064) {Cisco Systems, Inc.}
set vendor(00b069) {Honewell Oy}
set vendor(00b06d) {Jones Futurex Inc.}
set vendor(00b080) {Mannesmann Ipulsys B.V.}
set vendor(00b086) {LocSoft Limited}
set vendor(00b08e) {Cisco Systems, Inc.}
set vendor(00b009) {Grass Valley Group}
set vendor(00b091) {Transmeta Corp.}
set vendor(00b094) {Alaris, Inc.}
set vendor(00b09a) {Morrow Technologies Corp.}
set vendor(00b09d) {Point Grey Research Inc.}
set vendor(00b0ac) {SIAE-Microelettronica S.p.A.}
set vendor(00b0ae) {Symmetricom}
set vendor(00b0b3) {Xstreamis PLC}
set vendor(00b0c2) {Cisco Systems, Inc.}
set vendor(00b0c7) {Tellabs Operations, Inc.}
set vendor(00b0ce) {TECHNOLOGY RESCUE}
set vendor(00b0d0) {Dell Computer Corp.}
set vendor(00b0db) {Nextcell, Inc.}
set vendor(00b0df) {Reliable Data Technology, Inc.}
set vendor(00b0e7) {British Federal Ltd.}
set vendor(00b0ec) {EACEM}
set vendor(00b0ee) {Ajile Systems, Inc.}
set vendor(00b0f0) {CALY NETWORKS}
set vendor(00b0f5) {NetWorth Technologies, Inc.}
set vendor(000b00) {FUJIAN START COMPUTER EQUIPMENT CO.,LTD}
set vendor(000b01) {DAIICHI ELECTRONICS CO., LTD.}
set vendor(000b10) {11wave Technonlogy Co.,Ltd}
set vendor(000b11) {HIMEJI ABC TRADING CO.,LTD.}
set vendor(000b13) {ZETRON INC}
set vendor(000b14) {ViewSonic Corporation}
set vendor(000b15) {Platypus Technology}
set vendor(000b16) {Communication Machinery Corporation}
set vendor(000b17) {MKS Instruments}
set vendor(000b19) {Vernier Networks, Inc.}
set vendor(000b1a) {Teltone Corporation}
set vendor(000b1b) {Systronix, Inc.}
set vendor(000b1d) {LayerZero Power Systems, Inc.}
set vendor(000b1e) {KAPPA opto-electronics GmbH}
set vendor(000b1f) {I CON Computer Co.}
set vendor(000b02) {Dallmeier electronic}
set vendor(000b20) {Hirata corporation}
set vendor(000b21) {G-Star Communications Inc.}
set vendor(000b22) {Environmental Systems and Services}
set vendor(000b23) {Efficient Networks, Inc.}
set vendor(000b24) {AirLogic}
set vendor(000b25) {Aeluros}
set vendor(000b26) {Wetek Corporation}
set vendor(000b27) {Scion Corporation}
set vendor(000b28) {Quatech Inc.}
set vendor(000b29) {LG Industrial Systems Co.,Ltd.}
set vendor(000b2a) {HOWTEL Co., Ltd.}
set vendor(000b2b) {HOSTNET CORPORATION}
set vendor(000b2c) {Eiki Industrial Co. Ltd.}
set vendor(000b2d) {Danfoss Inc.}
set vendor(000b2e) {Cal-Comp Electronics (Thailand) Public Company Limited Taipe}
set vendor(000b2f) {bplan GmbH}
set vendor(000b03) {Taekwang Industrial Co., Ltd}
set vendor(000b30) {Beijing Gongye Science & Technology Co.,Ltd}
set vendor(000b31) {Yantai ZhiYang Scientific and technology industry CO., LTD}
set vendor(000b32) {VORMETRIC, INC.}
set vendor(000b33) {Vivato}
set vendor(000b34) {ShangHai Broadband Technologies CO.LTD}
set vendor(000b35) {Quad Bit System co., Ltd.}
set vendor(000b36) {Productivity Systems, Inc.}
set vendor(000b37) {MANUFACTURE DES MONTRES ROLEX SA}
set vendor(000b38) {Knuerr AG}
set vendor(000b39) {Keisoku Giken Co.,Ltd.}
set vendor(000b3a) {Fortel DTV, Inc.}
set vendor(000b3b) {devolo AG}
set vendor(000b3c) {Cygnal Integrated Products, Inc.}
set vendor(000b3d) {CONTAL OK Ltd.}
set vendor(000b3e) {BittWare, Inc}
set vendor(000b3f) {Anthology Solutions Inc.}
set vendor(000b04) {Volktek Corporation}
set vendor(000b40) {OpNext Inc.}
set vendor(000b41) {Ing. Buero Dr. Beutlhauser}
set vendor(000b42) {commax Co., Ltd.}
set vendor(000b43) {Microscan Systems, Inc.}
set vendor(000b44) {Concord IDea Corp.}
set vendor(000b45) {Cisco}
set vendor(000b46) {Cisco}
set vendor(000b47) {Advanced Energy}
set vendor(000b48) {sofrel}
set vendor(000b49) {RF-Link System Inc.}
set vendor(000b4a) {Visimetrics (UK) Ltd}
set vendor(000b4b) {VISIOWAVE SA}
set vendor(000b4c) {Clarion (M) Sdn Bhd}
set vendor(000b4d) {Emuzed}
set vendor(000b4e) {VertexRSI Antenna Products Division}
set vendor(000b4f) {Verifone, INC.}
set vendor(000b05) {Pacific Broadband Networks}
set vendor(000b50) {Oxygnet}
set vendor(000b51) {Micetek International Inc.}
set vendor(000b52) {JOYMAX ELECTRONICS CORP.}
set vendor(000b53) {INITIUM Co., Ltd.}
set vendor(000b54) {BiTMICRO Networks, Inc.}
set vendor(000b55) {ADInstruments}
set vendor(000b56) {Cybernetics}
set vendor(000b57) {Silicon Laboratories}
set vendor(000b58) {Astronautics C.A  LTD}
set vendor(000b59) {ScriptPro, LLC}
set vendor(000b5a) {HyperEdge}
set vendor(000b5b) {Rincon Research Corporation}
set vendor(000b5c) {Newtech Co.,Ltd}
set vendor(000b5d) {FUJITSU LIMITED}
set vendor(000b5e) {ATMAVA Ltd}
set vendor(000b5f) {Cisco Systems}
set vendor(000b06) {Motorola BCS}
set vendor(000b60) {Cisco Systems}
set vendor(000b61) {Friedrich Ltze GmbH &Co.}
set vendor(000b62) {Ingenieurbro Ingo Mohnen}
set vendor(000b64) {Kieback & Peter GmbH & Co KG}
set vendor(000b65) {Sy.A.C. srl}
set vendor(000b66) {Teralink Communications}
set vendor(000b67) {Topview Technology Corporation}
set vendor(000b68) {Addvalue Communications Pte Ltd}
set vendor(000b69) {Franke Finland Oy}
set vendor(000b6a) {Asiarock Incorporation}
set vendor(000b6b) {Wistron Neweb Corp.}
set vendor(000b6c) {Sychip Inc.}
set vendor(000b6d) {SOLECTRON JAPAN NAKANIIDA}
set vendor(000b6e) {Neff Instrument Corp.}
set vendor(000b6f) {Media Streaming Networks Inc}
set vendor(000b07) {Voxpath Networks}
set vendor(000b70) {Load Technology, Inc.}
set vendor(000b71) {Litchfield Communications Inc.}
set vendor(000b72) {Lawo AG}
set vendor(000b73) {Kodeos Communications}
set vendor(000b74) {Kingwave Technology Co., Ltd.}
set vendor(000b75) {Iosoft Ltd.}
set vendor(000b76) {ET&T Co. Ltd.}
set vendor(000b77) {Cogent Systems, Inc.}
set vendor(000b78) {TAIFATECH INC.}
set vendor(000b79) {X-COM, Inc.}
set vendor(000b7b) {Test-Um Inc.}
set vendor(000b7c) {Telex Communications}
set vendor(000b7d) {SOLOMON EXTREME INTERNATIONAL LTD.}
set vendor(000b7e) {SAGINOMIYA Seisakusho Inc.}
set vendor(000b7f) {OmniWerks}
set vendor(000b08) {Pillar Data Systems}
set vendor(000b81) {Kaparel Corporation}
set vendor(000b82) {Grandstream Networks, Inc.}
set vendor(000b83) {DATAWATT B.V.}
set vendor(000b84) {BODET}
set vendor(000b85) {Airespace, Inc.}
set vendor(000b86) {Aruba Networks}
set vendor(000b87) {American Reliance Inc.}
set vendor(000b88) {Vidisco ltd.}
set vendor(000b89) {Top Global Technology, Ltd.}
set vendor(000b8a) {MITEQ Inc.}
set vendor(000b8b) {KERAJET, S.A.}
set vendor(000b8c) {flextronics israel}
set vendor(000b8d) {Avvio Networks}
set vendor(000b8e) {Ascent Corporation}
set vendor(000b8f) {AKITA ELECTRONICS SYSTEMS CO.,LTD.}
set vendor(000b09) {Ifoundry Systems Singapore}
set vendor(000b90) {Covaro Networks, Inc.}
set vendor(000b91) {Aglaia Gesellschaft fr Bildverarbeitung und Kommunikation m}
set vendor(000b92) {Ascom Danmark A/S}
set vendor(000b93) {Barmag Electronic}
set vendor(000b94) {Digital Monitoring Products, Inc.}
set vendor(000b95) {eBet Gaming Systems Pty Ltd}
set vendor(000b96) {Innotrac Diagnostics Oy}
set vendor(000b97) {Matsushita Electric Industrial Co.,Ltd.}
set vendor(000b98) {NiceTechVision}
set vendor(000b99) {SensAble Technologies, Inc.}
set vendor(000b9a) {Shanghai Ulink Telecom Equipment Co. Ltd.}
set vendor(000b9b) {Sirius System Co, Ltd.}
set vendor(000b9c) {TriBeam Technologies, Inc.}
set vendor(000b9d) {TwinMOS Technologies Inc.}
set vendor(000b9e) {Yasing Technology Corp.}
set vendor(000b9f) {Neue ELSA GmbH}
set vendor(000b0a) {dBm Optics}
set vendor(000ba0) {T&L Information Inc.}
set vendor(000ba1) {SYSCOM Ltd.}
set vendor(000ba2) {Sumitomo Electric Networks, Inc}
set vendor(000ba3) {Siemens AG, I&S}
set vendor(000ba4) {Shiron Satellite Communications Ltd. (1996)}
set vendor(000ba5) {Quasar Cipta Mandiri, PT}
set vendor(000ba6) {Miyakawa Electric Works Ltd.}
set vendor(000ba7) {Maranti Networks}
set vendor(000ba8) {HANBACK ELECTRONICS CO., LTD.}
set vendor(000baa) {Aiphone co.,Ltd}
set vendor(000bab) {Advantech Technology (CHINA) Co., Ltd.}
set vendor(000bac) {3Com Europe Ltd.}
set vendor(000bad) {PC-PoS Inc.}
set vendor(000bae) {Vitals System Inc.}
set vendor(000baf) {WOOJU COMMUNICATIONS Co,.Ltd}
set vendor(000b0b) {Corrent Corporation}
set vendor(000bb0) {Sysnet Telematica srl}
set vendor(000bb1) {Super Star Technology Co., Ltd.}
set vendor(000bb2) {SMALLBIG TECHNOLOGY}
set vendor(000bb3) {RiT technologies Ltd.}
set vendor(000bb4) {RDC Semiconductor Inc.,}
set vendor(000bb5) {nStor Technologies, Inc.}
set vendor(000bb6) {Mototech Inc.}
set vendor(000bb7) {Micro Systems Co.,Ltd.}
set vendor(000bb8) {Kihoku Electronic Co.}
set vendor(000bb9) {Imsys AB}
set vendor(000bba) {Harmonic Broadband Access Networks}
set vendor(000bbb) {Etin Systems Co., Ltd}
set vendor(000bbc) {En Garde Systems, Inc.}
set vendor(000bbd) {Connexionz Limited}
set vendor(000bbe) {Cisco Systems}
set vendor(000bbf) {Cisco Systems}
set vendor(000b0c) {Agile Systems Inc.}
set vendor(000bc0) {China IWNComm Co., Ltd.}
set vendor(000bc1) {Bay Microsystems, Inc.}
set vendor(000bc2) {Corinex Communication Corp.}
set vendor(000bc3) {Multiplex, Inc.}
set vendor(000bc4) {BIOTRONIK GmbH & Co}
set vendor(000bc5) {SMC Networks, Inc.}
set vendor(000bc6) {ISAC, Inc.}
set vendor(000bc7) {ICET S.p.A.}
set vendor(000bc8) {AirFlow Networks}
set vendor(000bc9) {Electroline Equipment}
set vendor(000bca) {DATAVAN International Corporation}
set vendor(000bcb) {Fagor Automation , S. Coop}
set vendor(000bcc) {JUSAN, S.A.}
set vendor(000bcd) {Compaq (HP)}
set vendor(000bce) {Free2move AB}
set vendor(000bcf) {AGFA NDT INC.}
set vendor(000b0d) {Air2U, Inc.}
set vendor(000bd0) {XiMeta Technology Americas Inc.}
set vendor(000bd1) {Aeronix, Inc.}
set vendor(000bd2) {Remopro Technology Inc.}
set vendor(000bd3) {cd3o}
set vendor(000bd4) {Beijing Wise Technology & Science Development Co.Ltd}
set vendor(000bd5) {Nvergence, Inc.}
set vendor(000bd6) {Paxton Access Ltd}
set vendor(000bd7) {MBB Gelma GmbH}
set vendor(000bd8) {Industrial Scientific Corp.}
set vendor(000bd9) {General Hydrogen}
set vendor(000bda) {EyeCross Co.,Inc.}
set vendor(000bdb) {Dell ESG PCBA Test}
set vendor(000bdc) {AKCP}
set vendor(000bdd) {TOHOKU RICOH Co., LTD.}
set vendor(000bdf) {Shenzhen RouterD Networks Limited}
set vendor(000b0e) {Trapeze Networks}
set vendor(000be0) {SercoNet Ltd.}
set vendor(000be2) {Lumenera Corporation}
set vendor(000be3) {Key Stream Co., Ltd.}
set vendor(000be4) {Hosiden Corporation}
set vendor(000be5) {HIMS Korea Co., Ltd.}
set vendor(000be6) {Datel Electronics}
set vendor(000be7) {COMFLUX TECHNOLOGY INC.}
set vendor(000be8) {AOIP}
set vendor(000bea) {Zultys Technologies}
set vendor(000beb) {Systegra AG}
set vendor(000bec) {NIPPON ELECTRIC INSTRUMENT, INC.}
set vendor(000bed) {ELM Inc.}
set vendor(000bee) {inc.jet, Incorporated}
set vendor(000bef) {Code Corporation}
set vendor(000b0f) {Nyquist Industrial Control BV}
set vendor(000bf0) {MoTEX Products Co., Ltd.}
set vendor(000bf1) {LAP Laser Applikations}
set vendor(000bf2) {Chih-Kan Technology Co., Ltd.}
set vendor(000bf3) {BAE SYSTEMS}
set vendor(000bf5) {Shanghai Sibo Telecom Technology Co.,Ltd}
set vendor(000bf6) {Nitgen Co., Ltd}
set vendor(000bf7) {NIDEK CO.,LTD}
set vendor(000bf8) {Infinera}
set vendor(000bf9) {Gemstone communications, Inc.}
set vendor(000bfb) {D-NET International Corporation}
set vendor(000bfc) {Cisco Systems}
set vendor(000bfd) {Cisco Systems}
set vendor(000bfe) {CASTEL Broadband Limited}
set vendor(000bff) {Berkeley Camera Engineering}
set vendor(00bb01) {OCTOTHORPE CORP.}
set vendor(00bbf0) {UNGERMANN-BASS INC.}
set vendor(00c000) {LANOPTICS, LTD.}
set vendor(00c001) {DIATEK PATIENT MANAGMENT}
set vendor(00c010) {HIRAKAWA HEWTECH CORP.}
set vendor(00c011) {INTERACTIVE COMPUTING DEVICES}
set vendor(00c012) {NETSPAN CORPORATION}
set vendor(00c013) {NETRIX}
set vendor(00c014) {TELEMATICS CALABASAS INT'L,INC}
set vendor(00c015) {NEW MEDIA CORPORATION}
set vendor(00c016) {ELECTRONIC THEATRE CONTROLS}
set vendor(00c017) {FORTE NETWORKS}
set vendor(00c018) {LANART CORPORATION}
set vendor(00c019) {LEAP TECHNOLOGY, INC.}
set vendor(00c01a) {COROMETRICS MEDICAL SYSTEMS}
set vendor(00c01b) {SOCKET COMMUNICATIONS, INC.}
set vendor(00c01c) {INTERLINK COMMUNICATIONS LTD.}
set vendor(00c01d) {GRAND JUNCTION NETWORKS, INC.}
set vendor(00c01e) {LA FRANCAISE DES JEUX}
set vendor(00c01f) {S.E.R.C.E.L.}
set vendor(00c002) {SERCOMM CORPORATION}
set vendor(00c020) {ARCO ELECTRONIC, CONTROL LTD.}
set vendor(00c021) {NETEXPRESS}
set vendor(00c022) {LASERMASTER TECHNOLOGIES, INC.}
set vendor(00c023) {TUTANKHAMON ELECTRONICS}
set vendor(00c024) {EDEN SISTEMAS DE COMPUTACAO SA}
set vendor(00c025) {DATAPRODUCTS CORPORATION}
set vendor(00c026) {LANS TECHNOLOGY CO., LTD.}
set vendor(00c027) {CIPHER SYSTEMS, INC.}
set vendor(00c028) {JASCO CORPORATION}
set vendor(00c029) {Nexans Deutschland AG - ANS}
set vendor(00c02a) {OHKURA ELECTRIC CO., LTD.}
set vendor(00c02b) {GERLOFF GESELLSCHAFT FUR}
set vendor(00c02c) {CENTRUM COMMUNICATIONS, INC.}
set vendor(00c02d) {FUJI PHOTO FILM CO., LTD.}
set vendor(00c02e) {NETWIZ}
set vendor(00c02f) {OKUMA CORPORATION}
set vendor(00c003) {GLOBALNET COMMUNICATIONS}
set vendor(00c030) {INTEGRATED ENGINEERING B. V.}
set vendor(00c031) {DESIGN RESEARCH SYSTEMS, INC.}
set vendor(00c032) {I-CUBED LIMITED}
set vendor(00c033) {TELEBIT COMMUNICATIONS APS}
set vendor(00c034) {TRANSACTION NETWORK}
set vendor(00c035) {QUINTAR COMPANY}
set vendor(00c036) {RAYTECH ELECTRONIC CORP.}
set vendor(00c037) {DYNATEM}
set vendor(00c038) {RASTER IMAGE PROCESSING SYSTEM}
set vendor(00c039) {TDK SEMICONDUCTOR CORPORATION}
set vendor(00c03a) {MEN-MIKRO ELEKTRONIK GMBH}
set vendor(00c03b) {MULTIACCESS COMPUTING CORP.}
set vendor(00c03c) {TOWER TECH S.R.L.}
set vendor(00c03d) {WIESEMANN & THEIS GMBH}
set vendor(00c03e) {FA. GEBR. HELLER GMBH}
set vendor(00c03f) {STORES AUTOMATED SYSTEMS, INC.}
set vendor(00c004) {JAPAN BUSINESS COMPUTER CO.LTD}
set vendor(00c040) {ECCI}
set vendor(00c041) {DIGITAL TRANSMISSION SYSTEMS}
set vendor(00c042) {DATALUX CORP.}
set vendor(00c043) {STRATACOM}
set vendor(00c044) {EMCOM CORPORATION}
set vendor(00c045) {ISOLATION SYSTEMS, LTD.}
set vendor(00c046) {KEMITRON LTD.}
set vendor(00c047) {UNIMICRO SYSTEMS, INC.}
set vendor(00c048) {BAY TECHNICAL ASSOCIATES}
set vendor(00c049) {U.S. ROBOTICS, INC.}
set vendor(00c04a) {GROUP 2000 AG}
set vendor(00c04b) {CREATIVE MICROSYSTEMS}
set vendor(00c04c) {DEPARTMENT OF FOREIGN AFFAIRS}
set vendor(00c04d) {MITEC, INC.}
set vendor(00c04e) {COMTROL CORPORATION}
set vendor(00c04f) {DELL COMPUTER CORPORATION}
set vendor(00c005) {LIVINGSTON ENTERPRISES, INC.}
set vendor(00c050) {TOYO DENKI SEIZO K.K.}
set vendor(00c051) {ADVANCED INTEGRATION RESEARCH}
set vendor(00c052) {BURR-BROWN}
set vendor(00c053) {DAVOX CORPORATION}
set vendor(00c054) {NETWORK PERIPHERALS, LTD.}
set vendor(00c055) {MODULAR COMPUTING TECHNOLOGIES}
set vendor(00c056) {SOMELEC}
set vendor(00c057) {MYCO ELECTRONICS}
set vendor(00c058) {DATAEXPERT CORP.}
set vendor(00c059) {NIPPON DENSO CO., LTD.}
set vendor(00c05a) {SEMAPHORE COMMUNICATIONS CORP.}
set vendor(00c05b) {NETWORKS NORTHWEST, INC.}
set vendor(00c05c) {ELONEX PLC}
set vendor(00c05d) {L&N TECHNOLOGIES}
set vendor(00c05e) {VARI-LITE, INC.}
set vendor(00c05f) {FINE-PAL COMPANY LIMITED}
set vendor(00c006) {NIPPON AVIONICS CO., LTD.}
set vendor(00c060) {ID SCANDINAVIA AS}
set vendor(00c061) {SOLECTEK CORPORATION}
set vendor(00c062) {IMPULSE TECHNOLOGY}
set vendor(00c063) {MORNING STAR TECHNOLOGIES, INC}
set vendor(00c064) {GENERAL DATACOMM IND. INC.}
set vendor(00c065) {SCOPE COMMUNICATIONS, INC.}
set vendor(00c066) {DOCUPOINT, INC.}
set vendor(00c067) {UNITED BARCODE INDUSTRIES}
set vendor(00c068) {PHILIP DRAKE ELECTRONICS LTD.}
set vendor(00c069) {Axxcelera Broadband Wireless}
set vendor(00c06a) {ZAHNER-ELEKTRIK GMBH & CO. KG}
set vendor(00c06b) {OSI PLUS CORPORATION}
set vendor(00c06c) {SVEC COMPUTER CORP.}
set vendor(00c06d) {BOCA RESEARCH, INC.}
set vendor(00c06e) {HAFT TECHNOLOGY, INC.}
set vendor(00c06f) {KOMATSU LTD.}
set vendor(00c007) {PINNACLE DATA SYSTEMS, INC.}
set vendor(00c070) {SECTRA SECURE-TRANSMISSION AB}
set vendor(00c071) {AREANEX COMMUNICATIONS, INC.}
set vendor(00c072) {KNX LTD.}
set vendor(00c073) {XEDIA CORPORATION}
set vendor(00c074) {TOYODA AUTOMATIC LOOM}
set vendor(00c075) {XANTE CORPORATION}
set vendor(00c076) {I-DATA INTERNATIONAL A-S}
set vendor(00c077) {DAEWOO TELECOM LTD.}
set vendor(00c078) {COMPUTER SYSTEMS ENGINEERING}
set vendor(00c079) {FONSYS CO.,LTD.}
set vendor(00c07a) {PRIVA B.V.}
set vendor(00c07b) {ASCEND COMMUNICATIONS, INC.}
set vendor(00c07c) {HIGHTECH INFORMATION}
set vendor(00c07d) {RISC DEVELOPMENTS LTD.}
set vendor(00c07e) {KUBOTA CORPORATION ELECTRONIC}
set vendor(00c07f) {NUPON COMPUTING CORP.}
set vendor(00c008) {SECO SRL}
set vendor(00c080) {NETSTAR, INC.}
set vendor(00c081) {METRODATA LTD.}
set vendor(00c082) {MOORE PRODUCTS CO.}
set vendor(00c083) {TRACE MOUNTAIN PRODUCTS, INC.}
set vendor(00c084) {DATA LINK CORP. LTD.}
set vendor(00c085) {ELECTRONICS FOR IMAGING, INC.}
set vendor(00c086) {THE LYNK CORPORATION}
set vendor(00c087) {UUNET TECHNOLOGIES, INC.}
set vendor(00c088) {EKF ELEKTRONIK GMBH}
set vendor(00c089) {TELINDUS DISTRIBUTION}
set vendor(00c08a) {LAUTERBACH DATENTECHNIK GMBH}
set vendor(00c08b) {RISQ MODULAR SYSTEMS, INC.}
set vendor(00c08c) {PERFORMANCE TECHNOLOGIES, INC.}
set vendor(00c08d) {TRONIX PRODUCT DEVELOPMENT}
set vendor(00c08e) {NETWORK INFORMATION TECHNOLOGY}
set vendor(00c08f) {MATSUSHITA ELECTRIC WORKS, LTD}
set vendor(00c009) {KT TECHNOLOGY (S) PTE LTD}
set vendor(00c090) {PRAIM S.R.L.}
set vendor(00c091) {JABIL CIRCUIT, INC.}
set vendor(00c092) {MENNEN MEDICAL INC.}
set vendor(00c093) {ALTA RESEARCH CORP.}
set vendor(00c094) {VMX INC.}
set vendor(00c095) {ZNYX}
set vendor(00c096) {TAMURA CORPORATION}
set vendor(00c097) {ARCHIPEL SA}
set vendor(00c098) {CHUNTEX ELECTRONIC CO., LTD.}
set vendor(00c099) {YOSHIKI INDUSTRIAL CO.,LTD.}
set vendor(00c09a) {PHOTONICS CORPORATION}
set vendor(00c09b) {RELIANCE COMM/TEC, R-TEC}
set vendor(00c09c) {TOA ELECTRONIC LTD.}
set vendor(00c09d) {DISTRIBUTED SYSTEMS INT'L, INC}
set vendor(00c09e) {CACHE COMPUTERS, INC.}
set vendor(00c09f) {QUANTA COMPUTER, INC.}
set vendor(00c00a) {MICRO CRAFT}
set vendor(00c0a0) {ADVANCE MICRO RESEARCH, INC.}
set vendor(00c0a1) {TOKYO DENSHI SEKEI CO.}
set vendor(00c0a2) {INTERMEDIUM A/S}
set vendor(00c0a3) {DUAL ENTERPRISES CORPORATION}
set vendor(00c0a4) {UNIGRAF OY}
set vendor(00c0a5) {DICKENS DATA SYSTEMS}
set vendor(00c0a6) {EXICOM AUSTRALIA PTY. LTD}
set vendor(00c0a7) {SEEL LTD.}
set vendor(00c0a8) {GVC CORPORATION}
set vendor(00c0a9) {BARRON MCCANN LTD.}
set vendor(00c0aa) {SILICON VALLEY COMPUTER}
set vendor(00c0ab) {Telco Systems, Inc.}
set vendor(00c0ac) {GAMBIT COMPUTER COMMUNICATIONS}
set vendor(00c0ad) {MARBEN COMMUNICATION SYSTEMS}
set vendor(00c0ae) {TOWERCOM CO. INC. DBA PC HOUSE}
set vendor(00c0af) {TEKLOGIX INC.}
set vendor(00c00b) {NORCONTROL A.S.}
set vendor(00c0b0) {GCC TECHNOLOGIES,INC.}
set vendor(00c0b1) {GENIUS NET CO.}
set vendor(00c0b2) {NORAND CORPORATION}
set vendor(00c0b3) {COMSTAT DATACOMM CORPORATION}
set vendor(00c0b4) {MYSON TECHNOLOGY, INC.}
set vendor(00c0b5) {CORPORATE NETWORK SYSTEMS,INC.}
set vendor(00c0b6) {Snap Appliance, Inc.}
set vendor(00c0b7) {AMERICAN POWER CONVERSION CORP}
set vendor(00c0b8) {FRASER'S HILL LTD.}
set vendor(00c0b9) {FUNK SOFTWARE, INC.}
set vendor(00c0ba) {NETVANTAGE}
set vendor(00c0bb) {FORVAL CREATIVE, INC.}
set vendor(00c0bc) {TELECOM AUSTRALIA/CSSC}
set vendor(00c0bd) {INEX TECHNOLOGIES, INC.}
set vendor(00c0be) {ALCATEL - SEL}
set vendor(00c0bf) {TECHNOLOGY CONCEPTS, LTD.}
set vendor(00c00c) {RELIA TECHNOLGIES}
set vendor(00c0c0) {SHORE MICROSYSTEMS, INC.}
set vendor(00c0c1) {QUAD/GRAPHICS, INC.}
set vendor(00c0c2) {INFINITE NETWORKS LTD.}
set vendor(00c0c3) {ACUSON COMPUTED SONOGRAPHY}
set vendor(00c0c4) {COMPUTER OPERATIONAL}
set vendor(00c0c5) {SID INFORMATICA}
set vendor(00c0c6) {PERSONAL MEDIA CORP.}
set vendor(00c0c7) {SPARKTRUM MICROSYSTEMS, INC.}
set vendor(00c0c8) {MICRO BYTE PTY. LTD.}
set vendor(00c0c9) {ELSAG BAILEY PROCESS}
set vendor(00c0ca) {ALFA, INC.}
set vendor(00c0cb) {CONTROL TECHNOLOGY CORPORATION}
set vendor(00c0cc) {TELESCIENCES CO SYSTEMS, INC.}
set vendor(00c0cd) {COMELTA, S.A.}
set vendor(00c0ce) {CEI SYSTEMS & ENGINEERING PTE}
set vendor(00c0cf) {IMATRAN VOIMA OY}
set vendor(00c00d) {ADVANCED LOGIC RESEARCH, INC.}
set vendor(00c0d0) {RATOC SYSTEM INC.}
set vendor(00c0d1) {COMTREE TECHNOLOGY CORPORATION}
set vendor(00c0d2) {SYNTELLECT, INC.}
set vendor(00c0d3) {OLYMPUS IMAGE SYSTEMS, INC.}
set vendor(00c0d4) {AXON NETWORKS, INC.}
set vendor(00c0d5) {QUANCOM ELECTRONIC GMBH}
set vendor(00c0d6) {J1 SYSTEMS, INC.}
set vendor(00c0d7) {TAIWAN TRADING CENTER DBA}
set vendor(00c0d8) {UNIVERSAL DATA SYSTEMS}
set vendor(00c0d9) {QUINTE NETWORK CONFIDENTIALITY}
set vendor(00c0da) {NICE SYSTEMS LTD.}
set vendor(00c0db) {IPC CORPORATION (PTE) LTD.}
set vendor(00c0dc) {EOS TECHNOLOGIES, INC.}
set vendor(00c0dd) {QLogic Corporation}
set vendor(00c0de) {ZCOMM, INC.}
set vendor(00c0df) {KYE Systems Corp.}
set vendor(00c00e) {PSITECH, INC.}
set vendor(00c0e0) {DSC COMMUNICATION CORP.}
set vendor(00c0e1) {SONIC SOLUTIONS}
set vendor(00c0e2) {CALCOMP, INC.}
set vendor(00c0e3) {OSITECH COMMUNICATIONS, INC.}
set vendor(00c0e4) {SIEMENS BUILDING}
set vendor(00c0e5) {GESPAC, S.A.}
set vendor(00c0e6) {Verilink Corporation}
set vendor(00c0e7) {FIBERDATA AB}
set vendor(00c0e8) {PLEXCOM, INC.}
set vendor(00c0e9) {OAK SOLUTIONS, LTD.}
set vendor(00c0ea) {ARRAY TECHNOLOGY LTD.}
set vendor(00c0eb) {SEH COMPUTERTECHNIK GMBH}
set vendor(00c0ec) {DAUPHIN TECHNOLOGY}
set vendor(00c0ed) {US ARMY ELECTRONIC}
set vendor(00c0ee) {KYOCERA CORPORATION}
set vendor(00c0ef) {ABIT CORPORATION}
set vendor(00c00f) {QUANTUM SOFTWARE SYSTEMS LTD.}
set vendor(00c0f0) {KINGSTON TECHNOLOGY CORP.}
set vendor(00c0f1) {SHINKO ELECTRIC CO., LTD.}
set vendor(00c0f2) {TRANSITION NETWORKS}
set vendor(00c0f3) {NETWORK COMMUNICATIONS CORP.}
set vendor(00c0f4) {INTERLINK SYSTEM CO., LTD.}
set vendor(00c0f5) {METACOMP, INC.}
set vendor(00c0f6) {CELAN TECHNOLOGY INC.}
set vendor(00c0f7) {ENGAGE COMMUNICATION, INC.}
set vendor(00c0f8) {ABOUT COMPUTING INC.}
set vendor(00c0f9) {HARRIS AND JEFFRIES, INC.}
set vendor(00c0fa) {CANARY COMMUNICATIONS, INC.}
set vendor(00c0fb) {ADVANCED TECHNOLOGY LABS}
set vendor(00c0fc) {ELASTIC REALITY, INC.}
set vendor(00c0fd) {PROSUM}
set vendor(00c0fe) {APTEC COMPUTER SYSTEMS, INC.}
set vendor(00c0ff) {DOT HILL SYSTEMS CORPORATION}
set vendor(000c00) {BEB Industrie-Elektronik AG}
set vendor(000c01) {Abatron AG}
set vendor(000c10) {PNI Corporation}
set vendor(000c11) {NIPPON DEMPA CO.,LTD.}
set vendor(000c12) {Micro-Optronic-Messtechnik GmbH}
set vendor(000c13) {MediaQ}
set vendor(000c14) {Diagnostic Instruments, Inc.}
set vendor(000c15) {CyberPower Systems, Inc.}
set vendor(000c16) {Concorde Microsystems Inc.}
set vendor(000c17) {AJA Video Systems Inc}
set vendor(000c18) {Zenisu Keisoku Inc.}
set vendor(000c19) {Telio Communications GmbH}
set vendor(000c1a) {Quest Technical Solutions Inc.}
set vendor(000c1b) {ORACOM Co, Ltd.}
set vendor(000c1c) {MicroWeb Co., Ltd.}
set vendor(000c1d) {Mettler & Fuchs AG}
set vendor(000c1e) {Global Cache}
set vendor(000c1f) {Glimmerglass Networks}
set vendor(000c02) {ABB Oy}
set vendor(000c20) {Fi WIn, Inc.}
set vendor(000c21) {Faculty of Science and Technology, Keio University}
set vendor(000c22) {Double D Electronics Ltd}
set vendor(000c23) {Beijing Lanchuan Tech. Co., Ltd.}
set vendor(000c25) {Allied Telesyn Networks}
set vendor(000c26) {Weintek Labs. Inc.}
set vendor(000c27) {Sammy Corporation}
set vendor(000c28) {RIFATRON}
set vendor(000c29) {VMware, Inc.}
set vendor(000c2a) {OCTTEL Communication Co., Ltd.}
set vendor(000c2b) {ELIAS Technology, Inc.}
set vendor(000c2c) {Enwiser Inc.}
set vendor(000c2d) {FullWave Technology Co., Ltd.}
set vendor(000c2e) {Openet information technology(shenzhen) Co., Ltd.}
set vendor(000c2f) {SeorimTechnology Co.,Ltd.}
set vendor(000c03) {HDMI Licensing, LLC}
set vendor(000c30) {Cisco}
set vendor(000c31) {Cisco}
set vendor(000c32) {Avionic Design Development GmbH}
set vendor(000c33) {Compucase Enterprise Co. Ltd.}
set vendor(000c34) {Vixen Co., Ltd.}
set vendor(000c35) {KaVo Dental GmbH & Co. KG}
set vendor(000c36) {SHARP TAKAYA ELECTRONICS INDUSTRY CO.,LTD.}
set vendor(000c37) {Geomation, Inc.}
set vendor(000c38) {TelcoBridges Inc.}
set vendor(000c39) {Sentinel Wireless Inc.}
set vendor(000c3a) {Oxance}
set vendor(000c3b) {Orion Electric Co., Ltd.}
set vendor(000c3c) {MediaChorus, Inc.}
set vendor(000c3d) {Glsystech Co., Ltd.}
set vendor(000c3e) {Crest Audio}
set vendor(000c3f) {Cogent Defence & Security Networks,}
set vendor(000c04) {Tecnova}
set vendor(000c40) {Altech Controls}
set vendor(000c41) {The Linksys Group, Inc.}
set vendor(000c42) {Routerboard.com}
set vendor(000c43) {Ralink Technology, Corp.}
set vendor(000c44) {Automated Interfaces, Inc.}
set vendor(000c45) {Animation Technologies Inc.}
set vendor(000c46) {Allied Telesyn Inc.}
set vendor(000c47) {SK Teletech(R&D Planning Team)}
set vendor(000c48) {QoStek Corporation}
set vendor(000c49) {Dangaard Telecom RTC Division A/S}
set vendor(000c4a) {Cygnus Microsystems Private Limited}
set vendor(000c4b) {Cheops Elektronik}
set vendor(000c4c) {Arcor AG&Co.}
set vendor(000c4d) {ACRA CONTROL}
set vendor(000c4e) {Winbest Technology CO,LT}
set vendor(000c4f) {UDTech Japan Corporation}
set vendor(000c05) {RPA Reserch Co., Ltd.}
set vendor(000c50) {Seagate Technology}
set vendor(000c51) {Scientific Technologies Inc.}
set vendor(000c52) {Roll Systems Inc.}
set vendor(000c54) {Pedestal Networks, Inc}
set vendor(000c55) {Microlink Communications Inc.}
set vendor(000c56) {Megatel Computer (1986) Corp.}
set vendor(000c57) {MACKIE Engineering Services Belgium BVBA}
set vendor(000c58) {M&S Systems}
set vendor(000c59) {Indyme Electronics, Inc.}
set vendor(000c5a) {IBSmm Industrieelektronik Multimedia}
set vendor(000c5b) {HANWANG TECHNOLOGY CO.,LTD}
set vendor(000c5c) {GTN Systems B.V.}
set vendor(000c5d) {CHIC TECHNOLOGY (CHINA) CORP.}
set vendor(000c5f) {Avtec, Inc.}
set vendor(000c06) {Nixvue Systems  Pte Ltd}
set vendor(000c60) {ACM Systems}
set vendor(000c61) {AC Tech corporation DBA Advanced Digital}
set vendor(000c62) {ABB Automation Technology Products AB, Control}
set vendor(000c63) {Zenith Electronics Corporation}
set vendor(000c64) {X2 MSA Group}
set vendor(000c65) {Sunin Telecom}
set vendor(000c66) {Pronto Networks Inc}
set vendor(000c67) {OYO ELECTRIC CO.,LTD}
set vendor(000c68) {Oasis Semiconductor, Inc.}
set vendor(000c69) {National Radio Astronomy Observatory}
set vendor(000c6a) {MBARI}
set vendor(000c6b) {Kurz Industrie-Elektronik GmbH}
set vendor(000c6c) {Elgato Systems LLC}
set vendor(000c6d) {BOC Edwards}
set vendor(000c6e) {ASUSTEK COMPUTER INC.}
set vendor(000c6f) {Amtek system co.,LTD.}
set vendor(000c07) {Iftest AG}
set vendor(000c70) {ACC GmbH}
set vendor(000c71) {Wybron, Inc}
set vendor(000c72) {Tempearl Industrial Co., Ltd.}
set vendor(000c73) {TELSON ELECTRONICS CO., LTD}
set vendor(000c74) {RIVERTEC CORPORATION}
set vendor(000c75) {Oriental integrated electronics. LTD}
set vendor(000c76) {MICRO-STAR INTERNATIONAL CO., LTD.}
set vendor(000c77) {Life Racing Ltd}
set vendor(000c78) {In-Tech Electronics Limited}
set vendor(000c79) {Extel Communications P/L}
set vendor(000c7a) {DaTARIUS Technologies GmbH}
set vendor(000c7b) {ALPHA PROJECT Co.,Ltd.}
set vendor(000c7c) {Internet Information Image Inc.}
set vendor(000c7d) {TEIKOKU ELECTRIC MFG. CO., LTD}
set vendor(000c7e) {Tellium Incorporated}
set vendor(000c7f) {synertronixx GmbH}
set vendor(000c08) {HUMEX Technologies Corp.}
set vendor(000c80) {Opelcomm Inc.}
set vendor(000c81) {Nulec Industries Pty Ltd}
set vendor(000c82) {NETWORK TECHNOLOGIES INC}
set vendor(000c83) {Logical Solutions}
set vendor(000c84) {Eazix, Inc.}
set vendor(000c85) {Cisco Systems}
set vendor(000c86) {Cisco Systems}
set vendor(000c87) {ATI}
set vendor(000c88) {Apache Micro Peripherals, Inc.}
set vendor(000c89) {AC Electric Vehicles, Ltd.}
set vendor(000c8a) {Bose Corporation}
set vendor(000c8b) {Connect Tech Inc}
set vendor(000c8c) {KODICOM CO.,LTD.}
set vendor(000c8d) {MATRIX VISION GmbH}
set vendor(000c8e) {Mentor Engineering Inc}
set vendor(000c8f) {Nergal s.r.l.}
set vendor(000c09) {Hitachi IE Systems Co., Ltd}
set vendor(000c90) {Octasic Inc.}
set vendor(000c91) {Riverhead Networks Inc.}
set vendor(000c92) {WolfVision Gmbh}
set vendor(000c93) {Xeline Co., Ltd.}
set vendor(000c94) {United Electronic Industries, Inc.}
set vendor(000c95) {PrimeNet}
set vendor(000c96) {OQO, Inc.}
set vendor(000c97) {NV ADB TTV Technologies SA}
set vendor(000c98) {LETEK Communications Inc.}
set vendor(000c99) {HITEL LINK Co.,Ltd}
set vendor(000c9a) {Hitech Electronics Corp.}
set vendor(000c9b) {EE Solutions, Inc}
set vendor(000c9c) {Chongho information & communications}
set vendor(000c9d) {AirWalk Communications, Inc.}
set vendor(000c9e) {MemoryLink Corp.}
set vendor(000c9f) {NKE Corporation}
set vendor(000c0a) {Guangdong Province Electronic Technology Research Institute}
set vendor(000ca0) {StorCase Technology, Inc.}
set vendor(000ca1) {SIGMACOM Co., LTD.}
set vendor(000ca2) {Scopus Network Technologies Ltd}
set vendor(000ca3) {Rancho Technology, Inc.}
set vendor(000ca4) {Prompttec Product Management GmbH}
set vendor(000ca6) {Mintera Corporation}
set vendor(000ca7) {Metro (Suzhou) Technologies Co., Ltd.}
set vendor(000ca8) {Garuda Networks Corporation}
set vendor(000ca9) {Ebtron Inc.}
set vendor(000caa) {Cubic Transportation Systems Inc}
set vendor(000cab) {COMMEND International}
set vendor(000cac) {Citizen Watch Co., Ltd.}
set vendor(000cad) {BTU International}
set vendor(000cae) {Ailocom Oy}
set vendor(000caf) {TRI TERM CO.,LTD.}
set vendor(000c0b) {Broadbus Technologies}
set vendor(000cb0) {Star Semiconductor Corporation}
set vendor(000cb1) {Salland Engineering (Europe) BV}
set vendor(000cb2) {safei Co., Ltd.}
set vendor(000cb3) {ROUND Co.,Ltd.}
set vendor(000cb4) {Propagate Networks, Inc}
set vendor(000cb5) {Premier Technolgies, Inc}
set vendor(000cb6) {NANJING SEU MOBILE & INTERNET TECHNOLOGY CO.,LTD}
set vendor(000cb7) {Nanjing Huazhuo Electronics Co., Ltd.}
set vendor(000cb8) {MEDION AG}
set vendor(000cb9) {LEA}
set vendor(000cba) {Jamex}
set vendor(000cbb) {ISKRAEMECO}
set vendor(000cbc) {Iscutum}
set vendor(000cbd) {Interface Masters, Inc}
set vendor(000cbf) {Holy Stone Ent. Co., Ltd.}
set vendor(000c0c) {APPRO TECHNOLOGY INC.}
set vendor(000cc0) {Genera Oy}
set vendor(000cc1) {Cooper Industries Inc.}
set vendor(000cc3) {BeWAN systems}
set vendor(000cc4) {Tiptel AG}
set vendor(000cc5) {Nextlink Co., Ltd.}
set vendor(000cc6) {Ka-Ro electronics GmbH}
set vendor(000cc7) {Intelligent Computer Solutions Inc.}
set vendor(000cc8) {Integrated Digital Systems, Inc.}
set vendor(000cc9) {ILWOO DATA & TECHNOLOGY CO.,LTD}
set vendor(000cca) {Hitachi Global Storage Technologies}
set vendor(000ccb) {Design Combus Ltd}
set vendor(000ccc) {Bluesoft Ltd.}
set vendor(000ccd) {IEC - TC57}
set vendor(000cce) {Cisco Systems}
set vendor(000ccf) {Cisco Systems}
set vendor(000c0d) {Communications & Power Industries / Satcom Division}
set vendor(000cd0) {Symetrix}
set vendor(000cd1) {SFOM Technology Corp.}
set vendor(000cd2) {Schaffner EMV AG}
set vendor(000cd3) {Prettl Elektronik Radeberg GmbH}
set vendor(000cd4) {Positron Public Safety Systems inc.}
set vendor(000cd5) {Passave Inc.}
set vendor(000cd6) {PARTNER TECH}
set vendor(000cd7) {Nallatech Ltd}
set vendor(000cd8) {M. K. Juchheim GmbH & Co}
set vendor(000cd9) {Itcare Co., Ltd}
set vendor(000cda) {FreeHand Systems, Inc.}
set vendor(000cdb) {Foundry Networks}
set vendor(000cdc) {BECS Technology, Inc}
set vendor(000cdd) {AOS Technologies AG}
set vendor(000cde) {ABB STOTZ-KONTAKT GmbH}
set vendor(000cdf) {PULNiX America, Inc}
set vendor(000c0e) {XtremeSpectrum, Inc.}
set vendor(000ce0) {Trek Diagnostics Inc.}
set vendor(000ce1) {The Open Group}
set vendor(000ce2) {Rolls-Royce}
set vendor(000ce3) {Option International N.V.}
set vendor(000ce4) {NeuroCom International, Inc.}
set vendor(000ce5) {Motorola BCS}
set vendor(000ce6) {Meru Networks Inc}
set vendor(000ce7) {MediaTek Inc.}
set vendor(000ce8) {GuangZhou AnJuBao Co., Ltd}
set vendor(000ce9) {BLOOMBERG L.P.}
set vendor(000cea) {aphona Kommunikationssysteme}
set vendor(000ceb) {CNMP Networks, Inc.}
set vendor(000cec) {Spectracom Corp.}
set vendor(000ced) {Real Digital Media}
set vendor(000cee) {Q-Networks}
set vendor(000cef) {Open Networks Engineering Ltd}
set vendor(000c0f) {Techno-One Co., Ltd}
set vendor(000cf0) {M & N GmbH}
set vendor(000cf1) {Intel Corporation}
set vendor(000cf2) {GAMESA ELICA}
set vendor(000cf3) {CALL IMAGE SA}
set vendor(000cf4) {AKATSUKI ELECTRIC MFG.CO.,LTD.}
set vendor(000cf5) {InfoExpress}
set vendor(000cf6) {Sitecom Europe BV}
set vendor(000cf7) {Nortel Networks}
set vendor(000cf8) {Nortel Networks}
set vendor(000cf9) {ITT Flygt AB}
set vendor(000cfa) {Digital Systems Corp}
set vendor(000cfb) {Korea Network Systems}
set vendor(000cfc) {S2io Technologies Corp}
set vendor(000cfe) {Grand Electronic Co., Ltd}
set vendor(000cff) {MRO-TEK LIMITED}
set vendor(00cbbd) {Cambridge Broadband Ltd.}
set vendor(00cf1c) {COMMUNICATION MACHINERY CORP.}
set vendor(00d000) {FERRAN SCIENTIFIC, INC.}
set vendor(00d001) {VST TECHNOLOGIES, INC.}
set vendor(00d010) {CONVERGENT NETWORKS, INC.}
set vendor(00d011) {PRISM VIDEO, INC.}
set vendor(00d012) {GATEWORKS CORP.}
set vendor(00d013) {PRIMEX AEROSPACE COMPANY}
set vendor(00d014) {ROOT, INC.}
set vendor(00d015) {UNIVEX MICROTECHNOLOGY CORP.}
set vendor(00d016) {SCM MICROSYSTEMS, INC.}
set vendor(00d017) {SYNTECH INFORMATION CO., LTD.}
set vendor(00d018) {QWES. COM, INC.}
set vendor(00d019) {DAINIPPON SCREEN CORPORATE}
set vendor(00d01a) {URMET SUD S.P.A.}
set vendor(00d01b) {MIMAKI ENGINEERING CO., LTD.}
set vendor(00d01c) {SBS TECHNOLOGIES,}
set vendor(00d01d) {FURUNO ELECTRIC CO., LTD.}
set vendor(00d01e) {PINGTEL CORP.}
set vendor(00d01f) {CTAM PTY. LTD.}
set vendor(00d002) {DITECH CORPORATION}
set vendor(00d020) {AIM SYSTEM, INC.}
set vendor(00d021) {REGENT ELECTRONICS CORP.}
set vendor(00d022) {INCREDIBLE TECHNOLOGIES, INC.}
set vendor(00d023) {INFORTREND TECHNOLOGY, INC.}
set vendor(00d024) {Cognex Corporation}
set vendor(00d025) {XROSSTECH, INC.}
set vendor(00d026) {HIRSCHMANN AUSTRIA GMBH}
set vendor(00d027) {APPLIED AUTOMATION, INC.}
set vendor(00d028) {OMNEON VIDEO NETWORKS}
set vendor(00d029) {WAKEFERN FOOD CORPORATION}
set vendor(00d02a) {Voxent Systems Ltd.}
set vendor(00d02b) {JETCELL, INC.}
set vendor(00d02c) {CAMPBELL SCIENTIFIC, INC.}
set vendor(00d02d) {ADEMCO}
set vendor(00d02e) {COMMUNICATION AUTOMATION CORP.}
set vendor(00d02f) {VLSI TECHNOLOGY INC.}
set vendor(00d003) {COMDA ENTERPRISES CORP.}
set vendor(00d030) {SAFETRAN SYSTEMS CORP.}
set vendor(00d031) {INDUSTRIAL LOGIC CORPORATION}
set vendor(00d032) {YANO ELECTRIC CO., LTD.}
set vendor(00d033) {DALIAN DAXIAN NETWORK}
set vendor(00d034) {ORMEC SYSTEMS CORP.}
set vendor(00d035) {BEHAVIOR TECH. COMPUTER CORP.}
set vendor(00d036) {TECHNOLOGY ATLANTA CORP.}
set vendor(00d037) {PHILIPS-DVS-LO BDR}
set vendor(00d038) {FIVEMERE, LTD.}
set vendor(00d039) {UTILICOM, INC.}
set vendor(00d03a) {ZONEWORX, INC.}
set vendor(00d03b) {VISION PRODUCTS PTY. LTD.}
set vendor(00d03c) {Vieo, Inc.}
set vendor(00d03d) {GALILEO TECHNOLOGY, LTD.}
set vendor(00d03e) {ROCKETCHIPS, INC.}
set vendor(00d03f) {AMERICAN COMMUNICATION}
set vendor(00d004) {PENTACOM LTD.}
set vendor(00d040) {SYSMATE CO., LTD.}
set vendor(00d041) {AMIGO TECHNOLOGY CO., LTD.}
set vendor(00d042) {MAHLO GMBH & CO. UG}
set vendor(00d043) {ZONAL RETAIL DATA SYSTEMS}
set vendor(00d044) {ALIDIAN NETWORKS, INC.}
set vendor(00d045) {KVASER AB}
set vendor(00d046) {DOLBY LABORATORIES, INC.}
set vendor(00d047) {XN TECHNOLOGIES}
set vendor(00d048) {ECTON, INC.}
set vendor(00d049) {IMPRESSTEK CO., LTD.}
set vendor(00d04a) {PRESENCE TECHNOLOGY GMBH}
set vendor(00d04b) {LA CIE GROUP S.A.}
set vendor(00d04c) {EUROTEL TELECOM LTD.}
set vendor(00d04d) {DIV OF RESEARCH & STATISTICS}
set vendor(00d04e) {LOGIBAG}
set vendor(00d04f) {BITRONICS, INC.}
set vendor(00d005) {ZHS ZEITMANAGEMENTSYSTEME}
set vendor(00d050) {ISKRATEL}
set vendor(00d051) {O2 MICRO, INC.}
set vendor(00d052) {ASCEND COMMUNICATIONS, INC.}
set vendor(00d053) {CONNECTED SYSTEMS}
set vendor(00d054) {SAS INSTITUTE INC.}
set vendor(00d055) {KATHREIN-WERKE KG}
set vendor(00d056) {SOMAT CORPORATION}
set vendor(00d057) {ULTRAK, INC.}
set vendor(00d058) {CISCO SYSTEMS, INC.}
set vendor(00d059) {AMBIT MICROSYSTEMS CORP.}
set vendor(00d05a) {SYMBIONICS, LTD.}
set vendor(00d05b) {ACROLOOP MOTION CONTROL}
set vendor(00d05c) {TECHNOTREND SYSTEMTECHNIK GMBH}
set vendor(00d05d) {INTELLIWORXX, INC.}
set vendor(00d05e) {STRATABEAM TECHNOLOGY, INC.}
set vendor(00d05f) {VALCOM, INC.}
set vendor(00d006) {CISCO SYSTEMS, INC.}
set vendor(00d060) {PANASONIC EUROPEAN}
set vendor(00d061) {TREMON ENTERPRISES CO., LTD.}
set vendor(00d062) {DIGIGRAM}
set vendor(00d063) {CISCO SYSTEMS, INC.}
set vendor(00d064) {MULTITEL}
set vendor(00d065) {TOKO ELECTRIC}
set vendor(00d066) {WINTRISS ENGINEERING CORP.}
set vendor(00d067) {CAMPIO COMMUNICATIONS}
set vendor(00d068) {IWILL CORPORATION}
set vendor(00d069) {TECHNOLOGIC SYSTEMS}
set vendor(00d06a) {LINKUP SYSTEMS CORPORATION}
set vendor(00d06b) {SR TELECOM INC.}
set vendor(00d06c) {SHAREWAVE, INC.}
set vendor(00d06d) {ACRISON, INC.}
set vendor(00d06e) {TRENDVIEW RECORDERS LTD.}
set vendor(00d06f) {KMC CONTROLS}
set vendor(00d007) {MIC ASSOCIATES, INC.}
set vendor(00d070) {LONG WELL ELECTRONICS CORP.}
set vendor(00d071) {ECHELON CORP.}
set vendor(00d072) {BROADLOGIC}
set vendor(00d073) {ACN ADVANCED COMMUNICATIONS}
set vendor(00d074) {TAQUA SYSTEMS, INC.}
set vendor(00d075) {ALARIS MEDICAL SYSTEMS, INC.}
set vendor(00d076) {MERRILL LYNCH & CO., INC.}
set vendor(00d077) {LUCENT TECHNOLOGIES}
set vendor(00d078) {ELTEX OF SWEDEN AB}
set vendor(00d079) {CISCO SYSTEMS, INC.}
set vendor(00d07a) {AMAQUEST COMPUTER CORP.}
set vendor(00d07b) {COMCAM INTERNATIONAL LTD.}
set vendor(00d07c) {KOYO ELECTRONICS INC. CO.,LTD.}
set vendor(00d07d) {COSINE COMMUNICATIONS}
set vendor(00d07e) {KEYCORP LTD.}
set vendor(00d07f) {STRATEGY & TECHNOLOGY, LIMITED}
set vendor(00d008) {MACTELL CORPORATION}
set vendor(00d080) {EXABYTE CORPORATION}
set vendor(00d081) {REAL TIME DEVICES USA, INC.}
set vendor(00d082) {IOWAVE INC.}
set vendor(00d083) {INVERTEX, INC.}
set vendor(00d084) {NEXCOMM SYSTEMS, INC.}
set vendor(00d085) {OTIS ELEVATOR COMPANY}
set vendor(00d086) {FOVEON, INC.}
set vendor(00d087) {MICROFIRST INC.}
set vendor(00d088) {Terayon Communications Systems}
set vendor(00d089) {DYNACOLOR, INC.}
set vendor(00d08a) {PHOTRON USA}
set vendor(00d08b) {ADVA Limited}
set vendor(00d08c) {GENOA TECHNOLOGY, INC.}
set vendor(00d08d) {PHOENIX GROUP, INC.}
set vendor(00d08e) {NVISION INC.}
set vendor(00d08f) {ARDENT TECHNOLOGIES, INC.}
set vendor(00d009) {HSING TECH. ENTERPRISE CO. LTD}
set vendor(00d090) {CISCO SYSTEMS, INC.}
set vendor(00d091) {SMARTSAN SYSTEMS, INC.}
set vendor(00d092) {GLENAYRE WESTERN MULTIPLEX}
set vendor(00d093) {TQ - COMPONENTS GMBH}
set vendor(00d094) {TIMELINE VISTA, INC.}
set vendor(00d095) {XYLAN CORPORATION}
set vendor(00d096) {3COM EUROPE LTD.}
set vendor(00d097) {CISCO SYSTEMS, INC.}
set vendor(00d098) {Photon Dynamics Canada Inc.}
set vendor(00d099) {ELCARD OY}
set vendor(00d09a) {FILANET CORPORATION}
set vendor(00d09b) {SPECTEL LTD.}
set vendor(00d09c) {KAPADIA COMMUNICATIONS}
set vendor(00d09d) {VERIS INDUSTRIES}
set vendor(00d09e) {2WIRE, INC.}
set vendor(00d09f) {NOVTEK TEST SYSTEMS}
set vendor(00d00a) {LANACCESS TELECOM S.A.}
set vendor(00d0a0) {MIPS DENMARK}
set vendor(00d0a1) {OSKAR VIERLING GMBH + CO. KG}
set vendor(00d0a2) {INTEGRATED DEVICE}
set vendor(00d0a3) {VOCAL DATA, INC.}
set vendor(00d0a4) {ALANTRO COMMUNICATIONS}
set vendor(00d0a5) {AMERICAN ARIUM}
set vendor(00d0a6) {LANBIRD TECHNOLOGY CO., LTD.}
set vendor(00d0a7) {TOKYO SOKKI KENKYUJO CO., LTD.}
set vendor(00d0a8) {NETWORK ENGINES, INC.}
set vendor(00d0a9) {SHINANO KENSHI CO., LTD.}
set vendor(00d0aa) {CHASE COMMUNICATIONS}
set vendor(00d0ab) {DELTAKABEL TELECOM CV}
set vendor(00d0ac) {GRAYSON WIRELESS}
set vendor(00d0ad) {TL INDUSTRIES}
set vendor(00d0ae) {ORESIS COMMUNICATIONS, INC.}
set vendor(00d0af) {CUTLER-HAMMER, INC.}
set vendor(00d00b) {RHK TECHNOLOGY, INC.}
set vendor(00d0b0) {BITSWITCH LTD.}
set vendor(00d0b1) {OMEGA ELECTRONICS SA}
set vendor(00d0b2) {XIOTECH CORPORATION}
set vendor(00d0b3) {DRS FLIGHT SAFETY AND}
set vendor(00d0b4) {KATSUJIMA CO., LTD.}
set vendor(00d0b5) {IPricot formerly DotCom}
set vendor(00d0b6) {CRESCENT NETWORKS, INC.}
set vendor(00d0b7) {INTEL CORPORATION}
set vendor(00d0b8) {IOMEGA CORP.}
set vendor(00d0b9) {MICROTEK INTERNATIONAL, INC.}
set vendor(00d0ba) {CISCO SYSTEMS, INC.}
set vendor(00d0bb) {CISCO SYSTEMS, INC.}
set vendor(00d0bc) {CISCO SYSTEMS, INC.}
set vendor(00d0bd) {SICAN GMBH}
set vendor(00d0be) {EMUTEC INC.}
set vendor(00d0bf) {PIVOTAL TECHNOLOGIES}
set vendor(00d00c) {SNIJDER MICRO SYSTEMS}
set vendor(00d0c0) {CISCO SYSTEMS, INC.}
set vendor(00d0c1) {HARMONIC DATA SYSTEMS, LTD.}
set vendor(00d0c2) {BALTHAZAR TECHNOLOGY AB}
set vendor(00d0c3) {VIVID TECHNOLOGY PTE, LTD.}
set vendor(00d0c4) {TERATECH CORPORATION}
set vendor(00d0c5) {COMPUTATIONAL SYSTEMS, INC.}
set vendor(00d0c6) {THOMAS & BETTS CORP.}
set vendor(00d0c7) {PATHWAY, INC.}
set vendor(00d0c8) {I/O CONSULTING A/S}
set vendor(00d0c9) {ADVANTECH CO., LTD.}
set vendor(00d0ca) {INTRINSYC SOFTWARE INC.}
set vendor(00d0cb) {DASAN CO., LTD.}
set vendor(00d0cc) {TECHNOLOGIES LYRE INC.}
set vendor(00d0cd) {ATAN TECHNOLOGY INC.}
set vendor(00d0ce) {ASYST ELECTRONIC}
set vendor(00d0cf) {MORETON BAY}
set vendor(00d00d) {MICROMERITICS INSTRUMENT}
set vendor(00d0d0) {ZHONGXING TELECOM LTD.}
set vendor(00d0d1) {SIROCCO SYSTEMS, INC.}
set vendor(00d0d2) {EPILOG CORPORATION}
set vendor(00d0d3) {CISCO SYSTEMS, INC.}
set vendor(00d0d4) {V-BITS, INC.}
set vendor(00d0d5) {GRUNDIG AG}
set vendor(00d0d6) {AETHRA TELECOMUNICAZIONI}
set vendor(00d0d7) {B2C2, INC.}
set vendor(00d0d8) {3Com Corporation}
set vendor(00d0d9) {DEDICATED MICROCOMPUTERS}
set vendor(00d0da) {TAICOM DATA SYSTEMS CO., LTD.}
set vendor(00d0db) {MCQUAY INTERNATIONAL}
set vendor(00d0dc) {MODULAR MINING SYSTEMS, INC.}
set vendor(00d0dd) {SUNRISE TELECOM, INC.}
set vendor(00d0de) {PHILIPS MULTIMEDIA NETWORK}
set vendor(00d0df) {KUZUMI ELECTRONICS, INC.}
set vendor(00d00e) {PLURIS, INC.}
set vendor(00d0e0) {DOOIN ELECTRONICS CO.}
set vendor(00d0e1) {AVIONITEK ISRAEL INC.}
set vendor(00d0e2) {MRT MICRO, INC.}
set vendor(00d0e3) {ELE-CHEM ENGINEERING CO., LTD.}
set vendor(00d0e4) {CISCO SYSTEMS, INC.}
set vendor(00d0e5) {SOLIDUM SYSTEMS CORP.}
set vendor(00d0e6) {IBOND INC.}
set vendor(00d0e7) {VCON TELECOMMUNICATION LTD.}
set vendor(00d0e8) {MAC SYSTEM CO., LTD.}
set vendor(00d0e9) {ADVANTAGE CENTURY}
set vendor(00d0ea) {NEXTONE COMMUNICATIONS, INC.}
set vendor(00d0eb) {LIGHTERA NETWORKS, INC.}
set vendor(00d0ec) {NAKAYO TELECOMMUNICATIONS, INC}
set vendor(00d0ed) {XIOX}
set vendor(00d0ee) {DICTAPHONE CORPORATION}
set vendor(00d0ef) {IGT}
set vendor(00d00f) {SPEECH DESIGN GMBH}
set vendor(00d0f0) {CONVISION TECHNOLOGY GMBH}
set vendor(00d0f1) {SEGA ENTERPRISES, LTD.}
set vendor(00d0f2) {MONTEREY NETWORKS}
set vendor(00d0f3) {SOLARI DI UDINE SPA}
set vendor(00d0f4) {CARINTHIAN TECH INSTITUTE}
set vendor(00d0f5) {ORANGE MICRO, INC.}
set vendor(00d0f6) {Alcatel Canada}
set vendor(00d0f7) {NEXT NETS CORPORATION}
set vendor(00d0f8) {FUJIAN STAR TERMINAL}
set vendor(00d0f9) {ACUTE COMMUNICATIONS CORP.}
set vendor(00d0fa) {RACAL GUARDATA}
set vendor(00d0fb) {TEK MICROSYSTEMS, INCORPORATED}
set vendor(00d0fc) {GRANITE MICROSYSTEMS}
set vendor(00d0fd) {OPTIMA TELE.COM, INC.}
set vendor(00d0fe) {ASTRAL POINT}
set vendor(00d0ff) {CISCO SYSTEMS, INC.}
set vendor(000d00) {Seaway Networks Inc.}
set vendor(000d01) {P&E Microcomputer Systems, Inc.}
set vendor(000d10) {Embedtronics Oy}
set vendor(000d11) {DENTSPLY - Gendex}
set vendor(000d12) {AXELL Corporation}
set vendor(000d13) {Wilhelm Rutenbeck GmbH&Co.}
set vendor(000d14) {Vtech Innovation LP dba Advanced American Telephones}
set vendor(000d15) {Voipac s.r.o.}
set vendor(000d16) {UHS Systems Pty Ltd}
set vendor(000d17) {Turbo Networks Co.Ltd}
set vendor(000d18) {Sunitec Enterprise Co., Ltd.}
set vendor(000d19) {ROBE Show lighting}
set vendor(000d1a) {Mustek System Inc.}
set vendor(000d1b) {Kyoto Electronics Manufacturing Co., Ltd.}
set vendor(000d1c) {I2E TELECOM}
set vendor(000d1d) {HIGH-TEK HARNESS ENT. CO., LTD.}
set vendor(000d1e) {Control Techniques}
set vendor(000d1f) {AV Digital}
set vendor(000d02) {NEC Access Technica,Ltd}
set vendor(000d20) {ASAHIKASEI TECHNOSYSTEM CO.,LTD.}
set vendor(000d21) {WISCORE Inc.}
set vendor(000d22) {Unitronics}
set vendor(000d23) {Smart Solution, Inc}
set vendor(000d24) {SENTEC E&E CO., LTD.}
set vendor(000d25) {SANDEN CORPORATION}
set vendor(000d26) {Primagraphics Limited}
set vendor(000d27) {MICROPLEX Printware AG}
set vendor(000d28) {Cisco}
set vendor(000d29) {Cisco}
set vendor(000d2a) {Scanmatic AS}
set vendor(000d2b) {Racal Instruments}
set vendor(000d2c) {Patapsco Designs Ltd}
set vendor(000d2d) {NCT Deutschland GmbH}
set vendor(000d2e) {Matsushita Avionics Systems Corporation}
set vendor(000d2f) {AIN Comm.Tech.Co., LTD}
set vendor(000d03) {Matrics, Inc.}
set vendor(000d30) {IceFyre Semiconductor}
set vendor(000d31) {Compellent Technologies, Inc.}
set vendor(000d32) {DispenseSource, Inc.}
set vendor(000d33) {Prediwave Corp.}
set vendor(000d34) {Shell International Exploration and Production, Inc.}
set vendor(000d35) {PAC International Ltd}
set vendor(000d36) {Wu Han Routon Electronic Co., Ltd}
set vendor(000d37) {WIPLUG}
set vendor(000d38) {NISSIN INC.}
set vendor(000d39) {Network Electronics}
set vendor(000d3a) {Microsoft Corp.}
set vendor(000d3b) {Microelectronics Technology Inc.}
set vendor(000d3c) {i.Tech Dynamic Ltd}
set vendor(000d3e) {APLUX Communications Ltd.}
set vendor(000d3f) {VXI Technology}
set vendor(000d04) {Foxboro Eckardt Development GmbH}
set vendor(000d40) {Verint Loronix Video Solutions}
set vendor(000d41) {Siemens AG ICM MP UC RD IT KLF1}
set vendor(000d42) {Newbest Development Limited}
set vendor(000d43) {DRS Tactical Systems Inc.}
set vendor(000d45) {Tottori SANYO Electric Co., Ltd.}
set vendor(000d46) {Eurotherm Drives, Ltd.}
set vendor(000d47) {Collex}
set vendor(000d48) {AEWIN Technologies Co., Ltd.}
set vendor(000d49) {Triton Systems of Delaware, Inc.}
set vendor(000d4a) {Steag ETA-Optik}
set vendor(000d4b) {Roku, LLC}
set vendor(000d4c) {Outline Electronics Ltd.}
set vendor(000d4d) {Ninelanes}
set vendor(000d4e) {NDR Co.,LTD.}
set vendor(000d4f) {Kenwood Corporation}
set vendor(000d05) {cybernet manufacturing inc.}
set vendor(000d50) {Galazar Networks}
set vendor(000d51) {DIVR Systems, Inc.}
set vendor(000d52) {Comart system}
set vendor(000d53) {Beijing 5w Communication Corp.}
set vendor(000d54) {3Com Europe Ltd}
set vendor(000d55) {SANYCOM Technology Co.,Ltd}
set vendor(000d56) {Dell PCBA Test}
set vendor(000d57) {Fujitsu I-Network Systems Limited.}
set vendor(000d59) {Amity Systems, Inc.}
set vendor(000d5a) {Tiesse SpA}
set vendor(000d5b) {Smart Empire Investments Limited}
set vendor(000d5c) {Robert Bosch GmbH, VT-ATMO}
set vendor(000d5d) {Raritan Computer, Inc}
set vendor(000d5e) {NEC CustomTechnica, Ltd.}
set vendor(000d5f) {Minds Inc}
set vendor(000d06) {Compulogic Limited}
set vendor(000d60) {IBM Corporation}
set vendor(000d61) {Giga-Byte Technology Co., Ltd.}
set vendor(000d62) {Funkwerk Dabendorf GmbH}
set vendor(000d63) {DENT Instruments, Inc.}
set vendor(000d64) {COMAG Handels AG}
set vendor(000d65) {Cisco Systems}
set vendor(000d66) {Cisco Systems}
set vendor(000d67) {BelAir Networks Inc.}
set vendor(000d68) {Vinci Systems, Inc.}
set vendor(000d69) {TMT&D Corporation}
set vendor(000d6a) {Redwood Technologies LTD}
set vendor(000d6b) {Mita-Teknik A/S}
set vendor(000d6c) {M-Audio}
set vendor(000d6d) {K-Tech Devices Corp.}
set vendor(000d6e) {K-Patents Oy}
set vendor(000d6f) {Ember Corporation}
set vendor(000d07) {Calrec Audio Ltd}
set vendor(000d70) {Datamax Corporation}
set vendor(000d71) {boca systems}
set vendor(000d72) {2Wire, Inc}
set vendor(000d73) {Technical Support, Inc.}
set vendor(000d74) {Sand Network Systems, Inc.}
set vendor(000d75) {Kobian Pte Ltd - Taiwan Branch}
set vendor(000d76) {Hokuto Denshi Co,. Ltd.}
set vendor(000d77) {FalconStor Software}
set vendor(000d78) {Engineering & Security}
set vendor(000d79) {Dynamic Solutions Co,.Ltd.}
set vendor(000d7a) {DiGATTO Asia Pacific Pte Ltd}
set vendor(000d7b) {Consensys Computers Inc.}
set vendor(000d7c) {Codian Ltd}
set vendor(000d7d) {Afco Systems}
set vendor(000d7e) {Axiowave Networks, Inc.}
set vendor(000d7f) {MIDAS  COMMUNICATION TECHNOLOGIES PTE LTD ( Foreign Branch)}
set vendor(000d08) {AboveCable, Inc.}
set vendor(000d80) {Online Development Inc}
set vendor(000d81) {Pepperl+Fuchs GmbH}
set vendor(000d82) {PHS srl}
set vendor(000d83) {Sanmina-SCI Hungary  Ltd.}
set vendor(000d84) {Seodu Inchip, Inc.}
set vendor(000d85) {Tapwave, Inc.}
set vendor(000d86) {Huber + Suhner AG}
set vendor(000d87) {Elitegroup Computer System Co. (ECS)}
set vendor(000d88) {D-Link Corporation}
set vendor(000d89) {Bils Technology Inc}
set vendor(000d8a) {Winners Electronics Co., Ltd.}
set vendor(000d8b) {T&D Corporation}
set vendor(000d8c) {Shanghai Wedone Digital Ltd. CO.}
set vendor(000d8d) {ProLinx Communication Gateways, Inc.}
set vendor(000d8e) {Koden Electronics Co., Ltd.}
set vendor(000d8f) {King Tsushin Kogyo Co., LTD.}
set vendor(000d09) {Yuehua(Zhuhai) Electronic CO. LTD}
set vendor(000d90) {Factum Electronics AB}
set vendor(000d91) {Eclipse (HQ Espana) S.L.}
set vendor(000d92) {Arima Communication Corporation}
set vendor(000d93) {Apple Computer}
set vendor(000d94) {AFAR Communications,Inc}
set vendor(000d96) {Vtera Technology Inc.}
set vendor(000d97) {Tropos Networks, Inc.}
set vendor(000d98) {S.W.A.C. Schmitt-Walter Automation Consult GmbH}
set vendor(000d99) {Orbital Sciences Corp.; Launch Systems Group}
set vendor(000d9a) {INFOTEC LTD}
set vendor(000d9c) {Elan GmbH & Co KG}
set vendor(000d9d) {Hewlett Packard}
set vendor(000d9e) {TOKUDEN OHIZUMI SEISAKUSYO Co.,Ltd.}
set vendor(000d9f) {RF Micro Devices}
set vendor(000d0a) {Projectiondesign as}
set vendor(000da0) {NEDAP N.V.}
set vendor(000da1) {MIRAE ITS Co.,LTD.}
set vendor(000da2) {Infrant Technologies, Inc.}
set vendor(000da3) {Emerging Technologies Limited}
set vendor(000da4) {DOSCH & AMAND SYSTEMS AG}
set vendor(000da5) {Fabric7 Systems, Inc}
set vendor(000da6) {Universal Switching Corporation}
set vendor(000da8) {Teletronics Technology Corporation}
set vendor(000da9) {T.E.A.M. S.L.}
set vendor(000daa) {S.A.Tehnology co.,Ltd.}
set vendor(000dab) {Parker Hannifin GmbH Electromechanical Division Europe}
set vendor(000dac) {Japan CBM Corporation}
set vendor(000dad) {Dataprobe Inc}
set vendor(000dae) {SAMSUNG HEAVY INDUSTRIES CO., LTD.}
set vendor(000daf) {Plexus Corp (UK) Ltd}
set vendor(000d0b) {Melco Inc.}
set vendor(000db0) {Olym-tech Co.,Ltd.}
set vendor(000db1) {Japan Network Service Co., Ltd.}
set vendor(000db2) {Ammasso, Inc.}
set vendor(000db3) {SDO Communication Corperation}
set vendor(000db4) {NETASQ}
set vendor(000db5) {GLOBALSAT TECHNOLOGY CORPORATION}
set vendor(000db6) {Teknovus, Inc.}
set vendor(000db7) {SANKO ELECTRIC CO,.LTD}
set vendor(000db8) {SCHILLER AG}
set vendor(000db9) {PC Engines GmbH}
set vendor(000dba) {Oc Document Technologies GmbH}
set vendor(000dbb) {Nippon Dentsu Co.,Ltd.}
set vendor(000dbc) {Cisco Systems}
set vendor(000dbd) {Cisco Systems}
set vendor(000dbe) {Bel Fuse Europe Ltd.,UK}
set vendor(000dbf) {TekTone Sound & Signal Mfg., Inc.}
set vendor(000d0c) {MDI Security Systems}
set vendor(000dc0) {Spagat AS}
set vendor(000dc1) {SafeWeb Inc}
set vendor(000dc3) {First Communication, Inc.}
set vendor(000dc4) {Emcore Corporation}
set vendor(000dc5) {EchoStar International Corporation}
set vendor(000dc6) {DigiRose Technology Co., Ltd.}
set vendor(000dc7) {COSMIC ENGINEERING INC.}
set vendor(000dc8) {AirMagnet, Inc}
set vendor(000dc9) {THALES Elektronik Systeme GmbH}
set vendor(000dca) {Tait Electronics}
set vendor(000dcb) {Petcomkorea Co., Ltd.}
set vendor(000dcc) {NEOSMART Corp.}
set vendor(000dcd) {GROUPE TXCOM}
set vendor(000dce) {Dynavac Technology Pte Ltd}
set vendor(000dcf) {Cidra Corp.}
set vendor(000d0d) {ITSupported, LLC}
set vendor(000dd0) {TetraTec Instruments GmbH}
set vendor(000dd1) {Stryker Corporation}
set vendor(000dd2) {Simrad Optronics ASA}
set vendor(000dd3) {SAMWOO Telecommunication Co.,Ltd.}
set vendor(000dd4) {Revivio Inc.}
set vendor(000dd5) {O'RITE TECHNOLOGY CO.,LTD}
set vendor(000dd7) {Bright}
set vendor(000dd8) {BBN}
set vendor(000dd9) {Anton Paar GmbH}
set vendor(000dda) {ALLIED TELESIS K.K.}
set vendor(000ddb) {AIRWAVE TECHNOLOGIES INC.}
set vendor(000ddc) {VAC}
set vendor(000ddd) {PROFLO TELRA ELEKTRONK SANAY VE TCARET A..}
set vendor(000dde) {Joyteck Co., Ltd.}
set vendor(000ddf) {Japan Image & Network Inc.}
set vendor(000d0e) {Inqnet Systems, Inc.}
set vendor(000de0) {ICPDAS Co.,LTD}
set vendor(000de1) {Control Products, Inc.}
set vendor(000de2) {CMZ Sistemi Elettronici}
set vendor(000de3) {AT Sweden AB}
set vendor(000de4) {DIGINICS, Inc.}
set vendor(000de5) {Samsung Thales}
set vendor(000de6) {YOUNGBO ENGINEERING CO.,LTD}
set vendor(000de7) {Snap-on OEM Group}
set vendor(000de8) {Nasaco Electronics Pte. Ltd}
set vendor(000de9) {Napatech Aps}
set vendor(000dea) {Kingtel Telecommunication Corp.}
set vendor(000deb) {CompXs Limited}
set vendor(000dec) {Cisco Systems}
set vendor(000ded) {Cisco Systems}
set vendor(000def) {Soc. Coop. Bilanciai}
set vendor(000d0f) {Finlux Ltd}
set vendor(000df0) {QCOM TECHNOLOGY INC.}
set vendor(000df1) {IONIX INC.}
set vendor(000df3) {Asmax Solutions}
set vendor(000df4) {Watertek Co.}
set vendor(000df5) {Teletronics International Inc.}
set vendor(000df6) {Technology Thesaurus Corp.}
set vendor(000df7) {Space Dynamics Lab}
set vendor(000df8) {ORGA Kartensysteme GmbH}
set vendor(000df9) {NDS Limited}
set vendor(000dfa) {Micro Control Systems Ltd.}
set vendor(000dfb) {Komax AG}
set vendor(000dfc) {ITFOR Inc. resarch and development}
set vendor(000dfd) {Huges Hi-Tech Inc.,}
set vendor(000dfe) {Hauppauge Computer Works, Inc.}
set vendor(000dff) {CHENMING MOLD INDUSTRY CORP.}
set vendor(00dd00) {UNGERMANN-BASS INC.}
set vendor(00dd01) {UNGERMANN-BASS INC.}
set vendor(00dd02) {UNGERMANN-BASS INC.}
set vendor(00dd03) {UNGERMANN-BASS INC.}
set vendor(00dd04) {UNGERMANN-BASS INC.}
set vendor(00dd05) {UNGERMANN-BASS INC.}
set vendor(00dd06) {UNGERMANN-BASS INC.}
set vendor(00dd07) {UNGERMANN-BASS INC.}
set vendor(00dd08) {UNGERMANN-BASS INC.}
set vendor(00dd09) {UNGERMANN-BASS INC.}
set vendor(00dd0a) {UNGERMANN-BASS INC.}
set vendor(00dd0b) {UNGERMANN-BASS INC.}
set vendor(00dd0c) {UNGERMANN-BASS INC.}
set vendor(00dd0d) {UNGERMANN-BASS INC.}
set vendor(00dd0e) {UNGERMANN-BASS INC.}
set vendor(00dd0f) {UNGERMANN-BASS INC.}
set vendor(00e000) {FUJITSU, LTD}
set vendor(00e001) {STRAND LIGHTING LIMITED}
set vendor(00e010) {HESS SB-AUTOMATENBAU GmbH}
set vendor(00e011) {UNIDEN SAN DIEGO R&D CENTER, INC.}
set vendor(00e012) {PLUTO TECHNOLOGIES INTERNATIONAL INC.}
set vendor(00e013) {EASTERN ELECTRONIC CO., LTD.}
set vendor(00e014) {CISCO SYSTEMS, INC.}
set vendor(00e015) {HEIWA CORPORATION}
set vendor(00e016) {RAPID CITY COMMUNICATIONS}
set vendor(00e017) {EXXACT GmbH}
set vendor(00e018) {ASUSTEK COMPUTER INC.}
set vendor(00e019) {ING. GIORDANO ELETTRONICA}
set vendor(00e01a) {COMTEC SYSTEMS. CO., LTD.}
set vendor(00e01b) {SPHERE COMMUNICATIONS, INC.}
set vendor(00e01c) {MOBILITY ELECTRONICSY}
set vendor(00e01d) {WebTV NETWORKS, INC.}
set vendor(00e01e) {CISCO SYSTEMS, INC.}
set vendor(00e01f) {AVIDIA Systems, Inc.}
set vendor(00e002) {CROSSROADS SYSTEMS, INC.}
set vendor(00e020) {TECNOMEN OY}
set vendor(00e021) {FREEGATE CORP.}
set vendor(00e022) {MediaLight, Inc.}
set vendor(00e023) {TELRAD}
set vendor(00e024) {GADZOOX NETWORKS}
set vendor(00e025) {dit CO., LTD.}
set vendor(00e026) {EASTMAN KODAK CO.}
set vendor(00e027) {DUX, INC.}
set vendor(00e028) {APTIX CORPORATION}
set vendor(00e029) {STANDARD MICROSYSTEMS CORP.}
set vendor(00e02a) {TANDBERG TELEVISION AS}
set vendor(00e02b) {EXTREME NETWORKS}
set vendor(00e02c) {AST COMPUTER}
set vendor(00e02d) {InnoMediaLogic, Inc.}
set vendor(00e02e) {SPC ELECTRONICS CORPORATION}
set vendor(00e02f) {MCNS HOLDINGS, L.P.}
set vendor(00e003) {NOKIA WIRELESS BUSINESS COMMUN}
set vendor(00e030) {MELITA INTERNATIONAL CORP.}
set vendor(00e031) {HAGIWARA ELECTRIC CO., LTD.}
set vendor(00e032) {MISYS FINANCIAL SYSTEMS, LTD.}
set vendor(00e033) {E.E.P.D. GmbH}
set vendor(00e034) {CISCO SYSTEMS, INC.}
set vendor(00e035) {LOUGHBOROUGH SOUND IMAGES, PLC}
set vendor(00e036) {PIONEER CORPORATION}
set vendor(00e037) {CENTURY CORPORATION}
set vendor(00e038) {PROXIMA CORPORATION}
set vendor(00e039) {PARADYNE CORP.}
set vendor(00e03a) {CABLETRON SYSTEMS, INC.}
set vendor(00e03b) {PROMINET CORPORATION}
set vendor(00e03c) {AdvanSys}
set vendor(00e03d) {FOCON ELECTRONIC SYSTEMS A/S}
set vendor(00e03e) {ALFATECH, INC.}
set vendor(00e03f) {JATON CORPORATION}
set vendor(00e004) {PMC-SIERRA, INC.}
set vendor(00e040) {DeskStation Technology, Inc.}
set vendor(00e041) {CSPI}
set vendor(00e042) {Pacom Systems Ltd.}
set vendor(00e043) {VitalCom}
set vendor(00e044) {LSICS CORPORATION}
set vendor(00e045) {TOUCHWAVE, INC.}
set vendor(00e046) {BENTLY NEVADA CORP.}
set vendor(00e047) {INFOCUS SYSTEMS}
set vendor(00e048) {SDL COMMUNICATIONS, INC.}
set vendor(00e049) {MICROWI ELECTRONIC GmbH}
set vendor(00e04a) {ENHANCED MESSAGING SYSTEMS, INC}
set vendor(00e04b) {JUMP INDUSTRIELLE COMPUTERTECHNIK GmbH}
set vendor(00e04c) {REALTEK SEMICONDUCTOR CORP.}
set vendor(00e04d) {INTERNET INITIATIVE JAPAN, INC}
set vendor(00e04e) {SANYO DENKI CO., LTD.}
set vendor(00e04f) {CISCO SYSTEMS, INC.}
set vendor(00e005) {TECHNICAL CORP.}
set vendor(00e050) {EXECUTONE INFORMATION SYSTEMS, INC.}
set vendor(00e051) {TALX CORPORATION}
set vendor(00e052) {FOUNDRY NETWORKS, INC.}
set vendor(00e053) {CELLPORT LABS, INC.}
set vendor(00e054) {KODAI HITEC CO., LTD.}
set vendor(00e055) {INGENIERIA ELECTRONICA COMERCIAL INELCOM S.A.}
set vendor(00e056) {HOLONTECH CORPORATION}
set vendor(00e057) {HAN MICROTELECOM. CO., LTD.}
set vendor(00e058) {PHASE ONE DENMARK A/S}
set vendor(00e059) {CONTROLLED ENVIRONMENTS, LTD.}
set vendor(00e05a) {GALEA NETWORK SECURITY}
set vendor(00e05b) {WEST END SYSTEMS CORP.}
set vendor(00e05c) {MATSUSHITA KOTOBUKI ELECTRONICS INDUSTRIES, LTD.}
set vendor(00e05d) {UNITEC CO., LTD.}
set vendor(00e05e) {JAPAN AVIATION ELECTRONICS INDUSTRY, LTD.}
set vendor(00e05f) {e-Net, Inc.}
set vendor(00e006) {SILICON INTEGRATED SYS. CORP.}
set vendor(00e060) {SHERWOOD}
set vendor(00e061) {EdgePoint Networks, Inc.}
set vendor(00e062) {HOST ENGINEERING}
set vendor(00e063) {CABLETRON - YAGO SYSTEMS, INC.}
set vendor(00e064) {SAMSUNG ELECTRONICS}
set vendor(00e065) {OPTICAL ACCESS INTERNATIONAL}
set vendor(00e066) {ProMax Systems, Inc.}
set vendor(00e067) {eac AUTOMATION-CONSULTING GmbH}
set vendor(00e068) {MERRIMAC SYSTEMS INC.}
set vendor(00e069) {JAYCOR}
set vendor(00e06a) {KAPSCH AG}
set vendor(00e06b) {W&G SPECIAL PRODUCTS}
set vendor(00e06c) {AEP Systems International Ltd}
set vendor(00e06d) {COMPUWARE CORPORATION}
set vendor(00e06e) {FAR SYSTEMS S.p.A.}
set vendor(00e06f) {Terayon Communications Systems}
set vendor(00e007) {NETWORK ALCHEMY LTD.}
set vendor(00e070) {DH TECHNOLOGY}
set vendor(00e071) {EPIS MICROCOMPUTER}
set vendor(00e072) {LYNK}
set vendor(00e073) {NATIONAL AMUSEMENT NETWORK, INC.}
set vendor(00e074) {TIERNAN COMMUNICATIONS, INC.}
set vendor(00e075) {Verilink Corporation}
set vendor(00e076) {DEVELOPMENT CONCEPTS, INC.}
set vendor(00e077) {WEBGEAR, INC.}
set vendor(00e078) {BERKELEY NETWORKS}
set vendor(00e079) {A.T.N.R.}
set vendor(00e07a) {MIKRODIDAKT AB}
set vendor(00e07b) {BAY NETWORKS}
set vendor(00e07c) {METTLER-TOLEDO, INC.}
set vendor(00e07d) {NETRONIX, INC.}
set vendor(00e07e) {WALT DISNEY IMAGINEERING}
set vendor(00e07f) {LOGISTISTEM s.r.l.}
set vendor(00e008) {AMAZING CONTROLS! INC.}
set vendor(00e080) {CONTROL RESOURCES CORPORATION}
set vendor(00e081) {TYAN COMPUTER CORP.}
set vendor(00e082) {ANERMA}
set vendor(00e083) {JATO TECHNOLOGIES, INC.}
set vendor(00e084) {COMPULITE R&D}
set vendor(00e085) {GLOBAL MAINTECH, INC.}
set vendor(00e086) {CYBEX COMPUTER PRODUCTS}
set vendor(00e087) {LeCroy - Networking Productions Division}
set vendor(00e088) {LTX CORPORATION}
set vendor(00e089) {ION Networks, Inc.}
set vendor(00e08a) {GEC AVERY, LTD.}
set vendor(00e08b) {QLogic Corp.}
set vendor(00e08c) {NEOPARADIGM LABS, INC.}
set vendor(00e08d) {PRESSURE SYSTEMS, INC.}
set vendor(00e08e) {UTSTARCOM}
set vendor(00e08f) {CISCO SYSTEMS, INC.}
set vendor(00e009) {MARATHON TECHNOLOGIES CORP.}
set vendor(00e090) {BECKMAN LAB. AUTOMATION DIV.}
set vendor(00e091) {LG ELECTRONICS, INC.}
set vendor(00e092) {ADMTEK INCORPORATED}
set vendor(00e093) {ACKFIN NETWORKS}
set vendor(00e094) {OSAI SRL}
set vendor(00e095) {ADVANCED-VISION TECHNOLGIES CORP.}
set vendor(00e096) {SHIMADZU CORPORATION}
set vendor(00e097) {CARRIER ACCESS CORPORATION}
set vendor(00e098) {AboCom Systems, Inc.}
set vendor(00e099) {SAMSON AG}
set vendor(00e09a) {POSITRON INDUSTRIES, INC.}
set vendor(00e09b) {ENGAGE NETWORKS, INC.}
set vendor(00e09c) {MII}
set vendor(00e09d) {SARNOFF CORPORATION}
set vendor(00e09e) {QUANTUM CORPORATION}
set vendor(00e09f) {PIXEL VISION}
set vendor(00e00a) {DIBA, INC.}
set vendor(00e0a0) {WILTRON CO.}
set vendor(00e0a1) {HIMA PAUL HILDEBRANDT GmbH Co. KG}
set vendor(00e0a2) {MICROSLATE INC.}
set vendor(00e0a3) {CISCO SYSTEMS, INC.}
set vendor(00e0a4) {ESAOTE S.p.A.}
set vendor(00e0a5) {ComCore Semiconductor, Inc.}
set vendor(00e0a6) {TELOGY NETWORKS, INC.}
set vendor(00e0a7) {IPC INFORMATION SYSTEMS, INC.}
set vendor(00e0a8) {SAT GmbH & Co.}
set vendor(00e0a9) {FUNAI ELECTRIC CO., LTD.}
set vendor(00e0aa) {ELECTROSONIC LTD.}
set vendor(00e0ab) {DIMAT S.A.}
set vendor(00e0ac) {MIDSCO, INC.}
set vendor(00e0ad) {EES TECHNOLOGY, LTD.}
set vendor(00e0ae) {XAQTI CORPORATION}
set vendor(00e0af) {GENERAL DYNAMICS INFORMATION SYSTEMS}
set vendor(00e00b) {ROOFTOP COMMUNICATIONS CORP.}
set vendor(00e0b0) {CISCO SYSTEMS, INC.}
set vendor(00e0b1) {PACKET ENGINES, INC.}
set vendor(00e0b2) {TELMAX COMMUNICATIONS CORP.}
set vendor(00e0b3) {EtherWAN Systems, Inc.}
set vendor(00e0b4) {TECHNO SCOPE CO., LTD.}
set vendor(00e0b5) {ARDENT COMMUNICATIONS CORP.}
set vendor(00e0b6) {Entrada Networks}
set vendor(00e0b7) {PI GROUP, LTD.}
set vendor(00e0b8) {GATEWAY 2000}
set vendor(00e0b9) {BYAS SYSTEMS}
set vendor(00e0ba) {BERGHOF AUTOMATIONSTECHNIK GmbH}
set vendor(00e0bb) {NBX CORPORATION}
set vendor(00e0bc) {SYMON COMMUNICATIONS, INC.}
set vendor(00e0bd) {INTERFACE SYSTEMS, INC.}
set vendor(00e0be) {GENROCO INTERNATIONAL, INC.}
set vendor(00e0bf) {TORRENT NETWORKING TECHNOLOGIES CORP.}
set vendor(00e00c) {MOTOROLA}
set vendor(00e0c0) {SEIWA ELECTRIC MFG. CO., LTD.}
set vendor(00e0c1) {MEMOREX TELEX JAPAN, LTD.}
set vendor(00e0c2) {NECSY S.p.A.}
set vendor(00e0c3) {SAKAI SYSTEM DEVELOPMENT CORP.}
set vendor(00e0c4) {HORNER ELECTRIC, INC.}
set vendor(00e0c5) {BCOM ELECTRONICS INC.}
set vendor(00e0c6) {LINK2IT, L.L.C.}
set vendor(00e0c7) {EUROTECH SRL}
set vendor(00e0c8) {VIRTUAL ACCESS, LTD.}
set vendor(00e0c9) {AutomatedLogic Corporation}
set vendor(00e0ca) {BEST DATA PRODUCTS}
set vendor(00e0cb) {RESON, INC.}
set vendor(00e0cc) {HERO SYSTEMS, LTD.}
set vendor(00e0cd) {SENSIS CORPORATION}
set vendor(00e0ce) {ARN}
set vendor(00e0cf) {INTEGRATED DEVICE TECHNOLOGY, INC.}
set vendor(00e00d) {RADIANT SYSTEMS}
set vendor(00e0d0) {NETSPEED, INC.}
set vendor(00e0d1) {TELSIS LIMITED}
set vendor(00e0d2) {VERSANET COMMUNICATIONS, INC.}
set vendor(00e0d3) {DATENTECHNIK GmbH}
set vendor(00e0d4) {EXCELLENT COMPUTER}
set vendor(00e0d5) {ARCXEL TECHNOLOGIES, INC.}
set vendor(00e0d6) {COMPUTER & COMMUNICATION RESEARCH LAB.}
set vendor(00e0d7) {SUNSHINE ELECTRONICS, INC.}
set vendor(00e0d8) {LANBit Computer, Inc.}
set vendor(00e0d9) {TAZMO CO., LTD.}
set vendor(00e0da) {ASSURED ACCESS TECHNOLOGY, INC.}
set vendor(00e0db) {ViaVideo Communications, Inc.}
set vendor(00e0dc) {NEXWARE CORP.}
set vendor(00e0dd) {ZENITH ELECTRONICS CORPORATION}
set vendor(00e0de) {DATAX NV}
set vendor(00e0df) {KE KOMMUNIKATIONS-ELECTRONIK}
set vendor(00e00e) {AVALON IMAGING SYSTEMS, INC.}
set vendor(00e0e0) {SI ELECTRONICS, LTD.}
set vendor(00e0e1) {G2 NETWORKS, INC.}
set vendor(00e0e2) {INNOVA CORP.}
set vendor(00e0e3) {SK-ELEKTRONIK GmbH}
set vendor(00e0e4) {FANUC ROBOTICS NORTH AMERICA, Inc.}
set vendor(00e0e5) {CINCO NETWORKS, INC.}
set vendor(00e0e6) {INCAA DATACOM B.V.}
set vendor(00e0e7) {RAYTHEON E-SYSTEMS, INC.}
set vendor(00e0e8) {GRETACODER Data Systems AG}
set vendor(00e0e9) {DATA LABS, INC.}
set vendor(00e0ea) {INNOVAT COMMUNICATIONS, INC.}
set vendor(00e0eb) {DIGICOM SYSTEMS, INCORPORATED}
set vendor(00e0ec) {CELESTICA INC.}
set vendor(00e0ed) {SILICOM, LTD.}
set vendor(00e0ee) {MAREL HF}
set vendor(00e0ef) {DIONEX}
set vendor(00e00f) {SHANGHAI BAUD DATA}
set vendor(00e0f0) {ABLER TECHNOLOGY, INC.}
set vendor(00e0f1) {THAT CORPORATION}
set vendor(00e0f2) {ARLOTTO COMNET, INC.}
set vendor(00e0f3) {WebSprint Communications, Inc.}
set vendor(00e0f4) {INSIDE Technology A/S}
set vendor(00e0f5) {TELES AG}
set vendor(00e0f6) {DECISION EUROPE}
set vendor(00e0f7) {CISCO SYSTEMS, INC.}
set vendor(00e0f8) {DICNA CONTROL AB}
set vendor(00e0f9) {CISCO SYSTEMS, INC.}
set vendor(00e0fa) {TRL TECHNOLOGY, LTD.}
set vendor(00e0fb) {LEIGHTRONIX, INC.}
set vendor(00e0fc) {HUAWEI TECHNOLOGIES CO., LTD.}
set vendor(00e0fd) {A-TREND TECHNOLOGY CO., LTD.}
set vendor(00e0fe) {CISCO SYSTEMS, INC.}
set vendor(00e0ff) {SECURITY DYNAMICS TECHNOLOGIES, Inc.}
set vendor(00e6d3) {NIXDORF COMPUTER CORP.}
set vendor(000e01) {ASIP Technologies Inc.}
set vendor(000e11) {BDT Bro- und Datentechnik GmbH & Co. KG}
set vendor(000e12) {Adaptive Micro Systems Inc.}
set vendor(000e13) {Accu-Sort Systems inc.}
set vendor(000e14) {Visionary Solutions, Inc.}
set vendor(000e15) {Tadlys LTD}
set vendor(000e16) {SouthWing}
set vendor(000e18) {MyA Technology}
set vendor(000e19) {LogicaCMG Pty Ltd}
set vendor(000e1b) {IAV GmbH}
set vendor(000e1c) {Hach Company}
set vendor(000e1f) {TCL Networks Equipment Co., Ltd.}
set vendor(000e02) {Advantech AMT Inc.}
set vendor(000e20) {PalmSource, Inc.}
set vendor(000e21) {MTU Friedrichshafen GmbH}
set vendor(000e23) {Incipient, Inc.}
set vendor(000e25) {Hannae Technology Co., Ltd}
set vendor(000e26) {Gincom Technology Corp.}
set vendor(000e27) {Crere Networks, Inc.}
set vendor(000e28) {Dynamic Ratings P/L}
set vendor(000e29) {Shester Communications Inc}
set vendor(000e2b) {Safari Technologies}
set vendor(000e2c) {Netcodec co.}
set vendor(000e2d) {Hyundai Digital Technology Co.,Ltd.}
set vendor(000e2e) {Edimax Technology Co., Ltd.}
set vendor(000e2f) {Disetronic Medical Systems AG}
set vendor(000e03) {Aarohi Communications, Inc.}
set vendor(000e30) {AERAS Networks, Inc.}
set vendor(000e31) {Olympus BioSystems GmbH}
set vendor(000e32) {Kontron Medical}
set vendor(000e33) {Shuko Electronics Co.,Ltd}
set vendor(000e34) {NexxGenCity}
set vendor(000e35) {Intel Corp}
set vendor(000e36) {HEINESYS, Inc.}
set vendor(000e37) {Harms & Wende GmbH & Co.KG}
set vendor(000e38) {Cisco Systems}
set vendor(000e39) {Cisco Systems}
set vendor(000e3a) {Cirrus Logic}
set vendor(000e3b) {Hawking Technologies, Inc.}
set vendor(000e3c) {TransAct Technoloiges Inc.}
set vendor(000e3d) {Televic N.V.}
set vendor(000e3e) {Sun Optronics Inc}
set vendor(000e3f) {Soronti, Inc.}
set vendor(000e40) {Nortel Networks}
set vendor(000e41) {NIHON MECHATRONICS CO.,LTD.}
set vendor(000e42) {Motic Incoporation Ltd.}
set vendor(000e43) {G-Tek Electronics Sdn. Bhd.}
set vendor(000e44) {Digital 5, Inc.}
set vendor(000e45) {Beijing Newtry Electronic Technology Ltd}
set vendor(000e46) {Niigata Seimitsu Co.,Ltd.}
set vendor(000e47) {NCI System Co.,Ltd.}
set vendor(000e48) {Lipman TransAction Solutions}
set vendor(000e49) {Forsway Scandinavia AB}
set vendor(000e4a) {Changchun Huayu WEBPAD Co.,LTD}
set vendor(000e4b) {atrium c and i}
set vendor(000e4c) {Bermai Inc.}
set vendor(000e4d) {Numesa Inc.}
set vendor(000e4e) {Waveplus Technology Co., Ltd.}
set vendor(000e4f) {Trajet GmbH}
set vendor(000e05) {WIRELESS MATRIX CORP.}
set vendor(000e50) {Thomson Multi Media}
set vendor(000e51) {tecna elettronica srl}
set vendor(000e52) {Optium Corporation}
set vendor(000e53) {AV TECH CORPORATION}
set vendor(000e54) {AlphaCell Wireless Ltd.}
set vendor(000e55) {AUVITRAN}
set vendor(000e56) {4G Systems GmbH}
set vendor(000e57) {Iworld Networking, Inc.}
set vendor(000e58) {Rincon Networks}
set vendor(000e5a) {TELEFIELD inc.}
set vendor(000e5b) {ParkerVision - Direct2Data}
set vendor(000e5c) {Motorola BCS}
set vendor(000e5d) {Com-X Networks}
set vendor(000e5e) {Beijing Raisecom Science & Technology Development Co.,Ltd}
set vendor(000e5f) {activ-net GmbH & Co. KG}
set vendor(000e06) {Team Simoco Ltd}
set vendor(000e60) {360SUN Digital Broadband Corporation}
set vendor(000e61) {MICROTROL LIMITED}
set vendor(000e62) {Nortel Networks}
set vendor(000e63) {Lemke Diagnostics GmbH}
set vendor(000e64) {Elphel, Inc}
set vendor(000e65) {TransCore}
set vendor(000e66) {Hitachi Advanced Digital, Inc.}
set vendor(000e67) {Eltis Microelectronics Ltd.}
set vendor(000e68) {E-TOP Network Technology Inc.}
set vendor(000e69) {China Electric Power Research Institute}
set vendor(000e6a) {3COM EUROPE LTD}
set vendor(000e6b) {Janitza electronics GmbH}
set vendor(000e6c) {Device Drivers Limited}
set vendor(000e6d) {Murata Manufacturing Co., Ltd.}
set vendor(000e6e) {MICRELEC  ELECTRONICS S.A}
set vendor(000e6f) {IRIS Corporation Berhad}
set vendor(000e07) {Sony Ericsson Mobile Communications AB}
set vendor(000e70) {in2 Networks}
set vendor(000e71) {Gemstar Technology Development Ltd.}
set vendor(000e72) {CTS electronics}
set vendor(000e73) {Tpack A/S}
set vendor(000e74) {Solar Telecom. Tech}
set vendor(000e75) {New York Air Brake Corp.}
set vendor(000e76) {GEMSOC INNOVISION INC.}
set vendor(000e77) {Decru, Inc.}
set vendor(000e78) {Amtelco}
set vendor(000e79) {Ample Communications Inc.}
set vendor(000e7b) {Toshiba}
set vendor(000e7d) {Electronics Line 3000 Ltd.}
set vendor(000e7e) {Comprog Oy}
set vendor(000e7f) {Hewlett Packard}
set vendor(000e08) {Sipura Technology, Inc.}
set vendor(000e81) {Instant802 Networks Inc.}
set vendor(000e82) {Commtech Wireless}
set vendor(000e83) {Cisco Systems}
set vendor(000e84) {Cisco Systems}
set vendor(000e85) {Catalyst Enterprises, Inc.}
set vendor(000e86) {Alcatel North America}
set vendor(000e87) {adp Gauselmann GmbH}
set vendor(000e88) {VIDEOTRON CORP.}
set vendor(000e89) {CLEMATIC}
set vendor(000e8a) {Avara Technologies Pty. Ltd.}
set vendor(000e8b) {Astarte Technology Co, Ltd.}
set vendor(000e8c) {Siemens AG A&D ET}
set vendor(000e8d) {Systems in Progress Holding GmbH}
set vendor(000e8e) {SparkLAN Communications, Inc.}
set vendor(000e8f) {Sercomm Corp.}
set vendor(000e09) {Shenzhen Coship Software Co.,LTD.}
set vendor(000e90) {PONICO CORP.}
set vendor(000e92) {Millinet Co., Ltd.}
set vendor(000e93) {Milnio 3 Sistemas Electrnicos, Lda.}
set vendor(000e94) {Maas International BV}
set vendor(000e95) {Fujiya Denki Seisakusho Co.,Ltd.}
set vendor(000e96) {Cubic Defense Applications, Inc.}
set vendor(000e97) {Ultracker Technology CO., Inc}
set vendor(000e98) {Vitec CC, INC.}
set vendor(000e99) {Spectrum Digital, Inc}
set vendor(000e9a) {BOE TECHNOLOGY GROUP CO.,LTD}
set vendor(000e9c) {Pemstar}
set vendor(000e9d) {Video Networks Ltd}
set vendor(000e9e) {Topfield Co., Ltd}
set vendor(000e9f) {TEMIC SDS GmbH}
set vendor(000ea0) {NetKlass Technology Inc.}
set vendor(000ea1) {Formosa Teletek Corporation}
set vendor(000ea2) {CyberGuard Corporation}
set vendor(000ea3) {CNCR-IT CO.,LTD,HangZhou P.R.CHINA}
set vendor(000ea4) {Certance Inc.}
set vendor(000ea5) {BLIP Systems}
set vendor(000ea6) {ASUSTEK COMPUTER INC.}
set vendor(000ea7) {Endace Inc Ltd.}
set vendor(000ea8) {United Technologists Europe Limited}
set vendor(000ea9) {Shanghai Xun Shi Communications Equipment Ltd. Co.}
set vendor(000eac) {MINTRON ENTERPRISE CO., LTD.}
set vendor(000ead) {Metanoia Technologies, Inc.}
set vendor(000eae) {GAWELL TECHNOLOGIES CORP.}
set vendor(000eaf) {CASTEL}
set vendor(000e0b) {Netac Technology Co., Ltd.}
set vendor(000eb0) {Solutions Radio BV}
set vendor(000eb1) {Newcotech,Ltd}
set vendor(000eb2) {Micro-Research Finland Oy}
set vendor(000eb3) {LeftHand Networks}
set vendor(000eb4) {GUANGZHOU GAOKE COMMUNICATIONS TECHNOLOGY CO.LTD.}
set vendor(000eb5) {Ecastle Electronics Co., Ltd.}
set vendor(000eb6) {Riverbed Technology, Inc.}
set vendor(000eb7) {Knovative, Inc.}
set vendor(000eb8) {Iiga co.,Ltd}
set vendor(000eb9) {HASHIMOTO Electronics Industry Co.,Ltd.}
set vendor(000eba) {HANMI SEMICONDUCTOR CO., LTD.}
set vendor(000ebb) {Everbee Networks}
set vendor(000ebc) {Cullmann GmbH}
set vendor(000ebd) {Burdick, a Quinton Compny}
set vendor(000ebe) {B&B Electronics Manufacturing Co.}
set vendor(000e0c) {Intel Corporation}
set vendor(000ec0) {Nortel Networks}
set vendor(000ec1) {MYNAH Technologies}
set vendor(000ec2) {Lowrance Electronics, Inc.}
set vendor(000ec3) {Logic Controls, Inc.}
set vendor(000ec4) {Iskra Transmission d.d.}
set vendor(000ec6) {ASIX ELECTRONICS CORP.}
set vendor(000ec7) {Appeal Telecom Co.,Ltd.}
set vendor(000ec8) {Zoran Corporation}
set vendor(000ec9) {YOKO Technology Corp.}
set vendor(000ecb) {VineSys Technology}
set vendor(000ecc) {Tableau}
set vendor(000ecd) {SKOV A/S}
set vendor(000ece) {S.I.T.T.I. S.p.A.}
set vendor(000ecf) {PROFIBUS Nutzerorganisation e.V.}
set vendor(000e0d) {HESCH Schrder GmbH}
set vendor(000ed0) {Privaris, Inc.}
set vendor(000ed1) {Osaka Micro Computer.}
set vendor(000ed2) {Filtronic plc}
set vendor(000ed3) {Epicenter, Inc.}
set vendor(000ed4) {CRESITT INDUSTRIE}
set vendor(000ed5) {COPAN Systems Inc.}
set vendor(000ed6) {Cisco Systems}
set vendor(000ed7) {Cisco Systems}
set vendor(000ed8) {Aktino, Inc.}
set vendor(000ed9) {Aksys, Ltd.}
set vendor(000eda) {C-TECH UNITED CORP.}
set vendor(000edb) {XiNCOM Corp.}
set vendor(000edc) {Tellion INC.}
set vendor(000edd) {SHURE INCORPORATED}
set vendor(000ede) {REMEC, Inc.}
set vendor(000edf) {PLX Technology}
set vendor(000e0e) {ESA elettronica S.P.A.}
set vendor(000ee0) {Mcharge}
set vendor(000ee1) {ExtremeSpeed Inc.}
set vendor(000ee2) {Custom Engineering S.p.A.}
set vendor(000ee3) {Chiyu Technology Co.,Ltd}
set vendor(000ee5) {bitWallet, Inc.}
set vendor(000ee6) {Adimos Systems LTD}
set vendor(000ee7) {AAC ELECTRONICS CORP.}
set vendor(000ee8) {zioncom}
set vendor(000ee9) {WayTech Development, Inc.}
set vendor(000eea) {Shadong Luneng Jicheng Electronics,Co.,Ltd}
set vendor(000eeb) {Sandmartin(zhong shan)Electronics Co.,Ltd}
set vendor(000eec) {Orban}
set vendor(000eed) {Nokia Danmark A/S}
set vendor(000eee) {Muco Industrie BV}
set vendor(000e0f) {ERMME}
set vendor(000ef0) {Festo AG & Co. KG}
set vendor(000ef1) {EZQUEST INC.}
set vendor(000ef2) {World Axle Corporation}
set vendor(000ef3) {Smarthome}
set vendor(000ef4) {Shenzhen Kasda Digital Technology Co.,Ltd}
set vendor(000ef5) {iPAC Technology Co., Ltd.}
set vendor(000ef6) {E-TEN Information Systems Co., Ltd.}
set vendor(000ef7) {Vulcan Portals Inc}
set vendor(000ef8) {SBC ASI}
set vendor(000ef9) {REA Elektronik GmbH}
set vendor(000efa) {Optoway Technology Incorporation}
set vendor(000efb) {Macey Enterprises}
set vendor(000efc) {JTAG Technologies B.V.}
set vendor(000efd) {FUJI PHOTO OPTICAL CO., LTD.}
set vendor(000efe) {EndRun Technologies LLC}
set vendor(000eff) {Megasolution,Inc.}
set vendor(000f00) {Legra Systems, Inc.}
set vendor(000f01) {DIGITALKS INC}
set vendor(000f10) {RDM Corporation}
set vendor(000f11) {Prodrive B.V.}
set vendor(000f12) {Panasonic AVC Networks Germany GmbH}
set vendor(000f13) {Nisca corporation}
set vendor(000f14) {Mindray Co., Ltd.}
set vendor(000f15) {Kjaerulff1 A/S}
set vendor(000f16) {JAY HOW TECHNOLOGY CO.,}
set vendor(000f17) {Insta Elektro GmbH}
set vendor(000f18) {Industrial Control Systems}
set vendor(000f19) {Guidant Corporation}
set vendor(000f1a) {Gaming Support B.V.}
set vendor(000f1b) {Ego Systems Inc.}
set vendor(000f1c) {DigitAll World Co., Ltd}
set vendor(000f1d) {Cosmo Techs Co., Ltd.}
set vendor(000f1e) {Chengdu KT Electric Co.of High & New Technology}
set vendor(000f1f) {WW PCBA Test}
set vendor(000f02) {Digicube Technology Co., Ltd}
set vendor(000f20) {WW Ops}
set vendor(000f21) {Scientific Atlanta, Inc}
set vendor(000f22) {Helius, Inc.}
set vendor(000f23) {Cisco Systems}
set vendor(000f24) {Cisco Systems}
set vendor(000f25) {AimValley B.V.}
set vendor(000f26) {WorldAccxx  LLC}
set vendor(000f27) {TEAL Electronics, Inc.}
set vendor(000f28) {Itronix Corporation}
set vendor(000f29) {Augmentix Corporation}
set vendor(000f2a) {Cableware Electronics}
set vendor(000f2b) {GREENBELL SYSTEMS}
set vendor(000f2c) {Uplogix, Inc.}
set vendor(000f2d) {CHUNG-HSIN ELECTRIC & MACHINERY MFG.CORP.}
set vendor(000f2e) {Megapower International Corp.}
set vendor(000f2f) {W-LINX TECHNOLOGY CO., LTD.}
set vendor(000f03) {COM&C CO., LTD}
set vendor(000f30) {Raza Microelectronics Inc}
set vendor(000f31) {Prosilica}
set vendor(000f32) {LuTong Electronic Technology Co.,Ltd}
set vendor(000f33) {DUALi Inc.}
set vendor(000f34) {Cisco Systems}
set vendor(000f35) {Cisco Systems}
set vendor(000f36) {Accurate Techhnologies, Inc.}
set vendor(000f37) {Xambala Incorporated}
set vendor(000f38) {Netstar}
set vendor(000f39) {IRIS SENSORS}
set vendor(000f3a) {HISHARP}
set vendor(000f3b) {Fuji System Machines Co., Ltd.}
set vendor(000f3c) {Endeleo Limited}
set vendor(000f3d) {D-Link Corporation}
set vendor(000f3e) {CardioNet, Inc}
set vendor(000f3f) {Big Bear Networks}
set vendor(000f04) {cim-usa inc}
set vendor(000f40) {Optical Internetworking Forum}
set vendor(000f41) {Zipher Ltd}
set vendor(000f42) {Xalyo Systems}
set vendor(000f43) {Wasabi Systems Inc.}
set vendor(000f44) {Tivella Inc.}
set vendor(000f45) {Stretch, Inc.}
set vendor(000f46) {SINAR AG}
set vendor(000f47) {ROBOX SPA}
set vendor(000f48) {Polypix Inc.}
set vendor(000f49) {Northover Solutions Limited}
set vendor(000f4a) {Kyushu-kyohan co.,ltd}
set vendor(000f4b) {Katana Technology}
set vendor(000f4c) {Elextech INC}
set vendor(000f4d) {Centrepoint Technologies Inc.}
set vendor(000f4e) {Cellink}
set vendor(000f4f) {Cadmus Technology Ltd}
set vendor(000f05) {3B SYSTEM INC.}
set vendor(000f50) {BraddaHead Limited}
set vendor(000f06) {Nortel Networks}
set vendor(000f07) {Mangrove Systems, Inc.}
set vendor(000f08) {Indagon Oy}
set vendor(000f0b) {Kentima Technologies AB}
set vendor(000f0c) {SYNCHRONIC ENGINEERING}
set vendor(000f0d) {Hunt Electronic Co., Ltd.}
set vendor(000f0e) {WaveSplitter Technologies, Inc.}
set vendor(000f0f) {Real ID Technology Co., Ltd.}
set vendor(10005a) {IBM CORPORATION}
set vendor(100090) {Hewlett-Packard			Advisor products}
set vendor(1000d4) {DEC}
set vendor(1000e0) {Apple A/UX			(modified addresses for licensing)}
set vendor(1000e8) {NATIONAL SEMICONDUCTOR}
set vendor(021c7c) {PERQ SYSTEMS CORPORATION}
set vendor(020406) {BBN				internal usage (not registered)}
set vendor(026060) {3Com}
set vendor(026086) {LOGIC REPLACEMENT TECH. LTD.}
set vendor(02608c) {3COM CORPORATION}
set vendor(027001) {RACAL-DATACOM}
set vendor(0270b0) {M/A-COM INC. COMPANIES}
set vendor(0270b3) {DATA RECALL LTD}
set vendor(020701) {RACAL-DATACOM}
set vendor(029d8e) {CARDIAC RECORDERS INC.}
set vendor(02a0c9) {Intel}
set vendor(02aa3c) {OLIVETTI TELECOMM SPA (OLTECO)}
set vendor(02bb01) {OCTOTHORPE CORP.}
set vendor(02c08c) {3COM CORPORATION}
set vendor(02cf1c) {COMMUNICATION MACHINERY CORP.}
set vendor(02cf1f) {CMC				Masscomp; Silicon Graphics; Prime EXL}
set vendor(02e03b) {Prominet Corporation		Gigabit Ethernet Switch}
set vendor(02e6d3) {NIXDORF COMPUTER CORPORATION}
set vendor(2e2e2e) {LAA (Locally Administered Address) for Meditech Systems}
set vendor(3c0000) {3Com				dual function (V.34 modem + Ethernet) card}
set vendor(400003) {Net Ware (?)}
set vendor(444553) {Microsoft			(Windows95 internal "adapters")}
set vendor(444649) {DFI (Diamond Flower Industries)}
set vendor(475443) {GTC (Not registered!)		(This number is a multicast!)}
set vendor(484453) {HDS ???}
set vendor(484c00) {Network Solutions}
set vendor(4854e8) {winbond?}
set vendor(048845) {Bay Networks			token ring line card}
set vendor(040ae0) {XMIT AG COMPUTER NETWORKS}
set vendor(04e0c4) {TRIUMPH-ADLER AG}
set vendor(4c424c) {Information Modes software modified addresses (not registered?)}
set vendor(525400) {Realtek (UpTech? also reported)}
set vendor(52544c) {Novell 2000}
set vendor(5254ab) {REALTEK (a Realtek 8029 based PCI Card)}
set vendor(565857) {Aculab plc			audio bridges}
set vendor(800010) {ATT BELL LABORATORIES}
set vendor(80ad00) {CNET Technology Inc. (Probably an error, see instead 0080AD)}
set vendor(080001) {COMPUTERVISION CORPORATION}
set vendor(080010) {AT&T [misrepresentation of 800010?]}
set vendor(080011) {TEKTRONIX INC.}
set vendor(080012) {BELL ATLANTIC INTEGRATED SYST.}
set vendor(080013) {EXXON}
set vendor(080014) {EXCELAN}
set vendor(080015) {STC BUSINESS SYSTEMS}
set vendor(080016) {BARRISTER INFO SYS CORP}
set vendor(080017) {NATIONAL SEMICONDUCTOR}
set vendor(080018) {PIRELLI FOCOM NETWORKS}
set vendor(080019) {GENERAL ELECTRIC CORPORATION}
set vendor(08001a) {TIARA/ 10NET}
set vendor(08001b) {DATA GENERAL}
set vendor(08001c) {KDD-KOKUSAI DEBNSIN DENWA CO.}
set vendor(08001d) {ABLE COMMUNICATIONS INC.}
set vendor(08001e) {APOLLO COMPUTER INC.}
set vendor(08001f) {SHARP CORPORATION}
set vendor(080002) {BRIDGE COMMUNICATIONS INC.}
set vendor(080020) {SUN MICROSYSTEMS INC.}
set vendor(080021) {3M COMPANY}
set vendor(080022) {NBI INC.}
set vendor(080023) {Panasonic Communications Co., Ltd.}
set vendor(080024) {10NET COMMUNICATIONS/DCA}
set vendor(080025) {CONTROL DATA}
set vendor(080026) {NORSK DATA A.S.}
set vendor(080027) {CADMUS COMPUTER SYSTEMS}
set vendor(080028) {Texas Instruments}
set vendor(080029) {MEGATEK CORPORATION}
set vendor(08002a) {MOSAIC TECHNOLOGIES INC.}
set vendor(08002b) {DIGITAL EQUIPMENT CORPORATION}
set vendor(08002c) {BRITTON LEE INC.}
set vendor(08002d) {LAN-TEC INC.}
set vendor(08002e) {METAPHOR COMPUTER SYSTEMS}
set vendor(08002f) {PRIME COMPUTER INC.}
set vendor(080003) {ADVANCED COMPUTER COMM.}
set vendor(080030) {CERN *also* NETWORK RESEARCH CORPORATION *also* ROYAL MELBOURNE INST OF TECH}
set vendor(080031) {LITTLE MACHINES INC.}
set vendor(080032) {TIGAN INCORPORATED}
set vendor(080033) {BAUSCH & LOMB}
set vendor(080034) {FILENET CORPORATION}
set vendor(080035) {MICROFIVE CORPORATION}
set vendor(080036) {INTERGRAPH CORPORATION}
set vendor(080037) {FUJI-XEROX CO. LTD.}
set vendor(080038) {CII HONEYWELL BULL}
set vendor(080039) {SPIDER SYSTEMS LIMITED}
set vendor(08003a) {ORCATECH INC.}
set vendor(08003b) {TORUS SYSTEMS LIMITED}
set vendor(08003c) {SCHLUMBERGER WELL SERVICES}
set vendor(08003d) {CADNETIX CORPORATIONS}
set vendor(08003e) {CODEX CORPORATION}
set vendor(08003f) {FRED KOSCHARA ENTERPRISES}
set vendor(080004) {CROMEMCO INCORPORATED}
set vendor(080040) {FERRANTI COMPUTER SYS. LIMITED}
set vendor(080041) {RACAL-MILGO INFORMATION SYS..}
set vendor(080042) {JAPAN MACNICS CORP.}
set vendor(080043) {PIXEL COMPUTER INC.}
set vendor(080044) {DAVID SYSTEMS INC.}
set vendor(080045) {CONCURRENT COMPUTER CORP.}
set vendor(080046) {SONY CORPORATION LTD.}
set vendor(080047) {SEQUENT COMPUTER SYSTEMS INC.}
set vendor(080048) {EUROTHERM GAUGING SYSTEMS}
set vendor(080049) {UNIVATION}
set vendor(08004a) {BANYAN SYSTEMS INC.}
set vendor(08004b) {PLANNING RESEARCH CORP.}
set vendor(08004c) {HYDRA COMPUTER SYSTEMS INC.}
set vendor(08004d) {CORVUS SYSTEMS INC.}
set vendor(08004e) {3COM EUROPE LTD.}
set vendor(08004f) {CYGNET SYSTEMS}
set vendor(080005) {SYMBOLICS INC.}
set vendor(080050) {DAISY SYSTEMS CORP.}
set vendor(080051) {EXPERDATA}
set vendor(080052) {INSYSTEC}
set vendor(080053) {MIDDLE EAST TECH. UNIVERSITY}
set vendor(080055) {STANFORD TELECOMM. INC.}
set vendor(080056) {STANFORD LINEAR ACCEL. CENTER}
set vendor(080057) {EVANS & SUTHERLAND}
set vendor(080058) {SYSTEMS CONCEPTS}
set vendor(080059) {A/S MYCRON}
set vendor(08005a) {IBM CORPORATION}
set vendor(08005b) {VTA TECHNOLOGIES INC.}
set vendor(08005c) {FOUR PHASE SYSTEMS}
set vendor(08005d) {GOULD INC.}
set vendor(08005e) {COUNTERPOINT COMPUTER INC.}
set vendor(08005f) {SABER TECHNOLOGY CORP.}
set vendor(080006) {SIEMENS AG}
set vendor(080060) {INDUSTRIAL NETWORKING INC.}
set vendor(080061) {JAROGATE LTD.}
set vendor(080062) {GENERAL DYNAMICS}
set vendor(080063) {PLESSEY}
set vendor(080064) {AUTOPHON AG}
set vendor(080065) {GENRAD INC.}
set vendor(080066) {AGFA CORPORATION}
set vendor(080067) {COMDESIGN}
set vendor(080068) {RIDGE COMPUTERS}
set vendor(080069) {SILICON GRAPHICS INC.}
set vendor(08006a) {ATT BELL LABORATORIES}
set vendor(08006b) {ACCEL TECHNOLOGIES INC.}
set vendor(08006c) {SUNTEK TECHNOLOGY INT'L}
set vendor(08006d) {WHITECHAPEL COMPUTER WORKS}
set vendor(08006e) {MASSCOMP}
set vendor(08006f) {PHILIPS APELDOORN B.V.}
set vendor(080007) {APPLE COMPUTER INC.}
set vendor(080070) {MITSUBISHI ELECTRIC CORP.}
set vendor(080071) {MATRA (DSIE)}
set vendor(080072) {XEROX CORP UNIV GRANT PROGRAM}
set vendor(080073) {TECMAR INC.}
set vendor(080074) {CASIO COMPUTER CO. LTD.}
set vendor(080075) {DANSK DATA ELECTRONIK}
set vendor(080076) {PC LAN TECHNOLOGIES}
set vendor(080077) {TSL COMMUNICATIONS LTD.}
set vendor(080078) {ACCELL CORPORATION}
set vendor(080079) {THE DROID WORKS}
set vendor(08007a) {INDATA}
set vendor(08007b) {SANYO ELECTRIC CO. LTD.}
set vendor(08007c) {VITALINK COMMUNICATIONS CORP.}
set vendor(08007e) {AMALGAMATED WIRELESS(AUS) LTD}
set vendor(08007f) {CARNEGIE-MELLON UNIVERSITY}
set vendor(080008) {BOLT BERANEK AND NEWMAN INC.}
set vendor(080080) {AES DATA INC.}
set vendor(080081) {,ASTECH INC.}
set vendor(080082) {VERITAS SOFTWARE}
set vendor(080083) {Seiko Instruments Inc.}
set vendor(080084) {TOMEN ELECTRONICS CORP.}
set vendor(080085) {ELXSI}
set vendor(080086) {KONICA MINOLTA HOLDINGS, INC.}
set vendor(080087) {XYPLEX}
set vendor(080088) {MCDATA CORPORATION}
set vendor(080089) {KINETICS}
set vendor(08008a) {PERFORMANCE TECHNOLOGY}
set vendor(08008b) {PYRAMID TECHNOLOGY CORP.}
set vendor(08008c) {NETWORK RESEARCH CORPORATION}
set vendor(08008d) {XYVISION INC.}
set vendor(08008e) {TANDEM COMPUTERS}
set vendor(08008f) {CHIPCOM CORPORATION}
set vendor(080009) {HEWLETT PACKARD}
set vendor(080090) {SONOMA SYSTEMS}
set vendor(08000a) {NESTAR SYSTEMS INCORPORATED}
set vendor(08000b) {UNISYS CORPORATION}
set vendor(08000c) {MIKLYN DEVELOPMENT CO.}
set vendor(08000d) {INTERNATIONAL COMPUTERS LTD.}
set vendor(08000e) {NCR CORPORATION}
set vendor(08000f) {MITEL CORPORATION}
set vendor(081443) {UNIBRAIN S.A.}
set vendor(08bbcc) {AK-NORD EDV VERTRIEBSGES. mbH}
set vendor(09006a) {AT&T}
set vendor(a06a00) {Verilink Corporation}
set vendor(aa0000) {DIGITAL EQUIPMENT CORPORATION}
set vendor(aa0001) {DIGITAL EQUIPMENT CORPORATION}
set vendor(aa0002) {DIGITAL EQUIPMENT CORPORATION}
set vendor(aa0003) {DIGITAL EQUIPMENT CORPORATION}
set vendor(aa0004) {DIGITAL EQUIPMENT CORPORATION}
set vendor(c00000) {Western Digital (may be reversed 00 00 C0?)}
set vendor(e20c0f) {Kingston Technologies}
set vendor(ec1000) {Enance Source Co., Ltd.	PC clones(?)}

}